@@ -9,18 +9,21 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: index.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: index.php 22776 2006-10-31 07:56:34Z ralfbecker $ */
 
-	$GLOBALS['egw_info'] = array();
-	$GLOBALS['egw_info']['flags'] = array(
-		'currentapp' => 'addressbook',
-		'noheader'   => True,
-		'nonavbar'   => True
-	);
+	$GLOBALS['egw_info'] = array(
+		'flags' => array(
+			'currentapp' => 'addressbook',
+			'noheader'   => True,
+			'nonavbar'   => True
+	));
 	include('../header.inc.php');
 
-	$obj = CreateObject('addressbook.uiaddressbook');
-	$obj->index();
-
-	$GLOBALS['phpgw']->common->phpgw_footer();
-?>
+	// check if we have an advanced search and reset it in case
+	$old_state = $GLOBALS['egw']->session->appsession('index','addressbook');
+	if ($old_state['advanced_search'])
+	{
+		unset($old_state['advanced_search']);
+		$GLOBALS['egw']->session->appsession('index','addressbook',$old_state);
+	}
+	$GLOBALS['egw']->redirect_link('/index.php','menuaction=addressbook.uicontacts.index');
