@@ -9,7 +9,7 @@
 	*  Free Software Foundation; either version 2 of the License, or (at your  *
 	*  option) any later version.                                              *
 	\**************************************************************************/
-	/* $Id: class.bocategories.inc.php 20531 2006-03-10 09:59:18Z ralfbecker $ */
+	/* $Id: class.bocategories.inc.php 24717 2007-11-27 17:23:40Z pbf $ */
 	/* $Source$ */
 
 	class bocategories
@@ -124,7 +124,7 @@
 
 		function formatted_list($data)
 		{
-			return $this->cats->formated_list($data['select'],$data['all'],$data['cat_parent'],True);
+			return $this->cats->formatted_list($data['select'],$data['all'],$data['cat_parent'],True);
 		}
 
 		function delete($cat_id,$subs=False)
