@@ -10,7 +10,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.uiconfig.inc.php 20976 2006-04-06 10:51:04Z ralfbecker $ */
+	/* $Id: class.uiconfig.inc.php 23149 2006-12-29 07:08:47Z ralfbecker $ */
 
 	class uiconfig
 	{
@@ -24,7 +24,16 @@
 			}
 			$referer = $_POST['submit'] || $_POST['cancel'] ? $_POST['referer'] : $_SERVER['HTTP_REFERER'];
 			if (!$referer) $referer = $GLOBALS['egw']->link('/admin/index.php');
-			list(,$show_app) = explode($GLOBALS['egw_info']['server']['webserver_url'],$referer);
+			if ($GLOBALS['egw_info']['server']['webserver_url'])
+			{
+				list(,$show_app) = explode($GLOBALS['egw_info']['server']['webserver_url'],$referer);
+			}
+			else
+			{
+				$parts = parse_url($referer);
+				$show_app = $parts['path'];
+				unset($parts);
+			}
 			list(,$show_app) = explode('/',$show_app);
 			if (!$show_app) $show_app = 'admin';
 
@@ -36,7 +45,7 @@
 
 			if(get_magic_quotes_gpc() && is_array($_POST['newsettings']))
 			{
-				$_POST['newsettings'] = array_map("stripslashes", $_POST['newsettings']);
+				$_POST['newsettings'] = $this->array_stripslashes($_POST['newsettings']);
 			}
 			
 			switch($_GET['appname'])
@@ -241,5 +250,24 @@
 			$t->set_var('lang_cancel', lang('Cancel'));
 			$t->pfp('out','footer');
 		}
+
+		/**
+		 * applies stripslashes recursivly on each element of an array
+		 * 
+		 * @param array &$var 
+		 * @return array
+		 */
+		function array_stripslashes($var)
+		{
+			if (!is_array($var))
+			{
+				return stripslashes($var);
+			}
+			foreach($var as $key => $val)
+			{
+				$var[$key] = is_array($val) ? $this->array_stripslashes($val) : stripslashes($val);
+			}
+			return $var;
+		}
 	}
 ?>
