@@ -9,10 +9,10 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: setup.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: setup.inc.php 23741 2007-04-30 10:29:44Z lkneschke $ */
 
 	$setup_info['admin']['name']      = 'admin';
-	$setup_info['admin']['version']   = '1.2';
+	$setup_info['admin']['version']   = '1.4';
 	$setup_info['admin']['app_order'] = 1;
 	$setup_info['admin']['tables']    = '';
 	$setup_info['admin']['enable']    = 1;
@@ -42,12 +42,17 @@
 		'view_user' => 'admin.uiaccounts.edit_view_user_hook',
 		'edit_user' => 'admin.uiaccounts.edit_view_user_hook',
 		'group_manager' => 'admin.uiaccounts.edit_group_hook',
-		'sidebox_menu'
+		'sidebox_menu',
+		'topmenu_info'
 	);
 
 	/* Dependencies for this app to work */
 	$setup_info['admin']['depends'][] = array(
 		'appname' => 'phpgwapi',
-		'versions' => Array('1.0.0','1.0.1','1.2')
+		'versions' => Array('1.3','1.4','1.5')
+	);
+	$setup_info['admin']['depends'][] = array(
+		'appname' => 'etemplate',
+		'versions' => Array('1.3','1.4','1.5')
 	);
 ?>
