@@ -1,16 +1,14 @@
 <?php
-/**************************************************************************\
-* eGroupWare - Calendar's buisness-object - access only                    *
-* http://www.egroupware.org                                                *
-* Written and (c) 2004/5 by Ralf Becker <RalfBecker@outdoor-training.de>   *
-* --------------------------------------------                             *
-*  This program is free software; you can redistribute it and/or modify it *
-*  under the terms of the GNU General Public License as published by the   *
-*  Free Software Foundation; either version 2 of the License, or (at your  *
-*  option) any later version.                                              *
-\**************************************************************************/
-
-/* $Id: class.bocal.inc.php 23152 2006-12-29 08:47:28Z ralfbecker $ */
+/**
+ * eGroupWare - Calendar's buisness-object - access only
+ *
+ * @link http://www.egroupware.org
+ * @package calendar
+ * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2004-7 by RalfBecker-At-outdoor-training.de
+ * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+ * @version $Id: class.bocal.inc.php 24849 2007-12-20 19:54:15Z ralfbecker $ 
+ */
 
 require_once(EGW_INCLUDE_ROOT.'/calendar/inc/class.socal.inc.php');
 
@@ -23,6 +21,12 @@ define('HOUR_s',60*60);
 define('DAY_s',24*HOUR_s);
 define('WEEK_s',7*DAY_s);
 
+/**
+ * Gives read access to the calendar, but all events the user is not participating are private!
+ * Used be the addressbook.
+ */
+define('EGW_ACL_READ_FOR_PARTICIPANTS',EGW_ACL_CUSTOM_1);
+
 /**
  * Class to access all calendar data
  *
@@ -40,11 +44,6 @@ define('WEEK_s',7*DAY_s);
  * Nor does it store the state of any UI-elements (eg. cat-id selectbox). All this is the task of the UI class(es) !!!
  *
  * All permanent debug messages of the calendar-code should done via the debug-message method of this class !!!
- *
- * @package calendar
- * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
- * @copyright (c) 2004/5 by RalfBecker-At-outdoor-training.de
- * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  */
 
 class bocal
@@ -123,7 +122,6 @@ class bocal
 		MCAL_M_SATURDAY  => 'Saturday',
 		MCAL_M_SUNDAY    => 'Sunday',
 	);
-	var $so,$datetime;
 	/**
 	 * @var array $resources registered scheduling resources of the calendar (gets chached in the session for performance reasons)
 	 */
@@ -138,6 +136,18 @@ class bocal
 	 * @var array $cached_holidays holidays plus birthdays (gets cached in the session for performance reasons)
 	 */
 	var $cached_holidays;
+	/**
+	 * Instance of the socal class
+	 *
+	 * @var socal
+	 */
+	var $so;
+	/**
+	 * Instance of the datetime class
+	 *
+	 * @var egw_datetime
+	 */
+	var $datetime;
 
 	/**
 	 * Constructor
@@ -162,7 +172,6 @@ class bocal
 		}
 		$this->common_prefs =& $GLOBALS['egw_info']['user']['preferences']['common'];
 		$this->cal_prefs =& $GLOBALS['egw_info']['user']['preferences']['calendar'];
-		$this->check_set_default_prefs();
 
 		$this->tz_offset_s = $this->datetime->tz_offset;
 
@@ -232,7 +241,7 @@ class bocal
 	 *	users  mixed integer user-id or array of user-id's to use, defaults to the current user
 	 *	cat_id mixed category-id or array of cat-id's, defaults to all if unset, 0 or False
 	 *		Please note: only a single cat-id, will include all sub-cats (if the common-pref 'cats_no_subs' is False)
-	 *	filter string space delimited filter-names, atm. 'all' or 'private'
+	 *	filter string filter-name, atm. 'all' or 'hideprivate'
 	 *	query string pattern so search for, if unset or empty all matching entries are returned (no search)
 	 *		Please Note: a search never returns repeating events more then once AND does not honor start+end date !!!
 	 *	dayswise boolean on True it returns an array with YYYYMMDD strings as keys and an array with events
@@ -254,22 +263,23 @@ class bocal
 	{
 		$params_in = $params;
 
-		if (!isset($params['users']) || !$params['users'])
+		if (!isset($params['users']) || !$params['users'] || 
+			count($params['users']) == 1 && isset($params['users'][0]) && !$params['users'][0])	// null or '' casted to an array
 		{
 			// for a search use all account you have read grants from
 			$params['users'] = $params['query'] ? array_keys($this->grants) : $this->user;
 		}
 		if (!is_array($params['users']))
 		{
-			$params['users'] = array($params['users']);
+			$params['users'] = $params['users'] ? array($params['users']) : array();
 		}
 		// only query calendars of users, we have READ-grants from
 		$users = array();
 		foreach($params['users'] as $user)
 		{
-			if ($params['ignore_acl'] || $this->check_perms(EGW_ACL_READ,0,$user))
+			if ($params['ignore_acl'] || $this->check_perms(EGW_ACL_READ|EGW_ACL_READ_FOR_PARTICIPANTS,0,$user))
 			{
-				if (!in_array($user,$users))	// already added?
+				if ($user && !in_array($user,$users))	// already added?
 				{
 					$users[] = $user;
 				}
@@ -352,15 +362,25 @@ class bocal
 			if ($remove_rejected_by_user && $event['participants'][$remove_rejected_by_user] == 'R')
 			{
 				unset($events[$id]);	// remove the rejected event
+				$this->total--;
 				continue;
 			}
 			if ($params['enum_groups'] && $this->enum_groups($event))
 			{
 				$events[$id] = $event;
 			}
-			if (!$this->check_perms(EGW_ACL_READ,$event))
+			if (!$this->check_perms(EGW_ACL_READ,$event) || (!$event['public'] && $filter == 'hideprivate'))
 			{
-				$this->clear_private_infos($events[$id],$users);
+				if($params['query'])
+				{
+					unset($events[$id]);
+					$this->total--;
+					continue;
+				}
+				else
+				{
+					$this->clear_private_infos($events[$id],$users);
+				}
 			}
 		}
 
@@ -458,7 +478,12 @@ class bocal
 			$this->debug_message('bocal::check_move_horizont(%1) horizont=%2',true,$new_horizont,$this->config['horizont']);
 		}
 		$new_horizont = $this->date2ts($new_horizont,true);	// now we are in server-time, where this function operates
-
+		
+		if ($new_horizont > time()+1000*DAY_s)		// some user tries to "look" more then 1000 days in the future
+		{
+			if ($this->debug == 'check_move_horizont') $this->debug_message('bocal::check_move_horizont(%1) horizont=%2 new horizont more then 1000 days from now --> ignoring it',true,$new_horizont,$this->config['horizont']);
+			return;
+		}
 		if ($new_horizont <= $this->config['horizont'])	// no move necessary
 		{
 			if ($this->debug == 'check_move_horizont') $this->debug_message('bocal::check_move_horizont(%1) horizont=%2 is bigger ==> nothing to do',true,$new_horizont,$this->config['horizont']);
@@ -597,14 +622,14 @@ class bocal
 	{
 		if ($date) $date = $this->date2ts($date);
 
-		if ($ignore_acl || is_array($ids) || ($return = $this->check_perms(EGW_ACL_READ,$ids,0,$date_format)))
+		if ($ignore_acl || is_array($ids) || ($return = $this->check_perms(EGW_ACL_READ,$ids,0,$date_format,$date)))
 		{
 			if (is_array($ids) || !isset($this->cached_event['id']) || $this->cached_event['id'] != $ids || 
 				$this->cached_event_date_format != $date_format ||
-				!is_null($date) && $this->cached_event['start'] < $date && $this->cached_event['recur_type'] != MCAL_RECUR_NONE)
+				$this->cached_event['recur_type'] != MCAL_RECUR_NONE && !is_null($date) && (!$date || $this->cached_event['start'] < $date))
 			{
 				$events = $this->so->read($ids,$date ? $this->date2ts($date,true) : 0);
-				
+
 				if ($events)
 				{
 					$this->db2data($events,$date_format);
@@ -727,7 +752,7 @@ class bocal
 				$this->add_adjusted_event($events,$event,$search_date_ymd);
 				continue;
 			}
-			$freq = $event['recur_interval'];
+			$freq = $event['recur_interval'] ? $event['recur_interval'] : 1;
 			$type = $event['recur_type'];
 			switch($type)
 			{
@@ -750,7 +775,8 @@ class bocal
 					}
 					break;
 				case MCAL_RECUR_WEEKLY:
-					if (floor(($search_beg_day - $event_start_daybegin_ts)/WEEK_s) % $freq)
+					// we use round(,1) to deal with changing daylight saving
+					if (floor(round(($search_beg_day - $event_start_daybegin_ts)/WEEK_s,1)) % $freq)
 					{
 						continue;
 					}
@@ -888,10 +914,11 @@ class bocal
 	 * @param int $needed necessary ACL right: EGW_ACL_{READ|EDIT|DELETE}
 	 * @param mixed $event event as array or the event-id or 0 for a general check
 	 * @param int $other uid to check (if event==0) or 0 to check against $this->user
-	 * @param string $date_format='ts' date-formats: 'ts'=timestamp, 'array'=array, 'string'=iso8601 string for xmlrpc
+	 * @param string $date_format='ts' date-format used for reading: 'ts'=timestamp, 'array'=array, 'string'=iso8601 string for xmlrpc
+	 * @param mixed $date_to_read=null date used for reading, internal param for the caching
 	 * @return boolean true permission granted, false for permission denied or null if event not found
 	 */
-	function check_perms($needed,$event=0,$other=0,$date_format='ts')
+	function check_perms($needed,$event=0,$other=0,$date_format='ts',$date_to_read=null)
 	{
 		$event_in = $event;
 		if ($other && !is_numeric($other))
@@ -908,7 +935,7 @@ class bocal
 		{
 			if (!is_array($event))
 			{
-				$event = $this->read($event,null,True,$date_format);	// = no ACL check !!!
+				$event = $this->read($event,$date_to_read,True,$date_format);	// = no ACL check !!!
 			}
 			if (!is_array($event))
 			{
@@ -931,7 +958,7 @@ class bocal
 			//
 			foreach($event['participants'] as $uid => $accept)
 			{
-				if ($uid == $user || $uid < 0 && in_array($user,$this->accounts_members($uid,true))) 
+				if ($uid == $user || $uid < 0 && in_array($user,$GLOBALS['egw']->accounts->members($uid,true))) 
 				{
 					// if we are a participant, we have an implicite READ and PRIVAT grant
 					$grants |= EGW_ACL_READ | EGW_ACL_PRIVATE;
@@ -966,24 +993,6 @@ class bocal
 		}
 		return $access;
 	}
-	
-	/**
-	 * From the accounts class in trunk: Get all members of the group $account_id
-	 *
-	 * @param int/string $accountid='' numeric account-id or alphanum. account-lid, 
-	 *	default account of the user of this session
-	 * @param boolean $just_id=false return just an array of id's and not id => lid pairs, default false
-	 * @return array with account_id ($just_id) or account_id => account_lid pairs (!$just_id)
-	 */
-	function accounts_members($account_id,$just_id=false)
-	{
-		$members = array();
-		foreach($GLOBALS['egw']->accounts->member($account_id) as $data)
-		{
-			$members[$data['account_id']] = $data['account_lid'];
-		}
-		return $just_id ? array_keys($members) : $members;
-	}
 
 	/**
 	 * Converts several date-types to a timestamp and optionaly converts user- to server-time
@@ -1181,8 +1190,8 @@ class bocal
 		static $acl2string = array(
 			0               => 'ACL-UNKNOWN',
 			EGW_ACL_READ    => 'ACL_READ',
-			EGW_ACL_WRITE   => 'ACL_WRITE',
 			EGW_ACL_ADD     => 'ACL_ADD',
+			EGW_ACL_EDIT    => 'ACL_EDIT',
 			EGW_ACL_DELETE  => 'ACL_DELETE',
 			EGW_ACL_PRIVATE => 'ACL_PRIVATE',
 		);
@@ -1202,7 +1211,7 @@ class bocal
 						if (substr($param,0,strlen(ACL_TYPE_IDENTIFER))== ACL_TYPE_IDENTIFER)
 						{
 							$param = (int) substr($param,strlen(ACL_TYPE_IDENTIFER));
-							$param = isset($acl2string[$param]) ? $acl2string[$param] : $acl2string[0];
+							$param = (isset($acl2string[$param]) ? $acl2string[$param] : $acl2string[0])." ($param)";
 						}
 						else
 						{
@@ -1367,8 +1376,11 @@ class bocal
 		{
 			if (!is_numeric($id))
 			{
-				$res_info = $this->resource_info($id);
-				$id2lid[$id] = $res_info && isset($res_info['name']) ? $res_info['name'] : "resource($id)";
+				if (!is_object($GLOBALS['egw']->link))
+				{
+					$GLOBALS['egw']->link =& CreateObject('phpgwapi.bolink');
+				}
+				$id2lid[$id] = $GLOBALS['egw']->link->title($this->resources[$id{0}]['app'],substr($id,1));
 			}
 			else
 			{
@@ -1382,25 +1394,49 @@ class bocal
 	* Converts participants array of an event into array of (readable) participant-names with status
 	*
 	* @param array $event event-data
-	* @param boolean $long_status=false should the long/verbose status or only the one letter shortcut be used
+	* @param boolean $long_status=false should the long/verbose status or an icon be use
 	* @param boolean $show_group_invitation=false show group-invitations (status == 'G') or not (default)
 	* @return array with id / names with status pairs
 	*/
-	function participants($event,$long_status=False,$show_group_invitation=false)
+	function participants($event,$long_status=false,$show_group_invitation=false)
 	{
- 		//_debug_array($event);
- 		$names = array();
+		//_debug_array($event);
+		$names = array();
 		foreach($event['participants'] as $id => $status)
 		{
 			if ($status == 'G' && !$show_group_invitation) continue;	// dont show group-invitation
 
-			$status = $this->verbose_status[$status];
-
 			if (!$long_status)
 			{
-				$status = substr($status,0,1);
+				if (!is_object($GLOBALS['egw']->html))
+				{
+					$GLOBALS['egw']->html =& CreateObject('phpgwapi.html');
+				}
+				switch($status)
+				{
+					case 'A':	// accepted
+						$status = $GLOBALS['egw']->html->image('calendar','agt_action_success',$this->verbose_status[$status]);
+						break;
+					case 'R':	// rejected
+						$status = $GLOBALS['egw']->html->image('calendar','agt_action_fail',$this->verbose_status[$status]);
+						break;
+					case 'T':	// tentative
+						$status = $GLOBALS['egw']->html->image('calendar','tentative',$this->verbose_status[$status]);
+						break;
+					case 'U':	// no response = unknown
+						$status = $GLOBALS['egw']->html->image('calendar','cnr-pending',$this->verbose_status[$status]);
+						break;
+					case 'G':	// group invitation
+						// Todo: Image, seems not to be used
+						$status = '('.$this->verbose_status[$status].')';
+						break;
+				}
 			}
-			$names[$id] = $this->participant_name($id).' ('.$status.')';
+			else
+			{
+				$status = '('.$this->verbose_status[$status].')';
+			}
+			$names[$id] = $this->participant_name($id).' '.$status;
 		}
 		return $names;
 	}
@@ -1527,7 +1563,7 @@ class bocal
 					$str_extra[] = lang('days repeated').': '.implode(', ',$repeat_days);
 				}
 			}
-			if($event['recur_interval'])
+			if($event['recur_interval'] > 1)
 			{
 				$str_extra[] = lang('Interval').': '.$event['recur_interval'];
 			}
@@ -1655,7 +1691,7 @@ class bocal
 			'query' => 'calendar.bocal.link_query',
 			'title' => 'calendar.bocal.link_title',
 			'view'  => array(
-				'menuaction' => 'calendar.uiforms.view',
+				'menuaction' => 'calendar.uiforms.edit',
 			),
 			'view_id'    => 'cal_id',
 			'view_popup' => '750x400',
