@@ -1,16 +1,14 @@
 <?php
-/**************************************************************************\
-* eGroupWare - Calendar's buisness-object: access + update                 *
-* http://www.egroupware.org                                                *
-* Written and (c) 2005 by Ralf Becker <RalfBecker@outdoor-training.de>     *
-* --------------------------------------------                             *
-*  This program is free software; you can redistribute it and/or modify it *
-*  under the terms of the GNU General Public License as published by the   *
-*  Free Software Foundation; either version 2 of the License, or (at your  *
-*  option) any later version.                                              *
-\**************************************************************************/
-
-/* $Id: class.bocalupdate.inc.php 22790 2006-11-04 18:37:05Z jaytraxx $ */
+/**
+ * eGroupWare - Calendar's buisness-object - access + update
+ *
+ * @link http://www.egroupware.org
+ * @package calendar
+ * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2005-7 by RalfBecker-At-outdoor-training.de
+ * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+ * @version $Id: class.bocalupdate.inc.php 24792 2007-12-11 09:30:55Z pbf $
+ */
 
 require_once(EGW_INCLUDE_ROOT.'/calendar/inc/class.bocal.inc.php');
 
@@ -39,11 +37,6 @@ define('MSG_DISINVITE',7);
  * Nor does it store the state of any UI-elements (eg. cat-id selectbox). All this is the task of the UI class(es) !!!
  *
  * All permanent debug messages of the calendar-code should done via the debug-message method of the bocal class !!!
- *
- * @package calendar
- * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
- * @copyright (c) 2005 by RalfBecker-At-outdoor-training.de
- * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  */
 
 class bocalupdate extends bocal
@@ -125,8 +118,24 @@ class bocalupdate extends bocal
 		}
 		// check if user has the permission to update / create the event
 		if (!$ignore_acl && ($event['id'] && !$this->check_perms(EGW_ACL_EDIT,$event['id']) ||
-			!$event['id'] && !$this->check_perms(EGW_ACL_EDIT,0,$event['owner'])))
+			!$event['id'] && !$this->check_perms(EGW_ACL_EDIT,0,$event['owner'])) && 
+			!$this->check_perms(EGW_ACL_ADD,0,$event['owner']))
 		{
+			// Just update the status, if the user is in the event already
+			// is user is in both original and updated event
+			$egw_event = $this->read($event['id']);
+
+			if ( isset($egw_event['participants'][$this->user])
+				&& isset($event['participants'][$this->user]))
+			{
+				// Update their status in the event and say we're done.
+				// Admittedly, this is false, it's dropping any changes on the floor,
+				// But this will work better than dropping -everything- silently on
+				// the floor
+				$this->set_status($event['id'],'u',$this->user,$event['participants'][$this->user],0);
+				unset($egw_event);
+				return $event['id'];
+			}
 			return false;
 		}
 		// check for conflicts only happens !$ignore_conflicts AND if start + end date are given
@@ -142,7 +151,12 @@ class bocalupdate extends bocal
 			foreach($event['participants'] as $uid => $status)
 			{
 				if ($status[0] == 'R') continue;	// ignore rejected participants
-
+				
+				if ($uid < 0)	// group, check it's members too
+				{
+					$users += $GLOBALS['egw']->accounts->members($uid,true);
+					$users = array_unique($users);
+				}
 				$users[] = $uid;
 				if (in_array($uid{0},$types_with_quantity))
 				{
@@ -445,52 +459,52 @@ class bocalupdate extends bocal
 				$action = lang('Canceled');
 				$msg = 'Canceled';
 				$msgtype = '"calendar";';
-				$method = 'cancel';
+				$method = 'CANCEL';
 				break;
 			case MSG_MODIFIED:
 				$action = lang('Modified');
 				$msg = 'Modified';
 				$msgtype = '"calendar"; Version="'.$version.'"; Id="'.$new_event['id'].'"';
-				$method = 'request';
+				$method = 'REQUEST';
 				break;
 			case MSG_DISINVITE:
 				$action = lang('Disinvited');
 				$msg = 'Disinvited';
 				$msgtype = '"calendar";';
-				$method = 'cancel';
+				$method = 'CANCEL';
 				break;
 			case MSG_ADDED:
 				$action = lang('Added');
 				$msg = 'Added';
 				$msgtype = '"calendar"; Version="'.$version.'"; Id="'.$new_event['id'].'"';
-				$method = 'request';
+				$method = 'REQUEST';
 				break;
 			case MSG_REJECTED:
 				$action = lang('Rejected');
 				$msg = 'Response';
 				$msgtype = '"calendar";';
-				$method = 'reply';
+				$method = 'REPLY';
 				break;
 			case MSG_TENTATIVE:
 				$action = lang('Tentative');
 				$msg = 'Response';
 				$msgtype = '"calendar";';
-				$method = 'reply';
+				$method = 'REPLY';
 				break;
 			case MSG_ACCEPTED:
 				$action = lang('Accepted');
 				$msg = 'Response';
 				$msgtype = '"calendar";';
-				$method = 'reply';
+				$method = 'REPLY';
 				break;
 			case MSG_ALARM:
 				$action = lang('Alarm');
 				$msg = 'Alarm';
 				$msgtype = '"calendar";';
-				$method = 'publish';	// duno if thats right
+				$method = 'PUBLISH';	// duno if thats right
 				break;
 			default:
-				$method = 'publish';
+				$method = 'PUBLISH';
 		}
 		$notify_msg = $this->cal_prefs['notify'.$msg];
 		if (empty($notify_msg))
@@ -547,7 +561,7 @@ class bocalupdate extends bocal
 				$details['to-fullname'] = $GLOBALS['egw']->common->display_fullname('',$details['to-firstname'],$details['to-lastname']);
 
 				$to = $GLOBALS['egw']->accounts->id2name($userid,'account_email');
-				if (!$to || !strstr($to,'@'))
+				if (!$to || strpos($to,'@') === false)
 				{
 					// ToDo: give an error-message
 					echo '<p>'.lang('Invalid email-address "%1" for user %2',$to,$GLOBALS['egw']->common->grab_owner_name($userid))."</p>\n";
@@ -588,7 +602,7 @@ class bocalupdate extends bocal
 
 					case  'ical':
 						$ics = ExecMethod2('calendar.boical.exportVCal',$event['id'],'2.0',$method);
-						if ($method == "request") 
+						if ($method == 'REQUEST') 
 						{
 							$send->AddStringAttachment($ics, "cal.ics", "8bit", "text/calendar; method=$method");
 						}
@@ -605,6 +619,13 @@ class bocalupdate extends bocal
 				$returncode = $send->Send();
 				
 				// ToDo: give error-messages for all all failed sendings
+				
+				// notification via notification app.
+				if (version_compare("5.1.0", phpversion()) && array_key_exists('notifications',$GLOBALS['egw_info']['apps'])) {
+					require_once(EGW_INCLUDE_ROOT. '/notifications/inc/class.notification.inc.php');
+					include(EGW_INCLUDE_ROOT. '/calendar/inc/class.php5_notification.inc.php');
+				}
+
 			}
 		}
 		// restore the enviroment
@@ -675,7 +696,8 @@ class bocalupdate extends bocal
 	{
 		// check if user has the permission to update / create the event
 		if ($event['id'] && !$this->check_perms(EGW_ACL_EDIT,$event['id']) ||
-			!$event['id'] && !$this->check_perms(EGW_ACL_EDIT,0,$event['owner']))
+			!$event['id'] && !$this->check_perms(EGW_ACL_EDIT,0,$event['owner']) &&
+			!$this->check_perms(EGW_ACL_ADD,0,$event['owner']))
 		{
 			return false;
 		}
@@ -715,25 +737,51 @@ class bocalupdate extends bocal
 		return $cal_id;
 	}
 	
+	/**
+	 * Check if the current user has the necessary ACL rights to change the status of $uid
+	 * 
+	 * For contacts we use edit rights of the owner of the event (aka. edit rights of the event).
+	 *
+	 * @param int/string $uid account_id or 1-char type-identifer plus id (eg. c15 for addressbook entry #15)
+	 * @param array/int $event event array or id of the event
+	 * @return boolean
+	 */
+	function check_status_perms($uid,$event)
+	{
+		if ($uid{0} == 'c')	// for contact we use the owner of the event
+		{
+			if (!is_array($event) && !($event = $this->read($event))) return false;
+
+			return $this->check_perms(EGW_ACL_EDIT,0,$event['owner']);
+		}
+		if (!is_numeric($uid))	// this is eg. for resources (r123)
+		{
+			$resource = $this->resource_info($uid);
+
+			return EGW_ACL_EDIT & $resource['rights'];
+		}
+		// regular user and groups
+		return $this->check_perms(EGW_ACL_EDIT,0,$uid);
+	}
+
 	/**
 	 * set the status of one participant for a given recurrence or for all recurrences since now (includes recur_date=0)
 	 *
-	 * @param int $cal_id
-	 * @param char $user_type 'u' regular user
-	 * @param int $user_id
+	 * @param int/array $event event-array or id of the event
+	 * @param string/int $uid account_id or 1-char type-identifer plus id (eg. c15 for addressbook entry #15)
 	 * @param int/char $status numeric status (defines) or 1-char code: 'R', 'U', 'T' or 'A'
 	 * @param int $recur_date=0 date to change, or 0 = all since now
 	 * @return int number of changed recurrences
 	 */
-	function set_status($cal_id,$user_type,$user_id,$status,$recur_date=0)
+	function set_status($event,$uid,$status,$recur_date=0)
 	{
-		//echo "<p>bocalupdate::set_status($cal_id,$user_type,$user_id,$status,$recur_date)</p>\n";
-		if (!$cal_id || $user_type == 'u' && !$this->check_perms(EGW_ACL_EDIT,0,$user_id))
-			// ToDo: check for bookingpermission of resources !!!
+		$cal_id = is_array($event) ? $event['id'] : $event;
+		//echo "<p>bocalupdate::set_status($cal_id,$uid,$status,$recur_date)</p>\n";
+		if (!$cal_id || !$this->check_status_perms($uid,$event))
 		{
 			return false;
 		}
-		if (($Ok = $this->so->set_status($cal_id,$user_type,$user_id,$status,$recur_date ? $this->date2ts($recur_date,true) : 0)))
+		if (($Ok = $this->so->set_status($cal_id,is_numeric($uid)?'u':$uid{0},is_numeric($uid)?$uid:substr($uid,1),$status,$recur_date ? $this->date2ts($recur_date,true) : 0)))
 		{
 			$GLOBALS['egw']->contenthistory->updateTimeStamp('calendar',$cal_id,'modify',time());
 
@@ -744,7 +792,8 @@ class bocalupdate extends bocal
 			);
 			if (isset($status2msg[$status]))
 			{
-				$event = $this->read($cal_id);
+				if (!is_array($event)) $event = $this->read($cal_id);
+				if (isset($recur_date)) $event = $this->read($event['id'],$recur_date); //re-read the actually edited recurring event
 				$this->send_update($status2msg[$status],$event['participants'],$event);
 			}
 		}
@@ -805,7 +854,8 @@ class bocalupdate extends bocal
 		$details['participants'] = $details['participants'] ? implode("\n",$details['participants']) : '';
 
 		$event_arr['link']['field'] = lang('URL');
-		$link = $GLOBALS['egw_info']['server']['webserver_url'].'/index.php?menuaction=calendar.uiforms.view&cal_id='.$event['id'].'&no_popup=1';
+		$eventStart_arr = $this->date2array($event['start']); // give this as 'date' to the link to pick the right recurrence for the participants state
+		$link = $GLOBALS['egw_info']['server']['webserver_url'].'/index.php?menuaction=calendar.uiforms.edit&cal_id='.$event['id'].'&date='.$eventStart_arr['full'].'&no_popup=1';
 		// if url is only a path, try guessing the rest ;-)
 		if ($link{0} == '/')
 		{
@@ -987,4 +1037,66 @@ class bocalupdate extends bocal
 		}
 		return $this->so->delete_alarm($id);
 	}
+
+	var $categories;
+
+	function find_or_add_categories($catname_list)
+	{
+		if (!is_object($this->categories))
+		{
+			$this->categories =& CreateObject('phpgwapi.categories',$GLOBALS['egw_info']['user']['account_id'],'calendar');
+		}
+
+		$cat_id_list = array();
+		foreach($catname_list as $cat_name)
+		{
+			$cat_name = trim($cat_name);
+			$cat_id = $this->categories->name2id($cat_name, 'X-');
+			if (!$cat_id)
+			{
+				if (strncmp($cat_name, "X-", 2) == 0)
+				{
+					$cat_name = substr($cat_name, 2);
+				}
+				$cat_id = $this->categories->add(array('name' => $cat_name,'descr' => $cat_name));
+			}
+
+			if ($cat_id)
+			{
+				$cat_id_list[] = $cat_id;
+			}
+		}
+
+		if (count($cat_id_list) > 1)
+		{
+			$cat_id_list = array_unique($cat_id_list);
+			sort($cat_id_list, SORT_NUMERIC);
+		}
+		return $cat_id_list;
+	}
+
+	function get_categories($cat_id_list)
+	{
+		if (!is_object($this->categories))
+		{
+			$this->categories =& CreateObject('phpgwapi.categories',$GLOBALS['egw_info']['user']['account_id'],'calendar');
+		}
+
+		if (!is_array($cat_id_list))
+		{
+			$cat_id_list = explode(',',$cat_id_list);
+		}
+
+		$cat_list = array();
+		foreach($cat_id_list as $cat_id)
+		{
+			if ($cat_data = $this->categories->return_single($cat_id))
+			{
+				$cat_list[] = $cat_data[0]['name'];
+			}
+		}
+
+		return $cat_list;
+	}
+
 }
