@@ -10,7 +10,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.boholiday.inc.php 20561 2006-03-15 06:44:09Z ralfbecker $ */
+	/* $Id: class.boholiday.inc.php 23741 2007-04-30 10:29:44Z lkneschke $ */
 
 	/**
 	 * Business object for calendar holidays
@@ -298,7 +298,7 @@
 					return false;
 				}
 				$charset = split("[\t\n ]+",$lines[0]);		// give a bit flexibility in the syntax AND remove the lineend (\n)
-				if (strstr($charset[0],'charset') && $charset[1])
+				if (strpos($charset[0],'charset') !== false && $charset[1])
 				{
 					$lines = $GLOBALS['egw']->translation->convert($lines,$charset[1]);
 				}
@@ -463,9 +463,11 @@
 			{
 				return false;
 			}
-			$sbox =& CreateObject('phpgwapi.sbox');
-			$month = $holiday['month'] ? lang($sbox->monthnames[$holiday['month']]) : '';
-			unset($sbox);
+			$monthnames = array(
+				'','January','February','March','April','May','June',
+				'July','August','September','October','November','December'
+			);
+			$month = $holiday['month'] ? lang($monthnames[$holiday['month']]) : '';
 
 			if (!$holiday['day'])
 			{
