@@ -9,7 +9,7 @@
 	*  Free Software Foundation; either version 2 of the License.              *
 	\**************************************************************************/
 
-	/* $Id: class.boical.inc.php 22835 2006-11-13 08:34:39Z lkneschke $ */
+	/* $Id: class.boical.inc.php 25196 2008-03-27 08:31:17Z pbf $ */
 
 	require_once EGW_SERVER_ROOT.'/calendar/inc/class.bocalupdate.inc.php';
 	require_once EGW_SERVER_ROOT.'/phpgwapi/inc/horde/Horde/iCalendar.php';
@@ -117,24 +117,38 @@
 		function &exportVCal($events,$version='1.0', $method='PUBLISH')
 		{
 			$egwSupportedFields = array(
-				'CLASS'		=> array('dbName' => 'public'),
-				'SUMMARY'	=> array('dbName' => 'title'),
+				'CLASS'			=> array('dbName' => 'public'),
+				'SUMMARY'		=> array('dbName' => 'title'),
 				'DESCRIPTION'	=> array('dbName' => 'description'),
-				'LOCATION'	=> array('dbName' => 'location'),
-				'DTSTART'	=> array('dbName' => 'start'),
-				'DTEND'		=> array('dbName' => 'end'),
-				'ORGANIZER'	=> array('dbName' => 'owner'),
-				'ATTENDEE'	=> array('dbName' => 'participants'),
-				'RRULE'		=> array('dbName' => 'recur_type'),
-				'EXDATE'	=> array('dbName' => 'recur_exception'),
- 				'PRIORITY'	=> array('dbName' => 'priority'),
- 				'TRANSP'	=> array('dbName' => 'non_blocking'),
+				'LOCATION'		=> array('dbName' => 'location'),
+				'DTSTART'		=> array('dbName' => 'start'),
+				'DTEND'			=> array('dbName' => 'end'),
+				'ORGANIZER'		=> array('dbName' => 'owner'),
+				'ATTENDEE'		=> array('dbName' => 'participants'),
+				'RRULE'			=> array('dbName' => 'recur_type'),
+				'EXDATE'		=> array('dbName' => 'recur_exception'),
+ 				'PRIORITY'		=> array('dbName' => 'priority'),
+ 				'TRANSP'		=> array('dbName' => 'non_blocking'),
 				'CATEGORIES'	=> array('dbName' => 'category'),
 			);
 			if(!is_array($this->supportedFields))
 			{
 				$this->setSupportedFields();
 			}
+			
+			if($this->productManufacturer == '' )
+			{	// syncevolution is broken
+				$version = "2.0";
+			}
+			
+			$palm_enddate_workaround=False;
+			if($this->productManufacturer == 'Synthesis AG'
+				&& strpos($this->productName, "PalmOS") )
+			{
+				// This workaround adds 1 day to the recur_enddate if it exists, to fix a palm bug
+				$palm_enddate_workaround=True;
+			}
+			
 			$vcal = &new Horde_iCalendar;
 			$vcal->setAttribute('PRODID','-//eGroupWare//NONSGML eGroupWare Calendar '.$GLOBALS['egw_info']['apps']['calendar']['version'].'//'.
 				strtoupper($GLOBALS['egw_info']['user']['preferences']['common']['lang']));
@@ -150,7 +164,16 @@
 					return false;	// no permission to read $cal_id
 				}
 				//_debug_array($event);
-				
+
+				// correct daylight saving time
+				/* causes times wrong by one hour, if exporting events with DST different from the current date,
+				which this fix is suppost to fix. Maybe the problem has been fixed in the horde code too.
+				$currentDST = date('I', mktime());
+				$eventDST = date('I', $event['start']);
+				$DSTCorrection = ($currentDST - $eventDST) * 3600;
+				$event['start']	= $event['start'] + $DSTCorrection;
+				$event['end']	= $event['end'] + $DSTCorrection;
+				*/
 				$eventGUID = $GLOBALS['egw']->common->generate_uid('calendar',$event['id']);
 				
 				$vevent = Horde_iCalendar::newComponent('VEVENT',$vcal);
@@ -179,7 +202,22 @@
 									// PARTSTAT={NEEDS-ACTION|ACCEPTED|DECLINED|TENTATIVE|DELEGATED|COMPLETED|IN-PROGRESS} everything from delegated is NOT used by eGW atm.
 									$status = $this->status_egw2ical[$status];
 									// CUTYPE={INDIVIDUAL|GROUP|RESOURCE|ROOM|UNKNOWN}
-									$cutype = $GLOBALS['egw']->accounts->get_type($uid) == 'g' ? 'GROUP' : 'INDIVIDUAL';
+									switch (is_numeric($uid) ? $GLOBALS['egw']->accounts->get_type($uid) : $uid{0})
+									{
+										case 'g':
+											$cutype = 'GROUP';
+											break;
+										case 'r':
+											$cutype = 'RESOURCE';
+											break;
+										case 'u':
+											$cutype = 'INDIVIDUAL';
+											break;
+										default:
+											$cutype = 'UNKNOWN';
+											$cutype = 'INDIVIDUAL';
+											break;
+									};
 									$parameters['ATTENDEE'][] = array(
 										'CN'       => $cn, 
 										'ROLE'     => $role, 
@@ -206,6 +244,7 @@
 								
 							case 'DTEND':
 								if(date('H:i:s',$event['end']) == '23:59:59') $event['end']++;
+								if(date('H:i:s',$event['end']) == '23:59:00') $event['end']+=60; // needed by old eGW whole-day events
 		            					$attributes[$icalFieldName]	= $event['end'];
 		            					break;
 		            					
@@ -235,7 +274,20 @@
 		            								$rrule['FREQ'] = $rrule['FREQ'].' '.$rrule['BYDAY'];
 											break;
 									}
-									$rrule['UNTIL'] = ($event['recur_enddate']) ? date('Ymd',$event['recur_enddate']) : '#0';
+
+									if ($event['recur_enddate'])
+									{
+										$recur_enddate = (int)$event['recur_enddate'];
+										if ($palm_enddate_workaround)
+										{
+											$recur_enddate += 86400;
+										}
+										$rrule['UNTIL'] = date('Ymd',$recur_enddate);
+									}
+									else
+									{
+										$rrule['UNTIL'] = '#0';
+									}
 
 									$attributes['RRULE'] = $rrule['FREQ'].' '.$rrule['UNTIL'];
 								} else {
@@ -282,7 +334,7 @@
 									{
 										$days[] = date('Ymd',$day);
 									}
-									$attributes['EXDATE'] = implode(';',$days);
+									$attributes['EXDATE'] = implode(',',$days);
 									$parameters['EXDATE']['VALUE'] = 'DATE';
 								}
 								break;
@@ -292,9 +344,9 @@
 	 							break;
 	 							
 	 						case 'TRANSP':
-	 							if ($version == '1.0') {
-	 								$attributes['TRANSP'] = $event['non_blocking'] ? 1 : 0;
-	 							} else {
+								if ($version == '1.0') {
+									$attributes['TRANSP'] = $event['non_blocking'] ? 1 : 0;
+								} else {
 									$attributes['TRANSP'] = $event['non_blocking'] ? 'TRANSPARENT' : 'OPAQUE';
 								}
 								break;
@@ -302,9 +354,10 @@
 							case 'CATEGORIES':
 								if ($event['category'])
 								{
-									$attributes['CATEGORIES'] = implode(',',$this->categories($event['category'],$nul));
+									$attributes['CATEGORIES'] = implode(',',$this->get_categories($event['category']));
 								}
 								break;
+
 							default:
 								if ($event[$egwFieldInfo['dbName']])	// dont write empty fields
 								{
@@ -314,6 +367,16 @@
 						}
 					}
 				}
+				
+				if(strtolower($this->productManufacturer) == 'nokia') {
+					if($event['special'] == '1') {
+						$attributes['X-EPOCAGENDAENTRYTYPE'] = 'ANNIVERSARY';
+						$attributes['DTEND'] = $attributes['DTSTART'];
+					} else {
+						$attributes['X-EPOCAGENDAENTRYTYPE'] = 'APPOINTMENT';
+					}
+				}
+				
 				$modified = $GLOBALS['egw']->contenthistory->getTSforAction($eventGUID,'modify');
 				$created = $GLOBALS['egw']->contenthistory->getTSforAction($eventGUID,'add');
 				if (!$created && !$modified) $created = $event['modified'];
@@ -323,10 +386,47 @@
 				
 				foreach($event['alarm'] as $alarmID => $alarmData)
 				{
-					$attributes['DALARM'] = $vcal->_exportDateTime($alarmData['time']);
-					$attributes['AALARM'] = $vcal->_exportDateTime($alarmData['time']);
-					// lets take only the first alarm
-					break;
+					if ($version == '1.0')
+					{
+						$attributes['DALARM'] = $vcal->_exportDateTime($alarmData['time']);
+						$attributes['AALARM'] = $vcal->_exportDateTime($alarmData['time']);
+						// lets take only the first alarm
+						break;
+					}
+					else
+					{
+						// VCalendar 2.0 / RFC 2445
+
+						// skip over alarms that don't have the minimum required info
+						if (!$alarmData['offset'] && !$alarmData['time'])
+						{
+							error_log("Couldn't add VALARM (no alarm time info)");
+							continue;
+						}
+
+						// RFC requires DESCRIPTION for DISPLAY
+						if (!$event['title'] && !$event['description'])
+						{
+							error_log("Couldn't add VALARM (no description)");
+							continue;
+						}
+
+						$valarm = Horde_iCalendar::newComponent('VALARM',$vevent);
+						if ($alarmData['offset'])
+						{
+							$valarm->setAttribute('TRIGGER', -$alarmData['offset'],
+									array('VALUE' => 'DURATION', 'RELATED' => 'START'));
+						}
+						else
+						{
+							$valarm->setAttribute('TRIGGER', $alarmData['time'],
+									array('VALUE' => 'DATE-TIME'));
+						}
+
+						$valarm->setAttribute('ACTION','DISPLAY');
+						$valarm->setAttribute('DESCRIPTION',$event['title'] ? $event['title'] : $event['description']);
+						$vevent->addComponent($valarm);
+					}
 				}
 				
 				$attributes['UID'] = $eventGUID;
@@ -365,8 +465,7 @@
 			$_vcalData = preg_replace("/[\r\n]+ /",'',$_vcalData);
 
 			$vcal = &new Horde_iCalendar;
-			if(!$vcal->parsevCalendar($_vcalData)) 
-			{
+			if(!$vcal->parsevCalendar($_vcalData)) {
 				return FALSE;
 			}
 			
@@ -378,6 +477,13 @@
 			}
 			//echo "supportedFields="; _debug_array($this->supportedFields);
 
+			$syncevo_enddate_fix = False;
+			if( $this->productManufacturer == '' && $this->productName == '' )
+			{
+				// syncevolution needs an adjusted recur_enddate
+				$syncevo_enddate_fix = True;
+			}
+
 			$Ok = false;	// returning false, if file contains no components
 			foreach($vcal->getComponents() as $component)
 			{
@@ -387,7 +493,10 @@
 					#$event = array('participants' => array());
 					$event		= array();
 					$alarms		= array();
-					$vcardData	= array('recur_type' => 0);
+					$vcardData	= array(
+						'recur_type'		=> MCAL_RECUR_NONE,
+						'recur_exception'	=> array(),
+					);
 					
 					// lets see what we can get from the vcard
 					foreach($component->_attributes as $attributes) 
@@ -401,12 +510,23 @@
 									$alarms[$alarmTime] = array(
 										'time' => $alarmTime
 									);
-								} elseif (preg_match('/(........T......);;;$/',$attributes['value'],$matches)) {
-									#error_log(print_r($matches,true));
+								} elseif (preg_match('/(........T......);;(\d*);$/',$attributes['value'],$matches)) {
+									//error_log(print_r($matches,true));
 									$alarmTime = $vcal->_parseDateTime($matches[1]);
 									$alarms[$alarmTime] = array(
 										'time' => $alarmTime
 									);
+								} elseif (preg_match('/(........T......Z);;(\d*);$/',$attributes['value'],$matches)) {
+									//error_log(print_r($matches,true));
+									$alarmTime = $vcal->_parseDateTime($matches[1]);
+									$alarms[$alarmTime] = array(
+										'time' => $alarmTime
+									);
+								} elseif (preg_match('/(........T......)$/',$attributes['value'],$matches)) {
+									$alarmTime = $vcal->_parseDateTime($attributes['value']);
+									$alarms[$alarmTime] = array(
+										'time' => $alarmTime
+									);
 								}
 								break;
 							case 'CLASS':
@@ -416,9 +536,11 @@
 								$vcardData['description']	= $attributes['value'];
 								break;
 							case 'DTEND':
-								if(date('H:i:s',$attributes['value']) == '00:00:00')
-									$attributes['value']--;
-								$vcardData['end']		= $attributes['value'];
+								$dtend_ts = is_numeric($attributes['value']) ? $attributes['value'] : $this->date2ts($attributes['value']);
+								if(date('H:i:s',$dtend_ts) == '00:00:00') {
+									$dtend_ts -= 60;
+								}
+								$vcardData['end']		= $dtend_ts;
 								break;
 							case 'DTSTART':
 								$vcardData['start']		= $attributes['value'];
@@ -434,9 +556,14 @@
 								{
 									$vcardData['recur_enddate'] = $vcal->_parseDateTime($matches[1]);
 								}
+								elseif (preg_match('/COUNT=([0-9]+)/',$recurence,$matches))
+								{
+									$vcardData['recur_count'] = (int)$matches[1];
+								}
 								if (preg_match('/INTERVAL=([0-9]+)/',$recurence,$matches))
 								{
-									$vcardData['recur_interval'] = (int) $matches[1];
+									// 1 is invalid,, egw uses 0 for interval
+									$vcardData['recur_interval'] = (int) $matches[1] != 0 ? (int) $matches[1] : 0;
 								}
 								$vcardData['recur_data'] = 0;
 								switch($type)
@@ -468,6 +595,14 @@
 		            								}
 											$vcardData['recur_type'] = MCAL_RECUR_WEEKLY;
 										}
+
+										if (!empty($vcardData['recur_count']))
+										{
+											$vcardData['recur_enddate'] = mktime(0,0,0,
+												date('m',$vcardData['start']),
+												date('d',$vcardData['start']) + ($vcardData['recur_interval']*($vcardData['recur_count']-1)*7),
+												date('Y',$vcardData['start']));
+										}
 										break;
 									
 									case 'D':	// 1.0
@@ -494,6 +629,14 @@
 										// fall-through
 									case 'DAILY':	// 2.0
 										$vcardData['recur_type'] = MCAL_RECUR_DAILY;
+
+										if (!empty($vcardData['recur_count']))
+										{
+											$vcardData['recur_enddate'] = mktime(0,0,0,
+												date('m',$vcardData['start']),
+												date('d',$vcardData['start']) + ($vcardData['recur_interval']*($vcardData['recur_count']-1)),
+												date('Y',$vcardData['start']));
+										}
 										break;
 
 									case 'M':
@@ -525,8 +668,16 @@
 										}
 										break;
 									case 'MONTHLY':
-										$vcardData['recur_type'] = strstr($recurence,'BYDAY') ? 
+										$vcardData['recur_type'] = strpos($recurence,'BYDAY') !== false ? 
 											MCAL_RECUR_MONTHLY_WDAY : MCAL_RECUR_MONTHLY_MDAY;
+
+										if (!empty($vcardData['recur_count']))
+										{
+											$vcardData['recur_enddate'] = mktime(0,0,0,
+												date('m',$vcardData['start']) + ($vcardData['recur_interval']*($vcardData['recur_count']-1)),
+												date('d',$vcardData['start']),
+												date('Y',$vcardData['start']));
+										}
 										break;										
 
 									case 'Y':		// 1.0
@@ -553,11 +704,24 @@
 										// fall-through
 									case 'YEARLY':	// 2.0
 										$vcardData['recur_type'] = MCAL_RECUR_YEARLY;
+
+										if (!empty($vcardData['recur_count']))
+										{
+											$vcardData['recur_enddate'] = mktime(0,0,0,
+												date('m',$vcardData['start']),
+												date('d',$vcardData['start']),
+												date('Y',$vcardData['start']) + ($vcardData['recur_interval']*($vcardData['recur_count']-1)));
+										}
 										break;
 								}
+								if( $syncevo_enddate_fix && $vcardData['recur_enddate'] )
+								{
+									// Does syncevolution need to adjust recur_enddate
+									$vcardData['recur_enddate'] = (int)$vcardData['recur_enddate'] + 86400;
+								}
 								break;
 							case 'EXDATE':
-								$vcardData['recur_exception'] = $attributes['value'];
+								$vcardData['recur_exception'] = array_merge($vcardData['recur_exception'],$attributes['value']);
 								break;
 							case 'SUMMARY':
 								$vcardData['title']		= $attributes['value'];
@@ -581,26 +745,14 @@
 	 							$vcardData['priority'] = (int) $this->priority_ical2egw[$attributes['value']];
 	 							break;
 	 						case 'CATEGORIES':
-	 							$vcardData['category'] = array();
 	 							if ($attributes['value'])
 	 							{
-									if (!is_object($this->cat))
-									{
-										if (!is_object($GLOBALS['egw']->categories))
-										{
-											$GLOBALS['egw']->categories =& CreateObject('phpgwapi.categories',$this->owner,'calendar');
-										}
-										$this->cat =& $GLOBALS['egw']->categories;
-									}
-	 								foreach(explode(',',$attributes['value']) as $cat_name)
-	 								{
-	 									if (!($cat_id = $this->cat->name2id($cat_name)))
-	 									{
-	 										$cat_id = $this->cat->add( array('name' => $cat_name,'descr' => $cat_name ));
-	 									}
- 										$vcardData['category'][] = $cat_id;
-	 								}
+	 								$vcardData['category'] = $this->find_or_add_categories(explode(',',$attributes['value']));
 	 							}
+								else
+								{
+	 								$vcardData['category'] = array();
+								}
 	 							break;	
 	 						case 'ATTENDEE':
 	 							if (preg_match('/MAILTO:([@.a-z0-9_-]+)/i',$attributes['value'],$matches) &&
@@ -641,6 +793,18 @@
 								break;
 						}
 					}
+
+					// check if the entry is a birthday 
+					// this field is only set from NOKIA clients
+					$agendaEntryType = $component->getAttribute('X-EPOCAGENDAENTRYTYPE');
+					if (!is_a($agendaEntryType, 'PEAR_Error')) {
+						if(strtolower($agendaEntryType) == 'anniversary') {
+							$event['special'] = '1';
+							// make it a whole day event for eGW
+							$vcardData['end'] = $vcardData['start'] + 86399;
+						}
+					}
+					
 					if(!empty($vcardData['recur_enddate']))
 					{
 						// reset recure_enddate to 00:00:00 on the last day
@@ -698,8 +862,40 @@
 						$event['participants'] = array($GLOBALS['egw_info']['user']['account_id'] => 'A');
 	 				}
 
+					// If this is an updated meeting, and the client doesn't support
+					// participants, add them back
+					if( $cal_id >0 && !isset($this->supportedFields['participants']))
+					{
+						$egw_event = $this->read($cal_id);
+						if ($egw_event)
+						{
+							$event['participants'] = $egw_event['participants'];
+							$event['participant_types'] = $egw_event['participant_types'];
+						}
+					}
+
+					// Check for resources, and don't remove them
+					if( $cal_id > 0 )
+					{
+						// for each existing participant:
+						$egw_event = $this->read($cal_id);
+						if ( $egw_event )
+						{ 
+							foreach( $egw_event['participants'] as $uid => $status )
+							{
+								// Is it a resource?
+								if ( preg_match("/^r(.*)/", $uid, $matches) )
+								{
+									// Add it back in
+									$event['participants'][$uid] = 'A';
+									$event['participant_types']['r'][$matches[1]] = 'A';
+								}
+							}
+						}
+					}
+
 					#error_log('ALARMS');
-					#error_log(print_r($event['participants'], true));
+					#error_log(print_r($event, true));
 					
 					if (!($Ok = $this->update($event, TRUE))) {
 						break;	// stop with the first error
@@ -709,6 +905,14 @@
 						$eventID =& $Ok;
 
 						// handle the alarms
+						foreach ($component->getComponents() as $valarm)
+						{
+							if (is_a($valarm, 'Horde_iCalendar_valarm'))
+							{
+								$this->valarm2egw($alarms,$valarm);
+							}
+						}
+
 						if(count($alarms) > 0 || (isset($this->supportedFields['alarms'])  && count($alarms) == 0))
 						{
 							// delete the old alarms
@@ -731,27 +935,107 @@
 			return $Ok;
 		}
 
+		function valarm2egw(&$alarms, &$valarm)
+		{
+			$count = 0;
+			foreach($valarm->_attributes as $vattr)
+			{
+				switch($vattr['name'])
+				{
+					case 'TRIGGER':
+						$vtype = (isset($vattr['params']['VALUE']))
+							? $vattr['params']['VALUE'] : 'DURATION'; //default type
+						switch ($vtype)
+						{
+							case 'DURATION':
+								if (isset($vattr['params']['RELATED'])
+									&& $vattr['params']['RELATED'] != 'START')
+								{
+									error_log("Unsupported VALARM offset anchor ".$vattr['params']['RELATED']);
+								}
+								else
+								{
+									$alarms[] = array('offset' => -$vattr['value']);
+									$count++;
+								}
+								break;
+							case 'DATE-TIME':
+								$alarms[] = array('time' => $vattr['value']);
+								$count++;
+								break;
+							default:
+								// we should also do ;RELATED=START|END
+								error_log('VALARM/TRIGGER: unsupported value type:' . $vtype);
+						}
+						break;
+					// case 'ACTION':
+					// 	break;
+					// case 'DISPLAY':
+					// 	break;
+
+					default:
+						error_log('VALARM field:' .$vattr['name'] .':' . print_r($vattrval,true) . ' HAS NO CONVERSION YET');
+				}
+			}
+			return $count;
+		}
+
 		function setSupportedFields($_productManufacturer='file', $_productName='')
 		{
 			// save them vor later use
-			$this->productManufacturere = $_productManufacturer;
+			$this->productManufacturer = $_productManufacturer;
 			$this->productName = $_productName;
 
-			$defaultFields = array('public' => 'public', 'description' => 'description', 'end' => 'end',
-				'start' => 'start', 'location' => 'location', 'recur_type' => 'recur_type',
-				'recur_interval' => 'recur_interval', 'recur_data' => 'recur_data', 'recur_enddate' => 'recur_enddate',
-				'title' => 'title',	'priority' => 'priority', 'alarms' => 'alarms', 
-
+			$defaultFields['minimal'] = array(
+				'public'			=> 'public',
+				'description'		=> 'description',
+				'end'				=> 'end',
+				'start'				=> 'start',
+				'location'			=> 'location',
+				'recur_type'		=> 'recur_type',
+				'recur_interval'	=> 'recur_interval',
+				'recur_data'		=> 'recur_data',
+				'recur_enddate'		=> 'recur_enddate',
+				'title'				=> 'title',
+				'alarms'			=> 'alarms', 
 			);
+
+			$defaultFields['basic'] = $defaultFields['minimal'] + array(
+				'recur_exception'	=> 'recur_exception',
+				'priority'			=> 'priority',
+			);
+
+			$defaultFields['nexthaus'] = $defaultFields['basic'] + array(
+				'participants'		=> 'participants',
+			);
+			
+			$defaultFields['synthesis'] = $defaultFields['basic'] + array(
+				'non_blocking'		=> 'non_blocking',
+				'category'			=> 'category',
+			);
+			
+			$defaultFields['evolution'] = $defaultFields['basic'] + array(
+				'participants'		=> 'participants',
+				'owner'				=> 'owner',
+				'category'			=> 'category',
+			);
+
+			$defaultFields['full'] = $defaultFields['basic'] + array(
+				'participants'		=> 'participants',
+				'owner'				=> 'owner',
+				'category'			=> 'category',
+				'non_blocking'		=> 'non_blocking',
+			);
+			
 			
 			switch(strtolower($_productManufacturer))
 			{
 				case 'nexthaus corporation':
+				case 'nexthaus corp':
 					switch(strtolower($_productName))
 					{
 						default:
-							$this->supportedFields = $defaultFields + array('participants' => 'participants');
-							#$this->supportedFields = $defaultFields;
+							$this->supportedFields = $defaultFields['nexthaus'];
 							break;
 					}
 					break;
@@ -762,17 +1046,35 @@
 					switch(strtolower($_productName))
 					{
 						default:
-							$this->supportedFields = $defaultFields;
+							$this->supportedFields = $defaultFields['basic'];
+							break;
+					}
+					break;
+
+				case 'nokia':
+					switch(strtolower($_productName))
+					{
+						case 'e61':
+							$this->supportedFields = $defaultFields['minimal'];
+							break;
+						default:
+							error_log("Unknown Nokia phone '$_productName', assuming E61");
+							$this->supportedFields = $defaultFields['minimal'];
 							break;
 					}
 					break;
 
 				case 'sonyericsson':
+				case 'sony ericsson':
 					switch(strtolower($_productName))
 					{
 						case 'd750i':
+						case 'p910i':
+							$this->supportedFields = $defaultFields['basic'];
+							break;
 						default:
-							$this->supportedFields = $defaultFields;
+							error_log("Unknown Sony Ericsson phone '$_productName' assuming d750i");
+							$this->supportedFields = $defaultFields['basic'];
 							break;
 					}
 					break;
@@ -780,42 +1082,40 @@
 				case 'synthesis ag':
 					switch(strtolower($_productName))
 					{
+						case 'sysync client pocketpc std':
+						case 'sysync client pocketpc pro':
+							$this->supportedFields = $defaultFields['full'];
+							break;
 						default:
-							$this->supportedFields = $defaultFields + array(
-								'recur_exception' => 'recur_exception',
-								'non_blocking' => 'non_blocking',
-							);
+							$this->supportedFields = $defaultFields['synthesis'];
 							break;
 					}
 					break;
 
 				//Syncevolution compatibility	
 				case 'patrick ohly':
-					$this->supportedFields = $defaultFields + array(
-						'participants' => 'participants',
-						'owner'        => 'owner',
-						'category'     => 'category',
-					);
+					$this->supportedFields = $defaultFields['evolution'];
+					break;
+
+				case '': // seems syncevolution 0.5 doesn't send a manufacturer
+					error_log("No vendor name, assuming syncevolution 0.5");
+					$this->supportedFields = $defaultFields['evolution'];
 					break;
 					
 				case 'file':	// used outside of SyncML, eg. by the calendar itself ==> all possible fields
-					$this->supportedFields = $defaultFields + array(
-						'participants' => 'participants',
-						'owner'        => 'owner',
-						'non_blocking' => 'non_blocking',
-						'category'     => 'category',
-					);
+					$this->supportedFields = $defaultFields['full'];
 					break;
 
 				// the fallback for SyncML
 				default:
-					error_log("Client not found: $_productManufacturer $_productName");
-					$this->supportedFields = $defaultFields;
+					error_log("Unknown calendar SyncML client: manufacturer='$_productManufacturer'  product='$_productName'");
+					$this->supportedFields = $defaultFields['full'];
 					break;
 			}
 		}
 		
-		function icaltoegw($_vcalData) {
+		function icaltoegw($_vcalData)
+		{
 			// our (patched) horde classes, do NOT unfold folded lines, which causes a lot trouble in the import
 			$_vcalData = preg_replace("/[\r\n]+ /",'',$_vcalData);
 
@@ -947,7 +1247,7 @@
 										}
 										break;
 									case 'MONTHLY':
-										$vcardData['recur_type'] = strstr($recurence,'BYDAY') ? 
+										$vcardData['recur_type'] = strpos($recurence,'BYDAY') !== false ? 
 											MCAL_RECUR_MONTHLY_WDAY : MCAL_RECUR_MONTHLY_MDAY;
 										break;										
 
@@ -980,7 +1280,8 @@
 								$vcardData['non_blocking'] = $attributes['value'] == 'TRANSPARENT';
 								break;
 							case 'PRIORITY':
-								if ($this->productManufacturer == 'nexthaus corporation')
+								if ($this->productManufacturer == 'nexthaus corporation'
+									|| $this->productManufacturer == 'nexthaus corp')
 								{
 									$vcardData['priority'] = $attributes['value'] == 1 ? 3 : 2; // 1=high, 2=normal
 								}
@@ -990,26 +1291,14 @@
 								}
 	 							break;
 	 						case 'CATEGORIES':
-	 							$vcardData['category'] = array();
 	 							if ($attributes['value'])
 	 							{
-									if (!is_object($this->cat))
-									{
-										if (!is_object($GLOBALS['egw']->categories))
-										{
-											$GLOBALS['egw']->categories =& CreateObject('phpgwapi.categories',$this->owner,'calendar');
-										}
-										$this->cat =& $GLOBALS['egw']->categories;
-									}
-	 								foreach(explode(',',$attributes['value']) as $cat_name)
-	 								{
-	 									if (!($cat_id = $this->cat->name2id($cat_name)))
-	 									{
-	 										$cat_id = $this->cat->add( array('name' => $cat_name,'descr' => $cat_name ));
-	 									}
- 										$vcardData['category'][] = $cat_id;
-	 								}
-	 							}
+									$vcardData['category'] = $this->find_or_add_categories(explode(',',$attributes['value']));
+								}
+								else
+								{
+	 								$vcardData['category'] = array();
+								}
 	 							break;	
 	 						case 'ATTENDEE':
 	 							if (preg_match('/MAILTO:([@.a-z0-9_-]+)/i',$attributes['value'],$matches) &&
@@ -1035,6 +1324,17 @@
 								break;
 						}
 					}
+					
+					// check if the entry is a birthday 
+					// this field is only set from NOKIA clients
+					$agendaEntryType = $component->getAttribute('X-EPOCAGENDAENTRYTYPE');
+					if (!is_a($agendaEntryType, 'PEAR_Error')) {
+						if(strtolower($agendaEntryType) == 'anniversary') {
+							$event['special'] = '1';
+							$vcardData['end'] = $vcardData['start'] + 86399;
+						}
+					}
+					
 					if(!empty($vcardData['recur_enddate']))
 					{
 						// reset recure_enddate to 00:00:00 on the last day
@@ -1046,16 +1346,14 @@
 					}
 					//echo "event=";_debug_array($vcardData);
 					
-					// now that we know what the vard provides, we merge that data with the information we have about the device
-					$event['priority']		= 2;
-					if($cal_id > 0)
-					{
-						$event['id'] = $cal_id;
-					}
 					while(($fieldName = array_shift($supportedFields)))
 					{
 						switch($fieldName)
 						{
+							case 'recur_interval':
+							case 'recur_enddate':
+							case 'recur_data':
+							case 'recur_exception':
 							case 'alarms':
 								// not handled here
 								break;
@@ -1071,17 +1369,12 @@
 										}
 									}
 								}
-								unset($supportedFields['recur_type']);
-								unset($supportedFields['recur_interval']);
-								unset($supportedFields['recur_enddate']);
-								unset($supportedFields['recur_data']);
 								break;
 							default:
 								if (isset($vcardData[$fieldName]))
 								{
 									$event[$fieldName] = $vcardData[$fieldName];
 								}
-								unset($supportedFields[$fieldName]);
 								break;
 						}
 					}
@@ -1093,15 +1386,19 @@
 			return false;
 		}
 
-		function search($_vcalData) {
+		function search($_vcalData) 
+		{
 			if(!$event = $this->icaltoegw($_vcalData)) {
 				return false;
 			}
+			
 			$query = array(
 				'cal_start='.$this->date2ts($event['start'],true),	// true = Server-time
 				'cal_end='.$this->date2ts($event['end'],true),
 			);
-			foreach(array('title','location','priority','public','non_blocking') as $name) {
+			
+			#foreach(array('title','location','priority','public','non_blocking') as $name) {
+			foreach(array('title','location','public','non_blocking') as $name) {
 				if (isset($event[$name])) $query['cal_'.$name] = $event[$name];
 			}
 
@@ -1150,20 +1447,24 @@
 			{
 				$vfreebusy->setAttribute($attr, $value, $parameters[$name]);
 			}
-			foreach(parent::search(array(
-				'start' => $this->now_su,
-				'end'   => $end,
-				'users' => $user,
-				'date_format' => 'server',
-				'show_rejected' => false,
-			)) as $event)
+			$fbdata = parent::search(array(
+						'start' => $this->now_su,
+						'end'   => $end,
+						'users' => $user,
+						'date_format' => 'server',
+						'show_rejected' => false,
+					));
+			if (is_array($fbdata))
 			{
-				if ($event['non_blocking']) continue;
+				foreach ($fbdata as $event)
+				{
+					if ($event['non_blocking']) continue;
 
-				$vfreebusy->setAttribute('FREEBUSY',array(array(
-					'start' => $event['start'],
-					'end' => $event['end'],
-				)));
+					$vfreebusy->setAttribute('FREEBUSY',array(array(
+						'start' => $event['start'],
+						'end' => $event['end'],
+					)));
+				}
 			}
 			$vcal->addComponent($vfreebusy);
 
