@@ -9,7 +9,7 @@
 	*  Free Software Foundation; version 2 of the License.                     *
 	\**************************************************************************/
 
-	/* $Id: class.sifcalendar.inc.php 22839 2006-11-13 09:22:26Z lkneschke $ */
+	/* $Id: class.sifcalendar.inc.php 24605 2007-10-29 19:46:46Z ralfbecker $ */
 
 	require_once EGW_SERVER_ROOT.'/calendar/inc/class.bocalupdate.inc.php';
 	require_once EGW_SERVER_ROOT.'/phpgwapi/inc/horde/Horde/iCalendar.php';
@@ -71,9 +71,9 @@
 		}
 
 		function endElement($_parser, $_tag) {
-			#error_log($_tag .' => '. $this->sifData);
+			//error_log('endElem: ' . $_tag .' => '. trim($this->sifData));
 			if(!empty($this->sifMapping[$_tag])) {
-				$this->event[$this->sifMapping[$_tag]] = $this->sifData;
+				$this->event[$this->sifMapping[$_tag]] = trim($this->sifData);
 			}
 			unset($this->sifData);
 		}
@@ -117,7 +117,8 @@
 						if($value == 1) {
 							$startParts = explode('-',$this->event['start']);
 							$finalEvent['start'] = mktime(0, 0, 0, $startParts[1], $startParts[2], $startParts[0]);
-							$finalEvent['end'] = mktime(23, 59, 59, $startParts[1], $startParts[2], $startParts[0]);
+							$endParts = explode('-',$this->event['end']);
+							$finalEvent['end'] = mktime(23, 59, 59, $endParts[1], $endParts[2], $endParts[0]);
 						}
 						break;
 						
@@ -127,20 +128,7 @@
 						
 					case 'category':
 						if(!empty($value)) {
-							$isAdmin = $GLOBALS['egw']->acl->check('run',1,'admin');
-							$egwCategories =& CreateObject('phpgwapi.categories',$GLOBALS['egw_info']['user']['account_id'],'calendar');
-							$categories = explode('; ',$value);
-							$cat_id = '';
-							foreach($categories as $categorieName) {
-								$categorieName = trim($categorieName);
-								if(!($cat_id = $egwCategories->name2id($categorieName)) && $isAdmin) {
-									$cat_id = $egwCategories->add(array('name' => $categorieName, 'descr' => $categorieName));
-								}
-								if($cat_id) {
-									if(!empty($finalEvent[$key])) $finalEvent[$key] .= ',';
-									 $finalEvent[$key] .= $cat_id;
-								}
-							}
+							$finalEvent[$key] = implode(',',$this->find_or_add_categories(explode(';', $value)));
 						}
 						break;
 						
@@ -148,6 +136,7 @@
 					case 'start':
 						if($this->event['alldayevent'] < 1) {
 							$finalEvent[$key] = $vcal->_parseDateTime($value);
+							error_log("event ".$key." val=".$value.", parsed=".$finalEvent[$key]);
 						}
 						break;
 					
@@ -220,6 +209,27 @@
 				return false;
 			}
 
+			$query = array(
+				'cal_start='.$this->date2ts($event['start'],true),	// true = Server-time
+				'cal_end='.$this->date2ts($event['end'],true),
+			);
+			
+			#foreach(array('title','location','priority','public','non_blocking') as $name) {
+			foreach(array('title','location','public','non_blocking') as $name) {
+				if (isset($event[$name])) $query['cal_'.$name] = $event[$name];
+			}
+
+			if($foundEvents = parent::search(array(
+				'user'  => $this->user,
+				'query' => $query,
+			))) {
+				if(is_array($foundEvents)) {
+					$event = array_shift($foundEvents);
+					return $event['id'];
+				}
+			}
+			return false;
+
 			$search['start'] = $event['start'];
 			$search['end']	= $event['end'];
 
@@ -327,15 +337,8 @@
 					{
 						case 'Categories':
 							if(!empty($value)) {
-								$egwCategories =& CreateObject('phpgwapi.categories',$GLOBALS['egw_info']['user']['account_id'],'calendar');
-								$categories = explode(',',$value);
-								$value = '';
-								foreach($categories as $cat_id) {
-									if($catData = $egwCategories->return_single($cat_id)) {
-										if(!empty($value)) $value .= '; ';
-										$value .= $GLOBALS['egw']->translation->convert($catData[0]['name'], $sysCharSet, 'utf-8');
-									}
-								}
+								$value = implode('; ', $this->get_categories(explode(',',$value)));
+								$value = $GLOBALS['egw']->translation->convert($value, $sysCharSet, 'utf-8');
 							}
 							$sifEvent .= "<$sifField>$value</$sifField>";							
 							break;
