@@ -1,16 +1,14 @@
 <?php
-/**************************************************************************\
-* eGroupWare - Calendar's storage-object                                   *
-* http://www.egroupware.org                                                *
-* Written and (c) 2005 by Ralf Becker <RalfBecker@outdoor-training.de>     *
-* --------------------------------------------                             *
-*  This program is free software; you can redistribute it and/or modify it *
-*  under the terms of the GNU General Public License as published by the   *
-*  Free Software Foundation; either version 2 of the License, or (at your  *
-*  option) any later version.                                              *
-\**************************************************************************/
-
-/* $Id: class.socal.inc.php 21450 2006-04-25 15:59:19Z ralfbecker $ */
+/**
+ * eGroupWare - Calendar's storage-object
+ *
+ * @link http://www.egroupware.org
+ * @package calendar
+ * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2005-7 by RalfBecker-At-outdoor-training.de
+ * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+ * @version $Id: class.socal.inc.php 24806 2007-12-13 16:06:41Z ralfbecker $
+ */
 
 /**
  * some necessary defines used by the calendar
@@ -59,11 +57,6 @@ define('ACCEPTED',3);
  *  UI only operates in user-time, so there have to be no conversation at all !!!
  *  BO's functions take and return user-time only (!), they convert internaly everything to servertime, because
  *  SO operates only on server-time
- *
- * @package calendar
- * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
- * @copyright (c) 2005 by RalfBecker-At-outdoor-training.de
- * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  */
 class socal
 {
@@ -75,8 +68,16 @@ class socal
 
 	/**
 	 * internal copy of the global db-object
+	 * 
+	 * @var egw_db
 	 */
 	var $db;
+	/**
+	 * instance of the async object
+	 *
+	 * @var asyncservice
+	 */
+	var $async;
 
 	/**
 	 * Constructor of the socal class
@@ -169,13 +170,13 @@ class socal
 		}
 		else	// adjust the given recurance to the real time, it can be a date without time(!)
 		{
-			// check if the start read is the the first (default) entry of the recuring events, then it's recur_date is 0!!!
-			$this->db->select($this->dates_table,'MIN(cal_start) AS cal_start',array('cal_id' => $ids),__LINE__,__FILE__);
-			$first = $this->db->row(true);
-			$recur_date = $first['cal_start'] == $events[$ids]['start'] ? 0 : $events[$ids]['start'];
-
-			if ($recur_date) $events[$ids]['recur_date'] = $recur_date;	// remember it, maybe we need it later, duno now
+			if ($recur_date)
+			{
+				// also remember recur_date, maybe we need it later, duno now
+				$recur_date = $events[$ids]['recur_date'] = $events[$ids]['start'];
+			}
 		}
+
 		// participants, if a recur_date give, we read that recurance, else the one users from the default entry with recur_date=0
 		$this->db->select($this->user_table,'*',array(
 			'cal_id'      => $ids,
@@ -247,7 +248,7 @@ class socal
 			}
 			array_walk($cats,create_function('&$val,$key','$val = (int) $val;'));
 
-			$sql = '(cal_category'.(count($cats) > 1 ? ' IN ('.implode(',',$cats).')' : '='.$this->db->quote((int)$cat_id));
+			$sql = '(cal_category'.(count($cats) > 1 ? " IN ('".implode("','",$cats)."')" : '='.$this->db->quote((int)$cat_id));
 			foreach($cats as $cat)
 			{
 				$sql .= ' OR '.$this->db->concat("','",'cal_category',"','").' LIKE '.$this->db->quote('%,'.$cat.',%');
@@ -265,7 +266,7 @@ class socal
 	 * @param int/array $users user-id or array of user-id's, !$users means all entries regardless of users
 	 * @param int $cat_id=0 mixed category-id or array of cat-id's, default 0 = all
 	 *		Please note: only a single cat-id, will include all sub-cats (if the common-pref 'cats_no_subs' is False)
-	 * @param string $filter='' string space delimited filter-names, NOT used atm.
+	 * @param string $filter='' string filter-name, atm. all or hideprivate
 	 * @param string $query='' pattern so search for, if unset or empty all matching entries are returned (no search)
 	 *		Please Note: a search never returns repeating events more then once AND does not honor start+end date !!!
 	 * @param int/bool $offset=False offset for a limited query or False (default)
@@ -527,7 +528,7 @@ ORDER BY cal_user_type, cal_usre_id
 				return false;
 			}
 			// new event (without uid) or new created referencing event => create new uid
-			if (!$event['cal_uid'] || $event['cal_reference'] && strstr($event['cal_uid'],'cal-'.$event['calreference'].'-'))
+			if (!$event['cal_uid'] || $event['cal_reference'] && strpos($event['cal_uid'],'cal-'.$event['calreference'].'-') !== false)
 			{
 				$event['cal_uid'] = $GLOBALS['egw']->common->generate_uid('calendar',$cal_id);
 				$this->db->update($this->cal_table,array('cal_uid' => $event['cal_uid']),array('cal_id' => $cal_id),__LINE__,__FILE__);
@@ -811,13 +812,12 @@ ORDER BY cal_user_type, cal_usre_id
 				{
 					$this->db->insert($this->user_table,array(
 						'cal_status'	  => $status !== true ? $status{0} : 'U',
-						'cal_quantity'	=> substr($status,1) ? substr($status,1) : 1,
-						'cal_recur_date' => $recur_date,
-						),array(
-						'cal_id'	=> $cal_id,
+						'cal_quantity'	  => substr($status,1) ? substr($status,1) : 1,
+					),array(
+						'cal_id'	      => $cal_id,
+						'cal_recur_date'  => $recur_date,
 						'cal_user_type'   => $type,
 						'cal_user_id' 	  => $id,
-
 					),__LINE__,__FILE__);
 				}
 			}
@@ -829,7 +829,7 @@ ORDER BY cal_user_type, cal_usre_id
 	 * set the status of one participant for a given recurrence or for all recurrences since now (includes recur_date=0)
 	 *
 	 * @param int $cal_id
-	 * @param char $user_type 'u' regular user
+	 * @param char $user_type 'u' regular user, 'r' resource, 'c' contact
 	 * @param int $user_id
 	 * @param int/char $status numeric status (defines) or 1-char code: 'R', 'U', 'T' or 'A'
 	 * @param int $recur_date=0 date to change, or 0 = all since now
@@ -1094,6 +1094,23 @@ ORDER BY cal_user_type, cal_usre_id
 		else
 		{
 			$this->db->update($this->cal_table,array('cal_owner' => $new_user),array('cal_owner' => $old_user),__LINE__,__FILE__);
+			// delete participation of old user, if new user is already a participant
+			$this->db->select($this->user_table,'cal_id',array(		// MySQL does NOT allow to run this as delete!
+				'cal_user_type' => 'u',
+				'cal_user_id' => $old_user,
+				"cal_id IN (SELECT cal_id FROM $this->user_table other WHERE other.cal_id=cal_id AND other.cal_user_id=".(int)$new_user." AND cal_user_type='u')",
+			),__LINE__,__FILE__);
+			$ids = array();
+			while(($row = $this->db->row(true)))
+			{
+				$ids[] = $row['cal_id'];
+			}
+			if ($ids) $this->db->delete($this->user_table,array(
+				'cal_user_type' => 'u',
+				'cal_user_id' => $old_user,
+				'cal_id' => $ids,
+			),__LINE__,__FILE__);
+			// now change participant in the rest to contain new user instead of old user
 			$this->db->update($this->user_table,array('cal_user_id' => $new_user),array('cal_user_type' => 'u','cal_user_id' => $old_user),__LINE__,__FILE__);
 		}
 	}
