@@ -1,16 +1,14 @@
 <?php
-/**************************************************************************\
-* eGroupWare - Calendar - shared base-class of all calendar UI classes     *
-* http://www.egroupware.org                                                *
-* Written and (c) 2004/5 by Ralf Becker <RalfBecker@outdoor-training.de>   *
-* --------------------------------------------                             *
-*  This program is free software; you can redistribute it and/or modify it *
-*  under the terms of the GNU General Public License as published by the   *
-*  Free Software Foundation; either version 2 of the License, or (at your  *
-*  option) any later version.                                              *
-\**************************************************************************/
-
-/* $Id: class.uical.inc.php 21964 2006-06-24 17:34:38Z ralfbecker $ */
+/**
+ * eGroupWare - Calendar's shared base-class of all UI classes
+ *
+ * @link http://www.egroupware.org
+ * @package calendar
+ * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2004-8 by RalfBecker-At-outdoor-training.de
+ * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+ * @version $Id: class.uical.inc.php 25125 2008-03-20 09:03:32Z ralfbecker $
+ */
 
 /**
  * Shared base-class of all calendar UserInterface classes
@@ -23,11 +21,6 @@
  *  SO operates only on server-time
  *
  * All permanent debug messages of the calendar-code should done via the debug-message method of the bocal class !!!
- *
- * @package calendar
- * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
- * @copyright (c) 2004/5 by RalfBecker-At-outdoor-training.de
- * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  */
 class uical
 {
@@ -36,9 +29,41 @@ class uical
 	 */
 	var $debug=false;
 	/**
-	 * @var $bo class bocal
+	 * instance of the bocal or bocalupdate class
+	 * 
+	 * @var bocalupdate
 	 */
-	var $bo,$jscal,$html,$datetime,$cats,$accountsel;
+	var $bo;
+	/**
+	 * instance of jscalendar
+	 *
+	 * @var jscalendar
+	 */
+	var $jscal;
+	/**
+	 * Reference to global html class
+	 *
+	 * @var html
+	 */
+	var $html;
+	/**
+	 * Reference to global datetime class
+	 *
+	 * @var datetime
+	 */
+	var $datetime;
+	/**
+	 * Reference to global categories class
+	 *
+	 * @var categories
+	 */
+	var $cats;
+	/**
+	 * Reference to global uiaccountsel class
+	 *
+	 * @var uiaccountsel
+	 */
+	var $accountsel;
 	/**
 	 * @var array $common_prefs reference to $GLOBALS['egw_info']['user']['preferences']['common']
 	 */
@@ -72,7 +97,7 @@ class uical
 	 */
 	var $cat_id;
 	/**
-	 * @var int $filter session-state: selected filter, NOT used at the moment (was all or private)
+	 * @var int $filter session-state: selected filter, at the moment all or hideprivate
 	 */
 	var $filter;
 	/**
@@ -131,6 +156,8 @@ class uical
 		}
 		$this->common_prefs	= &$GLOBALS['egw_info']['user']['preferences']['common'];
 		$this->cal_prefs	= &$GLOBALS['egw_info']['user']['preferences']['calendar'];
+		$this->bo->check_set_default_prefs();
+
 		$this->wd_start		= 60*$this->cal_prefs['workdaystarts'];
 		$this->wd_end		= 60*$this->cal_prefs['workdayends'];
 		$this->interval_m	= $this->cal_prefs['interval'];
@@ -162,13 +189,13 @@ class uical
 				foreach($GLOBALS['egw']->accounts->member($owner) as $member)
 				{
 					$member = $member['account_id'];
-					if (!$this->bo->check_perms(EGW_ACL_READ,0,$member))
+					if (!$this->bo->check_perms(EGW_ACL_READ|EGW_ACL_READ_FOR_PARTICIPANTS,0,$member))
 					{
 						$no_access_group[$member] = $this->bo->participant_name($member);
 					} 
 				}
 			}
-			elseif (!$this->bo->check_perms(EGW_ACL_READ,0,$owner))
+			elseif (!$this->bo->check_perms(EGW_ACL_READ|EGW_ACL_READ_FOR_PARTICIPANTS,0,$owner))
 			{
 				$no_access[$owner] = $this->bo->participant_name($owner);
 			}
@@ -201,6 +228,7 @@ class uical
 	 */
 	function do_header()
 	{
+		$GLOBALS['egw_info']['flags']['include_xajax'] = true;
 		$GLOBALS['egw']->common->egw_header();
 		
 		if ($_GET['msg']) echo '<p class="redItalic" align="center">'.$this->html->htmlspecialchars($_GET['msg'])."</p>\n";
@@ -217,7 +245,7 @@ class uical
 	 *	- cat_id: the selected category
 	 *	- owner: the owner of the displayed calendar
 	 *	- save_owner: the overriden owner of the planner
-	 *	- filter: the used filter: no filter / all or only privat, NOT used atm.
+	 *	- filter: the used filter: all or hideprivate
 	 *	- sortby: category or user of planner
 	 *	- view: the actual view, where dialogs should return to or which they refresh
 	 * @param set_states array to manualy set / change one of the states, default NULL = use $_REQUEST
@@ -244,6 +272,7 @@ class uical
 			'sortby'     => 'category',
 			'planner_days'=> 0,	// full month
 			'view'       => $this->bo->cal_prefs['defaultcalendar'],
+			'listview_days'=> '',	// no range
 		) as $state => $default)
 		{
 			if (isset($set_states[$state]))
@@ -252,20 +281,27 @@ class uical
 				{
 					// only change the owners of the same resource-type as given in set_state[owner]
 					$set_owners = explode(',',$set_states['owner']);
-					$res_type = is_numeric($set_owners[0]) ? false : $set_owners[0]{0};
-					$owners = explode(',',$states['owner'] ? $states['owner'] : $default);
-					foreach($owners as $key => $owner)
+					if ((string)$set_owners[0] === '0')	// set exactly the specified owners (without the 0)
 					{
-						if (!$res_type && is_numeric($owner) || $res_type && $owner{0} == $res_type)
+						$set_states['owner'] = substr($set_states['owner'],2);
+					}
+					else	// change only the owners of the given type
+					{
+						$res_type = is_numeric($set_owners[0]) ? false : $set_owners[0]{0};
+						$owners = explode(',',$states['owner'] ? $states['owner'] : $default);
+						foreach($owners as $key => $owner)
 						{
-							unset($owners[$key]);
+							if (!$res_type && is_numeric($owner) || $res_type && $owner{0} == $res_type)
+							{
+								unset($owners[$key]);
+							}
 						}
+						if (!$res_type || !in_array($res_type.'0',$set_owners))
+						{
+							$owners = array_merge($owners,$set_owners);
+						}
+						$set_states['owner'] = implode(',',$owners);
 					}
-					if (!$res_type || !in_array($res_type.'0',$set_owners))
-					{
-						$owners = array_merge($owners,$set_owners);
-					}
-					$set_states['owner'] = implode(',',$owners);
 				}
 				// for the uiforms class (eg. edit), dont store the (new) owner, as it might change the view
 				if (substr($_GET['menuaction'],0,16) == 'calendar.uiforms')
@@ -330,7 +366,7 @@ class uical
 		}
 		$this->view_menuaction = $this->view == 'listview' ? 'calendar.uilist.listview' : 'calendar.uiviews.'.$this->view;
 
-		if ($this->debug > 0 || $this->debug == 'menage_states') $this->bo->debug_message('uical::manage_states(%1) session was %2, states now %3',True,$set_states,$states_session,$states);
+		if ($this->debug > 0 || $this->debug == 'manage_states') $this->bo->debug_message('uical::manage_states(%1) session was %2, states now %3',True,$set_states,$states_session,$states);
 		// save the states in the session
 		$GLOBALS['egw']->session->appsession('session_data','calendar',$states);
 	}
@@ -359,7 +395,7 @@ class uical
 			// icons for single user, multiple users or group(s) and resources
 			foreach($event['participants'] as  $uid => $status)
 			{
-				if(is_numeric($uid))
+				if(is_numeric($uid) || $uid{0} == 'c')
 				{
 					if (isset($icons['single']) || $GLOBALS['egw']->accounts->get_type($uid) == 'g')
 					{
@@ -403,7 +439,7 @@ class uical
 	{
 		if ($baseurl)	// we append the value to the baseurl
 		{
-			$baseurl .= strstr($baseurl,'?') === False ? '?' : '&';
+			$baseurl .= strpos($baseurl,'?') === False ? '?' : '&';
 			$onchange="location='$baseurl'+this.value;";
 		}
 		else			// we add $name=value to the actual location
@@ -531,6 +567,11 @@ class uical
 				'value' => 'menuaction=calendar.uiviews.week&days=5',
 				'selected' => $this->view == 'week' && $this->cal_prefs['days_in_weekview'] == 5,
 			),
+			array(
+				'text' => lang('Multiple week view'),
+				'value' => 'menuaction=calendar.uiviews.weekN',
+				'selected' => $this->view == 'weekN',
+			),
 			array(
 				'text' => lang('monthview'),
 				'value' => 'menuaction=calendar.uiviews.month',
@@ -577,19 +618,23 @@ class uical
 			'week'  => 'calendar.uiviews.week',
 			'month' => 'calendar.uiviews.month') as $view => $menuaction)
 		{
-			if ($this->view == 'planner')	
+			if ($this->view == 'planner' || $this->view == 'listview')	
 			{
 				switch($view)
 				{
-					case 'day':   $link_vars['planner_days'] = 1; break;
-					case 'week':  $link_vars['planner_days'] = $this->cal_prefs['days_in_weekview'] == 5 ? 5 : 7; break;
-					case 'month': $link_vars['planner_days'] = 0; break;
+					case 'day':   $link_vars[$this->view.'_days'] = $this->view == 'planner' ? 1 : ''; break;
+					case 'week':  $link_vars[$this->view.'_days'] = $this->cal_prefs['days_in_weekview'] == 5 ? 5 : 7; break;
+					case 'month': $link_vars[$this->view.'_days'] = 0; break;
 				}
 				$link_vars['menuaction'] = $this->view_menuaction;	// stay in the planner
 			}
-			elseif ($this->view == 'listview' || $view == 'day' && $this->view == 'day4')
+			elseif(substr($this->view,0,4) == 'week' && $view == 'week')
 			{
-				$link_vars['menuaction'] = $this->view_menuaction;	// stay in the listview
+				$link_vars['menuaction'] = $this->view_menuaction;	// stay in the N-week-view
+			}
+			elseif ($view == 'day' && $this->view == 'day4')
+			{
+				$link_vars['menuaction'] = $this->view_menuaction;	// stay in the day-view
 			}
 			else
 			{
@@ -607,22 +652,13 @@ class uical
 			'<option value="0">'.lang('All categories').'</option>'.
 		$this->cats->formatted_list('select','all',$this->cat_id,'True'));
 
-		// we need a form for the select-boxes => insert it in the first selectbox
-		$file[$n]['text'] = $this->html->form(False,$base_hidden_vars,'/index.php',array('menuaction' => $_GET['menuaction'])) .
-			$file[$n]['text'];
+		// Filter all or hideprivate
+		$file[] = $this->_select_box('Filter','filter',
+			'<option value="all"'.($this->filter=='all'?' selected="selected"':'').'>'.lang('No filter').'</option>'."\n".
+			'<option value="hideprivate"'.($this->filter=='hideprivate'?' selected="selected"':'').'>'.lang('Hide private infos').'</option>'."\n");
 
-		// Filter all or private
-/* 		NOT used at the moment
-		if(is_numeric($this->owner) && $this->bo->check_perms(EGW_ACL_PRIVATE,0,$this->owner))
-		{
-			$file[] = $this->_select_box('Filter','filter',
-				'<option value=" all "'.($this->filter==' all '?' selected="1"':'').'>'.lang('No filter').'</option>'."\n".
-				'<option value=" private "'.($this->filter==' private '?' selected="1"':'').'>'.lang('Private Only').'</option>'."\n");
-		}
-*/
 		// Calendarselection: User or Group
-		if(count($this->bo->grants) > 0 && (!isset($GLOBALS['egw_info']['server']['deny_user_grants_access']) ||
-			!$GLOBALS['egw_info']['server']['deny_user_grants_access']))
+		if(count($this->bo->grants) > 0 && $this->accountsel->account_selection != 'none')
 		{
 			$grants = array();
 			foreach($this->bo->list_cals() as $grant)
@@ -635,6 +671,7 @@ class uical
 			{
 				if (is_numeric($owner)) $accounts[] = $owner;
 			}
+			if (!$accounts) $grants[''] = lang('None');
 			$file[] = array(
 				'text' => "
 <script type=\"text/javascript\">
@@ -653,7 +690,7 @@ function load_cal(url,id) {
 </script>
 ".
 				$this->accountsel->selection('owner','uical_select_owner',$accounts,'calendar+',count($accounts) > 1 ? 4 : 1,False,
-					' style="width: '.(count($accounts) > 1 && $this->common_prefs['account_selection']=='selectbox' ? 185 : 165).'px;"'.
+					' style="width: '.(count($accounts) > 1 && in_array($this->common_prefs['account_selection'],array('selectbox','groupmembers')) ? '100%' : '165px').';"'.
 					' title="'.lang('select a %1',lang('user')).'" onchange="load_cal(\''.
 					$GLOBALS['egw']->link('/index.php',array(
 						'menuaction' => $this->view_menuaction,
@@ -695,19 +732,9 @@ function load_cal(url,id) {
 			);
 		}				
 */
-		// we need to set the sidebox-width a bit wider, as idots.css sets it to 147, to small for the jscal
-		// setting it to auto, uses the smallest possible size, but IE kills the jscal if the width is set to auto !!!
-		$width = 203;
-		echo '<style>
-.divSidebox
-{
-	width: '.($this->html->user_agent == 'msie' ? $width.'px' : 'auto; max-width: '.$width.'px;').';
-}
-</style>'."\n";
 		$appname = 'calendar';
 		$menu_title = lang('Calendar Menu');
 		display_sidebox($appname,$menu_title,$file);
-		echo "</form>\n";
 		
 		// resources menu hooks
  		foreach ($this->bo->resources as $resource)
