@@ -12,7 +12,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.uiholiday.inc.php 20562 2006-03-15 06:45:14Z ralfbecker $ */
+	/* $Id: class.uiholiday.inc.php 23796 2007-05-04 11:47:40Z lkneschke $ */
 
 	/**
 	 * User interface for calendar holidays
@@ -48,7 +48,7 @@
 			$this->bo->check_admin();
 			$this->base_url = $this->bo->base_url;
 			$this->template_dir = $GLOBALS['egw']->common->get_tpl_dir('calendar');
-			$this->sb =& CreateObject('phpgwapi.sbox');
+			$this->sb =& CreateObject('calendar.sbox');
 
 			// jscalendar is needed by the new navigation-menu AND it need to be loaded befor the header !!!
 			if (!is_object($GLOBALS['egw']->jscalendar))
@@ -267,9 +267,9 @@
 			{
 				$holiday = $this->bo->read_entry($this->bo->id);
 			}
-			if ($this->locale)
+			if ($this->bo->locale)
 			{
-				$holiday['locale'] = $this->locale;
+				$holiday['locale'] = $this->bo->locale;
 			}
 			unset($GLOBALS['egw_info']['flags']['noheader']);
 			unset($GLOBALS['egw_info']['flags']['nonavbar']);
