@@ -1,26 +1,31 @@
 <?php
-/**************************************************************************\
-* eGroupWare - Calendar - Views and Widgets                                *
-* http://www.egroupware.org                                                *
-* Written and (c) 2004/5 by Ralf Becker <RalfBecker@outdoor-training.de>   *
-* --------------------------------------------                             *
-*  This program is free software; you can redistribute it and/or modify it *
-*  under the terms of the GNU General Public License as published by the   *
-*  Free Software Foundation; either version 2 of the License, or (at your  *
-*  option) any later version.                                              *
-\**************************************************************************/
-
-/* $Id: class.uiviews.inc.php 23119 2006-12-25 12:58:03Z ralfbecker $ */
+/**
+ * eGroupWare - Calendar's views and widgets
+ *
+ * @link http://www.egroupware.org
+ * @package calendar
+ * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2004-8 by RalfBecker-At-outdoor-training.de
+ * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+ * @version $Id: class.uiviews.inc.php 25125 2008-03-20 09:03:32Z ralfbecker $
+ */
 
 include_once(EGW_INCLUDE_ROOT . '/calendar/inc/class.uical.inc.php');
+require_once(EGW_INCLUDE_ROOT . '/phpgwapi/inc/class.dragdrop.inc.php');
 
 /**
  * Class to generate the calendar views and the necesary widgets
+ * 
+ * The listview is in a separate class uilist!
  *
- * @package calendar
- * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
- * @copyright (c) 2004/5 by RalfBecker-At-outdoor-training.de
- * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+ * The new UI, BO and SO classes have a strikt definition, in which time-zone they operate:
+ *  UI only operates in user-time, so there have to be no conversation at all !!!
+ *  BO's functions take and return user-time only (!), they convert internaly everything to servertime, because
+ *  SO operates only on server-time
+ *
+ * The state of the UI elements is managed in the uical class, which all UI classes extend.
+ *
+ * All permanent debug messages of the calendar-code should done via the debug-message method of the bocal class !!!
  */
 class uiviews extends uical
 {
@@ -28,6 +33,7 @@ class uiviews extends uical
 		'day'   => True,
 		'day4'  => True,
 		'week'  => True,
+		'weekN' => True,
 		'month' => True,
 		'planner' => True,
 	);
@@ -35,60 +41,81 @@ class uiviews extends uical
 	/**
 	 * integer level or string function- or widget-name
 	 * 
-	 * @var mixed $debug 
+	 * @var mixed
 	 */
 	var $debug=false;
 
 	/**
 	 * minimum width for an event
 	 * 
-	 * @var int $eventCol_min_width
+	 * @var int
 	 */
 	var $eventCol_min_width = 80;
 	
 	/**
 	 * extra rows above and below the workday
 	 * 
-	 * @var int $extraRows 
+	 * @var int
 	 */
-	var $extraRows = 1;
+	var $extraRows = 2;
+
+	/**
+	 * extra rows original (save original value even if it gets changed in the class)
+	 * 
+	 * @var int
+	 */
+	var $extraRowsOriginal;
 
 	var $timeRow_width = 40;
 
 	/**
 	 * how many rows per day get displayed, gets set be the timeGridWidget
 	 * 
-	 * @var int $rowsToDisplay 
+	 * @var int
 	 */
 	var $rowsToDisplay;
 
 	/**
 	 * height in percent of one row, gets set be the timeGridWidget
 	 * 
-	 * @var int $rowHeight
+	 * @var int
 	 */
 	var $rowHeight;
 	
 	/**
 	 * standard params for calling bocal::search for all views, set by the constructor
 	 * 
-	 * @var array $search_params
+	 * @var array
 	 */
 	var $search_params;
 	
 	/**
 	 * should we use a time grid, can be set for week- and month-view to false by the cal_pref no_time_grid
 	 * 
-	 * @var boolean $use_time_grid=true 
+	 * @var boolean
 	 */
 	var $use_time_grid=true;
 	
+	/**
+	 * Dragdrop Object
+	 *
+	 * @var dragdrop;
+	 */
+	var $dragdrop;
+ 
 	/**
 	 * Can we display the whole day in a timeGrid of the size of the workday and just scroll to workday start
 	 *
-	 * @var boolean $scroll_to_wdstart;
+	 * @var boolean
 	 */
 	var $scroll_to_wdstart=false;
+	
+	/**
+	 * counter for the current whole day event of a single day
+	 *
+	 * @var int
+	 */
+	var $wholeDayPosCounter=1;
 
 	/**
 	 * Constructor
@@ -98,6 +125,7 @@ class uiviews extends uical
 	function uiviews($set_states=null)
 	{
 		$this->uical(false,$set_states);	// call the parent's constructor
+		$this->extraRowsOriginal = $this->extraRows; //save original extraRows value
 
 		$GLOBALS['egw_info']['flags']['nonavbar'] = False;
 		$app_header = array(
@@ -123,6 +151,14 @@ class uiviews extends uical
 		$this->holidays = $this->bo->read_holidays($this->year);
 		
 		$this->check_owners_access();
+
+		if($GLOBALS['egw_info']['user']['preferences']['common']['enable_dragdrop'])
+		{
+			$this->dragdrop = new dragdrop();
+			// if the object would auto-disable itself unset object
+			// to avoid unneccesary dragdrop calls later
+			if(!$this->dragdrop->validateBrowser()) { $this->dragdrop = false; }
+		}
 	}
 	
 	/**
@@ -249,23 +285,35 @@ class uiviews extends uical
 		}
 		return $content;
 	}
+	
+	/**
+	 * Displays a multiple week-view
+	 *
+	 * @param boolean $home=false if true return content suitable for home-page
+	 */
+	function &weekN($home=false)
+	{
+		if (($num = (int)$this->cal_prefs['multiple_weeks']) < 2) $num = 3;	// default 3 weeks
+
+		return $this->month($num,$home);
+	}
 
 	/**
 	 * Displays the monthview or a multiple week-view
 	 *
-	 * @param int $weeks=0 number of weeks to show, if 0 (default) all weeks of one month are shows
+	 * @param int $weeks=0 number of weeks to show, if 0 (default) all weeks of one month are shown
 	 * @param boolean $home=false if true return content suitable for home-page
 	 */
 	function &month($weeks=0,$home=false)
 	{
 		if ($this->debug > 0) $this->bo->debug_message('uiviews::month(weeks=%1) date=%2',True,$weeks,$this->date);
 
-		$this->use_time_grid = $this->cal_prefs['use_time_grid'] == '';	// all views
+		$this->use_time_grid = !$this->cal_prefs['use_time_grid'] || $this->cal_prefs['use_time_grid'] == 'all';	// all views
 
 		if ($weeks)
 		{
-			$this->first = $this->datetime->get_weekday_start($this->year,$this->month,$this->day=1);
-			$this->last = $this->first + $weeks * 7 * DAY_s - 1;
+			$this->first = $this->datetime->get_weekday_start($this->year,$this->month,$this->day);
+			$this->last = strtotime("+$weeks weeks",$this->first) - 1;
 		}
 		else
 		{
@@ -282,12 +330,12 @@ class uiviews extends uical
 
 		$content = '';
 		// we add DAY_s/2 to $this->first (using 12h), to deal with daylight saving changes
-		for ($week_start = $this->first+DAY_s/2; $week_start < $this->last; $week_start += WEEK_s)
+		for ($week_start = $this->first; $week_start < $this->last; $week_start = strtotime("+1 week",$week_start))
 		{
 			$week = array();
 			for ($i = 0; $i < 7; ++$i)
 			{
-				$day_ymd = $this->bo->date2string($week_start+$i*DAY_s);
+				$day_ymd = $this->bo->date2string($i ? strtotime("+$i days",$week_start) : $week_start);
 				$week[$day_ymd] = array_shift($days);
 			}
 			$week_view = array(
@@ -297,7 +345,7 @@ class uiviews extends uical
 			$title = lang('Wk').' '.adodb_date('W',$week_start);
 			$title = $this->html->a_href($title,$week_view,'',' title="'.lang('Weekview').'"');
 
-			$content .= $this->timeGridWidget($week,60,200,'',$title,0,$week_start+WEEK_s >= $this->last);
+			$content .= $this->timeGridWidget($this->tagWholeDayOnTop($week),$weeks == 2 ? 30 : 60,200,'',$title,0,$week_start+WEEK_s >= $this->last);
 		}
 		if (!$home)
 		{
@@ -305,6 +353,10 @@ class uiviews extends uical
 		
 			echo $content;
 		}
+
+		// make wz_dragdrop elements work
+		if(is_object($this->dragdrop)) { $this->dragdrop->setJSCode(); }
+
 		return $content;
 	}
 
@@ -375,7 +427,7 @@ class uiviews extends uical
 		if ($days == 4)		// next 4 days view
 		{
 			$wd_start = $this->first = $this->bo->date2ts($this->date);
-			$this->last = $this->first + $days * DAY_s - 1;
+			$this->last = strtotime("+$days days",$this->first) - 1;
 			$GLOBALS['egw_info']['flags']['app_header'] .= ': '.lang('Four days view').' '.$this->bo->long_date($this->first,$this->last);
 		}
 		else
@@ -386,16 +438,32 @@ class uiviews extends uical
 				switch($this->cal_prefs['weekdaystarts'])
 				{
 					case 'Saturday':
-						$this->first += DAY_s;
-						// fall through
+						$this->first = strtotime("+2 days",$this->first);
+						break;
 					case 'Sunday':
-						$this->first += DAY_s;
+						$this->first = strtotime("+1 day",$this->first);
 						break;
 				}
 			}
-			$this->last = $this->first + $days * DAY_s - 1;
+			$this->last = strtotime("+$days days",$this->first) - 1; 
 			$GLOBALS['egw_info']['flags']['app_header'] .= ': '.lang('Week').' '.adodb_date('W',$this->first).': '.$this->bo->long_date($this->first,$this->last);
 		}
+
+        #	temporarly disabled, because it collides with the title for the website
+        #
+	#	// add navigation for previous and next
+	#	// prev. week
+	#	$GLOBALS['egw_info']['flags']['app_header'] = $this->html->a_href($this->html->image('phpgwpai','first',lang('previous'),$options=' alt="<<"'),array(
+	#		'menuaction' => $this->view_menuaction,
+	#		'date'       => date('Ymd',$this->first-$days*DAY_s),
+	#		)) . ' &nbsp; <b>'.$GLOBALS['egw_info']['flags']['app_header'];
+	#	// next week
+	#	$GLOBALS['egw_info']['flags']['app_header'] .= '</b> &nbsp; '.$this->html->a_href($this->html->image('phpgwpai','last',lang('next'),$options=' alt=">>"'),array(
+	#		'menuaction' => $this->view_menuaction,
+	#		'date'       => date('Ymd',$this->last+$days*DAY_s),
+	#		));
+	#
+	#		$class = $class == 'row_on' ? 'th' : 'row_on';
 		//echo "<p>weekdaystarts='".$this->cal_prefs['weekdaystarts']."', get_weekday_start($this->year,$this->month,$this->day)=".date('l Y-m-d',$wd_start).", first=".date('l Y-m-d',$this->first)."</p>\n";
 
 		$search_params = array(
@@ -406,9 +474,9 @@ class uiviews extends uical
 		$users = $this->search_params['users'];
 		if (!is_array($users)) $users = array($users);
 		
-		if (count($users) == 1 || count($users) > 3)	// for more then 3 users, show all in one row
+		if (count($users) == 1 || count($users) > 5)	// for more then 3 users, show all in one row
 		{
-			$content =& $this->timeGridWidget($this->bo->search($search_params),$this->cal_prefs['interval']);
+			$content =& $this->timeGridWidget($this->tagWholeDayOnTop($this->bo->search($search_params)),$this->cal_prefs['interval']);
 		}
 		else
 		{
@@ -417,7 +485,7 @@ class uiviews extends uical
 			{
 				$search_params['users'] = $uid;
 				$content .= '<b>'.$label."</b>\n";
-				$content .= $this->timeGridWidget($this->bo->search($search_params),
+				$content .= $this->timeGridWidget($this->tagWholeDayOnTop($this->bo->search($search_params)),
 					count($users) * $this->cal_prefs['interval'],400 / count($users),'','',$uid);
 			}
 		}		
@@ -427,6 +495,10 @@ class uiviews extends uical
 			
 			echo $content;
 		}
+
+		// make wz_dragdrop elements work
+		if(is_object($this->dragdrop)) { $this->dragdrop->setJSCode(); }
+
 		return $content;
 	}
 
@@ -471,7 +543,7 @@ class uiviews extends uical
 				}
 			}
 			$cols = array();
-			$cols[0] =& $this->timeGridWidget($dayEvents,$this->cal_prefs['interval'],450,'','',$owner);
+			$cols[0] =& $this->timeGridWidget($this->tagWholeDayOnTop($dayEvents),$this->cal_prefs['interval'],450,'','',$owner);
 
 			// only show todo's for a single user
 			if (count($users) == 1 && ($todos = $this->get_todos($todo_label)) !== false)
@@ -499,10 +571,17 @@ class uiviews extends uical
 			{
 				echo $cols[0];
 			}
+			// make wz_dragdrop elements work
+			if(is_object($this->dragdrop)) { $this->dragdrop->setJSCode(); }
 		}
 		else
 		{
-			return $this->timeGridWidget($this->bo->search($this->search_params),$this->cal_prefs['interval'],300);
+			$content = $this->timeGridWidget($this->bo->search($this->search_params),$this->cal_prefs['interval'],300);
+			
+			// make wz_dragdrop elements work
+			if(is_object($this->dragdrop)) { $this->dragdrop->setJSCode(); }
+
+			return $content;
 		}
 	}
 
@@ -597,7 +676,7 @@ class uiviews extends uical
 		// time before workday => condensed in the first $this->extraRows rows
 		if ($this->wd_start > 0 && $time < $this->wd_start)
 		{
-			$pos = (1 + $this->extraRows * $time / $this->wd_start) * $this->rowHeight;	// 1 for the header
+			$pos = (($this->extraRows - $this->extraRowsOriginal + 1) + ($time / $this->wd_start * ($this->extraRowsOriginal - 1))) * $this->rowHeight;
 		}
 		// time after workday => condensed in the last row
 		elseif ($this->wd_end < 24*60 && $time > $this->wd_end+1*$this->granularity_m)
@@ -748,6 +827,7 @@ class uiviews extends uical
 			$n = 0;
 			foreach($daysEvents as $day => $events)
 			{
+				$this->wholeDayPosCounter=1;
 				$short_title = count($daysEvents) > 1;
 				$col_owner = $owner;
 				if (!is_numeric($day))
@@ -775,6 +855,7 @@ class uiviews extends uical
 			}
 			$html .= "</script>\n";
 		}
+
 		return $html;
 	}
 
@@ -821,7 +902,7 @@ class uiviews extends uical
 				$event['end_m'] = 24*60-1;
 				$event['multiday'] = True;
 			}
-			if ($this->use_time_grid)
+			if ($this->use_time_grid && !$event['whole_day_on_top'])
 			{
 				for($c = 0; $event['start_m'] < $col_ends[$c]; ++$c);
 				$col_ends[$c] = $event['end_m'];
@@ -840,10 +921,15 @@ class uiviews extends uical
 		$ts = $this->bo->date2ts((string)$day_ymd);
 		$title = !is_bool($short_title) ? $short_title :
 			($short_title ? lang(adodb_date('l',$ts)).' '.adodb_date('d.',$ts) : $this->bo->long_date($ts,0,false,true));
+		
 		$day_view = array(
 			'menuaction' => 'calendar.uiviews.day',
 			'date' => $day_ymd,
 		);
+		$this->_day_class_holiday($day_ymd,$class,$holidays);
+		// the weekday and date
+		if (!$short_title && $holidays) $title .= ': '.$holidays;
+
 		if ($short_title === true)
 		{
 			$title = $this->html->a_href($title,$day_view,'',
@@ -857,13 +943,23 @@ class uiviews extends uical
 			$day_view['date'] = $this->bo->date2string($ts += 48*HOUR_s);
 			$title .= ' &nbsp; '.$this->html->a_href($this->html->image('phpgwapi','right',$this->bo->long_date($ts)),$day_view);
 		}
-		$this->_day_class_holiday($day_ymd,$class,$holidays);
-		// the weekday and date
 		$html .= $indent."\t".'<div style="height: '. $this->rowHeight .'%;" class="calDayColHeader '.$class.'"'.($holidays ? ' title="'.$holidays.'"':'').'>'.
-			$title.(!$short_title && $holidays ? ': '.$holidays : '')."</div>\n";
+			$title."</div>\n";
 
 		if ($this->use_time_grid)
 		{
+			// drag and drop: check if the current user has EDIT permissions on the grid
+			if(is_object($this->dragdrop))
+			{
+				if($owner)
+				{
+					$dropPermission = $this->bo->check_perms(EGW_ACL_EDIT,0,$owner);
+				}
+				else
+				{
+					$dropPermission = true;
+				}
+			}
 			// adding divs to click on for each row / time-span
 			for($t = $this->scroll_to_wdstart ? 0 : $this->wd_start,$i = 1+$this->extraRows;
 				$t <= $this->wd_end || $this->scroll_to_wdstart && $t < 24*60;
@@ -872,20 +968,35 @@ class uiviews extends uical
 				$linkData = array(
 					'menuaction'	=>'calendar.uiforms.edit',
 					'date'		=> $day_ymd,
-					'hour'		=> floor($t / 60),
-					'minute'	=> floor($t % 60),
+					'hour'		=> sprintf("%02d",floor($t / 60)),
+					'minute'	=> sprintf("%02d",floor($t % 60)),
 				);
 				if ($owner) $linkData['owner'] = $owner;
+
+				$droppableDateTime = $linkData['date'] . "T" . $linkData['hour'] . $linkData['minute'];
+				$droppableID='drop_'.$droppableDateTime.'_O'.$owner;
 				
-				$html .= $indent."\t".'<div style="height:'. $this->rowHeight .'%; top: '. $i*$this->rowHeight .
+				$html .= $indent."\t".'<div id="' . $droppableID . '" style="height:'. $this->rowHeight .'%; top: '. $i*$this->rowHeight .
 					'%;" class="calAddEvent" onclick="'.$this->popup($GLOBALS['egw']->link('/index.php',$linkData)).';return false;"></div>'."\n";
+				
+				if(is_object($this->dragdrop) && $dropPermission)
+				{
+					$this->dragdrop->addDroppable(
+						$droppableID,
+						array(
+							'datetime'=>$droppableDateTime,
+							'owner'=>$owner ? $owner : $this->user,
+						)
+					);
+				}
 			}
 		}
 		// displaying all event columns of the day
 		foreach($eventCols as $n => $eventCol)
 		{
 			$html .= $this->eventColWidget($eventCol,!$n ? 0 : 60-10*(count($eventCols)-$n),
-				count($eventCols) == 1 ? 100 : (!$n ? 80 : 50),$indent."\t");
+				count($eventCols) == 1 ? 100 : (!$n ? 80 : 50),$indent."\t",
+				$owner ? $owner : $this->user);
 		}
 		$html .= $indent."</div>\n";	// calDayCol
 
@@ -952,8 +1063,9 @@ class uiviews extends uical
 	 * @param int $left start of the widget
 	 * @param int $width width of the widget
 	 * @param string $indent string for correct indention
+	 * @param int $owner owner of the eventCol
 	 */
-	function eventColWidget($events,$left,$width,$indent)
+	function eventColWidget($events,$left,$width,$indent,$owner)
 	{
 		if ($this->debug > 1 || $this->debug==='eventColWidget') $this->bo->debug_message('uiviews::eventColWidget(%1,left=%2,width=%3,)',False,$events,$left,$width);
 
@@ -961,7 +1073,7 @@ class uiviews extends uical
 			(!$this->use_time_grid ? ' top: '.$this->rowHeight.'%;' : '').'">'."\n";
 		foreach($events as $event)
 		{
-			$html .= $this->eventWidget($event,$width,$indent."\t");
+			$html .= $this->eventWidget($event,$width,$indent."\t",$owner);
 		}
 		$html .= $indent."</div>\n";
 
@@ -976,14 +1088,17 @@ class uiviews extends uical
 	 * @param $event array with the data of event to show
 	 * @param $width int width of the widget
 	 * @param string $indent string for correct indention
+	 * @param int $owner owner of the calendar the event is in
 	 * @param boolean $return_array=false should an array with keys(tooltip,popup,html) be returned or the complete widget as string
 	 * @param string $block='event_widget' template used the render the widget
 	 * @return string/array 
 	 */
-	function eventWidget($event,$width,$indent,$return_array=false,$block='event_widget')
+	function eventWidget($event,$width,$indent,$owner,$return_array=false,$block='event_widget')
 	{
 		if ($this->debug > 1 || $this->debug==='eventWidget') $this->bo->debug_message('uiviews::eventWidget(%1,width=%2)',False,$event,$width);
 
+		if($this->use_time_grid && $event['whole_day_on_top']) { $block='event_widget_wholeday_on_top'; }
+
 		static $tpl = False;
 		if (!$tpl)
 		{
@@ -991,6 +1106,7 @@ class uiviews extends uical
 			$tpl->set_root($GLOBALS['egw']->common->get_tpl_dir('calendar'));
 			$tpl->set_file('event_widget_t','event_widget.tpl');
 			$tpl->set_block('event_widget_t','event_widget');
+			$tpl->set_block('event_widget_t','event_widget_wholeday_on_top');
 			$tpl->set_block('event_widget_t','event_tooltip');
 			$tpl->set_block('event_widget_t','planner_event');
 		}
@@ -1041,7 +1157,7 @@ class uiviews extends uical
 		}
 		foreach($part_array as $part_group => $participant)
 		{
-			$participants .= $this->add_nonempty($participant,$part_group,True);
+			$participants .= $this->add_nonempty($participant,$part_group,True,False);
 		}
 		// as we only deal with percentual widht, we consider only the full dayview (1 colum) as NOT small
 		$small = $this->view != 'day' || $width < 50;
@@ -1052,6 +1168,7 @@ class uiviews extends uical
 
 		$tpl->set_var(array(
 			// event-content, some of it displays only if it really has content or is needed
+			'owner' => $GLOBALS['egw']->common->grab_owner_name($event['owner']),
 			'header_icons' => $small ? '' : implode("",$icons),
 			'body_icons' => $small ? implode("\n",$icons) : '',
 			'icons' => implode('',$icons),
@@ -1104,7 +1221,7 @@ class uiviews extends uical
 		$tpl->set_var('tooltip',$this->html->tooltip($tooltip,False,array('BorderWidth'=>0,'Padding'=>0)));
 		$html = $tpl->fp('out',$block);
 
-		$view_link = $GLOBALS['egw']->link('/index.php',array('menuaction'=>'calendar.uiforms.view','cal_id'=>$event['id'],'date'=>$this->bo->date2string($event['start'])));
+		$view_link = $GLOBALS['egw']->link('/index.php',array('menuaction'=>'calendar.uiforms.edit','cal_id'=>$event['id'],'date'=>$this->bo->date2string($event['start'])));
 		$popup = $is_private ? '' : ' onclick="'.$this->popup($view_link).'; return false;"';
 		
 		if ($return_array)
@@ -1126,23 +1243,69 @@ class uiviews extends uical
         }
 		if ($this->use_time_grid)
 		{
-			$style = 'top: '.$this->time2pos($event['start_m']).'%; height: '.$height.'%;';
+			if($event['whole_day_on_top'])
+			{
+					$style = 'top: '.($this->rowHeight*$this->wholeDayPosCounter).'%; height: '.$this->rowHeight.'%;';
+					$this->wholeDayPosCounter++;
+			}
+			else
+			{
+					$style = 'top: '.$this->time2pos($event['start_m']).'%; height: '.$height.'%;';
+			}
 		}
 		else
 		{
 			$style = 'position: relative; margin-top: 3px;';
 		}
-		return $indent.'<div class="calEvent'.($is_private ? 'Private' : '').
-			'" style="'.$style.' border-color: '.$headerbgcolor.'; background: '.$background.';"'.
+
+		$draggableID = 'drag_'.$event['id'].'_O'.$event['owner'].'_C'.$owner;
+
+		$html = $indent.'<div id="'.$draggableID.'" class="calEvent'.($is_private ? 'Private' : '').
+			'" style="'.$style.' border-color: '.$headerbgcolor.'; background: '.$background.'; z-index: 20;"'.
 			$popup.' '.$this->html->tooltip($tooltip,False,array('BorderWidth'=>0,'Padding'=>0)).
-			'>'."\n".$ie_fix.$html.$indent."</div>\n";
+			'>'."\n".$ie_fix.$html."\n".
+			$indent."</div>"."\n";
+
+		// ATM we do not support whole day events or recurring events for dragdrop
+		if (	is_object($this->dragdrop) &&
+			$this->use_time_grid &&
+			$this->bo->check_perms(EGW_ACL_EDIT,$event) &&
+			!$event['whole_day_on_top'] &&
+			!$event['whole_day'] &&
+			!$event['recur_type']
+		)
+		{
+			// register event as draggable
+			$this->dragdrop->addDraggable(
+					$draggableID,
+					array(
+						'eventId'=>$event['id'],
+						'eventOwner'=>$event['owner'],
+						'calendarOwner'=>$owner,
+						'errorImage'=>addslashes($this->html->image('phpgwapi','dialog_error',false,'style="width: 16px;"')),
+						'loaderImage'=>addslashes($this->html->image('phpgwapi','ajax-loader')),
+					),
+					'calendar.dragDropFunctions.dragEvent',
+					'calendar.dragDropFunctions.dropEvent',
+					'top center 2'
+			);
+		}
+
+		return $html;
 	}
 
-	function add_nonempty($content,$label,$one_per_line=False)
+	function add_nonempty($content,$label,$one_per_line=False,$space = True)
 	{
 		if (is_array($content))
 		{
-			$content = implode($one_per_line ? ",\n" : ', ',$content);
+		   if($space)
+		   {
+			  $content = implode($one_per_line ? ",\n" : ', ',$content);
+		   }
+		   else
+		   {
+			  $content = implode($one_per_line ? "\n" : ', ',$content);
+		   }
 		}
 		if (!empty($content))
 		{
@@ -1235,6 +1398,8 @@ class uiviews extends uical
 		{
 			$sort2label = $this->_get_planner_users();
 		}
+		if (!is_array($events)) $events = array();
+
 		foreach($events as $key => $event)
 		{
 			if ($by_cat === false)	// planner by user
@@ -1261,8 +1426,12 @@ class uiviews extends uical
 		// display a plannerRowWidget for each row (user or category)
 		foreach($sort2label as $sort => $label)
 		{
-			if (!isset($rows[$sort])) continue;		// dont show empty categories (user-rows get all initialised
-
+			if (!isset($rows[$sort]) && (!$this->cal_prefs['planner_show_empty_rows'] ||
+				$by_cat === false && $this->cal_prefs['planner_show_empty_rows'] == 'cat' ||
+				$by_cat !== false && $this->cal_prefs['planner_show_empty_rows'] == 'user'))
+			{
+				continue;		// dont show empty categories or user rows
+			}
 			$class = $class == 'row_on' ? 'row_off' : 'row_on';
 			$content .= $this->plannerRowWidget(isset($rows[$sort]) ? $rows[$sort] : array(),$start,$end,$label,$class,$indent."\t");
 		}
@@ -1524,7 +1693,7 @@ class uiviews extends uical
 					'menuaction'   => 'calendar.uiviews.planner',
 					'planner_days' => 1,
 					'date'         => date('Ymd',$t),
-				),false,strstr($class,'calHoliday') || strstr($class,'calBirthday') ? '' : ' title="'.$this->html->htmlspecialchars(lang('Dayview')).'"');
+				),false,strpos($class,'calHoliday') !== false || strpos($class,'calBirthday') !== false ? '' : ' title="'.$this->html->htmlspecialchars(lang('Dayview')).'"');
 			}
 			if ($days < 5)
 			{
@@ -1693,7 +1862,9 @@ class uiviews extends uical
 				}
 				else
 				{
-					$day_percentage = ($time_of_day-$this->wd_start) / ($this->wd_end - $this->wd_start);		// between 0 and 1
+					$wd_lenght = $this->wd_end - $this->wd_start;
+					if ($wd_lenght <= 0) $wd_lenght = 24*60;
+					$day_percentage = ($time_of_day-$this->wd_start) / $wd_lenght;		// between 0 and 1
 				}
 				$days = ($end - $start) / DAY_s;
 				$percent += $day_percentage / $days;
@@ -1720,9 +1891,10 @@ class uiviews extends uical
 		$event['start_m'] = ($event['start'] - $day_start) / 60;
 		$event['end_m'] = round(($event['end'] - $day_start) / 60);
 		$event['multiday'] = true;
+		unset($event['whole_day_on_top']);
+
+		$data = $this->eventWidget($event,200,$indent,$this->owner,true,'planner_event');
 
-		$data = $this->eventWidget($event,200,$indent,true,'planner_event');
-		
 		$left = $this->_planner_pos($event['start'],$start,$end);
 		$width = $this->_planner_pos($event['end'],$start,$end) - $left;
 		$color = $data['color'] ? $data['color'] : 'gray';
@@ -1731,4 +1903,43 @@ class uiviews extends uical
 			'%; width: '.$width.'%; background-color: '.$color.';"'.$data['popup'].' '.
 			$this->html->tooltip($data['tooltip'],False,array('BorderWidth'=>0,'Padding'=>0)).'>'."\n".$data['html'].$indent."</div>\n";
 	}
+
+	/**
+	 * Marks whole day events for later usage and increments extraRows
+	 *
+	 * @param array $dayEvents
+	 * @return array $dayEvents
+	 */
+	function tagWholeDayOnTop($dayEvents)
+	{
+		$this->extraRows = $this->extraRowsOriginal;
+		foreach ($dayEvents as $day=>$oneDayEvents)
+		{
+		  $extraRowsToAdd = 0;
+			foreach ($oneDayEvents as $num=>$event)
+			{
+				$start = $this->bo->date2array($event['start']);
+				$end = $this->bo->date2array($event['end']);
+				if(!$start['hour'] && !$start['minute'] && $end['hour'] == 23 && $end['minute'] == 59)
+				{
+					if($event['non_blocking'])
+					{
+						$dayEvents[$day][$num]['whole_day_on_top']=true;
+						$this->whole_day_positions[$num]=($this->rowHeight*($num+2));
+						$extraRowsToAdd++;
+					}
+					else
+					{
+						$dayEvents[$day][$num]['whole_day']=true;
+					}
+				}
+			}
+			// check after every day if we have to increase $this->extraRows
+			if(($this->extraRowsOriginal+$extraRowsToAdd) > $this->extraRows) { $this->extraRows = ($this->extraRowsOriginal+$extraRowsToAdd); }
+			}
+				
+		return $dayEvents;
+ 	}
+
+
 }
