@@ -1,19 +1,16 @@
 <?php
-	/**************************************************************************\
-	* eGroupWare - Calendar Preferences                                        *
-	* http://www.egroupware.org                                                *
-	* Based on Webcalendar by Craig Knudsen <cknudsen@radix.net>               *
-	*          http://www.radix.net/~cknudsen                                  *
-	* Modified by Mark Peters <skeeter@phpgroupware.org>                       *
-	* Modified by Ralf Becker <ralfbecker@outdoor-training.de>                 *
-	* --------------------------------------------                             *
-	*  This program is free software; you can redistribute it and/or modify it *
-	*  under the terms of the GNU General Public License as published by the   *
-	*  Free Software Foundation; either version 2 of the License, or (at your  *
-	*  option) any later version.                                              *
-	\**************************************************************************/
-
-	/* $Id: hook_settings.inc.php 22347 2006-08-25 08:23:27Z ralfbecker $ */
+/**
+ * eGroupWare - Calendar Preferences
+ *
+ * @link http://www.egroupware.org
+ * @package calendar
+ * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @author Mark Peters <skeeter@phpgroupware.org> 
+ *	Originally based on Webcalendar by Craig Knudsen <cknudsen@radix.net>
+ *	http://www.radix.net/~cknudsen
+ * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+ * @version $Id: hook_settings.inc.php 25125 2008-03-20 09:03:32Z ralfbecker $
+ */
 
 	$bocal =& CreateObject('calendar.bocal');
 	$bocal->check_set_default_prefs();
@@ -22,13 +19,14 @@
 		'day'          => lang('Dayview'),
 		'day4'         => lang('Four days view'),
 		'week'         => lang('Weekview'),
+		'weekN'        => lang('Multiple week view'),
 		'month'        => lang('Monthview'),
 		'planner_cat'  => lang('Planner by category'),
 		'planner_user' => lang('Planner by user'),
 		'listview'     => lang('Listview'),
 	);
 	$grid_views = array(
-		'' => lang('all'),
+		'all' => lang('all'),
 		'day_week' => lang('Dayview').', '.lang('Four days view').' &amp; '.lang('Weekview'),
 		'day4' => lang('Dayview').' &amp; '.lang('Four days view'),
 		'day' => lang('Dayview'),
@@ -94,6 +92,11 @@
 	{
 		$times[$i] = $GLOBALS['egw']->common->formattime($i,'00');
 	}
+	
+	for ($i = 2; $i <= 9; ++$i)
+	{
+		$muliple_weeks[$i.' weeks'] = lang('%1 weeks',$i);
+	}
 
 	$intervals = array(
 		5	=> '5',
@@ -144,6 +147,15 @@
 			'xmlrpc' => True,
 			'admin'  => False
 		),
+		'multiple_weeks' => array(
+			'type'   => 'select',
+			'label'  => 'Weeks in multiple week view',
+			'name'   => 'multiple_weeks',
+			'values' => $muliple_weeks,
+			'help'   => 'How many weeks should the multiple week view show?',
+			'xmlrpc' => True,
+			'admin'  => False
+		),
 		'mainscreen_showevents' => array(
 			'type'   => 'select',
 			'label'  => 'show default view on main screen',
@@ -223,6 +235,20 @@
 			'xmlrpc' => True,
 			'admin'  => False
 		),
+		'planner_show_empty_rows' => array(
+			'type'   => 'select',
+			'label'  => 'Show empty rows in Planner',
+			'name'   => 'planner_show_empty_rows',
+			'values' => array(
+				0 => lang('no'),
+				'user' => lang('Planner by user'),
+				'cat'  => lang('Planner by category'),
+				'both' => lang('All'),
+			),
+			'help'   => 'Should the planner display an empty row for users or categories without any appointment.',
+			'xmlrpc' => True,
+			'admin'  => False
+		),
 		'default_private' => array(
 			'type'  => 'check',
 			'label' => 'Set new events to private',
@@ -326,7 +352,6 @@
 			'xmlrpc' => True,
 			'admin'  => False
 		),
-// disabled free/busy stuff til it gets rewritten with new Horde iCal classes -- RalfBecker 2006/03/03
 		'freebusy' => array(
 			'type'  => 'check',
 			'label' => 'Make freebusy information available to not loged in persons?',
