@@ -9,10 +9,10 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: setup.inc.php 21493 2006-04-30 12:53:55Z ralfbecker $ */
+	/* $Id: setup.inc.php 23741 2007-04-30 10:29:44Z lkneschke $ */
 
 	$setup_info['calendar']['name']    = 'calendar';
-	$setup_info['calendar']['version'] = '1.2.001';
+	$setup_info['calendar']['version'] = '1.4';
 	$setup_info['calendar']['app_order'] = 3;
 	$setup_info['calendar']['enable']  = 1;
 
@@ -46,12 +46,23 @@
 	/* Dependencies for this app to work */
 	$setup_info['calendar']['depends'][] = array(
 		 'appname' => 'phpgwapi',
-		 'versions' => Array('1.0.0','1.0.1','1.2')
+		 'versions' => Array('1.3','1.4','1.5')
 	);
 	$setup_info['calendar']['depends'][] = array(
 		 'appname' => 'etemplate',
-		 'versions' => Array('1.0.0','1.0.1','1.2')
+		 'versions' => Array('1.3','1.4','1.5')
 	);
+	
+	// installation checks for calendar
+	$setup_info['calendar']['check_install'] = array(
+		// check if PEAR is availible
+		'' => array(
+			'func' => 'pear_check',
+			'from' => 'Calendar (iCal import+export)',
+		),
+	);	
+	
+
 
 
 
