@@ -9,7 +9,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: tables_current.inc.php 20295 2006-02-15 12:31:25Z  $ */
+  /* $Id: tables_current.inc.php 22300 2006-08-21 08:15:14Z ralfbecker $ */
 
 	$phpgw_baseline = array(
 		'egw_cal' => array(
@@ -26,7 +26,8 @@
 				'cal_location' => array('type' => 'varchar','precision' => '255'),
 				'cal_reference' => array('type' => 'int','precision' => '4','nullable' => False,'default' => '0'),
 				'cal_modifier' => array('type' => 'int','precision' => '4'),
-				'cal_non_blocking' => array('type' => 'int','precision' => '2','default' => '0')
+				'cal_non_blocking' => array('type' => 'int','precision' => '2','default' => '0'),
+				'cal_special' => array('type' => 'int','precision' => '2','default' => '0')
 			),
 			'pk' => array('cal_id'),
 			'fk' => array(),
