@@ -9,7 +9,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: tables_update.inc.php 21493 2006-04-30 12:53:55Z ralfbecker $ */
+  /* $Id: tables_update.inc.php 23741 2007-04-30 10:29:44Z lkneschke $ */
 
 	function calendar_v0_9_2to0_9_3update_owner($table, $field)
 	{
@@ -1508,3 +1508,22 @@
 		
 		return $GLOBALS['setup_info']['calendar']['currentver'] = '1.2.001';
 	}
+
+	$test[] = '1.2.001';
+	function calendar_upgrade1_2_001()
+	{
+		$GLOBALS['egw_setup']->oProc->AddColumn('egw_cal','cal_special',array(
+			'type' => 'int',
+			'precision' => '2',
+			'default' => '0'
+		));
+
+		return $GLOBALS['setup_info']['calendar']['currentver'] = '1.3.001';
+	}
+
+	$test[] = '1.3.001';
+	function calendar_upgrade1_3_001()
+	{
+		return $GLOBALS['setup_info']['calendar']['currentver'] = '1.4';
+	}
+?>
