@@ -10,7 +10,7 @@
 	* Free Software Foundation; either version 2 of the License, or (at your    *
 	* option) any later version.                                                *
 	\***************************************************************************/
-	/* $Id: class.bo.inc.php 21720 2006-06-06 10:24:49Z lkneschke $ */
+	/* $Id: class.bo.inc.php 23944 2007-05-26 06:59:35Z lkneschke $ */
 
 	class bo
 	{
@@ -18,9 +18,11 @@
 		var $LDAPData;
 		
 		var $SMTPServerType = array();		// holds a list of config options
+		var $IMAPServerType = array();		// holds a list of config options
 		
 		var $imapClass;				// holds the imap/pop3 class
 		var $smtpClass;				// holds the smtp class
+		
 
 		function bo($_profileID=-1,$_restoreSesssion=true)
 		{
@@ -32,6 +34,8 @@
 						'smtpServer',
 						'smtpPort',
 						'smtpAuth',
+						'ea_smtp_auth_username',
+						'ea_smtp_auth_password',
 						'smtpType'
 					),
 					'description'	=> lang('standard SMTP-Server'),
@@ -42,6 +46,8 @@
 						'smtpServer',
 						'smtpPort',
 						'smtpAuth',
+						'ea_smtp_auth_username',
+						'ea_smtp_auth_password',
 						'smtpType',
 						'editforwardingaddress',
 						'smtpLDAPServer',
@@ -50,13 +56,56 @@
 						'smtpLDAPBaseDN',
 						'smtpLDAPUseDefault'
 					),
-					'description'	=> lang('Postfix with LDAP'),
+					'description'	=> 'Postfix (qmail Schema)',
 					'classname'	=> 'postfixldap'
-				)
+				),
+				'3'     => array(
+					'fieldNames'    => array(
+						'smtpServer',
+						'smtpPort',
+						'smtpAuth',
+						'ea_smtp_auth_username',
+						'ea_smtp_auth_password',
+						'smtpType',
+					),
+					'description'   => 'Postfix (inetOrgPerson Schema)',
+					'classname'     => 'postfixinetorgperson'
+				),
+				'4'     => array(
+					'fieldNames'    => array(
+						'smtpServer',
+						'smtpPort',
+						'smtpAuth',
+						'ea_smtp_auth_username',
+						'ea_smtp_auth_password',
+						'smtpType',
+						'editforwardingaddress',
+					),
+					'description'   => 'Plesk SMTP-Server (Qmail)',
+					'classname'     => 'smtpplesk'
+				),
+				'5' 	=> array(
+					'fieldNames'	=> array(
+						'smtpServer',
+						'smtpPort',
+						'smtpAuth',
+						'ea_smtp_auth_username',
+						'ea_smtp_auth_password',
+						'smtpType',
+						'editforwardingaddress',
+						'smtpLDAPServer',
+						'smtpLDAPAdminDN',
+						'smtpLDAPAdminPW',
+						'smtpLDAPBaseDN',
+						'smtpLDAPUseDefault'
+					),
+					'description'	=> 'Postfix (dbmail Schema)',
+					'classname'	=> 'postfixdbmailuser'
+				),
 			);
 
 			$this->IMAPServerType = array(
-				'1' 	=> array(
+/*				'1' 	=> array(
 					'fieldNames'	=> array(
 						'imapServer',
 						'imapPort',
@@ -66,10 +115,10 @@
 						'imapTLSAuthentication',
 						'imapoldcclient'
 					),
-					'description'	=> lang('standard POP3 server'),
+					'description'	=> 'standard POP3 server',
 					'protocol'	=> 'pop3',
 					'classname'	=> 'defaultpop'
-				),
+				),*/
 				'2' 	=> array(
 					'fieldNames'	=> array(
 						'imapServer',
@@ -80,7 +129,7 @@
 						'imapTLSAuthentication',
 						'imapoldcclient'
 					),
-					'description'	=> lang('standard IMAP server'),
+					'description'	=> 'standard IMAP server',
 					'protocol'	=> 'imap',
 					'classname'	=> 'defaultimap'
 				),
@@ -100,10 +149,58 @@
 						'imapSieveServer',
 						'imapSievePort'
 					),
-					'description'	=> lang('Cyrus IMAP Server'),
+					'description'	=> 'Cyrus IMAP Server',
 					'protocol'	=> 'imap',
 					'classname'	=> 'cyrusimap'
-				)
+				),
+				'4' 	=> array(
+					'fieldNames'	=> array(
+						'imapServer',
+						'imapPort',
+						'imapType',
+						'imapLoginType',
+						'imapTLSEncryption',
+						'imapTLSAuthentication',
+						'imapoldcclient',
+						'imapEnableSieve',
+						'imapSieveServer',
+						'imapSievePort'
+					),
+					'description'	=> 'DBMail (qmailUser schema)',
+					'protocol'	=> 'imap',
+					'classname'	=> 'dbmailqmailuser'
+				),
+				'5'     => array(
+					'fieldNames'    => array(
+						'imapServer',
+						'imapPort',
+						'imapType',
+						'imapLoginType',
+						'imapTLSEncryption',
+						'imapTLSAuthentication',
+						'imapoldcclient',
+					),
+					'description'   => 'Plesk IMAP Server (Courier)',
+					'protocol'      => 'imap',
+					'classname'     => 'pleskimap'
+				),
+				'6' 	=> array(
+					'fieldNames'	=> array(
+						'imapServer',
+						'imapPort',
+						'imapType',
+						'imapLoginType',
+						'imapTLSEncryption',
+						'imapTLSAuthentication',
+						'imapoldcclient',
+						'imapEnableSieve',
+						'imapSieveServer',
+						'imapSievePort'
+					),
+					'description'	=> 'DBMail (dbmailUser schema)',
+					'protocol'	=> 'imap',
+					'classname'	=> 'dbmaildbmailuser'
+				),
 			); 
 			
 			if ($_restoreSesssion) $this->restoreSessionData();
@@ -114,45 +211,38 @@
 			
 				$this->profileData	= $this->getProfile($_profileID);
 			
-				$this->imapClass	= $this->IMAPServerType[$this->profileData['imapType']]['classname'];
-				$this->smtpClass	= $this->SMTPServerType[$this->profileData['smtpType']]['classname'];
+				$this->imapClass	=& CreateObject('emailadmin.'.$this->IMAPServerType[$this->profileData['imapType']]['classname']);
+				$this->smtpClass	=& CreateObject('emailadmin.'.$this->SMTPServerType[$this->profileData['smtpType']]['classname']);
 			}
 		}
 		
 		function addAccount($_hookValues)
 		{
-			$this->profileData	= $this->getUserProfile('felamimail', $_hookValues['account_groups']);
-
-			$this->imapClass	= $this->IMAPServerType[$this->profileData['imapType']]['classname'];
-			$this->smtpClass	= $this->SMTPServerType[$this->profileData['smtpType']]['classname'];
-			
-
-			if (!empty($this->imapClass))
+			if (is_object($this->imapClass))
 			{
-				ExecMethod("emailadmin.".$this->imapClass.".addAccount",$_hookValues,3,$this->profileData);
+				#ExecMethod("emailadmin.".$this->imapClass.".addAccount",$_hookValues,3,$this->profileData);
+				$this->imapClass->addAccount($_hookValues);
 			}
 			
-			if (!empty($this->smtpClass))
+			if (is_object($this->smtpClass))
 			{
-				ExecMethod("emailadmin.".$this->smtpClass.".addAccount",$_hookValues,3,$this->profileData);
+				#ExecMethod("emailadmin.".$this->smtpClass.".addAccount",$_hookValues,3,$this->profileData);
+				$this->smtpClass->addAccount($_hookValues);
 			}
 		}
 		
 		function deleteAccount($_hookValues)
 		{
-			$this->profileData	= $this->getUserProfile('felamimail', $_hookValues['account_groups']);
-
-			$this->imapClass	= $this->IMAPServerType[$this->profileData['imapType']]['classname'];
-			$this->smtpClass	= $this->SMTPServerType[$this->profileData['smtpType']]['classname'];
-			
-			if (!empty($this->imapClass))
+			if (is_object($this->imapClass))
 			{
-				ExecMethod("emailadmin.".$this->imapClass.".deleteAccount",$_hookValues,3,$this->profileData);
+				#ExecMethod("emailadmin.".$this->imapClass.".deleteAccount",$_hookValues,3,$this->profileData);
+				$this->imapClass->deleteAccount($_hookValues);
 			}
 
-			if (!empty($this->smtpClass))
+			if (is_object($this->smtpClass))
 			{
-				ExecMethod("emailadmin.".$this->smtpClass.".deleteAccount",$_hookValues,3,$this->profileData);
+				#ExecMethod("emailadmin.".$this->smtpClass.".deleteAccount",$_hookValues,3,$this->profileData);
+				$this->smtpClass->deleteAccount($_hookValues);
 			}
 		}
 		
@@ -181,7 +271,7 @@
 						// imap_8bit does not convert "?"
 						// it does not need, but it should
 						$value = str_replace("?","=3F",$value);
-						$retString .= "=?".strtoupper($this->displayCharset)."?Q?".$value."?=";
+						$retString .= "=?".strtoupper($this->displayCharset)."?Q?" . $value. "?=";
 					}
 					#exit;
 					return $retString;
@@ -195,9 +285,11 @@
 		{
 			$profileData	= $this->getProfile($_profileID);
 			
-			$smtpClass	= $this->SMTPServerType[$profileData['smtpType']]['classname'];
+			#$smtpClass	= $this->SMTPServerType[$profileData['smtpType']]['classname'];
+			$smtpClass	=& CreateObject('emailadmin.'.$this->SMTPServerType[$profileData['smtpType']]['classname']);
 
-			return empty($smtpClass) ? False : ExecMethod("emailadmin.$smtpClass.getAccountEmailAddress",$_accountName,3,$profileData);
+			#return empty($smtpClass) ? False : ExecMethod("emailadmin.$smtpClass.getAccountEmailAddress",$_accountName,3,$profileData);
+			return is_object($smtpClass) ?  $smtpClass->getAccountEmailAddress($_accountName) : False;
 		}
 		
 		function getFieldNames($_serverTypeID, $_class)
@@ -224,14 +316,12 @@
 #			return $this->imapClass;
 #		}
 		
-		function getIMAPServerTypes()
-		{
-			foreach($this->IMAPServerType as $key => $value)
-			{
+		function getIMAPServerTypes() {
+			foreach($this->IMAPServerType as $key => $value) {
 				$retData[$key]['description']	= $value['description'];
 				$retData[$key]['protocol']	= $value['protocol'];
 			}
-			
+
 			return $retData;
 		}
 		
@@ -243,9 +333,10 @@
 		
 		function getMailboxString($_folderName)
 		{
-			if (!empty($this->imapClass))
+			if (is_object($this->imapClass))
 			{
 				return ExecMethod("emailadmin.".$this->imapClass.".getMailboxString",$_folderName,3,$this->profileData);
+				return $this->imapClass->getMailboxString($_folderName);
 			}
 			else
 			{
@@ -270,14 +361,11 @@
 			}
 			if ($found === false)		// no existing profile selected
 			{
-				if (is_array($profileData) && count($profileData))	// if we have a profile use that
-				{
+				if (is_array($profileData) && count($profileData)) {	// if we have a profile use that
 					reset($profileData);
 					list($found,$data) = each($profileData);
 					$this->profileID = $_profileID = $data['profileID'];
-				}
-				elseif ($GLOBALS['egw_info']['server']['smtp_server'])	// create a default profile, from the data in the api config
-				{
+				} elseif ($GLOBALS['egw_info']['server']['smtp_server']) { // create a default profile, from the data in the api config
 					$this->profileID = $_profileID = $this->soemailadmin->addProfile(array(
 						'description' => $GLOBALS['egw_info']['server']['smtp_server'],
 						'defaultDomain' => $GLOBALS['egw_info']['server']['mail_suffix'],
@@ -295,7 +383,7 @@
 						'imapType' => '2',	// imap
 						'imapLoginType' => $GLOBALS['egw_info']['server']['mail_login_type'] ? 
 							$GLOBALS['egw_info']['server']['mail_login_type'] : 'standard',
-						'imapTLSEncryption' => '',
+						'imapTLSEncryption' => '0',
 						'imapTLSAuthentication' => '',
 						'imapoldcclient' => '',						
 					));
@@ -319,7 +407,9 @@
 			$fieldNames[] = 'ea_appname';
 			$fieldNames[] = 'ea_group';
 			
-			return $this->soemailadmin->getProfile($_profileID, $fieldNames);
+			$profileData = $this->soemailadmin->getProfile($_profileID, $fieldNames);
+			$profileData['imapTLSEncryption'] = ($profileData['imapTLSEncryption'] == 'yes' ? 1 : (int)$profileData['imapTLSEncryption']);
+			return $profileData;
 		}
 		
 		function getProfileList($_profileID='')
@@ -327,70 +417,114 @@
 			return $this->soemailadmin->getProfileList($_profileID);
 		}
 		
-#		function getSMTPClass($_profileID)
-#		{
-#			if(!is_object($this->smtpClass))
-#			{
-#				$profileData		= $this->getProfile($_profileID);
-#				$this->smtpClass	=& CreateObject('emailadmin.postfixldap',$profileData);
-#			}
-#			
-#			return $this->smtpClass;
-#		}
-		
 		function getSMTPServerTypes()
 		{
 			foreach($this->SMTPServerType as $key => $value)
 			{
 				$retData[$key] = $value['description'];
 			}
-			
 			return $retData;
 		}
 		
 		function getUserProfile($_appName='', $_groups='')
 		{
 			$appName	= ($_appName != '' ? $_appName : $GLOBALS['egw_info']['flags']['currentapp']);
-			if(!is_array($_groups))
-			{
+			if(!is_array($_groups)) {
 				// initialize with 0 => means no group id
 				$groups = array(0);
 				$userGroups = $GLOBALS['egw']->accounts->membership($GLOBALS['egw_info']['user']['account_id']);
-				foreach((array)$userGroups as $groupInfo)
-				{
+				foreach((array)$userGroups as $groupInfo) {
 					$groups[] = $groupInfo['account_id'];
 				}
-			}
-			else
-			{
+			} else {
 				$groups = $_groups;
 			}
 
-			return $this->soemailadmin->getUserProfile($appName, $groups);
+			if($data = $this->soemailadmin->getUserProfile($appName, $groups)) {
+			
+				$eaPreferences =& CreateObject('emailadmin.ea_preferences');
+
+				// fetch the IMAP / incomming server data
+				$icClass = isset($this->IMAPServerType[$data['imapType']]) ? $this->IMAPServerType[$data['imapType']]['classname'] : 'defaultimap';
+
+				$icServer =& CreateObject('emailadmin.'.$icClass);
+				$icServer->encryption	= ($data['imapTLSEncryption'] == 'yes' ? 1 : (int)$data['imapTLSEncryption']);
+				$icServer->host		= $data['imapServer'];
+				$icServer->port 	= $data['imapPort'];
+				$icServer->validatecert	= $data['imapTLSAuthentication'] == 'yes';
+				$icServer->username 	= $GLOBALS['egw_info']['user']['account_lid'];
+				$icServer->password	= $GLOBALS['egw_info']['user']['passwd'];
+				$icServer->loginType	= $data['imapLoginType'];
+				$icServer->domainName	= $data['defaultDomain'];
+				$icServer->loginName 	= $data['imapLoginType'] == 'standard' ? $GLOBALS['egw_info']['user']['account_lid'] : $GLOBALS['egw_info']['user']['account_lid'].'@'.$data['defaultDomain'];
+				$icServer->enableCyrusAdmin = ($data['imapEnableCyrusAdmin'] == 'yes');
+				$icServer->adminUsername = $data['imapAdminUsername'];
+				$icServer->adminPassword = $data['imapAdminPW'];
+				$icServer->enableSieve	= ($data['imapEnableSieve'] == 'yes');
+				$icServer->sievePort	= $data['imapSievePort'];
+				$eaPreferences->setIncomingServer($icServer);
+
+				// fetch the SMTP / outgoing server data
+				$ogClass = isset($this->SMTPServerType[$data['smtpType']]) ? $this->SMTPServerType[$data['smtpType']]['classname'] : 'defaultsmtp';
+				$ogServer =& CreateObject('emailadmin.'.$ogClass);
+				$ogServer->host		= $data['smtpServer'];
+				$ogServer->port		= $data['smtpPort'];
+				$ogServer->editForwardingAddress = ($data['editforwardingaddress'] == 'yes');
+				$ogServer->smtpAuth	= $data['smtpAuth'] == 'yes';
+				if($ogServer->smtpAuth) {
+					if(!empty($data['ea_smtp_auth_username'])) {
+						$ogServer->username 	= $data['ea_smtp_auth_username'];
+						$ogServer->password 	= $data['ea_smtp_auth_password'];
+					} else {
+						$ogServer->username 	= $GLOBALS['egw_info']['user']['account_lid'];
+						$ogServer->password 	= $GLOBALS['egw_info']['user']['passwd'];
+					}
+				}
+				$eaPreferences->setOutgoingServer($ogServer);
+
+				foreach($ogServer->getAccountEmailAddress($GLOBALS['egw_info']['user']['account_lid']) as $emailAddresses)
+				{
+					$identity =& CreateObject('emailadmin.ea_identity');
+					$identity->emailAddress	= $emailAddresses['address'];
+					$identity->realName	= $emailAddresses['name'];
+					$identity->default	= ($emailAddresses['type'] == 'default');
+					$identity->organization	= $data['organisationName'];
+					
+					$eaPreferences->setIdentity($identity);
+				}
+				
+				$eaPreferences->userDefinedAccounts = ($data['userDefinedAccounts'] == 'yes');
+				
+				return $eaPreferences;
+			}
+			
+			return false;
 		}
 		
-		function getUserData($_accountID, $_usecache)
+		function getUserData($_accountID)
 		{
-			if ($_usecache)
-			{
-				$userData = $this->userSessionData[$_accountID];
+			$userGroups = $GLOBALS['egw']->accounts->membership($_accountID);
+			$groups = array(0);
+			foreach((array)$userGroups as $groupInfo) {
+				$groups[] = $groupInfo['account_id'];
 			}
-			else
-			{
-				$userData = $this->soemailadmin->getUserData($_accountID);
-				$bofelamimail =& CreateObject('felamimail.bofelamimail');
-				$bofelamimail->openConnection('','',true);
-				$userQuota = 
-					$bofelamimail->imapGetQuota($GLOBALS['egw']->accounts->id2name($_accountID));
-				if(is_array($userQuota))
-				{
-					$userData['quotaLimit']	= $userQuota['limit'];
+
+			if($userProfile = $this->getUserProfile('felamimail', $groups)) {
+				$icServer = $userProfile->getIncomingServer(0);
+				if(is_a($icServer, 'defaultimap') && $username = $GLOBALS['egw']->accounts->id2name($_accountID)) {
+					$icUserData = $icServer->getUserData($username);
 				}
-				$bofelamimail->closeConnection();
-				$this->userSessionData[$_accountID] = $userData;
-				$this->saveSessionData();
+
+				$ogServer = $userProfile->getOutgoingServer(0);
+				if(is_a($ogServer, 'defaultsmtp')) {
+					$ogUserData = $ogServer->getUserData($_accountID);
+				}
+				
+				return $icUserData + $ogUserData;
+				
 			}
-			return $userData;
+			
+			return false;
 		}
 
 		function restoreSessionData()
@@ -401,10 +535,11 @@
 		
 		function saveSMTPForwarding($_accountID, $_forwardingAddress, $_keepLocalCopy)
 		{
-			if (!empty($this->smtpClass))
+			if (is_object($this->smtpClass))
 			{
-				$smtpClass = &CreateObject('emailadmin.'.$this->smtpClass,$this->profileID);
-				$smtpClass->saveSMTPForwarding($_accountID, $_forwardingAddress, $_keepLocalCopy);
+				#$smtpClass = &CreateObject('emailadmin.'.$this->smtpClass,$this->profileID);
+				#$smtpClass->saveSMTPForwarding($_accountID, $_forwardingAddress, $_keepLocalCopy);
+				$this->smtpClass->saveSMTPForwarding($_accountID, $_forwardingAddress, $_keepLocalCopy);
 			}
 			
 		}
@@ -413,7 +548,7 @@
 		 * called by the validation hook in setup
 		 *
 		 * @param array $settings following keys: mail_server, mail_server_type {IMAP|IMAPS|POP-3|POP-3S}, 
-		 *	mail_login_type {standard|vmailmgr}, mail_suffix (domain), smtp_server, smtp_port, smtp_auth_user, smtp_auth_passwd
+		 *	mail_login_type {standard|vmailmgr}, mail_suffix (domain), smtp_server, smpt_port, smtp_auth_user, smtp_auth_passwd
 		 */
 		function setDefaultProfile($settings)
 		{
@@ -436,33 +571,36 @@
 					'imap' => array(
 						'imapType' => 2,
 						'imapPort' => 143,
-						'imapTLSEncryption' => null,
+						'imapTLSEncryption' => 0,
 					),
 					'imaps' => array(
 						'imapType' => 2,
 						'imapPort' => 993,
 						'imapTLSEncryption' => 'yes',
 					),
-					'pop3' => array(
+/*					'pop3' => array(
 						'imapType' => 1,
 						'imapPort' => 110,
-						'imapTLSEncryption' => null,
+						'imapTLSEncryption' => 0,
 					),
 					'pop3s' => array(
 						'imapType' => 1,
 						'imapPort' => 995,
-						'imapTLSEncryption' => 'yes',
-					),
+						'imapTLSEncryption' => '1',
+					),*/
 				),
 				'mail_login_type' => 'imapLoginType',
-				'mail_suffix'	=> 'defaultDomain',
-				'smtp_server'	=> 'smtpServer',
-				'smtp_port'	=> 'smtpPort',
+				'mail_suffix' => 'defaultDomain',
+				'smtp_server' => 'smtpServer',
+				'smpt_port' => 'smtpPort',
+				'smtp_auth_user' => 'ea_smtp_auth_username',
+				'smtp_auth_passwd' => 'ea_smtp_auth_password',
 			) as $setup_name => $ea_name_data)
 			{
 				if (!is_array($ea_name_data))
 				{
 					$profile[$ea_name_data] = $settings[$setup_name];
+					if ($setup_name == 'smtp_auth_user') $profile['stmpAuth'] = !empty($settings['smtp_auth_user']);
 				}
 				else
 				{
@@ -488,13 +626,14 @@
 
 		function saveProfile($_globalSettings, $_smtpSettings, $_imapSettings)
 		{
-			if(!isset($_globalSettings['profileID']))
-			{
+			if(!isset($_imapSettings['imapTLSAuthentication'])) {
+				$_imapSettings['imapTLSAuthentication'] = true;
+			}
+
+			if(!isset($_globalSettings['profileID'])) {
 				$_globalSettings['ea_order'] = count($this->getProfileList()) + 1;
 				$this->soemailadmin->addProfile($_globalSettings, $_smtpSettings, $_imapSettings);
-			}
-			else
-			{
+			} else {
 				$this->soemailadmin->updateProfile($_globalSettings, $_smtpSettings, $_imapSettings);
 			}
 			$all = $_globalSettings+$_smtpSettings+$_imapSettings;
@@ -507,8 +646,11 @@
 					'imapLoginType' => 'mail_login_type',
 					'defaultDomain' => 'mail_suffix',
 					'smtpServer'    => 'smtp_server',
-					'smtpPort'      => 'smtp_port',
-				) as $ea_name => $config_name)
+					'smtpPort'      => 'smpt_port',
+				)+($all['smtpAuth'] ? array(
+					'ea_smtp_auth_username' => 'smtp_auth_user',
+					'ea_smtp_auth_password' => 'smtp_auth_passwd',
+				) : array()) as $ea_name => $config_name)
 				{
 					if (isset($all[$ea_name]))
 					{
@@ -541,127 +683,52 @@
 			$GLOBALS['egw']->session->appsession('user_session_data','',$this->userSessionData);
 		}
 		
-		function saveUserData($_accountID, $_formData, $_boAction)
-		{
-			$this->userSessionData[$_accountID]['mailLocalAddress'] 	= $_formData["mailLocalAddress"];
-			$this->userSessionData[$_accountID]['accountStatus'] 		= $_formData["accountStatus"];
-			$this->userSessionData[$_accountID]['deliveryMode'] 		= $_formData["deliveryMode"];
-			$this->userSessionData[$_accountID]['qmailDotMode'] 		= $_formData["qmailDotMode"];
-			$this->userSessionData[$_accountID]['deliveryProgramPath'] 	= $_formData["deliveryProgramPath"];
-			$this->userSessionData[$_accountID]['quotaLimit'] 		= $_formData["quotaLimit"];
+		function saveUserData($_accountID, $_formData) {
+			$groups = array_merge(array(0),(array)$GLOBALS['egw']->accounts->memberships($_accountID,true));
 
-			switch ($_boAction)
-			{
-				case 'add_mailAlternateAddress':
-					if (is_array($this->userSessionData[$_accountID]['mailAlternateAddress']))
-					{
-						$count = count($this->userSessionData[$_accountID]['mailAlternateAddress']);
-					}
-					else
-					{
-						$count = 0;
-						$this->userSessionData[$_accountID]['mailAlternateAddress'] = array();
-					}
-					
-					$this->userSessionData[$_accountID]['mailAlternateAddress'][$count] = 
-						$_formData['add_mailAlternateAddress'];
-						
-					$this->saveSessionData();
-					
-					break;
-					
-				case 'remove_mailAlternateAddress':
-					$i=0;
-					
-					while(list($key, $value) = @each($this->userSessionData[$_accountID]['mailAlternateAddress']))
-					{
-						#print ".. $key: $value<br>";
-						if ($key != $_formData['remove_mailAlternateAddress'])
-						{
-							$newMailAlternateAddress[$i]=$value;
-							#print "!! $i: $value<br>";
-							$i++;
-						}
-					}
-					$this->userSessionData[$_accountID]['mailAlternateAddress'] = $newMailAlternateAddress;
-					
-					$this->saveSessionData();
+			if($userProfile = $this->getUserProfile('felamimail', $groups)) {
+				$ogServer = $userProfile->getOutgoingServer(0);
+				if(is_a($ogServer, 'defaultsmtp')) {
+					$ogServer->setUserData($_accountID, 
+						(array)$_formData['mailAlternateAddress'], 
+						(array)$_formData['mailForwardingAddress'],
+						$_formData['deliveryMode'],
+						$_formData['accountStatus'],
+						$_formData['mailLocalAddress']
+					);
+				}
 
-					break;
-					
-				case 'add_mailRoutingAddress':
-					if (is_array($this->userSessionData[$_accountID]['mailRoutingAddress']))
-					{
-						$count = count($this->userSessionData[$_accountID]['mailRoutingAddress']);
-					}
-					else
-					{
-						$count = 0;
-						$this->userSessionData[$_accountID]['mailRoutingAddress'] = array();
-					}
-					
-					$this->userSessionData[$_accountID]['mailRoutingAddress'][$count] = 
-						$_formData['add_mailRoutingAddress'];
-						
-					$this->saveSessionData();
+				$icServer = $userProfile->getIncomingServer(0);
+				if(is_a($icServer, 'defaultimap') && $username = $GLOBALS['egw']->accounts->id2name($_accountID)) {
+					$icServer->setUserData($username, $_formData['quotaLimit']);
+				}
 
-					break;
-					
-				case 'remove_mailRoutingAddress':
-					$i=0;
-					
-					while(list($key, $value) = @each($this->userSessionData[$_accountID]['mailRoutingAddress']))
-					{
-						if ($key != $_formData['remove_mailRoutingAddress'])
-						{
-							$newMailRoutingAddress[$i]=$value;
-							$i++;
-						}
-					}
-					$this->userSessionData[$_accountID]['mailRoutingAddress'] = $newMailRoutingAddress;
-					
-					$this->saveSessionData();
-
-					break;
-					
-				case 'save':
-					$this->soemailadmin->saveUserData(
-						$_accountID, 
-						$this->userSessionData[$_accountID]);
-					$bofelamimail =& CreateObject('felamimail.bofelamimail');
-					$bofelamimail->openConnection('','',true);
-					$bofelamimail->imapSetQuota($GLOBALS['egw']->accounts->id2name($_accountID),
-										$this->userSessionData[$_accountID]['quotaLimit']);
-					$bofelamimail->closeConnection();
-					$GLOBALS['egw']->accounts->cache_invalidate($_accountID);
-					
-					
-					break;
+				// calling a hook to allow other apps to monitor the changes
+				$_formData['account_id'] = $_accountID;
+				$_formData['location'] = 'editaccountemail';
+				$GLOBALS['egw']->hooks->process($_formData);
+				
+				return true;
 			}
+			
+			return false;
 		}
 		
-		function setOrder($_order)
-		{
+		function setOrder($_order) {
 			if(is_array($_order)) {
 				$this->soemailadmin->setOrder($_order);
 			}
 		}
 
-		function updateAccount($_hookValues)
-		{
-			$this->profileData	= $this->getUserProfile('felamimail', $_hookValues['account_groups']);
-
-			$this->imapClass	= $this->IMAPServerType[$this->profileData['imapType']]['classname'];
-			$this->smtpClass	= $this->SMTPServerType[$this->profileData['smtpType']]['classname'];
-			
-			if (!empty($this->imapClass))
-			{
-				ExecMethod("emailadmin.".$this->imapClass.".updateAccount",$_hookValues,3,$this->profileData);
+		function updateAccount($_hookValues) {
+			if (is_object($this->imapClass)) {
+				#ExecMethod("emailadmin.".$this->imapClass.".updateAccount",$_hookValues,3,$this->profileData);
+				$this->imapClass->updateAccount($_hookValues);
 			}
 
-			if (!empty($this->smtpClass))
-			{
-				ExecMethod("emailadmin.".$this->smtpClass.".updateAccount",$_hookValues,3,$this->profileData);
+			if (is_object($this->smtpClass)) {
+				#ExecMethod("emailadmin.".$this->smtpClass.".updateAccount",$_hookValues,3,$this->profileData);
+				$this->smtpClass->updateAccount($_hookValues);
 			}
 		}
 		
