@@ -9,16 +9,28 @@
 	* Free Software Foundation; either version 2 of the License, or (at your    *
 	* option) any later version.                                                *
 	\***************************************************************************/
-	/* $Id: class.defaultsmtp.inc.php 19408 2005-10-14 10:10:06Z ralfbecker $ */
+	/* $Id: class.defaultsmtp.inc.php 22738 2006-10-26 09:46:39Z lkneschke $ */
 
 	class defaultsmtp
 	{
-		var $profileData;
-	
+		var $smtpAuth = false;
+		
+		var $editForwardingAddress = false;		
+
+		var $host;
+		
+		var $port;
+		
+		var $username;
+		
+		var $password;
+		
+		var $defaultDomain;
+		
 		// the constructor
-		function defaultsmtp($_profileData)
+		function defaultsmtp($defaultDomain=null)
 		{
-			$this->profileData = $_profileData;
+			$this->defaultDomain = $defaultDomain ? $defaultDomain : $GLOBALS['egw_info']['server']['mail_suffix'];
 		}
 		
 		// add a account
@@ -38,25 +50,35 @@
 			$accountID = $GLOBALS['egw']->accounts->name2id($_accountName);
 			$emailAddress = $GLOBALS['egw']->accounts->id2name($accountID,'account_email');
 			if(empty($emailAddress))
-				$emailAddress = $_accountName.'@'.$this->profileData['defaultDomain'];
+				$emailAddress = $_accountName.'@'.$this->defaultDomain;
+
+			$realName = trim($GLOBALS['egw_info']['user']['firstname'] . (!empty($GLOBALS['egw_info']['user']['firstname']) ? ' ' : '') . $GLOBALS['egw_info']['user']['lastname']);
 
 			return array(
 				array(
-					'name'		=> $GLOBALS['egw_info']['user']['fullname'], 
+					'name'		=> $realName, 
 					'address'	=> $emailAddress, 
 					'type'		=> 'default'
 				)
 			);
 		}
 
-		function saveSMTPForwarding($_accountID, $_forwardingAddress, $_keepLocalCopy)
-		{
+		function getUserData($_uidnumber) {
+			$userData = array();
+			
+			return $userData;
+		}
+
+		function saveSMTPForwarding($_accountID, $_forwardingAddress, $_keepLocalCopy) {
+			return true;
+		}
+
+		function setUserData($_uidnumber, $_mailAlternateAddress, $_mailForwardingAddress, $_deliveryMode) {
 			return true;
 		}
 		
 		// update a account
-		function updateAccount($_hookValues)
-		{
+		function updateAccount($_hookValues) {
 			return true;
 		}
 	}
