@@ -9,7 +9,7 @@
 	* Free Software Foundation; either version 2 of the License, or (at your    *
 	* option) any later version.                                                *
 	\***************************************************************************/
-	/* $Id: class.postfixldap.inc.php 20199 2006-01-05 05:54:52Z lkneschke $ */
+	/* $Id: class.postfixldap.inc.php 22738 2006-10-26 09:46:39Z lkneschke $ */
 
 	include_once(EGW_SERVER_ROOT."/emailadmin/inc/class.defaultsmtp.inc.php");
 
@@ -17,7 +17,9 @@
 	{
 		function addAccount($_hookValues)
 		{
-			$mailLocalAddress	= $_hookValues['account_lid']."@".$this->profileData['defaultDomain'];
+			$mailLocalAddress = $_hookValues['account_email'] ? $_hookValues['account_email'] :
+				$GLOBALS['egw']->common->email_address($_hookValues['account_firstname'],
+					$_hookValues['account_lastname'],$_hookValues['account_lid'],$this->defaultDomain);
 
 			$ds = $GLOBALS['egw']->common->ldapConnect();
 			
@@ -65,12 +67,13 @@
 			
 			if ($sri)
 			{
+				$realName = trim($GLOBALS['egw_info']['user']['firstname'] . (!empty($GLOBALS['egw_info']['user']['firstname']) ? ' ' : '') . $GLOBALS['egw_info']['user']['lastname']);
 				$allValues = ldap_get_entries($ds, $sri);
 				if(isset($allValues[0]['mail'][0]))
 				{
 					$emailAddresses[] = array
 					(
-						'name'		=> $GLOBALS['egw_info']['user']['fullname'],
+						'name'		=> $realName,
 						'address'	=> $allValues[0]['mail'][0],
 						'type'		=> 'default'
 					);
@@ -82,7 +85,7 @@
 					{
 						$emailAddresses[] = array
 						(
-							'name'		=> $GLOBALS['egw_info']['user']['fullname'],
+							'name'		=> $realName,
 							'address'	=> $allValues[0]['mailalternateaddress'][$i],
 							'type'		=> 'alternate'
 						);
@@ -92,6 +95,76 @@
 			
 			return $emailAddresses;
 		}
+
+		function getUserData($_uidnumber) {
+			$userData = array();
+
+			$ldap = $GLOBALS['egw']->common->ldapConnect();
+			
+			if (($sri = @ldap_search($ldap,$GLOBALS['egw_info']['server']['ldap_context'],"(uidnumber=$_uidnumber)")))
+			{
+				$allValues = ldap_get_entries($ldap, $sri);
+				if ($allValues['count'] > 0)
+				{
+					#print "found something<br>";
+					$userData["mailLocalAddress"]		= $allValues[0]["mail"][0];
+					$userData["mailAlternateAddress"]	= $allValues[0]["mailalternateaddress"];
+					$userData["accountStatus"]		= $allValues[0]["accountstatus"][0];
+					$userData["mailForwardingAddress"]	= $allValues[0]["mailforwardingaddress"];
+					$userData["qmailDotMode"]		= $allValues[0]["qmaildotmode"][0];
+					$userData["deliveryProgramPath"]	= $allValues[0]["deliveryprogrampath"][0];
+					$userData["deliveryMode"]		= $allValues[0]["deliverymode"][0];
+
+					unset($userData["mailAlternateAddress"]["count"]);
+					unset($userData["mailForwardingAddress"]["count"]);					
+
+					return $userData;
+				}
+			}
+			
+			return $userData;
+		}
+		
+		function setUserData($_uidnumber, $_mailAlternateAddress, $_mailForwardingAddress, $_deliveryMode, $_accountStatus, $_mailLocalAddress) {
+			$filter = "uidnumber=$_uidnumber";
+
+			$ldap = $GLOBALS['egw']->common->ldapConnect();
+
+			$sri = @ldap_search($ldap,$GLOBALS['egw_info']['server']['ldap_context'],$filter);
+			if ($sri) {
+				$allValues 	= ldap_get_entries($ldap, $sri);
+
+				$accountDN 	= $allValues[0]['dn'];
+				$uid	   	= $allValues[0]['uid'][0];
+				$objectClasses	= $allValues[0]['objectclass'];
+				
+				unset($objectClasses['count']);
+
+				if(!in_array('qmailUser',$objectClasses) &&
+					!in_array('qmailuser',$objectClasses))
+				{
+					$objectClasses[]	= 'qmailuser'; 
+					sort($objectClasses);
+					$newData['objectclass']	= $objectClasses;
+				}
+
+				sort($_mailAlternateAddress);
+				sort($_mailForwardingAddress);
+				
+				$newData['mailalternateaddress'] = (array)$_mailAlternateAddress;
+				$newData['mailforwardingaddress'] = (array)$_mailForwardingAddress;
+				$newData['deliverymode']	= $_deliveryMode ? 'forwardOnly' : array();
+				$newData['accountstatus']	= $_accountStatus ? 'active' : array();
+				$newData['mail'] = $_mailLocalAddress;
+
+				ldap_mod_replace($ldap, $accountDN, $newData);
+			}
+			else
+			{
+				return false;
+			}
+
+		}
 		
 		function saveSMTPForwarding($_accountID, $_forwardingAddress, $_keepLocalCopy)
 		{
