@@ -9,7 +9,7 @@
 	* Free Software Foundation; either version 2 of the License, or (at your    *
 	* option) any later version.                                                *
 	\***************************************************************************/
-	/* $Id: class.so.inc.php 21290 2006-04-09 04:28:30Z lkneschke $ */
+	/* $Id: class.so.inc.php 21937 2006-06-23 19:04:21Z lkneschke $ */
 
 	class so
 	{
@@ -47,6 +47,8 @@
 			'ea_order'			=> 'ea_order',
 			'ea_group'			=> 'ea_group',
 			'ea_appname'			=> 'ea_appname',
+			'ea_smtp_auth_username'		=> 'ea_smtp_auth_username',
+			'ea_smtp_auth_password'		=> 'ea_smtp_auth_password',
 		);
 
 		function so()
@@ -145,15 +147,15 @@
 				' OR ea_appname IS NULL or ea_appname = \'\') and ',
 				'(',
 				array('ea_group'=>$_groups),
-				' OR ea_group IS NULL or ea_group = \'\' or ea_group = \'0\')'
+				' OR ea_group IS NULL or ea_group = \'\')'
 			);
 
 			$this->db->select($this->table,'ea_profile_id',$where, __LINE__, __FILE__, false, 'ORDER BY ea_order', false, 1);
 			
-			if (($data = $this->db->row(true)))
-			{
+			if (($data = $this->db->row(true))) {
 				return $this->getProfile($data['ea_profile_id'], $this->db_cols);
 			}
+
 			return false;
 		}
 
