@@ -9,7 +9,7 @@
 	* Free Software Foundation; either version 2 of the License, or (at your    *
 	* option) any later version.                                                *
 	\***************************************************************************/
-	/* $Id: class.ui.inc.php 20261 2006-01-22 17:59:06Z lkneschke $ */
+	/* $Id: class.ui.inc.php 24009 2007-06-04 06:43:09Z ralfbecker $ */
 
 	class ui
 	{
@@ -67,7 +67,7 @@
 			
 			#$this->t->set_var('profile_name',$profileList[0]['description']);
 			$this->t->set_var('smtpActiveTab','1');
-			$this->t->set_var('imapActiveTab','1');
+			$this->t->set_var('imapActiveTab','2');	// IMAP
 			$this->t->set_var('application_select_box', $GLOBALS['egw']->html->select('globalsettings[ea_appname]','',$applications, true, "style='width: 250px;'"));
 			$this->t->set_var('group_select_box', $GLOBALS['egw']->html->select('globalsettings[ea_group]','',$allGroups, true, "style='width: 250px;'"));
 			
@@ -83,15 +83,30 @@
 			);
 			$this->t->set_var('back_url',$GLOBALS['egw']->link('/index.php',$linkData));
 
-			foreach($this->boemailadmin->getSMTPServerTypes() as $key => $value)
-			{
-				$this->t->set_var("lang_smtp_option_$key",$value);
-			};
+			$this->t->set_var('smtptype',$GLOBALS['egw']->html->select(
+				'smtpsettings[smtpType]',
+				$profileData['smtpType'], 
+				$this->boemailadmin->getSMTPServerTypes(),
+				true,
+				'style="width: 250px;" id="smtpselector" onchange="smtp.display(this.value);"'
+			));
 						
-			foreach($this->boemailadmin->getIMAPServerTypes() as $key => $value)
-			{
-				$this->t->set_var("lang_imap_option_$key",$value['description']);
+			foreach($this->boemailadmin->getIMAPServerTypes() as $key => $value) {
+				$imapServerTypes[$key] = $value['description'];
 			};
+			$selectFrom = $GLOBALS['egw']->html->select(
+				'imapsettings[imapType]', 
+				'', 
+				$imapServerTypes, 
+				false, 
+				// stupid tabs javascript assumes value=position in selectbox, here's a littel workaround ;-)
+				"style='width: 250px;' id='imapselector' onchange='var v=this.value; imap.display(this.value); this.value=v; ea_setIMAPDefaults(this.value);'"
+			);
+			$this->t->set_var('imaptype', $selectFrom);
+
+			$this->t->set_var('value_smtpPort', '25');
+			$this->t->set_var('value_imapPort', '110');
+			$this->t->set_var('value_imapSievePort', '2000');
 						
 			$this->t->parse("out","main");
 			print $this->t->get('out','main');
@@ -170,8 +185,11 @@
 				echo parse_navbar();
 		}
 
-		function editProfile($_profileID='')
-		{
+		function editProfile($_profileID='') {
+			if(!is_object($GLOBALS['egw']->html)) {
+				$GLOBALS['egw']->html =& CreateObject('phpgwapi.html');
+			}
+			                                                        
 			$allGroups = $GLOBALS['egw']->accounts->get_list('groups');
 			foreach($allGroups as $groupInfo)
 			{
@@ -214,22 +232,27 @@
 			
 			$this->translate();
 			
-			foreach((array)$profileData as $key => $value)
-			{
-				//print "$key $value<br>";
-				switch($key)
-				{
+			foreach((array)$profileData as $key => $value) {
+				#print "$key $value<br>";
+				switch($key) {
+					case 'imapTLSEncryption':
+						$this->t->set_var('checked_'. $key .'_'. $value,'checked="1"');
+						break;
+					case 'imapTLSAuthentication':
+						if(!$value) {
+							$this->t->set_var('selected_'.$key,'checked="1"');
+						}
+						break;
 					case 'imapEnableCyrusAdmin':
 					case 'imapEnableSieve':
-					case 'imapTLSAuthentication':
-					case 'imapTLSEncryption':
 					case 'smtpAuth':
 					case 'smtpLDAPUseDefault':
 					case 'userDefinedAccounts':
 					case 'imapoldcclient':
 					case 'editforwardingaddress':
-						if($value == 'yes')
+						if($value == 'yes') {
 							$this->t->set_var('selected_'.$key,'checked="1"');
+						}
 						break;
 					case 'imapType':
 					case 'smtpType':
@@ -261,15 +284,25 @@
 			);
 			$this->t->set_var('back_url',$GLOBALS['egw']->link('/index.php',$linkData));
 
-			foreach($this->boemailadmin->getSMTPServerTypes() as $key => $value)
-			{
-				$this->t->set_var("lang_smtp_option_$key",$value);
-			};
-
-			foreach($this->boemailadmin->getIMAPServerTypes() as $key => $value)
-			{
-				$this->t->set_var("lang_imap_option_$key",$value['description']);
+			$this->t->set_var('smtptype',$GLOBALS['egw']->html->select(
+				'smtpsettings[smtpType]',
+				$profileData['smtpType'], 
+				$this->boemailadmin->getSMTPServerTypes(),
+				true,
+				'style="width: 250px;" id="smtpselector" onchange="smtp.display(this.value);"'
+			));
+			foreach($this->boemailadmin->getIMAPServerTypes() as $key => $value) {
+				$imapServerTypes[$key] = $value['description'];
 			};
+			$selectFrom = $GLOBALS['egw']->html->select(
+				'imapsettings[imapType]', 
+				$profileData['imapType'], 
+				$imapServerTypes, 
+				true, 
+				// stupid tabs javascript assumes value=position in selectbox, here's a littel workaround ;-)
+				"style='width: 250px;' id='imapselector' onchange='var v = this.value; imap.display(this.value); this.value=v;'"
+			);
+			$this->t->set_var('imaptype', $selectFrom);
 						
 			$this->t->parse("out","main");
 			print $this->t->get('out','main');
@@ -367,7 +400,7 @@
 			$rows = array(
 				lang('description'),
 				lang('smtp server name'),
-				lang('imap/pop3 server name'),
+				lang('imap server name'),
 				lang('application'),
 				lang('group'),
 				lang('delete'),
@@ -453,8 +486,7 @@
 			$imapSettings	= array();
 			
 			// try to get the profileID
-			if(is_int(intval($_GET['profileID'])) && !empty($_GET['profileID']))
-			{
+			if(is_int(intval($_GET['profileID'])) && !empty($_GET['profileID'])) {
 				$globalSettings['profileID'] = intval($_GET['profileID']);
 			}
 			$globalSettings['description'] = $_POST['globalsettings']['description'];
@@ -467,33 +499,31 @@
 			
 			// get the settings for the smtp server
 			$smtpType = $_POST['smtpsettings']['smtpType'];
-			foreach($this->boemailadmin->getFieldNames($smtpType,'smtp') as $key)
-			{
+			foreach($this->boemailadmin->getFieldNames($smtpType,'smtp') as $key) {
 				$smtpSettings[$key] = $_POST['smtpsettings'][$smtpType][$key];
 			}
 			$smtpSettings['smtpType'] = $smtpType;
 			
-			#_debug_array($smtpSettings);
+			#_debug_array($smtpSettings); exit;
 			
 			// get the settings for the imap/pop3 server
 			$imapType = $_POST['imapsettings']['imapType'];
-			foreach($this->boemailadmin->getFieldNames($imapType,'imap') as $key)
-			{
-				$imapSettings[$key] = $_POST['imapsettings'][$imapType][$key];
+			foreach($this->boemailadmin->getFieldNames($imapType,'imap') as $key) {
+				switch($key) {
+					case 'imapTLSAuthentication':
+						$imapSettings[$key] = !isset($_POST['imapsettings'][$imapType][$key]);
+						break;
+					default:
+						$imapSettings[$key] = $_POST['imapsettings'][$imapType][$key];
+						break;
+				}
 			}
 			$imapSettings['imapType'] = $imapType;
-			
+
 			#_debug_array($imapSettings);
 			
 			$this->boemailadmin->saveProfile($globalSettings, $smtpSettings, $imapSettings);
-			#if ($_POST['bo_action'] == 'save_ldap' || $_GET['bo_action'] == 'save_ldap')
-			#{
-			#	$this->listProfiles();
-			#}
-			#else
-			#{
-			#	$this->editServer($_GET["serverid"],$_GET["pagenumber"]);
-			#}
+
 			print "<script type=\"text/javascript\">opener.location.reload(); window.close();</script>";
 			$GLOBALS['egw']->common->egw_exit();
 			exit;
@@ -531,7 +561,7 @@
 			$this->t->set_var('lang_LDAP_server_base_dn',lang('LDAP server accounts DN'));
 			$this->t->set_var('lang_use_LDAP_defaults',lang('use LDAP defaults'));
 			$this->t->set_var('lang_LDAP_settings',lang('LDAP settings'));
-			$this->t->set_var('lang_select_type_of_imap/pop3_server',lang('select type of IMAP/POP3 server'));
+			$this->t->set_var('lang_select_type_of_imap/pop3_server',lang('select type of IMAP server'));
 			$this->t->set_var('lang_pop3_server_hostname_or_IP_address',lang('POP3 server hostname or ip address'));
 			$this->t->set_var('lang_pop3_server_port',lang('POP3 server port'));
 			$this->t->set_var('lang_imap_server_hostname_or_IP_address',lang('IMAP server hostname or ip address'));
@@ -545,7 +575,7 @@
 			$this->t->set_var('lang_enable_cyrus_imap_administration',lang('enable Cyrus IMAP server administration'));
 			$this->t->set_var('lang_cyrus_imap_administration',lang('Cyrus IMAP server administration'));
 			$this->t->set_var('lang_admin_username',lang('admin username'));
-			$this->t->set_var('lang_admin_password',lang('admin passwort'));
+			$this->t->set_var('lang_admin_password',lang('admin password'));
 			$this->t->set_var('lang_imap_server_logintyp',lang('imap server logintyp'));
 			$this->t->set_var('lang_standard',lang('username (standard)'));
 			$this->t->set_var('lang_vmailmgr',lang('username@domainname (Virtual MAIL ManaGeR)'));
@@ -564,9 +594,9 @@
 			$this->t->set_var('lang_global_options',lang('global options'));
 			$this->t->set_var('lang_server_settings',lang('server settings'));
 			$this->t->set_var('lang_encryption_settings',lang('encryption settings'));
-			$this->t->set_var('',lang(''));
-			$this->t->set_var('',lang(''));
-			$this->t->set_var('',lang(''));
+			$this->t->set_var('lang_no_encryption',lang('no encryption'));
+			$this->t->set_var('lang_encrypted_connection',lang('encrypted connection'));
+			$this->t->set_var('lang_do_not_validate_certificate',lang('do not validate certificate'));
 			$this->t->set_var('',lang(''));
 			# $this->t->set_var('',lang(''));
 			
