@@ -10,7 +10,7 @@
 	* Free Software Foundation; either version 2 of the License, or (at your    *
 	* option) any later version.                                                *
 	\***************************************************************************/
-	/* $Id: class.uiuserdata.inc.php 19408 2005-10-14 10:10:06Z ralfbecker $ */
+	/* $Id: class.uiuserdata.inc.php 22425 2006-09-14 03:16:48Z lkneschke $ */
 
 	class uiuserdata
 	{
@@ -29,12 +29,23 @@
 	
 		function display_app_header()
 		{
+			if(!@is_object($GLOBALS['egw']->js))
+			{
+				$GLOBALS['egw']->js =& CreateObject('phpgwapi.javascript');
+			}
+			$GLOBALS['egw']->js->validate_file('jscode','editUserdata','emailadmin');
+			$GLOBALS['egw_info']['flags']['include_xajax'] = True;
+
 			$GLOBALS['egw']->common->egw_header();
 			echo parse_navbar();
 		}
 
 		function editUserData($_useCache='0')
 		{
+			if(!is_object($GLOBALS['egw']->html)) {
+				$GLOBALS['egw']->html =& CreateObject('phpgwapi.html');
+			}
+			                                                        
 			$accountID = $_GET['account_id'];			
 			$GLOBALS['account_id'] = $accountID;
 
@@ -69,48 +80,43 @@
 			);
 			$this->t->set_var("form_action", $GLOBALS['egw']->link('/index.php',$linkData));
 
-			// only when we show a existing user
-			if($userData = $this->boemailadmin->getUserData($accountID, $_useCache))
-			{
-				if ($userData['mailAlternateAddress'] != '')
-				{
-					$options_mailAlternateAddress = "<select size=\"6\" name=\"mailAlternateAddress\">\n";
-					for ($i=0;$i < count($userData['mailAlternateAddress']); $i++)
-					{
-						$options_mailAlternateAddress .= "<option value=\"$i\">".
-							$userData['mailAlternateAddress'][$i].
-							"</option>\n";
-					}
-					$options_mailAlternateAddress .= "</select>\n";
-				}
-				else
-				{
-					$options_mailAlternateAddress = lang('no alternate email address');
-				}
+			$this->t->set_var('url_image_add',$GLOBALS['egw']->common->image('phpgwapi','new'));
+			$this->t->set_var('url_image_edit',$GLOBALS['egw']->common->image('phpgwapi','edit'));
+			$this->t->set_var('url_image_delete',$GLOBALS['egw']->common->image('phpgwapi','delete'));
 			
-				if ($userData['mailRoutingAddress'] != '')
-				{
-					$options_mailRoutingAddress = "<select size=\"6\" name=\"mailRoutingAddress\">\n";
-					for ($i=0;$i < count($userData['mailRoutingAddress']); $i++)
-					{
-						$options_mailRoutingAddress .= "<option value=\"$i\">".
-							$userData['mailRoutingAddress'][$i].
-							"</option>\n";
-					}
-					$options_mailRoutingAddress .= "</select>\n";
+			// only when we show a existing user
+			if($userData = $this->boemailadmin->getUserData($accountID)) {
+				$addresses = array();
+				foreach((array)$userData['mailAlternateAddress'] as $data) {
+					$addresses[$data] = $data;
 				}
-				else
-				{
-					$options_mailRoutingAddress = lang('no forwarding email address');
+				$this->t->set_var('selectbox_mailAlternateAddress', $GLOBALS['egw']->html->select(
+					'mailAlternateAddress',
+					'',
+					$addresses, 
+					true, 
+					"style='width: 100%;' id='mailAlternateAddress'",
+					5)
+				);
+			
+				$addresses = array();
+				foreach((array)$userData['mailForwardingAddress'] as $data) {
+					$addresses[$data] = $data;
 				}
+				$this->t->set_var('selectbox_mailRoutingAddress', $GLOBALS['egw']->html->select(
+					'mailForwardingAddress',
+					'',
+					$addresses, 
+					true, 
+					"style='width: 100%;' id='mailRoutingAddress'",
+					5)
+				);
 				
 				$this->t->set_var("quotaLimit",$userData["quotaLimit"]);
 			
 				$this->t->set_var("mailLocalAddress",$userData["mailLocalAddress"]);
 				$this->t->set_var("mailAlternateAddress",'');
 				$this->t->set_var("mailRoutingAddress",'');
-				$this->t->set_var("options_mailAlternateAddress",$options_mailAlternateAddress);
-				$this->t->set_var("options_mailRoutingAddress",$options_mailRoutingAddress);
 				$this->t->set_var("selected_".$userData["qmailDotMode"],'selected');
 				$this->t->set_var("deliveryProgramPath",$userData["deliveryProgramPath"]);
 				
@@ -121,9 +127,7 @@
 					$this->t->set_var("forwardOnly_checked","checked");
 				if ($_accountData["deliverExtern"] == "active")
 					$this->t->set_var("deliver_checked","checked");
-			}
-			else
-			{
+			} else {
 				$this->t->set_var("mailLocalAddress",'');
 				$this->t->set_var("mailAlternateAddress",'');
 				$this->t->set_var("mailRoutingAddress",'');
@@ -131,6 +135,26 @@
 				$this->t->set_var("options_mailRoutingAddress",lang('no forwarding email address'));
 				$this->t->set_var("account_checked",'');
 				$this->t->set_var("forwardOnly_checked",'');
+
+				$this->t->set_var('selectbox_mailAlternateAddress', $GLOBALS['egw']->html->select(
+					'mailAlternateAddress',
+					'',
+					array(), 
+					true, 
+					"style='width: 100%;' id='mailAlternateAddress'",
+					5)
+				);
+			
+				$this->t->set_var('selectbox_mailRoutingAddress', $GLOBALS['egw']->html->select(
+					'mailForwardingAddress',
+					'',
+					array(), 
+					true, 
+					"style='width: 100%;' id='mailRoutingAddress'",
+					5)
+				);
+				
+				$this->t->set_var('quotaLimit','');
 			}
 		
 			// create the menu on the left, if needed		
@@ -143,49 +167,29 @@
 		
 		function saveUserData()
 		{
-			if($_POST["accountStatus"] == "on")
-			{
+			if($_POST["accountStatus"] == "on") {
 				$accountStatus = "active";
 			}
-			if($_POST["forwardOnly"] == "on")
-			{
+			
+			if($_POST["forwardOnly"] == "on") {
 				$deliveryMode = "forwardOnly";
 			}
 
-			$formData = array
-			(
+			$formData = array (
 				'mailLocalAddress'		=> $_POST["mailLocalAddress"],
-				'mailRoutingAddress'		=> $_POST["mailRoutingAddress"],
-				'add_mailAlternateAddress'	=> $_POST["mailAlternateAddressInput"],
-				'remove_mailAlternateAddress'	=> $_POST["mailAlternateAddress"],
+				'mailAlternateAddress'		=> $_POST["mailAlternateAddress"],
+				'mailForwardingAddress'		=> $_POST["mailForwardingAddress"],
 				'quotaLimit'			=> $_POST["quotaLimit"],
-				'add_mailRoutingAddress'	=> $_POST["mailRoutingAddressInput"],
-				'remove_mailRoutingAddress'	=> $_POST["mailRoutingAddress"],
-				
 				'qmailDotMode'			=> $_POST["qmailDotMode"],
 				'deliveryProgramPath'		=> $_POST["deliveryProgramPath"],
-				'accountStatus'			=> $accountStatus,
+				'accountStatus'			=> $accountStatus, 
 				'deliveryMode'			=> $deliveryMode
 			);
-			
-			if($_POST["add_mailAlternateAddress"]) $bo_action='add_mailAlternateAddress';
-			if($_POST["remove_mailAlternateAddress"]) $bo_action='remove_mailAlternateAddress';
-			if($_POST["add_mailRoutingAddress"]) $bo_action='add_mailRoutingAddress';
-			if($_POST["remove_mailRoutingAddress"]) $bo_action='remove_mailRoutingAddress';
-			if($_POST["save"]) $bo_action='save';
-			
-			$this->boemailadmin->saveUserData($_GET['account_id'], $formData, $bo_action);
 
-			if ($bo_action == 'save')
-			{
-				// read date fresh from ldap storage
-				$this->editUserData();
-			}
-			else
-			{
-				// use cached data
-				$this->editUserData('1');
-			}
+			$this->boemailadmin->saveUserData($_GET['account_id'], $formData);
+
+			// read date fresh from ldap storage
+			$this->editUserData();
 		}
 		
 		function translate()
@@ -204,6 +208,8 @@
 			$this->t->set_var('lang_inmbyte',lang('in MByte'));
 			$this->t->set_var('lang_0forunlimited',lang('leave empty for no quota'));
 			$this->t->set_var('lang_forward_only',lang('forward only'));
+			$this->t->set_var('lang_enter_new_address',lang('Add new email address:'));
+			$this->t->set_var('lang_update_current_address',lang('Update current email address:'));
 		}
 	}
 ?>
