@@ -10,11 +10,11 @@
 	*  Free Software Foundation; either version 2 of the License, or (at your  *
 	*  option) any later version.                                              *
 	\**************************************************************************/
-	/* $Id: setup.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: setup.inc.php 23741 2007-04-30 10:29:44Z lkneschke $ */
 
 	$setup_info['emailadmin']['name']      = 'emailadmin';
 	$setup_info['emailadmin']['title']     = 'EMailAdmin';
-	$setup_info['emailadmin']['version']   = '1.2.001';
+	$setup_info['emailadmin']['version']   = '1.4';
 	$setup_info['emailadmin']['app_order'] = 10;
 	$setup_info['emailadmin']['enable']    = 2;
 
@@ -38,6 +38,30 @@
 	/* Dependencies for this app to work */
 	$setup_info['emailadmin']['depends'][] = array(
 		'appname'  => 'phpgwapi',
-		'versions' => Array('1.0.0','1.0.1','1.2')
+		'versions' => Array('1.3','1.4','1.5')
 	);
+	$setup_info['felamimail']['depends'][] = array(
+		'appname'  => 'egw-pear',
+		'versions' => Array('1.4.000','1.5')
+	);
+	// installation checks for felamimail
+	$setup_info['emailadmin']['check_install'] = array(
+		'' => array(
+			'func' => 'pear_check',
+			'from' => 'EMailAdmin',
+		),
+		'Auth_SASL' => array(
+			'func' => 'pear_check',
+			'from' => 'EMailAdmin',
+		),
+		'Net_IMAP' => array(
+			'func' => 'pear_check',
+			'from' => 'FeLaMiMail',
+		),
+		'imap' => array(
+			'func' => 'extension_check',
+			'from' => 'EMailAdmin',
+		),
+	);	
+
 
