@@ -11,7 +11,7 @@
 	*  option) any later version.                                              *
  	\**************************************************************************/
 
-	/* $Id: tables_current.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: tables_current.inc.php 21845 2006-06-15 15:41:02Z lkneschke $ */
 
 	$phpgw_baseline = array(
 		'egw_emailadmin' => array(
@@ -46,11 +46,13 @@
 				'ea_imapoldcclient' => array('type' => 'varchar','precision' => '3'),
 				'ea_order' => array('type' => 'int','precision' => '4'),
 				'ea_appname' => array('type' => 'varchar','precision' => '80'),
-				'ea_group' => array('type' => 'varchar','precision' => '80')
+				'ea_group' => array('type' => 'varchar','precision' => '80'),
+				'ea_smtp_auth_username' => array('type' => 'varchar','precision' => '80'),
+				'ea_smtp_auth_password' => array('type' => 'varchar','precision' => '80')
 			),
 			'pk' => array('ea_profile_id'),
 			'fk' => array(),
-			'ix' => array(),
+			'ix' => array('ea_appname','ea_group'),
 			'uc' => array()
 		)
 	);
