@@ -1,17 +1,16 @@
 <?php
-	/**************************************************************************\
-	* eGroupWare - eTemplate Extension - Advanced search                       *
-	* http://www.egroupware.org                                                *
-	* Written by Cornelius Weiss <egw@von-und-zu-weiss.de>                     *
-	* --------------------------------------------                             *
-	*  This program is free software; you can redistribute it and/or modify it *
-	*  under the terms of the GNU General Public License as published by the   *
-	*  Free Software Foundation; either version 2 of the License, or (at your  *
-	*  option) any later version.                                              *
-	\**************************************************************************/
+	/**
+	 * eGroupWare eTemplate Extension - Advanced search
+	 *
+	 * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+	 * @package etemplate
+	 * @link http://www.egroupware.org
+	 * @author Cornelius Weiss <egw@von-und-zu-weiss.de>
+	 * @deprecated Don't use any more, this will be removed after 1.4 release.
+	 * Please manage advanced searches in you app! 
+	 * @version $Id: class.advancedsearch_widget.inc.php 22729 2006-10-24 20:14:47Z nelius_weiss $
+	 */
 
-	/* $Id: class.advancedsearch_widget.inc.php 22505 2006-09-26 13:11:56Z nelius_weiss $ */
-	
 	/**
 	* eTemplate Extension: Advanced Search
 	*
@@ -55,6 +54,7 @@
 		 */
 		function advancedsearch_widget($ui='')
 		{
+			error_log(__LINE__. __FILE__. "@deprecated Don't use any more, this will be removed after 1.4 release. Please manage advanced searches in you app! ");
 		}
 
 		/**
@@ -149,10 +149,9 @@
 						'search_method' => $extension_data['search_method'],
 						'colums_to_present' => $extension_data['colums_to_present'],
 						'template' => $result_rows_tpl,
-				));
-				
-				$action_buttons =& $tpl->empty_cell('hbox','action_buttons');
-				$tpl->add_child($tpl, $action_buttons);
+					));
+
+				$tpl->add_child($tpl, $action_buttons = $tpl->empty_cell('hbox','action_buttons'));
 				foreach ($extension_data['actions'] as $action => $options)
 				{
 					$tpl->add_child($action_buttons, $result_button = $tpl->empty_cell($options['type'],'action['.$action.']',$options['options']));
@@ -162,9 +161,9 @@
 			else
 			{
 				$GLOBALS['egw_info']['etemplate']['advanced_search'] = true;
-
+				
 				$tpl->add_child($tpl, $search_template = $tpl->empty_cell('template',$extension_data['input_template']));
-				$button_box = $tpl->empty_cell('hbox','button_box');
+				$button_box = $tpl->empty_cell('hbox','button_box'); 
 				$tpl->add_child($tpl, $button_box);
 				$tpl->add_child($button_box, $op_select = $tpl->empty_cell('select','opt_select',array(
 					'sel_options' => array(
@@ -186,7 +185,6 @@
 					'label' => 'Search',
 				)));
 			}
-
 			$cell['size'] = $cell['name'];
 			$cell['type'] = 'template';
 			$cell['name'] = $tpl->name;
@@ -194,7 +192,6 @@
 				
 			// keep the editor away from the generated tmpls
 			$tpl->no_onclick = true;
-//_debug_array($tpl);
 			return True;
 		}
 		
