@@ -1,16 +1,13 @@
 <?php
-	/**************************************************************************\
-	* eGroupWare - EditableTemplates - Business Objects                       *
-	* http://www.eGroupWare.org                                                *
-	* Written by Ralf Becker <RalfBecker@outdoor-training.de>                  *
-	* --------------------------------------------                             *
-	*  This program is free software; you can redistribute it and/or modify it *
-	*  under the terms of the GNU General Public License as published by the   *
-	*  Free Software Foundation; either version 2 of the License, or (at your  *
-	*  option) any later version.                                              *
-	\**************************************************************************/
-
-	/* $Id: class.boetemplate.inc.php 22824 2006-11-10 11:36:13Z ralfbecker $ */
+	/**
+	 * eGroupWare EditableTemplates - Business Objects
+	 *
+	 * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+	 * @package etemplate
+	 * @link http://www.egroupware.org
+	 * @author Ralf Becker <RalfBecker@outdoor-training.de>
+	 * @version $Id: class.boetemplate.inc.php 24423 2007-09-06 12:00:02Z ralfbecker $
+	 */
 
 	include_once(EGW_INCLUDE_ROOT . '/etemplate/inc/class.soetemplate.inc.php');
 
@@ -38,6 +35,7 @@
 			'checkbox'=> 'Checkbox',
 			'radio'	=> 'Radiobutton',	// Radiobutton (size = value if checked)
 			'button'=> 'Submitbutton',
+			'buttononly' => 'Button',	// input type="button"
 			'hrule'	=> 'Horizontal Rule',
 			'template' => 'Template',	// $cell['name'] contains template-name, $cell['size'] index into $content,$cname,$readonlys
 			'image'	=> 'Image',			// label = url, name=link or method, help=alt or title
@@ -51,7 +49,8 @@
 			'groupbox' => 'GroupBox',	// a box with a label containing other elements to group them (html: fieldset)
 			'box'	=> 'Box',			// just a container for widgets (html: div)
 			'grid'	=> 'Grid',			// tabular widget containing rows with columns of widgets
-			'deck'	=> 'Deck'			// a container of elements where only one is visible, size = # of elem.
+			'deck'	=> 'Deck',			// a container of elements where only one is visible, size = # of elem.
+			'passwd' => 'Password'		// a text of type password
 		);
 		var $garbage_collection_done;
 
@@ -72,7 +71,7 @@
 			{
 				$tname = &$name['name'];
 			}
-			$tname = (strstr($tname,'.') === False && !empty($tname) ?
+			$tname = (strpos($tname,'.') === false && !empty($tname) ?
 				(is_array($load_via) ? $load_via['name'] : $load_via).'.':'').$tname;
 
 			if (empty($tname) || !$this->read($name,'','',0,'',$load_via))
@@ -114,7 +113,7 @@
 			{
 				$check_val = $this->get_array($content,substr($check_val,1));
 			}
-			$result = count($vals) == 1 ? $val != '' : $val == $check_val;
+			$result = count($vals) == 1 ? $val != '' : ($check_val{0} == '/' ? preg_match($check_val,$val) : $val == $check_val);
 			if ($not) $result = !$result;
 			//echo "<p>check_disabled: '".($not?'!':'')."$disabled' = '$val' ".(count($vals) == 1 ? '' : ($not?'!':'=')."= '$check_val'")." = ".($result?'True':'False')."</p>\n";
 			return $result;
@@ -134,6 +133,7 @@
 		 * accessing the array it can by the index or the key of an array element.
 		 * To make it short and clear, use "Row$row" or "$col$row" not "$row" or "$row$col" !!!
 		 *
+		 * @static 
 		 * @param sring $name the name to expand
 		 * @param int $c is the column index starting with 0 (if you have row-headers, data-cells start at 1)
 		 * @param int $row is the row number starting with 0 (if you have col-headers, data-cells start at 1)
@@ -150,14 +150,15 @@
 		function expand_name($name,$c,$row,$c_='',$row_='',$cont='')
 		{
 			$is_index_in_content = $name[0] == '@';
-			if (strstr($name,'$') !== False)
+			if (strpos($name,'$') !== false)
 			{
 				if (!$cont)
 				{
 					$cont = array();
 				}
-				$col = $this->num2chrs($c-1);	// $c-1 to get: 0:'@', 1:'A', ...
-				$col_ = $this->num2chrs($c_-1);
+				if (!is_numeric($c)) $c = boetemplate::chrs2num($c);
+				$col = boetemplate::num2chrs($c-1);	// $c-1 to get: 0:'@', 1:'A', ...
+				$col_ = boetemplate::num2chrs($c_-1);
 				$row_cont = $cont[$row];
 				$col_row_cont = $cont[$col.$row];
 
@@ -165,7 +166,7 @@
 			}
 			if ($is_index_in_content)
 			{
-				$name = $this->get_array($cont,substr($name,1));
+				$name = boetemplate::get_array($cont,substr($name,1));
 			}
 			return $name;
 		}
@@ -193,11 +194,11 @@
 		 * @param boolean $check_col to check for col- or row-autorepeat
 		 * @return boolean true if cell is autorepeat (has index with vars / '$') or false otherwise
 		 */
-		function autorepeat_idx($cell,$c,$r,&$idx,&$idx_cname,$check_col=False)
+		function autorepeat_idx($cell,$c,$r,&$idx,&$idx_cname,$check_col=False,$cont=null)
 		{
 			$org_idx = $idx = $cell[ $cell['type'] == 'template' ? 'size' : 'name' ];
 
-			$idx = $this->expand_name($idx,$c,$r);
+			$idx = $this->expand_name($idx,$c,$r,'','',$cont);
 			if (!($komma = strpos($idx,',')))
 			{
 				$idx_cname = $idx;
@@ -209,7 +210,7 @@
 			}
 			$Ok = False;
 			$pat = $org_idx;
-			while (!$Ok && ($pat = strstr($pat,'$')))
+			while (!$Ok && ($pat = @strstr($pat,'$')))
 			{
 				$pat = substr($pat,$pat[1] == '{' ? 2 : 1);
 
@@ -221,7 +222,7 @@
 				else
 				{
 					$Ok = $pat[0] == 'r' && !(substr($pat,0,2) == 'r_' || 
-						substr($pat,0,4) == 'row_' && substr($pat,0,8) != 'row_cont');
+						substr($pat,0,4) == 'row_');
 				}
 			}
 			if ($this->name && $this->name == $this->debug)
@@ -386,67 +387,84 @@
 		/**
 		 * set one or more attibutes for row $n
 		 *
-		 * @deprecated as it uses this->data
 		 * @param int $n numerical row-number starting with 1 (!)
 		 * @param string $height percent or pixel or '' for no height
 		 * @param string $class name of css class (without the leading '.') or '' for no class
 		 * @param string $valign alignment (top,middle,bottom) or '' for none
 		 * @param boolean $disabled True or expression or False to disable or enable the row (Only the number 0 means dont change the attribute !!!)
+		 * @param string $path='/0' default is the first widget in the tree of children
+		 * @return false if $path is no grid or array(height,class,valign,disabled) otherwise
 		 */
-		function set_row_attributes($n,$height=0,$class=0,$valign=0,$disabled=0)
+		function set_row_attributes($n,$height=0,$class=0,$valign=0,$disabled=0,$path='/0')
 		{
-			list($old_height,$old_disabled) = explode(',',$this->data[0]["h$n"]);
+			$grid =& $this->get_widget_by_path($path);
+			if (is_null($grid) || $grid['type'] != 'grid') return false;
+			$grid_attr =& $grid['data'][0];
+
+			list($old_height,$old_disabled) = explode(',',$grid_attr["h$n"]);
 			$disabled = $disabled !== 0 ? $disabled : $old_disabled;
-			$this->data[0]["h$n"] = ($height !== 0 ? $height : $old_height).
+			$grid_attr["h$n"] = ($height !== 0 ? $height : $old_height).
 				($disabled ? ','.$disabled : '');
-			list($old_class,$old_valign) = explode(',',$this->data[0]["c$n"]);
+			list($old_class,$old_valign) = explode(',',$grid_attr["c$n"]);
 			$valign = $valign !== 0 ? $valign : $old_valign;
-			$this->data[0]["c$n"] = ($class !== 0 ? $class : $old_class).
+			$grid_attr["c$n"] = ($class !== 0 ? $class : $old_class).
 				($valign ? ','.$valign : '');
+				
+			list($height,$disabled) = explode(',',$grid_attr["h$n"]);
+			list($class,$valign) = explode(',',$grid_attr["c$n"]);
+			return array($height,$class,$valign,$disabled);
 		}
 
 		/**
 		 * disables row $n
 		 *
-		 * @deprecated as it uses this->data
 		 * @param int $n numerical row-number starting with 1 (!)
 		 * @param boolean $enable=false can be used to re-enable a row if set to True
+		 * @param string $path='/0' default is the first widget in the tree of children
 		 */
-		function disable_row($n,$enable=False)
+		function disable_row($n,$enable=False,$path='/0')
 		{
-			$this->set_row_attributes($n,0,0,0,!$enable);
+			$this->set_row_attributes($n,0,0,0,!$enable,$path);
 		}
 
 		/**
 		 * set one or more attibutes for column $c
 		 *
-		 * @deprecated as it uses this->data
 		 * @param int/string $c numerical column-number starting with 0 (!), or the char-code starting with 'A'
 		 * @param string $width percent or pixel or '' for no height
 		 * @param mixed $disabled=0 True or expression or False to disable or enable the column (Only the number 0 means dont change the attribute !!!)
+		 * @param string $path='/0' default is the first widget in the tree of children
+		 * @return false if $path specifies no grid or array(width,disabled) otherwise
 		 */
-		function set_column_attributes($c,$width=0,$disabled=0)
+		function set_column_attributes($c,$width=0,$disabled=0,$path='/0')
 		{
 			if (is_numeric($c))
 			{
 				$c = $this->num2chrs($c);
 			}
-			list($old_width,$old_disabled) = explode(',',$this->data[0][$c]);
+			$grid =& $this->get_widget_by_path($path);
+			if (is_null($grid) || $grid['type'] != 'grid') return false;
+			$grid_attr =& $grid['data'][0];
+			
+			list($old_width,$old_disabled) = explode(',',$grid_attr[$c]);
 			$disabled = $disabled !== 0 ? $disabled : $old_disabled;
-			$this->data[0][$c] = ($width !== 0 ? $width : $old_width).
+			$grid_attr[$c] = ($width !== 0 ? $width : $old_width).
 				($disabled ? ','.$disabled : '');
+				
+			//echo "set_column_attributes('$c',,'$path'): ".$grid_attr[$c]."</p>\n"; _debug_array($grid_attr);
+			return explode(',',$grid_attr[$c]);
 		}
 
 		/**
 		 * disables column $c
 		 *
-		 * @deprecated as it uses this->data
 		 * @param int/string $c numerical column-number starting with 0 (!), or the char-code starting with 'A'
 		 * @param boolean $enable can be used to re-enable a column if set to True
-		*/
-		function disable_column($c,$enable=False)
+		 * @param string $path='/0' default is the first widget in the tree of children
+		 */
+		function disable_column($c,$enable=False,$path='/0')
 		{
-			$this->set_column_attributes($c,0,!$enable);
+			$this->set_column_attributes($c,0,!$enable,$path);
 		}
 
 		/**
@@ -583,7 +601,9 @@
 				}
 				$pos = &$pos[$idx];
 			}
-			return isset($pos[$last_idx]);
+			// was return isset($pos[$last_idx]);
+			// array_key_exists also returns true for keys with value null, which fixes some problems with autorepeating rows
+			return is_array($pos) && array_key_exists($last_idx,$pos);
 		}
 
 		/**
@@ -621,9 +641,10 @@
 		 * @param array $arr the array to search, referenz as a referenz gets returned
 		 * @param string $idx the index, may contain sub-indices like a[b], see example below
 		 * @param boolean $reference_into default False, if True none-existing sub-arrays/-indices get created to be returned as referenz, else False is returned
+		 * @param bool $skip_empty returns false if $idx is not present in $arr
 		 * @return mixed reference to $arr[$idx] or false if $idx is not set and not $reference_into
 		 */
-		function &get_array(&$arr,$idx,$reference_into=False)
+		function &get_array(&$arr,$idx,$reference_into=False,$skip_empty=False)
 		{
 			if (!is_array($arr))
 			{
@@ -639,11 +660,12 @@
 				{
 					return False;
 				}
+				if($skip_empty && !isset($pos[$idx])) return false;
 				$pos = &$pos[$idx];
 			}
 			return $pos;
 		}
-
+		
 		/**
 		 * unsets $arr[$idx]
 		 *
@@ -690,7 +712,8 @@
 
 				foreach($new as $k => $v)
 				{
-					if (!is_array($v) || !isset($old[$k]))
+					if (!is_array($v) || !isset($old[$k]) || 	// no array or a new array
+						isset($v[0]) && isset($v[count($v)-1]))	// or no associative array, eg. selecting multiple accounts
 					{
 						$old[$k] = $v;
 					}
@@ -723,6 +746,7 @@
 			}
 			$path = implode('/',$path_parts);
 			if ($path == '/' || $path === '') return $this->children;
+			if (count($path_parts) == 2) return $this->children[$path_parts[1]];
 
 			return $this->widget_tree_walk('get_widget_by_path_helper',$path);
 		}
