@@ -1,16 +1,13 @@
 <?php
-	/**************************************************************************\
-	* eGroupWare - eTemplate Extension - Date Widget                           *
-	* http://www.egroupware.org                                                *
-	* Written by Ralf Becker <RalfBecker@outdoor-training.de>                  *
-	* --------------------------------------------                             *
-	*  This program is free software; you can redistribute it and/or modify it *
-	*  under the terms of the GNU General Public License as published by the   *
-	*  Free Software Foundation; either version 2 of the License, or (at your  *
-	*  option) any later version.                                              *
-	\**************************************************************************/
-
-	/* $Id: class.date_widget.inc.php 22216 2006-08-12 06:15:32Z ralfbecker $ */
+	/**
+	 * eGroupWare eTemplate Extension - Date Widget
+	 *
+	 * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+	 * @package etemplate
+	 * @link http://www.egroupware.org
+	 * @author Ralf Becker <RalfBecker@outdoor-training.de>
+	 * @version $Id: class.date_widget.inc.php 24396 2007-08-28 13:01:42Z nelius_weiss $
+	 */
 
 	/**
 	 * eTemplate extension to input or display date and/or time values
@@ -23,6 +20,7 @@
 	 *           &4 = 1min steps for time (default is 5min, with fallback to 1min if value is not in 5min-steps),
 	 *           &8 = dont show time for readonly and type date-time if time is 0:00, 
 	 *           &16 = prefix r/o display with dow
+	 *           &32 = prefix r/o display with week-number
 	 *
 	 * This widget is independent of the UI as it only uses etemplate-widgets and has therefor no render-function.
 	 * Uses the adodb datelibary to overcome the windows-limitation to not allow dates before 1970
@@ -122,16 +120,27 @@
 				$date = split('[- /.:,]',$value);
 				//echo "date=<pre>"; print_r($date); echo "</pre>";
 				$mdy  = split('[- /.:,]',$data_format);
+				
+				if (count($mdy) == 1)	// no seperators, eg. YmdHi
+				{
+					for($n = $i = 0; $n < strlen($data_format); ++$n)
+					{
+						$mdy[$n] = $data_format{$n};
+						$len = $data_format{$n} == 'Y' ? 4 : 2;
+						$date[$n] = substr($value,$i,$len);
+						$i += $len;
+					}
+				}
 				$value = array();
 				foreach ($date as $n => $dat)
 				{
 					switch($mdy[$n])
 					{
-						case 'Y': $value['Y'] = $dat; break;
-						case 'm': $value['m'] = $dat; break;
-						case 'd': $value['d'] = $dat; break;
-						case 'H': $value['H'] = $dat; break;
-						case 'i': $value['i'] = $dat; break;
+						case 'Y': $value['Y'] = (int) $dat; break;
+						case 'm': $value['m'] = (int) $dat; break;
+						case 'd': $value['d'] = (int) $dat; break;
+						case 'H': $value['H'] = (int) $dat; break;
+						case 'i': $value['i'] = (int) $dat; break;
 					}
 				}
 			}
@@ -141,12 +150,11 @@
 				if (substr($type,-4) == 'only') $value -= adodb_date('Z',0);
 
 				$value = array(
-					'Y' => adodb_date('Y',$value),
-					'm' => adodb_date('m',$value),
-					'M' => substr(lang(adodb_date('F',$value)),0,3),
-					'd' => adodb_date('d',$value),
-					'H' => adodb_date('H',$value),
-					'i' => adodb_date('i',$value)
+					'Y' => (int) adodb_date('Y',$value),
+					'm' => (int) adodb_date('m',$value),
+					'd' => (int) adodb_date('d',$value),
+					'H' => (int) adodb_date('H',$value),
+					'i' => (int) adodb_date('i',$value)
 				);
 			}
 			$time_0h0 = !(int)$value['H'] && !(int)$value['i'];
@@ -165,10 +173,25 @@
 			{
 				$format += $timeformat;
 			}
+			if ($value['m'] && strchr($this->dateformat,'M') !== false)
+			{
+				static $month = array('','January','February','March','April','May','June','July','August','September','October','November','December');
+				static $substr;
+				if (is_null($substr)) $substr = function_exists('mb_substr') ? 'mb_substr' : 'substr';
+				static $chars_shortcut;
+				if (is_null($chars_shortcut)) $chars_shortcut = (int)lang('3 number of chars for month-shortcut');	// < 0 to take the chars from the end
+				
+				$value['M'] = lang($m = substr($month[$value['m']],0,3));	// check if we have a translation of the short-cut
+				if ($value['M'] == $m || $substr($value['M'],-1) == '*')	// if not generate one by truncating the translation of the long name
+				{
+					$value['M'] = $chars_shortcut > 0 ? $substr(lang($month[$value['m']]),0,$chars_shortcut) : 
+						$substr(lang($month[$value['m']]),$chars_shortcut);
+				}
+			}
 			if ($readonly)	// is readonly
 			{
 				if ($value['H'] === '') unset($value['a']);	// no am/pm if no hour set
-
+				
 				$sep = array(
 					1 => $this->dateformat[1],
 					2 => $this->dateformat[1],
@@ -177,13 +200,18 @@
 				);
 				for ($str='',$n = substr($type,-4) == 'only' ? 3 : 0; $n < count($format); ++$n)
 				{
-					if ($value[$format[$n]])
+					if ($value[$format[$n]] && $n < 3 || $n >= 3 && ($value[$format[3]] || $value[$format[4]]))
 					{
 						if (!$n && $options & 16 )
 						{
 							$str = lang(adodb_date('l',adodb_mktime(12,0,0,$value['m'],$value['d'],$value['Y']))).' ';
 						}
-						$str .= ($str != '' ? $sep[$n] : '') . $value[$format[$n]];
+						if (!$n && $options & 32 )
+						{
+							$str = lang('Wk').adodb_date('W',adodb_mktime(12,0,0,$value['m'],$value['d'],$value['Y'])).' ';
+						}
+						$str .= ($str != '' ? $sep[$n] : '') . 
+							(is_numeric($value[$format[$n]]) ? sprintf('%02d',$value[$format[$n]]) : $value[$format[$n]]);
 					}
 					if ($type == 'date-houronly') ++$n;	// no minutes
 				}
@@ -241,7 +269,8 @@
 				{
 					$dcell['type'] = 'html';
 					$dcell['name'] = 'str';
-					$value['str'] = $this->jscal->input($name.'[str]',False,$value['Y'],$value['m'],$value['d'],lang($cell['help']));
+					$jscaloptions =  $cell['onchange'] ? ( "onchange='". ( (int)$cell['onchange'] === 1 ? "this.form.submit();'" : $cell['onchange']. "'" ) ) : '' ;
+					$value['str'] = $this->jscal->input($name.'[str]',False,$value['Y'],$value['m'],$value['d'],lang($cell['help']),$jscaloptions);
 					$n = 2;				// no other fields
 					$options &= ~2;		// no set-today button
 				}
@@ -325,7 +354,7 @@
 			$readonly = $readonlys || $cell['readonly'];
 			list($data_format,$input_format,$hours_per_day,$empty_not_0,$short_labels) = explode(',',$cell['size']);
 			if (!$hours_per_day) $hours_per_day = 8; // workday is 8 hours
-			if (($percent_allowed = strstr($input_format,'%') !== false))
+			if (($percent_allowed = strpos($input_format,'%') !== false))
 			{
 				$input_format = str_replace('%','',$input_format);
 			}
@@ -342,6 +371,7 @@
 					'percent_allowed'=> $percent_allowed,
 					'empty_not_0'   => $empty_not_0,
 				);
+				$cell['size'] = '4,,/^-?[0-9]*[,.]?[0-9]*'.($percent_allowed ? '%?' : '').'$/';
 			}
 			if ($value)
 			{
@@ -356,15 +386,14 @@
 				}
 			}			
 			$cell['type'] = 'text';
-			$cell['size'] = '4,,/^-?[0-9]*[,.]?[0-9]*'.($percent_allowed ? '%?' : '').'$/';
 			$cell_name = $cell['name'];
 			$cell['name'] .= '[value]';
 			
-			if (strstr($input_format,'m') && $value && $value < 60)
+			if (strpos($input_format,'m') !== false && $value && $value < 60)
 			{
 				$unit = 'm';
 			}
-			elseif (strstr($input_format,'d') && $value >= 60*$hours_per_day)
+			elseif (strpos($input_format,'d') !== false && $value >= 60*$hours_per_day)
 			{
 				$unit = 'd';
 			}
@@ -383,9 +412,9 @@
 				$tpl->no_onclick = true;
 				
 				$selbox =& $tpl->empty_cell('select',$cell_name.'[unit]');
-				if (strstr($input_format,'m')) $selbox['sel_options']['m'] = $short_labels ? 'm' : 'minutes';
-				if (strstr($input_format,'h')) $selbox['sel_options']['h'] = $short_labels ? 'h' : 'hours';
-				if (strstr($input_format,'d')) $selbox['sel_options']['d'] = $short_labels ? 'd' : 'days';
+				if (strpos($input_format,'m') !== false) $selbox['sel_options']['m'] = $short_labels ? 'm' : 'minutes';
+				if (strpos($input_format,'h') !== false) $selbox['sel_options']['h'] = $short_labels ? 'h' : 'hours';
+				if (strpos($input_format,'d') !== false) $selbox['sel_options']['d'] = $short_labels ? 'd' : 'days';
 				if ($cell['tabindex']) $selbox['tabindex'] = $cell['tabindex'];
 				
 				$tpl->data[0] = array();
@@ -537,7 +566,7 @@
 				{
 					for ($n = 0,$str = ''; $n < strlen($data_format); ++$n)
 					{
-						if (strstr('YmdHi',$c = $data_format[$n]))
+						if (strpos('YmdHi',$c = $data_format[$n]) !== false)
 						{
 							$str .= sprintf($c=='Y'?'%04d':'%02d',$value[$c]);
 						}
