@@ -1,16 +1,13 @@
 <?php
-	/**************************************************************************\
-	* eGroupWare - eTemplates - DB-Tools                                       *
-	* http://www.egroupware.org                                                *
-	* Written by Ralf Becker <RalfBecker@outdoor-training.de>                  *
-	* --------------------------------------------                             *
-	*  This program is free software; you can redistribute it and/or modify it *
-	*  under the terms of the GNU General Public License as published by the   *
-	*  Free Software Foundation; either version 2 of the License, or (at your  *
-	*  option) any later version.                                              *
-	\**************************************************************************/
-
-	/* $Id: class.db_tools.inc.php 20167 2005-12-19 04:27:19Z ralfbecker $ */
+	/**
+	 * eGroupWare  eTemplates - DB-Tools  
+	 *
+	 * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+	 * @package etemplate
+	 * @link http://www.egroupware.org
+	 * @author Ralf Becker <RalfBecker@outdoor-training.de>
+	 * @version $Id: class.db_tools.inc.php 23741 2007-04-30 10:29:44Z lkneschke $
+	 */
 
 	/**
 	 * db-tools: creats and modifys eGroupWare schem-files (to be installed via setup)
@@ -48,20 +45,6 @@
 			'bool'      => 'boolean',
 //			'abstime'   => 'abstime (mysql:timestamp)',
 		);
-		var $setup_header = '<?php
-	/**************************************************************************\\
-	* eGroupWare - Setup                                                       *
-	* http://www.eGroupWare.org                                                *
-	* Created by eTemplates DB-Tools written by ralfbecker@outdoor-training.de *
-	* --------------------------------------------                             *
-	* This program is free software; you can redistribute it and/or modify it  *
-	* under the terms of the GNU General Public License as published by the    *
-	* Free Software Foundation; either version 2 of the License, or (at your   *
-	* option) any later version.                                               *
-	\\**************************************************************************/
-	
-	/* $Id: class.db_tools.inc.php 20167 2005-12-19 04:27:19Z ralfbecker $ */
-';
 
 		/**
 		 * constructor of class
@@ -676,7 +659,7 @@
 			}
 			if (!$header)
 			{
-				$header = $this->setup_header . "\n\n";
+				$header = $this->setup_header($this->app) . "\n\n";
 			}
 			if (!is_writeable(EGW_SERVER_ROOT."/$app/setup") || !($f = fopen($file,'w')))
 			{
@@ -786,7 +769,7 @@
 				}
 				else	// add the tables array
 				{
-					if (strstr($fnew,'?>'))	// remove a closeing tag
+					if (strpos($fnew,'?>') !== false)	// remove a closeing tag
 					{
 						$fnew = str_replace('?>','',$fnew);
 					}
@@ -845,7 +828,7 @@
 			}
 			else
 			{
-				$update = $this->setup_header;
+				$update = $this->setup_header($this->app);
 			}
 			$update .= "
 	\$test[] = '$old_version';
@@ -1067,4 +1050,25 @@
 
 			return $a == $b;
 		}
+		
+	/**
+	 * creates file header 
+	 *
+	 */
+	function setup_header($app)
+	{
+		return '<?php
+
+	/**
+	 * eGroupWare - Setup
+	 * http://www.egroupware.org 
+	 * Created by eTemplates DB-Tools written by ralfbecker@outdoor-training.de
+	 *
+	 * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+	 * @package '. $app. '
+	 * @subpackage setup
+	 * @version $Id: class.db_tools.inc.php 23741 2007-04-30 10:29:44Z lkneschke $
+	 */
+';
 	}
+}
\ No newline at end of file
