@@ -1,16 +1,13 @@
 <?php
-	/**************************************************************************\
-	* eGroupWare - eTemplates - Editor                                         *
-	* http://www.eGroupWare.org                                                *
-	* Written by Ralf Becker <RalfBecker@outdoor-training.de>                  *
-	* --------------------------------------------                             *
-	*  This program is free software; you can redistribute it and/or modify it *
-	*  under the terms of the GNU General Public License as published by the   *
-	*  Free Software Foundation; either version 2 of the License, or (at your  *
-	*  option) any later version.                                              *
-	\**************************************************************************/
-
-	/* $Id: class.editor.inc.php 20458 2006-03-07 23:47:59Z ralfbecker $ */
+	/**
+	 * eGroupWare  eTemplates - Editor   
+	 *
+	 * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+	 * @package etemplate
+	 * @link http://www.egroupware.org
+	 * @author Ralf Becker <RalfBecker@outdoor-training.de>
+	 * @version $Id: class.editor.inc.php 23865 2007-05-14 20:43:23Z lkneschke $
+	 */
 
 	/**
 	 * template editor of the eTemplate package
@@ -23,8 +20,18 @@
 	class editor
 	{
 		var $debug;
-		var $etemplate; // eTemplate we edit
-		var $editor;	// editor eTemplate
+		/**
+		 * eTemplate we edit
+		 *
+		 * @var etemplate
+		 */
+		var $etemplate;
+		/**
+		 * editor eTemplate
+		 *
+		 * @var etemplate
+		 */
+		var $editor;
 		var $aligns = array(
 			'' => 'Left',
 			'right' => 'Right',
@@ -313,7 +320,7 @@
 				$msg = $ok ? lang('Template saved') : lang('Error: while saving !!!');
 				if ($ok) unset($preserv['import']);
 			}
-			elseif (isset($_GET['name']) || isset($content['name']))
+			elseif (!$content['import_xml'] && (isset($_GET['name']) || isset($content['name'])))
 			{
 				if ($_GET['name'])
 				{
@@ -559,7 +566,7 @@
 					}
 					else	// 1 row with 1 column/child
 					{
-						soetemplate::add_child($widget,soetemplate::empty_cell());
+						soetemplate::add_child($widget,$cell=soetemplate::empty_cell());
 					}
 					break;
 
@@ -1192,6 +1199,10 @@
 						$msg .= $this->column_actions($action,$parent,$child_id);
 						break;
 						
+					case '':	// reload, eg. by changing the type
+						$widget = $content['cell'];
+						break;
+
 					default: 
 						// all menu's are (only) working on the parent, referencing widget is unnecessary 
 						// and gives unexpected results, if parent is changed (eg. content gets copied)
@@ -1313,7 +1324,10 @@
 
 			$editor =& new etemplate('etemplate.editor.widget');
 			$type_tmpl =& new etemplate;
-			if ($type_tmpl->read('etemplate.editor.widget.'.$widget['type']))
+
+			list($ext_type) = explode('-',$widget['type']);
+			if ($type_tmpl->read('etemplate.editor.widget.'.$widget['type']) ||
+				$type_tmpl->read('etemplate.editor.widget.'.$ext_type))
 			{
 				$editor->set_cell_attribute('etemplate.editor.widget.generic','obj',$type_tmpl);
 			}
