@@ -1,16 +1,13 @@
 <?php
-	/**************************************************************************\
-	* eGroupWare - eTemplate Extension - Link Widgets / UI for the link class  *
-	* http://www.egroupware.org                                                *
-	* Written by Ralf Becker <RalfBecker@outdoor-training.de>                  *
-	* --------------------------------------------                             *
-	*  This program is free software; you can redistribute it and/or modify it *
-	*  under the terms of the GNU General Public License as published by the   *
-	*  Free Software Foundation; either version 2 of the License, or (at your  *
-	*  option) any later version.                                              *
-	\**************************************************************************/
-
-	/* $Id: class.link_widget.inc.php 20202 2006-01-06 04:50:11Z ralfbecker $ */
+	/**
+	 * eGroupWare  eTemplate Extension - Link Widgets / UI for the link class
+	 *
+	 * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+	 * @package etemplate
+	 * @link http://www.egroupware.org
+	 * @author Ralf Becker <RalfBecker@outdoor-training.de>
+	 * @version $Id: class.link_widget.inc.php 24759 2007-12-06 22:18:19Z ralfbecker $
+	 */
 
 	/**
 	 * eTemplate Extension: several widgets as user-interface for the link-class
@@ -28,6 +25,8 @@
 	 * - link-string: comma-separated list of link-titles with a link to its view method, value is like get_links() 
 	 *	or array with keys to_app and to_id (widget calls then get_links itself)
 	 * - link-add:    Add a new entry of the select app, which is already linked to a given entry
+	 * - link-entry:  Allow to select an entry of a selectable or in options specified app
+	 * - link-apps:   Select an app registerd in the link system, options: '' or 'add'
 	 *
 	 *<code>
 	 * $content[$name] = array(
@@ -39,6 +38,8 @@
 	 *   'link_label'   => // I  string label for the link button, default 'Link'
 	 *  // optional only for the link-add widget
 	 *   'extra'        => // I  array with extra parameters, eg. array('cat_id' => 15)
+	 *  // optional for link-string:
+	 *   'only_app'     => // I  string with appname, eg. 'projectmananager' to list only linked projects
 	 * );
 	 *</code>
 	 *
@@ -55,8 +56,9 @@
 		 * @var array exported methods of this class
 		 */
 		var $public_functions = array(
-			'pre_process' => True,
-			'post_process' => True
+			'pre_process'  => True,
+			'post_process' => True,
+			'ajax_search'  => True,
 		);
 		/**
 		 * @var array availible extensions and there names for the editor
@@ -67,13 +69,17 @@
 			'link-list'   => 'LinkList',
 			'link-string' => 'LinkString',
 			'link-add'    => 'LinkEntry',
+			'link-entry'  => 'Select entry',
+			'link-apps'   => 'LinkApps',
 		);
 		/**
 		 * @var boolean $debug switches debug-messages on and off
 		 */
 		var $debug = False;
 		/**
-		 * @var object $link reference to the link class
+		 * reference to the link class
+		 * 
+		 * @var bolink
 		 */
 		var $link;
 
@@ -82,11 +88,11 @@
 		 *
 		 * @param string $ui '' for html
 		 */
-		function link_widget($ui)
+		function link_widget($ui='')
 		{
 			if (!is_object($GLOBALS['egw']->link))
 			{
-				$GLOBALS['egw']->link =& CreateObject('infolog.bolink');
+				$GLOBALS['egw']->link =& CreateObject('phpgwapi.bolink');
 			}
 			$this->link =& $GLOBALS['egw']->link;
 		}
@@ -106,17 +112,19 @@
 		 */
 		function pre_process($name,&$value,&$cell,&$readonlys,&$extension_data,&$tmpl)
 		{
-			$type = $cell['type'];
+			$extension_data['type'] = $type = $cell['type'];
+			$extension_data['needed'] = $cell['needed'];
 			$help = $cell['help'] ? ($value['help'] ? $value['help'] : $cell['help']) : lang('view this linked entry in its application');
 
-			if (($type == 'link-to' || $type == 'link-add') && ($cell['readonly'] || $readonlys))
+			if (($type == 'link-to' || $type == 'link-add' || $type == 'link-entry' && !$value) && ($cell['readonly'] || $readonlys))
 			{
-				//echo "<p>link-to is readonly, cell=".print_r($cell,true).", readonlys=".print_r($readonlys)."</p>\n";
+				//echo "<p>link-to is readonly, cell=".print_r($cell,true).", readonlys=".print_r($readonlys).", value='$value'</p>\n";
 				// readonly ==> omit the whole widget
+				$value = '';
 				$cell = $tmpl->empty_cell();
 				return;
 			}
-			if (!is_array($value) && $type != 'link-string' && $type != 'link')
+			if (!is_array($value) && in_array($type,array('link-to','link-list','link-add')))
 			{
 				$value = array(
 					'to_id' => $value,
@@ -129,7 +137,7 @@
 				echo "<p>start: $cell[type][$name]::pre_process: value ="; _debug_array($value);
 				echo "extension_data[$cell[type]][$name] ="; _debug_array($extension_data);
 			}
-			switch ($type = $cell['type'])
+			switch ($cell['type'])
 			{
 			case 'link':
 				$cell['readonly'] = True;	// set it readonly to NOT call our post_process function
@@ -150,7 +158,7 @@
 					}
 					if (!$cell['help'])
 					{
-						$cell['help'] = $help;
+						$cell['help'] = $value['help'];
 						$cell['no_lang'] = 2;
 					}
 				}
@@ -169,9 +177,24 @@
 
 			case 'link-string':
 				$str = '';
-				if ($values['to_id'] && $values['to_app'])
+				if ($value && !is_array($value) && $cell['size'])
 				{
-					$values = $this->link->get_links($values['to_app'],$values['to_id']);
+					$value = array('to_id' => $value);
+					list($value['to_app'],$value['only_app']) = explode(',',$cell['size']);
+				}
+				if ($value['to_id'] && $value['to_app'])
+				{
+					$value = $this->link->get_links($value['to_app'],$value['to_id'],$only_app = $value['only_app']);
+					if ($only_app)
+					{
+						foreach($value as $key => $id)
+						{
+							$value[$key] = array(
+								'id'  => $id,
+								'app' => $only_app,
+							);
+						}
+					}
 				}
 				if (is_array($value))
 				{
@@ -199,14 +222,14 @@
 				return True;
 
 			case 'link-add':
-				$apps = $this->link->app_list($type == 'link-add' ? 'add' : '');
-				if (!$apps)	// cant do an add without apps or already created entry
+				$apps = $this->link->app_list($type == 'link-add' ? 'add_app' : 'query');
+				if (!$apps || !$value['to_id'] || is_array($value['to_id']))	// cant do an add without apps or already created entry
 				{
 					$cell = $tmpl->empty_cell();
 					return;
 				}
 				asort($apps);	// sort them alphabetic
-				$value['options-app'] = array();
+				$value['options-add_app'] = array();
 				foreach($apps as $app => $label)
 				{
 					$link = $GLOBALS['egw']->link('/index.php',$this->link->add($app,$value['to_app'],$value['to_id'])+
@@ -220,12 +243,21 @@
 					{
 						$action = "location.href = '$link';";
 					}
-					$value['options-app'][$action] = $label;
+					$value['options-add_app'][$action] = $label;
+					// modify add_app default to the action used as value
+					if (isset($value['add_app']) && $app == $value['add_app']) $value['add_app'] = $action;
 				}
 				$tpl =& new etemplate('etemplate.link_widget.add');
 				break;
 
 			case 'link-to':
+				$GLOBALS['egw_info']['flags']['include_xajax'] = true;
+				if ($value['search_label'] && $extension_data['search_label'] != $value['search_label']) $value['search_label'] = lang($value['search_label']);
+				$extension_data = $value;
+				$tpl =& new etemplate('etemplate.link_widget.to');
+				if ($value['link_label']) $tpl->set_cell_attribute('create','label',$value['link_label']);
+				if ($value['search_label']) $tpl->set_cell_attribute('search','label',$value['search_label']);
+				/* old request code
 				$value['msg'] = '';
 				if ($value['button'] == 'search' && count($ids = $this->link->query($value['app'],$value['query'])))
 				{
@@ -251,7 +283,7 @@
 						$extension_data = $value;
 					}
 					$value = array_merge($extension_data,$value);
-					$value['options-app'] = $this->link->app_list();
+					$value['options-app'] = $this->link->app_list('query');
 					asort($value['options-app']);	// sort them alphabetic
 
 					$tpl =& new etemplate('etemplate.link_widget.search');
@@ -261,7 +293,7 @@
 					}
 					$tpl->set_cell_attribute('comment','onchange',"set_style_by_class('*','hide_comment','display',this.checked ? 'block' : 'none');");
 					unset($value['comment']);
-				}
+				}*/
 				break;
 
 			case 'link-list':
@@ -312,6 +344,83 @@
 					}
 				}
 				break;
+
+			case 'link-entry':
+				$GLOBALS['egw_info']['flags']['include_xajax'] = true;
+				$tpl =& new etemplate('etemplate.link_widget.entry');
+				$options = $cell['size'] ? explode(',',$cell['size']) : array();
+				$app = $extension_data['app'] = array_shift($options);
+				if ($value)	// show pre-selected entry in select-box and not the search
+				{
+					// add selected-entry plus "new search" to the selectbox-options
+					if (($app = $cell['size']))
+					{
+						$id = $value;
+					}
+					else
+					{
+						list($app,$id) = explode(':',$value);
+					}
+					$titles = array();
+					foreach(explode(',',$id) as $id)
+					{
+						if ($id && ($title = $this->link->title($app,$id)))
+						{
+							$titles[$id] = $title;
+						}
+					}
+					if ($titles)
+					{
+						$titles[''] = lang('new search').' ...';
+						$selectbox =& $tpl->get_widget_by_name('id');
+						$selectbox['sel_options'] = $titles;
+						// remove link_hide class from select-box-line
+						$span =& $tpl->get_cell_attribute('select_line','span');
+						$span = str_replace('link_hide','',$span);
+						// add link_hide class to search_line
+						$span =& $tpl->get_cell_attribute('search_line','span');
+						$span .= ' link_hide';
+						unset($span);
+					}
+				}
+				if ($extension_data['app'])	// no app-selection, using app given in first option
+				{
+					$tpl->disable_cells('app');	
+					$onchange =& $tpl->get_cell_attribute('search','onclick');
+					$onchange = str_replace("document.getElementById(form::name('app')).value",'\''.$cell['size'].'\'',$onchange);
+					unset($onchange);
+				}
+				$value = array(
+					'app'        => $app,
+					'no_app_sel' => !!$extension_data['app'],
+					'id'         => $value,
+				);
+				if ($options)	// limit the app-selectbox to the given apps
+				{
+					$tpl->set_cell_attribute('app','type','select');
+					$tpl->set_cell_attribute('app','no_lang',true);
+					$apps = $this->link->app_list('query');
+					asort($apps);	// sort them alphabetic
+					foreach($apps as $app => $label)
+					{
+						if (!in_array($app,$options)) unset($apps[$app]);
+					}
+					$value['options-app'] = $apps;
+				}
+				break;
+				
+			case 'link-apps':
+				$apps = $this->link->app_list($cell['size'] ? $cell['size'] : 'query');
+				if (!$apps)	// cant do an add without apps or already created entry
+				{
+					$cell = $tmpl->empty_cell();
+					return;
+				}
+				asort($apps);	// sort them alphabetic
+				$cell['sel_options'] = $apps;
+				$cell['no_lang'] = True;	// already translated
+				$cell['type'] = 'select';
+				return true;
 			}
 			$cell['size'] = $cell['name'];
 			$cell['type'] = 'template';
@@ -348,6 +457,26 @@
 		{
 			//echo "<p>link_widget::post_process('$name',value=".print_r($value,true).",ext=".print_r($extension_data,true).",$loop,,value_in=".print_r($value_in,true)."</p>\n";
 
+			switch($extension_data['type'])
+			{
+				case 'link-entry':
+					if (!$value_in['id'] && $extension_data['needed'])
+					{
+						$tmpl->set_validation_error($name,lang('Field must not be empty !!!'),'');
+						return true;
+					}
+					$value = $extension_data['app'] ? $value_in['id'] : $value['app'].':'.$value_in['id'];
+					return !!$value_in['id'];
+					
+				case 'link-apps':
+					if (!$value_in && $extension_data['needed'])
+					{
+						$tmpl->set_validation_error($name,lang('Field must not be empty !!!'),'');
+						return true;
+					}
+					$value = $value_in;
+					return !!$value;
+			}
 			$buttons = array('search','create','new','upload','attach');
 			while (!$button && list(,$bname) = each($buttons))
 			{
@@ -377,7 +506,7 @@
 					{
 						$link_id = $this->link->link($value['to_app'],$value['to_id'],
 							$value['app'],$value['id'],$value['remark']);
-						$value['remark'] = '';
+						$value['remark'] = $value['query'] = '';
 
 						if (isset($value['primary']) && !$value['anz_links'] )
 						{
@@ -408,6 +537,7 @@
 						{
 							$value['primary'] = $link_id;
 						}
+						unset($value['comment']);
 						unset($value['file']);
 					}
 					else
@@ -440,4 +570,47 @@
 			}
 			return True;
 		}
+		
+		/**
+		 * ajax callback to search in $app for $pattern, result is displayed in $id
+		 *
+		 * @param string $app app-name to search
+		 * @param string $pattern search-pattern
+		 * @param string $id_res id of selectbox to show the result
+		 * @param string $id_hide id(s) of the search-box/-line to hide after a successful search
+		 * @param string $id_show id(s) of the select-box/-line to show after a successful search
+		 * @param string $id_input id of the search input-field
+		 */
+		function ajax_search($app,$pattern,$id_res,$id_hide,$id_show,$id_input)
+		{
+			$response = new xajaxResponse();
+			//$args = func_get_args(); $response->addAlert("link_widget::ajax_search('".implode("','",$args)."')");
+			
+			if (!($found = $this->link->query($app,$pattern == lang('Search') ? '' : $pattern)))	// ignore the blur-text
+			{
+				$GLOBALS['egw']->translation->add_app('etemplate');
+				$response->addAlert(lang('Nothing found - try again !!!'));
+				$response->addScript("document.getElementById('$id_input').select();");
+			}
+			else
+			{
+				$script = "var select = document.getElementById('$id_res');\nselect.options.length=0;\n";
+				foreach($found as $id => $title)
+				{
+					$script .= "select.options[select.options.length] = new Option('".addslashes($title)."','$id');\n";
+				}
+				$script .= "select.options[select.options.length] = new Option('".addslashes(lang('New search').' ...')."','');\n";
+				foreach(explode(',',$id_show) as $id)
+				{
+					$script .= "document.getElementById('$id').style.display='inline';\n";
+				}
+				foreach(explode(',',$id_hide) as $id)
+				{
+					$script .= "document.getElementById('$id').style.display='none';\n";
+				}
+				//$response->addAlert($script);
+				$response->addScript($script);
+			}
+			return $response->getXML();
+		}
 	}
