@@ -1,21 +1,18 @@
 <?php
-	/**************************************************************************\
-	* eGroupWare - eTemplate Extension - Select Widgets                        *
-	* http://www.egroupware.org                                                *
-	* Written by Ralf Becker <RalfBecker@outdoor-training.de>                  *
-	* --------------------------------------------                             *
-	*  This program is free software; you can redistribute it and/or modify it *
-	*  under the terms of the GNU General Public License as published by the   *
-	*  Free Software Foundation; either version 2 of the License, or (at your  *
-	*  option) any later version.                                              *
-	\**************************************************************************/
-
-	/* $Id: class.select_widget.inc.php 23570 2007-04-06 12:15:59Z ralfbecker $ */
+	/**
+	 * eGroupWare  eTemplate Extension - Select Widgets
+	 *
+	 * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+	 * @package etemplate
+	 * @link http://www.egroupware.org
+	 * @author Ralf Becker <RalfBecker@outdoor-training.de>
+	 * @version $Id: class.select_widget.inc.php 24337 2007-07-23 09:21:22Z ralfbecker $
+	 */
 
 	/**
 	 * eTemplate Extension: several select-boxes with predefined eGW specific content
 	 *
-	 * This widgets replaces the old phpgwapi.sbox class. The widgets are independent of the UI,
+	 * This widgets replaces the not longer exiting phpgwapi.sbox class. The widgets are independent of the UI,
 	 * as they only uses etemplate-widgets and therefor have no render-function.
 	 *
 	 * @package etemplate
@@ -52,7 +49,8 @@
 			'select-dow'      => 'Select Day of week',
 			'select-hour'     => 'Select Hour',		// either 0-23 or 12am,1am-11am,12pm,1pm-11pm
 			'select-number'   => 'Select Number',
-			'select-app'      => 'Select Application'
+			'select-app'      => 'Select Application',
+			'select-lang'     => 'Select Language',
 		);
 		/**
 		 * @var array
@@ -72,64 +70,6 @@
 			11 => 'November',
 			12 => 'December'
 		);
-		/**
-		 * @var array
-		 */
-		var $states = array(
-			''		=> '',
-			'--'	=> 'non US',
-			'AL'	=>	'Alabama',
-			'AK'	=>	'Alaska',
-			'AZ'	=>	'Arizona',
-			'AR'	=>	'Arkansas',
-			'CA'	=>	'California',
-			'CO'	=>	'Colorado',
-			'CT'	=>	'Connecticut',
-			'DE'	=>	'Delaware',
-			'DC'	=>	'District of Columbia',
-			'FL'	=>	'Florida',
-			'GA'	=>	'Georgia',
-			'HI'	=>	'Hawaii',
-			'ID'	=>	'Idaho',
-			'IL'	=>	'Illinois',
-			'IN'	=>	'Indiana',
-			'IA'	=>	'Iowa',
-			'KS'	=>	'Kansas',
-			'KY'	=>	'Kentucky',
-			'LA'	=>	'Louisiana',
-			'ME'	=>	'Maine',
-			'MD'	=>	'Maryland',
-			'MA'	=>	'Massachusetts',
-			'MI'	=>	'Michigan',
-			'MN'	=>	'Minnesota',
-			'MO'	=>	'Missouri',
-			'MS'	=>	'Mississippi',
-			'MT'	=>	'Montana',
-			'NC'	=>	'North Carolina',
-			'ND'	=>	'Noth Dakota',
-			'NE'	=>	'Nebraska',
-			'NH'	=>	'New Hampshire',
-			'NJ'	=>	'New Jersey',
-			'NM'	=>	'New Mexico',
-			'NV'	=>	'Nevada',
-			'NY'	=>	'New York',
-			'OH'	=>	'Ohio',
-			'OK'	=>	'Oklahoma',
-			'OR'	=>	'Oregon',
-			'PA'	=>	'Pennsylvania',
-			'RI'	=>	'Rhode Island',
-			'SC'	=>	'South Carolina',
-			'SD'	=>	'South Dakota',
-			'TN'	=>	'Tennessee',
-			'TX'	=>	'Texas',
-			'UT'	=>	'Utah',
-			'VA'	=>	'Virginia',
-			'VT'	=>	'Vermont',
-			'WA'	=>	'Washington',
-			'WI'	=>	'Wisconsin',
-			'WV'	=>	'West Virginia',
-			'WY'	=>	'Wyoming'
-		);
 
 		/**
 		 * Constructor of the extension
@@ -167,6 +107,7 @@
 
 			$extension_data['type'] = $cell['type'];
 
+			$readonly = $cell['readonly'] || $readonlys;
 			switch ($cell['type'])
 			{
 				case 'select-percent':	// options: #row,decrement(default=10)
@@ -195,30 +136,30 @@
 					);
 					break;
 
-				case 'select-country':
-					if (!$this->countrys)
+				case 'select-country':	// #Row|Extralabel,1=use country name, 0=use 2 letter-code
+					if (!is_object($GLOBALS['egw']->country))
 					{
-						$country =& CreateObject('phpgwapi.country');
-						$this->countrys = &$country->country_array;
-						unset($country);
-						unset($this->countrys['  ']);
-						$this->countrys[''] = '';
-						// try to translate them and sort alphabetic
-						foreach($this->countrys as $k => $name)
+						$GLOBALS['egw']->country =& CreateObject('phpgwapi.country');
+					}
+					$cell['sel_options'] = $GLOBALS['egw']->country->countries();
+
+					if (($extension_data['country_use_name'] = $type) && $value)
+					{
+						$value = $GLOBALS['egw']->country->country_code($value);
+						if (!isset($cell['sel_options'][$value]))
 						{
-							if (($translated = lang($name)) != $name.'*')
-							{
-								$this->countrys[$k] = $translated;
-							}
+							$cell['sel_options'][$value] = $value;
 						}
-						asort($this->countrys);
 					}
-					$cell['sel_options'] = $this->countrys;
 					$cell['no_lang'] = True;
 					break;
 
 				case 'select-state':
-					$cell['sel_options'] = $this->states;
+					if (!is_object($GLOBALS['egw']->country))
+					{
+						$GLOBALS['egw']->country =& CreateObject('phpgwapi.country');
+					}
+					$cell['sel_options'] = $GLOBALS['egw']->country->us_states();
 					$cell['no_lang'] = True;
 					break;
 
@@ -227,6 +168,26 @@
 					{
 						$GLOBALS['egw']->categories =& CreateObject('phpgwapi.categories');
 					}
+					if ($readonly)	// for readonly we dont need to fetch all cat's, nor do we need to indent them by level
+					{
+						$cell['no_lang'] = True;
+						if ($value)
+						{
+							if (!is_array($value)) $value = explode(',',$value);
+							foreach($value as $key => $id)
+							{
+								if ($id && ($name = stripslashes($GLOBALS['egw']->categories->id2name($id))) && $name != '--')
+								{
+									$cell['sel_options'][$id] = $name;
+								}
+								else
+								{
+									unset($value[$key]);	// remove not (longer) existing or inaccessible cats
+								}
+							}
+						}
+						break;
+					}
 					if (!$type3 || $type3 === $GLOBALS['egw']->categories->app_name)
 					{
 						$categories =& $GLOBALS['egw']->categories;
@@ -252,11 +213,16 @@
 							$cell['sel_options'][$cat['cat_id']] = $s;
 						}
 					}
+					// preserv unavailible cats (eg. private user-cats)
+					if ($value && ($unavailible = array_diff(is_array($value) ? $value : explode(',',$value),array_keys((array)$cell['sel_options']))))
+					{
+						$extension_data['unavailible'] = $unavailible;
+					}
 					$cell['size'] = $rows.($type2 ? ','.$type2 : '');
 					$cell['no_lang'] = True;
 					break;
 
-				case 'select-account':	// options: #rows,{accounts(default)|both|groups|owngroups},{0(=lid)|1(default=name)|2(=lid+name))}
+				case 'select-account':	// options: #rows,{accounts(default)|both|groups|owngroups},{0(=lid)|1(default=name)|2(=lid+name),expand-multiselect-rows)}
 					//echo "<p>select-account widget: name=$cell[name], type='$type', rows=$rows, readonly=".(int)($cell['readonly'] || $readonlys)."</p>\n";
 					if($type == 'owngroups') 
 					{
@@ -265,7 +231,7 @@
 						foreach($GLOBALS['egw']->accounts->membership() as $group) $mygroups[] = $group['account_id'];
 					}
 					// in case of readonly, we read/create only the needed entries, as reading accounts is expensive
-					if ($cell['readonly'] || $readonlys)
+					if ($readonly)
 					{
 						$cell['no_lang'] = True;
 						foreach(is_array($value) ? $value : (strpos($value,',') !== false ? explode(',',$value) : array($value)) as $id)
@@ -278,7 +244,8 @@
 					{
 						if (!is_object($GLOBALS['egw']->uiaccountsel))
 						{
-							$GLOBALS['egw']->uiaccountsel =& CreateObject('phpgwapi.uiaccountsel');
+							require_once(EGW_API_INC.'/class.uiaccountsel.inc.php');
+							$GLOBALS['egw']->uiaccountsel =& new uiaccountsel;
 						}
 						$help = (int)$cell['no_lang'] < 2 ? lang($cell['help']) : $cell['help'];
 						$onFocus = "self.status='".addslashes(htmlspecialchars($help))."'; return true;";
@@ -292,8 +259,9 @@
 							$onlyPrint = $onlyPrint ? implode('<br />',$onlyPrint) : lang((int)$rows < 0 ? 'all' : $rows);
 							$noPrint_class = ' class="noPrint"';
 						}
+						if (($rows > 0 || $type3) && substr($name,-2) != '[]') $name .= '[]';
 						$value = $GLOBALS['egw']->uiaccountsel->selection($name,'eT_accountsel_'.str_replace(array('[','][',']'),array('_','_',''),$name),
-							$value,$type,$rows > 0 ? $rows : 0,False,' onfocus="'.$onFocus.'" onblur="'.$onBlur.'"'.$noPrint_class,
+							$value,$type,$rows > 0 ? $rows : ($type3 ? -$type3 : 0),False,' onfocus="'.$onFocus.'" onblur="'.$onBlur.'"'.$noPrint_class,
 							$cell['onchange'] == '1' ? 'this.form.submit();' : $cell['onchange'],
 							!empty($rows) && 0+$rows <= 0 ? lang($rows < 0 ? 'all' : $rows) : False);
 						if ($cell['noprint'])
@@ -390,7 +358,6 @@
 					}
 					$value_in = $value;
 					$value = array();
-					$readonly = $cell['readonly'] || $readonlys;
 					foreach($cell['sel_options'] as $val => $lable)
 					{
 						if (($value_in & $val) == $val)
@@ -427,11 +394,11 @@
 						$format = '%0'.strlen($type3).'d';
 					}
 					$type3 = !$type3 ? 1 : intval($type3);			// decrement
-					if (($type < $type2) != ($type3 > 0))
+					if (($type <= $type2) != ($type3 > 0))
 					{
 						$type3 = -$type3;	// void infinite loop
 					}
-					for ($i=0,$n=$type; $n <= $type2 && $i <= 100; $n += $type3)
+					for ($i=0,$n=$type; $n <= $type2 && $i <= 100; $n += $type3,++$i)
 					{
 						$cell['sel_options'][$n] = sprintf($format,$n);
 					}
@@ -481,6 +448,10 @@
 						$cell['sel_options'][$app] = $apps[$app];
 					}
 					break;
+				case 'select-lang':
+					$cell['sel_options'] = $GLOBALS['egw']->translation->list_langs();
+					$cell['no_lang'] = True;
+				break;
 			}
 			if ($rows > 1)
 			{
@@ -502,6 +473,7 @@
 			if (!is_array($acc))
 			{
 				$data = $GLOBALS['egw']->accounts->get_account_data($id);
+				if (!isset($data[$id])) return '#'.$id;
 				foreach(array('type','lid','firstname','lastname') as $name)
 				{
 					$acc['account_'.$name] = $data[$id][$name];
@@ -554,6 +526,22 @@
 		{
 			switch ($extension_data['type'])
 			{
+				case 'select-cat':
+					$value = $value_in;
+					// check if we have some unavailible cats and add them again
+					if (is_array($extension_data['unavailible']) && $extension_data['unavailible'])
+					{
+						if (is_array($value))	// multiselection
+						{
+							$value = array_merge($value,$extension_data['unavailible']);
+						}
+						elseif (!$value)		// non-multiselection and nothing selected by the user
+						{
+							$value = $extension_data['unavailible'][0];
+						}
+					}
+					break;
+
 				case 'select-dow':
 					$value = 0;
 					if (!is_array($value_in)) $value_in = explode(',',$value_in);
@@ -563,6 +551,19 @@
 					}
 					//echo "<p>select_widget::post_process('$name',...,'$value_in'): value='$value'</p>\n";
 					break;
+				case 'select-country':
+					if ($extension_data['country_use_name'] && $value_in)
+					{
+						if (!is_object($GLOBALS['egw']->country))
+						{
+							$GLOBALS['egw']->country =& CreateObject('phpgwapi.country');
+						}
+						if (($value = $GLOBALS['egw']->country->get_full_name($value_in)))
+						{
+							break;
+						}
+					}
+					// fall through
 				default:
 					$value = $value_in;
 					break;
