@@ -1,16 +1,13 @@
 <?php
-	/**************************************************************************\
-	* eGroupWare - generalized SQL Storage Object                              *
-	* http://www.egroupware.org                                                *
-	* Written by Ralf Becker <RalfBecker@outdoor-training.de>                  *
-	* --------------------------------------------                             *
-	*  This program is free software; you can redistribute it and/or modify it *
-	*  under the terms of the GNU General Public License as published by the   *
-	*  Free Software Foundation; either version 2 of the License, or (at your  *
-	*  option) any later version.                                              *
-	\**************************************************************************/
-
-	/* $Id: class.so_sql.inc.php 21495 2006-04-30 16:45:38Z ralfbecker $ */
+/**
+ * eGroupWare generalized SQL Storage Object
+ *
+ * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+ * @package etemplate
+ * @link http://www.egroupware.org
+ * @author Ralf Becker <RalfBecker@outdoor-training.de>
+ * @version $Id: class.so_sql.inc.php 24501 2007-10-07 13:29:59Z ralfbecker $
+ */
 
 /**
  * generalized SQL Storage Object
@@ -28,43 +25,63 @@
 class so_sql
 {
  	/** 
- 	 * @var string $table_name need to be set in the derived class to the db-table-name 
+ 	 * need to be set in the derived class to the db-table-name 
+ 	 * 
+ 	 * @var string
  	 */
 	var $table_name;
  	/**
- 	 * @var string $autoinc_id db-col-name of autoincrement id or ''
+ 	 * db-col-name of autoincrement id or ''
+ 	 * 
+ 	 * @var string
  	 */
 	var $autoinc_id = '';
 	/**
-	 * @var array $non_db_cols all cols in data which are not (direct)in the db, for data_merge
+	 * all cols in data which are not (direct)in the db, for data_merge
+	 * 
+	 * @var array
 	 */
 	var $non_db_cols = array();
 	/**
-	 * @var int $debug=0 4 turns on the so_sql debug-messages
+	 * 4 turns on the so_sql debug-messages, default 0
+	 * 
+	 * @var int
 	 */
 	var $debug = 0;
 	/**
-	 * @var string $empty_on_write string to be written to db if a col-value is '', eg. "''" or 'NULL' (default)
+	 * string to be written to db if a col-value is '', eg. "''" or 'NULL' (default)
+	 * 
+	 * @var string
 	 */
 	var $empty_on_write = 'NULL';
 	/**
-	 * @var int/boolean $total total number of entries of last search with start != false
+	 * total number of entries of last search with start != false
+	 * 
+	 * @var int/boolean
 	 */
 	var $total = false;
 	/**
-	 * @var db-object $db privat instance of the db-object
+	 * privat instance of the db-object
+	 * 
+	 * @var egw_db
 	 */
 	var $db;
 	/**
-	 * @var array $db_uni_cols unique keys/index, set by derived class or via so_sql($app,$table)
+	 * unique keys/index, set by derived class or via so_sql($app,$table)
+	 * 
+	 * @var array
 	 */
 	var $db_uni_cols = array();
 	/**
-	 * @var array $db_key_cols db-col-name / internal-name pairs, set by derived calls or via so_sql($app,$table) 
+	 * db-col-name / internal-name pairs, set by derived calls or via so_sql($app,$table)
+	 * 
+	 * @var array
 	 */
 	var $db_key_cols = array();
 	/**
-	 * @var array $db_data_cols db-col-name / internal-name pairs, set by derived calls or via so_sql($app,$table) 
+	 * db-col-name / internal-name pairs, set by derived calls or via so_sql($app,$table) 
+	 * 
+	 * @var array
 	 */
 	var $db_data_cols = array();
 	/**
@@ -72,16 +89,20 @@ class so_sql
 	 */
 	var $db_cols = array();
 	/**
-	 * @var array $this->table_def eGW table definition
+	 * eGW table definition
+	 * 
+	 * @var array
 	 */
 	var $table_def = array();
 	/**
-	 * @var array $data holds the content of all columns
+	 * holds the content of all columns
+	 * 
+	 * @var array
 	 */
 	var $data = array();
 	/**
 	 * @deprecated  a SO class dont need to and should NOT export functions (make them callable via menuaction)
-	 * @var array $public_functions
+	 * @var array
 	 */
 	var $public_functions = array();
 
@@ -94,6 +115,8 @@ class so_sql
 	 * @param string $table should be set if table-defs to be read from <app>/setup/tables_current.inc.php
 	 * @param object/db $db database object, if not the one in $GLOBALS['egw']->db should be used, eg. for an other database
 	 * @param string $colum_prefix='' column prefix to automatic remove from the column-name, if the column name starts with it
+	 * 
+	 * @return so_sql
 	 */
 	function so_sql($app='',$table='',$db=null,$column_prefix='')
 	{
@@ -178,14 +201,14 @@ class so_sql
 		}
 		foreach($this->db_cols as $db_col => $col)
 		{
-			if (isset($new[$col]))
+			if (array_key_exists($col,$new))
 			{
 				$this->data[$col] = $new[$col];
 			}
 		}
 		foreach($this->non_db_cols as $db_col => $col)
 		{
-			if (isset($new[$col]))
+			if (array_key_exists($col,$new))
 			{
 				$this->data[$col] = $new[$col];
 			}
@@ -235,6 +258,7 @@ class so_sql
 	 * initializes data with the content of key
 	 *
 	 * @param array $keys array with keys in form internalName => value
+	 * @return array internal data after init
 	 */
 	function init($keys=array())
 	{
@@ -243,6 +267,8 @@ class so_sql
 		$this->db2data();
 
 		$this->data_merge($keys);
+		
+		return $this->data;
 	}
 
 	/**
@@ -250,9 +276,9 @@ class so_sql
 	 *
 	 * @param array $keys array with keys in form internalName => value, may be a scalar value if only one key
 	 * @param string/array $extra_cols string or array of strings to be added to the SELECT, eg. "count(*) as num"
-	 * @param string $join='' sql to do a join, added as is after the table-name, eg. ", table2 WHERE x=y" or 
+	 * @param string $join sql to do a join, added as is after the table-name, eg. ", table2 WHERE x=y" or 
 	 * @return array/boolean data if row could be retrived else False
-	*/
+	 */
 	function read($keys,$extra_cols='',$join='')
 	{
 		if (!is_array($keys))
@@ -282,12 +308,31 @@ class so_sql
 				}
 			}
 		}
+		if (!$query)	// no unique key in keys, lets try everything else
+		{
+			foreach($this->db_data_cols as $db_col => $col)
+			{
+				if ($this->data[$col] != '')
+				{
+					$query[$db_col] = $this->data[$col];
+				}
+			}
+		}
 		if (!$query)	// keys has no cols
 		{
 			$this->db2data();
 
 			return False;
 		}
+		if ($join)	// Prefix the columns with the table-name, as they might exist in the join
+		{
+			foreach($query as $col => $val)
+			{
+				if (is_int($col) || strpos($join,$col) === false) continue;
+				$query[] = $this->db->expression($this->table_name,$this->table_name.'.',array($col=>$val));
+				unset($query[$col]);
+			}
+		}
 		$this->db->select($this->table_name,'*'.($extra_cols?','.(is_array($extra_cols)?implode(',',$extra_cols):$extra_cols):''),
 			$query,__LINE__,__FILE__,False,'',False,0,$join);
 
@@ -308,7 +353,7 @@ class so_sql
 		{
 			foreach(is_array($extra_cols) ? $extra_cols : array($extra_cols) as $col)
 			{
-				if (stristr($col,'as')) $col = preg_replace('/^.*as *([a-z0-9_]+) *$/i','\\1',$col);
+				if (FALSE!==stripos($col,'as')) $col = preg_replace('/^.*as *([a-z0-9_]+) *$/i','\\1',$col);
 				$cols[$col] = $col;
 			}
 		}
@@ -345,7 +390,7 @@ class so_sql
 			{
 				if (!$this->autoinc_id || $db_col != $this->autoinc_id)	// not write auto-inc-id
 				{
-					if (!isset($this->data[$col]) && 	// handling of unset columns in $this->data
+					if (!array_key_exists($col,$this->data) && 	// handling of unset columns in $this->data
 						(isset($this->table_def['fd'][$db_col]['default']) ||	// we have a default value
 						 !isset($this->table_def['fd'][$db_col]['nullable']) || $this->table_def['fd'][$db_col]['nullable']))	// column is nullable
 					{
@@ -365,7 +410,10 @@ class so_sql
 		{
 			foreach($this->db_data_cols as $db_col => $col)
 			{
-				if (!isset($this->data[$col]) &&	// handling of unset columns in $this->data
+				// we need to update columns set to null: after a $this->data[$col]=null:
+				// - array_key_exits($col,$this->data) === true
+				// - isset($this->data[$col]) === false
+				if (!array_key_exists($col,$this->data) &&	// handling of unset columns in $this->data
 					($this->autoinc_id ||			// update of table with auto id or
 					 isset($this->table_def['fd'][$db_col]['default']) ||	// we have a default value or
 					 !isset($this->table_def['fd'][$db_col]['nullable']) || $this->table_def['fd'][$db_col]['nullable']))	// column is nullable
@@ -374,6 +422,14 @@ class so_sql
 				}
 				$data[$db_col] = (string) $this->data[$col] === '' && $this->empty_on_write == 'NULL' ? null : $this->data[$col];
 			}
+			// allow to add direct sql updates, eg. "etag=etag+1" with int keys
+			if (is_array($keys) && isset($keys[0]))
+			{
+				for($n=0; isset($keys[$n]); ++$n)
+				{
+					$data[] = $keys[$n];
+				}
+			}
 			$keys = '';
 			foreach($this->db_key_cols as $db_col => $col)
 			{
@@ -398,6 +454,40 @@ class so_sql
 		return $this->db->Errno;
 	}
 
+	/**
+	 * Update only the given fields, if the primary key is not given, it will be taken from $this->data
+	 * 
+	 * @param array $fields
+	 * @param boolean $merge=true if true $fields will be merged with $this->data (after update!), otherwise $this->data will be just $fields
+	 * @return int 0 on success, errno != 0 otherwise
+	 */
+	function update($fields,$merge=true)
+	{
+		if ($merge) $backup_data = $this->data ? $this->data : array();
+
+		if ($this->autoinc_id && !isset($fields[$this->autoinc_id]) ||
+			$this->db_key_cols && count(array_intersect(array_keys($this->db_key_cols),array_keys($fields)) != count($this->db_key_cols)))
+		{
+			foreach($this->db_key_cols as $col => $name)
+			{
+				if (!isset($fields[$name]))
+				{
+					$fields[$name] = $this->data[$name];
+				}
+			}
+		}
+		$this->init($fields);
+
+		$ret = $this->save();
+		
+		if ($merge)
+		{
+			$this->init($backup_data);
+			$this->data_merge($fields);
+		}
+		return $ret;
+	}
+	
 	/**
 	 * deletes row representing keys in internal data or the supplied $keys if != null
 	 *
@@ -441,7 +531,8 @@ class so_sql
 	 * For a union-query you call search for each query with $start=='UNION' and one more with only $order_by and $start set to run the union-query.
 	 *
 	 * @param array/string $criteria array of key and data cols, OR a SQL query (content for WHERE), fully quoted (!)
-	 * @param boolean/string $only_keys=true True returns only keys, False returns all cols. comma seperated list of keys to return
+	 * @param boolean/string/array $only_keys=true True returns only keys, False returns all cols. or 
+	 *	comma seperated list or array of columns to return
 	 * @param string $order_by='' fieldnames + {ASC|DESC} separated by colons ',', can also contain a GROUP BY (if it contains ORDER BY)
 	 * @param string/array $extra_cols='' string or array of strings to be added to the SELECT, eg. "count(*) as num"
 	 * @param string $wildcard='' appended befor and after each criteria
@@ -449,14 +540,14 @@ class so_sql
 	 * @param string $op='AND' defaults to 'AND', can be set to 'OR' too, then criteria's are OR'ed together
 	 * @param mixed $start=false if != false, return only maxmatch rows begining with start, or array($start,$num), or 'UNION' for a part of a union query
 	 * @param array $filter=null if set (!=null) col-data pairs, to be and-ed (!) into the query without wildcards
-	 * @param string $join='' sql to do a join, added as is after the table-name, eg. ", table2 WHERE x=y" or 
-	 *	"LEFT JOIN table2 ON (x=y)", Note: there's no quoting done on $join!
+	 * @param string $join='' sql to do a join, added as is after the table-name, eg. "JOIN table2 ON x=y" or
+	 *	"LEFT JOIN table2 ON (x=y AND z=o)", Note: there's no quoting done on $join, you are responsible for it!!!
 	 * @param boolean $need_full_no_count=false If true an unlimited query is run to determine the total number of rows, default false
 	 * @return boolean/array of matching rows (the row is an array of the cols) or False
 	 */
 	function &search($criteria,$only_keys=True,$order_by='',$extra_cols='',$wildcard='',$empty=False,$op='AND',$start=false,$filter=null,$join='',$need_full_no_count=false)
 	{
-		if ((int) $this->debug >= 4) echo "<p>so_sql::search(".print_r($criteria,true).",'$only_keys','$order_by','$extra_cols','$wildcard','$empty','$op','$start',".print_r($filter,true).",'$join')</p>\n";
+		if ((int) $this->debug >= 4) echo "<p>so_sql::search(".print_r($criteria,true).",'$only_keys','$order_by',".print_r($extra_cols,true).",'$wildcard','$empty','$op','$start',".print_r($filter,true).",'$join')</p>\n";
 
 		if (!is_array($criteria))
 		{
@@ -477,21 +568,22 @@ class so_sql
 					{
 						$db_col = $col;
 					}
-					if ($wildcard || strstr($criteria[$col],'*') || strstr($criteria[$col],'?') || $criteria[$col]{0} == '!')
+					if ($wildcard || $criteria[$col]{0} == '!' ||
+						is_string($criteria[$col]) && (strpos($criteria[$col],'*')!==false || strpos($criteria[$col],'?')!==false))
 					{
-						$cmp_op = ' LIKE ';
+						$cmp_op = ' '.$this->db->capabilities['case_insensitive_like'].' ';
 						if ($criteria[$col]{0} == '!')
 						{
-							$cmp_op = ' NOT LIKE ';
+							$cmp_op = ' NOT'.$cmp_op;
 							$criteria[$col] = substr($criteria[$col],1);
 						}
 						$query[] = $db_col.$cmp_op.$this->db->quote($wildcard.str_replace(array('%','_','*','?'),array('\\%','\\_','%','_'),$criteria[$col]).$wildcard);
 					}
-					elseif (strstr($db_col,'.'))	// we have a table-name specified
+					elseif (strpos($db_col,'.')!==false)	// we have a table-name specified
 					{
 						list($table,$only_col) = explode('.',$db_col);
 						
-						$table_def = $this->db->get_table_definitions(false,$table);
+						$table_def = $this->db->get_table_definitions(true,$table);
 						
 						$query[] = $db_col.(is_array($val) ? ' IN ' : '=').$this->db->quote($val,$table_def['fd'][$only_col]);
 					}
@@ -517,11 +609,22 @@ class so_sql
 				if ($val !== '')
 				{
 					// check if a db-internal name conversation necessary
-					if (!is_numeric($col) && ($c = array_search($col,$this->db_cols))) 
+					if (!is_int($col) && ($c = array_search($col,$this->db_cols))) 
 					{
 						$col = $c;
 					}
-					$db_filter[$col] = $val;
+					if(is_int($col))
+					{
+						$db_filter[] = $val;
+					}
+					elseif ($val === "!''")
+					{
+						$db_filter[] = $col." != ''";
+					}
+					else
+					{
+						$db_filter[$col] = $val;
+					}
 				}
 			}
 			if ($query) 
@@ -542,13 +645,33 @@ class so_sql
 			echo "<p>so_sql::search(,only_keys=$only_keys,order_by='$order_by',wildcard='$wildcard',empty=$empty,$op,start='$start',".print_r($filter,true).") query=".print_r($query,true).", total='$this->total'</p>\n";
 			echo "<br>criteria = "; _debug_array($criteria);
 		}
-		$colums = ($only_keys === true ? implode(',',$this->db_key_cols) : (!$only_keys ? '*' : $only_keys)).
-			($extra_cols ? ','.(is_array($extra_cols) ? implode(',',$extra_cols) : $extra_cols) : '');
+		if ($only_keys === true)
+		{
+			$colums = implode(',',array_keys($this->db_key_cols));
+		}
+		elseif (is_array($only_keys))
+		{
+			$colums = array();
+			foreach($only_keys as $key => $col)
+			{
+				$colums[] = ($db_col = array_search($col,$this->db_cols)) ? $db_col : $col;
+			}
+			$colums = implode(',',$colums);
+		}
+		elseif (!$only_keys)
+		{
+			$colums = '*';
+		}
+		else
+		{
+			$colums = $only_keys;
+		}
+		if ($extra_cols) $colums .= ($colums ? ',' : '').(is_array($extra_cols) ? implode(',',$extra_cols) : $extra_cols);
 
 		$num_rows = 0;	// as spec. in max_matches in the user-prefs
 		if (is_array($start)) list($start,$num_rows) = $start;
 		
-		if ($order_by && !stristr($order_by,'ORDER BY') && !stristr($order_by,'GROUP BY'))
+		if ($order_by && stripos($order_by,'ORDER BY')===false && stripos($order_by,'GROUP BY')===false)
 		{
 			$order_by = 'ORDER BY '.$order_by;
 		}
@@ -597,9 +720,9 @@ class so_sql
 				{
 					$mysql_calc_rows = 'SQL_CALC_FOUND_ROWS ';
 				}
-				elseif (!$need_full_no_count && (!$join || stristr($join,'LEFT JOIN')))
+				elseif (!$need_full_no_count && (!$join || stripos($join,'LEFT JOIN')!==false))
 				{
-					$this->db->select($this->table_name,'COUNT(*)',$query,__LINE__,__FILE__);
+					$this->db->select($this->table_name,'COUNT(*)',$query,__LINE__,__FILE__,false,'',false,0,$join);
 					$this->total = $this->db->next_record() ? (int) $this->db->f(0) : false;
 				}
 				else	// cant do a count, have to run the query without limit
@@ -613,6 +736,8 @@ class so_sql
 
 			$cols = $this->_get_columns($only_keys,$extra_cols);
 		}
+		if ((int) $this->debug >= 4) echo "<p>sql='{$this->db->Query_ID->sql}'</p>\n";
+
 		if ($mysql_calc_rows)
 		{
 			$this->total = $this->db->Link_ID->GetOne('SELECT FOUND_ROWS()');
@@ -640,6 +765,7 @@ class so_sql
 	 */	 
 	function _get_columns($only_keys,$extra_cols)
 	{
+		//echo "_get_columns() only_keys="; _debug_array($only_keys); echo "extra_cols="; _debug_array($extra_cols);
 		if ($only_keys === true)	// only primary key
 		{
 			$cols = $this->db_key_cols;
@@ -647,7 +773,7 @@ class so_sql
 		else
 		{
 			$cols = array();
-			foreach(explode(',',str_replace(array('DISTINCT ','distinct '),'',$only_keys)) as $col)
+			foreach(is_array($only_keys) ? $only_keys : explode(',',str_replace(array('DISTINCT ','distinct '),'',$only_keys)) as $col)
 			{
 				if (!$col || $col == '*' || $col == $this->table_name.'.*')	// all columns
 				{
@@ -655,8 +781,15 @@ class so_sql
 				}
 				else	// only the specified columns
 				{
-					if (stristr($col,'as')) $col = preg_replace('/^.*as +([a-z0-9_]+) *$/i','\\1',$col);
-					$cols[$col] = $col;
+					if (stripos($col,'as')!==false) $col = preg_replace('/^.*as +([a-z0-9_]+) *$/i','\\1',$col);
+					if (($db_col = array_search($col,$this->db_cols)) !== false)
+					{
+						$cols[$db_col] = $col;
+					}
+					else
+					{
+						$cols[$col] = isset($this->db_cols[$col]) ? $this->db_cols[$col] : $col;
+					}
 				}
 			}
 		}
@@ -664,8 +797,15 @@ class so_sql
 		{
 			foreach(is_array($extra_cols) ? $extra_cols : explode(',',$extra_cols) as $col)
 			{
-				if (stristr($col,'as ')) $col = preg_replace('/^.*as +([a-z0-9_]+) *$/i','\\1',$col);
-				$cols[$col] = $col;
+				if (stripos($col,'as ')!==false) $col = preg_replace('/^.*as +([a-z0-9_]+) *$/i','\\1',$col);
+				if (($db_col = array_search($col,$this->db_cols)) !== false)
+				{
+					$cols[$db_col] = $col;
+				}
+				else
+				{
+					$cols[$col] = isset($this->db_cols[$col]) ? $this->db_cols[$col] : $col;
+				}
 			}
 		}
 		return $cols;
@@ -698,7 +838,8 @@ class so_sql
 			}
 		}
 		$rows = (array) $this->search($criteria,false,$query['order']?$query['order'].' '.$query['sort']:'',
-			'','%',false,'OR',(int)$query['start'],$query['col_filter'],$join,$need_full_no_count);
+			'','%',false,'OR',$query['num_rows']?array((int)$query['start'],$query['num_rows']):(int)$query['start'],
+			$query['col_filter'],$join,$need_full_no_count);
 
 		return $this->total;
 	}
@@ -762,7 +903,7 @@ class so_sql
 		if (!is_array($value_col)) $value_col = array($value_col);
 		
 		$cols = array();
-		foreach(is_array($value_col) ? $value_col : array($value_col) as $key => $col)
+		foreach($value_col as $key => $col)
 		{
 			$cols[$key] = preg_match('/AS ([a-z_0-9]+)$/i',$col,$matches) ? $matches[1] : $col;
 		}			
@@ -798,3 +939,14 @@ class so_sql
 		return $cache[$cache_key] =& $ret;
 	}
 }
+
+if (!function_exists("stripos")) 
+{
+	/**
+	 * stripos for php < 5
+	 */
+	function stripos($str,$needle,$offset=0)
+	{
+		return strpos(strtolower($str),strtolower($needle),$offset);
+	}
+}
