@@ -1,16 +1,13 @@
 <?php
-	/**************************************************************************\
-	* eGroupWare - eTemplate Extension - Tab Widget                            *
-	* http://www.egroupware.org                                                *
-	* Written by Ralf Becker <RalfBecker@outdoor-training.de>                  *
-	* --------------------------------------------                             *
-	*  This program is free software; you can redistribute it and/or modify it *
-	*  under the terms of the GNU General Public License as published by the   *
-	*  Free Software Foundation; either version 2 of the License, or (at your  *
-	*  option) any later version.                                              *
-	\**************************************************************************/
-
-	/* $Id: class.tab_widget.inc.php 19711 2005-11-09 20:50:45Z ralfbecker $ */
+	/**
+	 * eGroupWare - eTemplate Extension - Tab Widget
+	 *
+	 * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+	 * @package etemplate
+	 * @link http://www.egroupware.org
+	 * @author Ralf Becker <RalfBecker@outdoor-training.de>
+	 * @version $Id: class.tab_widget.inc.php 23741 2007-04-30 10:29:44Z lkneschke $
+	 */
 
 	/**
 	 * eTemplate Extension: widget that shows one row of tabs and an other row with the eTemplate of the selected tab
@@ -92,13 +89,13 @@
 			$tab_widget =& new etemplate('etemplate.tab_widget');
 			$tab_widget->no_onclick = true;
 	
-			if ($value && !strstr($value,'.'))
+			if ($value && strpos($value,'.') === false)
 			{
 				$value = $tmpl->name . '.' . $value;
 			}
 			foreach($names as $k => $name)
 			{
-				if (!strstr($name,'.'))
+				if (strpos($name,'.') === false)
 				{
 					$name = $names[$k] = $tmpl->name . '.' . $name;
 				}
@@ -115,18 +112,18 @@
 
 			foreach($names as $k => $name)
 			{
-				if (!strstr($name,'.'))
+				if (strpos($name,'.') === false)
 				{
 					$name = $names[$k] = $tmpl->name . '.' . $name;
 				}
 				$tcell =& $tab_widget->empty_cell();
 				if ($value == $name)
 				{
-					$tcell['span'] = ',etemplate_tab_active th';
+					$tcell['span'] = ',etemplate_tab_active';
 				}
 				else
 				{
-					$tcell['span'] = ',etemplate_tab row_on';
+					$tcell['span'] = ',etemplate_tab';
 				}
 				if ($dom_enabled)
 				{
