@@ -1,17 +1,14 @@
 <?php
-	/**************************************************************************\
-	* eGroupWare - eTemplates - xml-tools - helper class to create xml-files   *
-	* http://www.eGroupWare.org                                                *
-	* Originaly from the phpGW XSLT API                                        *
-	* Adapted by Ralf Becker <RalfBecker@outdoor-training.de>                  *
-	* --------------------------------------------                             *
-	*  This program is free software; you can redistribute it and/or modify it *
-	*  under the terms of the GNU General Public License as published by the   *
-	*  Free Software Foundation; either version 2 of the License, or (at your  *
-	*  option) any later version.                                              *
-	\**************************************************************************/
-
-	/* $Id: class.xmltool.inc.php 19711 2005-11-09 20:50:45Z ralfbecker $ */
+	/**
+	 * eGroupWare - eTemplates - xml-tools - helper class to create xml-files
+	 * Originaly from the phpGW XSLT API
+	 *
+	 * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+	 * @package etemplate
+	 * @link http://www.egroupware.org
+	 * @author Ralf Becker <RalfBecker@outdoor-training.de>
+	 * @version $Id: class.xmltool.inc.php 23913 2007-05-22 04:04:13Z lkneschke $
+	 */
 
 	function var2xml($name, $data)
 	{
@@ -169,7 +166,7 @@
 
 		function import_var($name, $value,$is_root=False,$export_xml=False)
 		{
-			echo "<p>import_var: this->indentstring='$this->indentstring'</p>\n";
+			//echo "<p>import_var: this->indentstring='$this->indentstring'</p>\n";
 			$node =& new xmltool('node',$name,$this->indentstring);
 			switch (gettype($value))
 			{
@@ -307,8 +304,8 @@
 
 			if($this->data_type != 'node')
 			{	
-				$found_at = strstr($this->data,'PHP_SERIALIZED_OBJECT&:');
-				if($found_at != False)
+				$found_at = strpos($this->data,'PHP_SERIALIZED_OBJECT&:');
+				if($found_at !== False)
 				{
 					return unserialize(str_replace ('PHP_SERIALIZED_OBJECT&:', '', $this->data));
 				}
@@ -362,8 +359,8 @@
 			$retval['attributes'] = $this->attributes;
 			if($this->data_type != 'node')
 			{	
-				$found_at = strstr($this->data,'PHP_SERIALIZED_OBJECT&:');
-				if($found_at != False)
+				$found_at = strpos($this->data,'PHP_SERIALIZED_OBJECT&:');
+				if($found_at !== False)
 				{
 					$retval['value'] = unserialize(str_replace ('PHP_SERIALIZED_OBJECT&:', '', $this->data));
 				}
@@ -494,7 +491,7 @@
 					reset($this->attributes);
 					while(list($key,$val) = each ($this->attributes))
 					{
-						$result .= ' '.$key.'="'.htmlspecialchars($val,ENT_COMPAT,'utf-8').'"';
+						if (!is_array($val)) $result .= ' '.$key.'="'.htmlspecialchars($val,ENT_COMPAT,'utf-8').'"';
 					}
 				}
 
