@@ -1,16 +1,13 @@
 <?php
-	/**************************************************************************\
-	* eGroupWare - eTemplates - XUL/XML Import & Export                        *  
-	* http://www.egroupware.org                                                *
-	* Written by Ralf Becker <RalfBecker@outdoor-training.de>                  *
-	* --------------------------------------------                             *
-	*  This program is free software; you can redistribute it and/or modify it *
-	*  under the terms of the GNU General Public License as published by the   *
-	*  Free Software Foundation; either version 2 of the License, or (at your  *
-	*  option) any later version.                                              *
-	\**************************************************************************/
-
-	/* $Id: class.xul_io.inc.php 20839 2006-03-27 12:23:49Z ralfbecker $ */
+	/**
+	 * eGroupWare - eTemplates - XUL/XML Import & Export
+	 *
+	 * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+	 * @package etemplate
+	 * @link http://www.egroupware.org
+	 * @author Ralf Becker <RalfBecker@outdoor-training.de>
+	 * @version $Id: class.xul_io.inc.php 23865 2007-05-14 20:43:23Z lkneschke $
+	 */
 
 	if (!function_exists('var2xml'))
 	{
@@ -36,87 +33,86 @@
 	 */
 	class xul_io
 	{
-		var $widget2xul;
-		var $attr2xul;
-		var $xul2widget;
-
-		function xul_io()
-		{
-			/**
-			 * @var array $attr2xul how to translate attr, common to all widgets
-			 */
-			$this->attr2xul = array(
-				'name' => 'id',
-				'help' => 'statustext',
-				'span' => 'span,class',
-				'type' => '',	// this is the widget-name => dont write as attr
-				'disabled' => 'disabled=true',
-				'readonly' => 'readonly=true',
-				'size' => 'options'
-			);
-			/**
-			 * @var array $widget2xul how to widget-names and widget-spec. attr., not set ones are identical
-			 */
-			$this->widget2xul = array(
-				'label' => array(
-					'.name' => 'description',
-					'label' => 'value'
-				),
-				'text' => array(
-					'.name' => 'textbox',
-					'size' => 'size,maxlength,validator'
-				),
-				'textarea' => array(
-					'.name' => 'textbox',
-					'.set' => 'multiline=true',
-					'size' => 'rows,cols'
-				),
-				'integer' => array(
-					'.name' => 'textbox',
-					'.set' => 'type=integer',
-					'size' => 'min,max,size'
-				),
-				'float' => array(
-					'.name' => 'textbox',
-					'.set' => 'type=float',
-					'size' => 'min,max,size,precision'
-				),
-				'select' => array(
-					'.name' => 'menulist,menupopup',
-				),
-				'select-multi' => array(	// multiselection, if size > 0
-					'.name' => 'listbox',
-					'size'  => 'rows,options'
-				),
-				'template' => array(
-					'.name' => 'template',
-					'size'  => 'content'
-				),
-				'image'   => array(
-					'.name' => 'image',
-					'name' => 'src'
-				),
-				'tab' => array(
-					'.name' => 'tabbox,tabs,tabpanels'
-				),
-				'button' => array(
-					'.name' => 'button',
-					'size'  => 'image,ro_image'
-				),
-				'htmlarea' => array(
-					'size' => 'style,plugins',
-				),
-			);
-			/**
-			 * @var array $xul2widget how to xul-widget names to our internal ones, not set ones are identical
-			 */
-			$this->xul2widget = array(
-				'menulist' => 'select',
-				'listbox' => 'select',
-				'menupopup' => 'select',
-				'description' => 'label'
-			);
-		}
+		/**
+		 * translate attr, common to all widgets
+		 * 
+		 * @var array
+		 */
+		var $attr2xul = array(
+			'name' => 'id',
+			'help' => 'statustext',
+			'span' => 'span,class',
+			'type' => '',	// this is the widget-name => dont write as attr
+			'disabled' => 'disabled=true',
+			'readonly' => 'readonly=true',
+			'size' => 'options'
+		);
+		/**
+		 * translate widget-names and widget-spec. attr., not set ones are identical
+		 * 
+		 * @var array
+		 */
+		var $widget2xul = array(
+			'label' => array(
+				'.name' => 'description',
+				'label' => 'value'
+			),
+			'text' => array(
+				'.name' => 'textbox',
+				'size' => 'size,maxlength,validator'
+			),
+			'textarea' => array(
+				'.name' => 'textbox',
+				'.set' => 'multiline=true',
+				'size' => 'rows,cols'
+			),
+			'integer' => array(
+				'.name' => 'textbox',
+				'.set' => 'type=integer',
+				'size' => 'min,max,size'
+			),
+			'float' => array(
+				'.name' => 'textbox',
+				'.set' => 'type=float',
+				'size' => 'min,max,size,precision'
+			),
+			'select' => array(
+				'.name' => 'menulist,menupopup',
+			),
+			'select-multi' => array(	// multiselection, if size > 0
+				'.name' => 'listbox',
+				'size'  => 'rows,options'
+			),
+			'template' => array(
+				'.name' => 'template',
+				'size'  => 'content'
+			),
+			'image'   => array(
+				'.name' => 'image',
+				'name' => 'src'
+			),
+			'tab' => array(
+				'.name' => 'tabbox,tabs,tabpanels'
+			),
+			'button' => array(
+				'.name' => 'button',
+				'size'  => 'image,ro_image'
+			),
+			'htmlarea' => array(
+				'size' => 'mode,height,width,toolbar,base_href',
+			),
+		);
+		/**
+		 * translate xul-widget names to our internal ones, not set ones are identical
+		 * 
+		 * @var array
+		 */
+		var $xul2widget = array(
+			'menulist' => 'select',
+			'listbox' => 'select',
+			'menupopup' => 'select',
+			'description' => 'label'
+		);
 
 		/**
 		 * sets an attribute in the xml object representing a widget
@@ -227,7 +223,7 @@
 			case 'menulist':	// id,options belongs to the 'menupopup' child
 				if ($cell['span'])
 				{
-					$widget->set_attribute('span',$cell['span']);
+					$this->set_attributes($widget,'span,class',$cell['span']);
 					unset($cell['span']);
 				}
 				// fall-trought
@@ -250,12 +246,14 @@
 			case 'hbox':
 			case 'box':
 			case 'deck':
-				list($anz,$orient,$options) = split(',',$cell['size'],2);
+				list($anz,$orient,$options) = split(',',$cell['size'],3);
 				for ($n = 1; $n <= $anz; ++$n)
 				{
 					$this->add_widget($widget,$cell[$n],$embeded_too);
 					unset($cell[$n]);
 				}
+				// no sure where the data key gets set, but it gives a warning in xml serialization (empty array)
+				unset($cell['data']);
 				$cell['orient'] = $orient;
 				$cell['size'] = $options;
 				break;
@@ -315,6 +313,7 @@
 		{
 			$xul_grid =& new xmlnode('grid');
 			$this->set_attributes($xul_grid,'width,height,border,class,spacing,padding,overflow',$grid['size']);
+			$this->set_attributes($xul_grid,'id',$grid['name']);
 
 			$xul_columns =& new xmlnode('columns');
 			$xul_rows =& new xmlnode('rows');
@@ -387,7 +386,7 @@
 			if ($etempl->style != '')
 			{
 				$styles =& new xmlnode('styles');
-				$styles->set_value($etempl->style);
+				$styles->set_value(str_replace("\r",'',$etempl->style));
 				$template->add_node($styles);
 			}
 			$this->xul_overlay->add_node($template);
@@ -429,7 +428,7 @@
 		 *
 		 * @param object &$etempl eTemplate object to set
 		 * @param string $data the XML 
-		 * @param array/string array with names of imported templates or error-message
+		 * @return array/string array with names of imported templates or error-message
 		 */
 		function import(&$etempl,$data)
 		{
@@ -499,9 +498,8 @@
 						switch ($type)
 						{
 							case 'close':
-								if (!count($parents) || $parent['.is_root'])	// templ import complet => save it
+								if (!count($parents))	// templ import complet => save it
 								{
-									unset($parent['.is_root']);
 									unset($parent); $parents = array();
 									$etempl->fix_old_template_format(); 	// set the depricated compat vars
 									// save tmpl to the cache, as the file may contain more then one tmpl
@@ -526,7 +524,7 @@
 								{
 									$etempl->init($attr);
 									$etempl->children = array();	// init adds one grid by default
-									$parent = &$etempl->children;
+									$parent = &$etempl;				// parent is the template-object itself!
 								}
 								if ($tag == 'grid')
 								{
@@ -542,7 +540,6 @@
 										'rows' => 0,
 										'size' => $size,
 									);
-									if ($is_root) $grid['.is_root'] = true;	// we need to remember we have no template as parent 
 									soetemplate::add_child($parent,$grid);
 									$parents[count($parents)] = &$parent;
 									$parent = &$grid;
