@@ -9,7 +9,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: tables_update.inc.php 20295 2006-02-15 12:31:25Z  $ */
+  /* $Id: tables_update.inc.php 23741 2007-04-30 10:29:44Z lkneschke $ */
 
 	$test[] = '0.9.13.001';
 	function etemplate_upgrade0_9_13_001()
@@ -92,4 +92,18 @@
 		$GLOBALS['setup_info']['etemplate']['currentver'] = '1.2';
 		return $GLOBALS['setup_info']['etemplate']['currentver'];
 	}
+
+
+	$test[] = '1.2';
+	function etemplate_upgrade1_2()
+	{
+		$GLOBALS['egw_setup']->oProc->AlterColumn('egw_etemplate','et_modified',array(
+			'type' => 'int',
+			'precision' => '8',
+			'nullable' => False,
+			'default' => '0'
+		));
+
+		return $GLOBALS['setup_info']['etemplate']['currentver'] = '1.4';
+	}
 ?>
