@@ -11,7 +11,7 @@
 	* Free Software Foundation; either version 2 of the License, or (at your    *
 	* option) any later version.                                                *
 	\***************************************************************************/
-	/* $Id: class.bofilter.inc.php 18876 2005-07-23 15:52:49Z ralfbecker $ */
+	/* $Id: class.bofilter.inc.php 23157 2006-12-31 11:36:55Z lkneschke $ */
 
 	class bofilter
 	{
@@ -34,13 +34,13 @@
 			
 			$this->restoreSessionData();
 			
-			if(!is_array($this->sessionData['filter']))
-			{
+			if(!is_array($this->sessionData['filter'])) {
 				$this->sessionData['filter'][0]['filterName'] = lang('Quicksearch');
 				$this->saveSessionData();
 			}
-			if(!isset($this->sessionData['activeFilter']))
+			if(!isset($this->sessionData['activeFilter'])) {
 				$this->sessionData['activeFilter'] = "-1";
+			}
 		}
 		
 		function deleteFilter($_filterID)
