@@ -11,7 +11,7 @@
 	* Free Software Foundation; either version 2 of the License, or (at your    *
 	* option) any later version.                                                *
 	\***************************************************************************/
-	/* $Id: class.socaching.inc.php 19596 2005-11-04 18:37:37Z ralfbecker $ */
+	/* $Id: class.socaching.inc.php 22548 2006-09-29 04:25:20Z lkneschke $ */
 
 	class socaching
 	{
@@ -116,26 +116,31 @@
 			$where = $this->host_account_folder;
 			$filter = $this->getFilterSQL($_filter);
 			if ($filter) $where[] = $filter;
+			$foundSomething = false;
 				
 			$this->db->select($this->cache_table,'fmail_uid,fmail_date,fmail_subject,fmail_sender_name,fmail_sender_address,fmail_to_name,fmail_to_address,fmail_size,fmail_attachments',
 				$where,__LINE__,__FILE__,$_firstMessage?$_firstMessage-1:False,$this->getSortSQL($_sort),False,$_numberOfMessages);
 				
-			while($this->db->next_record())
-			{
-				//(regis) add subject and size
-				$retValue[] = array(
-					'uid'		=> $this->db->f('fmail_uid'),
+			while($this->db->next_record()) {
+				$foundSomething = true;
+				$retValue[$this->db->f('fmail_uid')] = array(
+					'uid'				=> $this->db->f('fmail_uid'),
 					'sender_name'	=> $this->db->f('fmail_sender_name'), 
-					'subject'	=> $this->db->f('fmail_subject'), 
-					'size'		=> $this->db->f('fmail_size'), 
-					'sender_address'=> $this->db->f('fmail_sender_address'), 
-					'to_name'	=> $this->db->f('fmail_to_name'), 
-					'to_address'	=> $this->db->f('fmail_to_address'),
-					'attachments'	=> $this->db->f('fmail_attachments'),
-					'date'		=> $this->db->f('fmail_date')
+					'subject'			=> $this->db->f('fmail_subject'), 
+					'size'			=> $this->db->f('fmail_size'), 
+					'sender_address'	=> $this->db->f('fmail_sender_address'), 
+					'to_name'		=> $this->db->f('fmail_to_name'), 
+					'to_address'		=> $this->db->f('fmail_to_address'),
+					'attachments'		=> $this->db->f('fmail_attachments'),
+					'date'			=> $this->db->f('fmail_date')
 				);
 			}
-			return $retValue;
+			
+			if($foundSomething) {
+				return $retValue;
+			}
+
+			return false;
 		}
 		
 		/**
@@ -171,7 +176,9 @@
 			if($_filter)
 			{
 				$filter = $this->getFilterSQL($_filter);
-				$where[] = $filter;
+				if(!empty($filter)) {
+					$where[] = $filter;
+				}
 			}
 			
 			$this->db->select($this->cache_table,'count(*)',$where,__LINE__,__FILE__);
