@@ -10,7 +10,7 @@
 	* under the terms of the GNU General Public License as published by the     *
 	* Free Software Foundation; version 2 of the License.                       *
 	\***************************************************************************/
-	/* $Id: class.uifelamimail.inc.php 20042 2005-11-28 18:24:40Z lkneschke $ */
+	/* $Id: class.uifelamimail.inc.php 23375 2007-02-02 07:18:33Z lkneschke $ */
 
 	class uifelamimail
 	{
@@ -33,97 +33,39 @@
 		var $sort;		// how to sort the messages
 		var $moveNeeded;	// do we need to move some messages?
 
+		var $timeCounter;
+		
+		// the object storing the data about the incoming imap server
+		var $icServerID=0;
+		
 		function uifelamimail()
 		{
-			if(isset($_POST["mark_unread_x"])) 
-				$_POST["mark_unread"] = "true";
-			if(isset($_POST["mark_read_x"])) 
-				$_POST["mark_read"] = "true";
-			if(isset($_POST["mark_unflagged_x"])) 
-				$_POST["mark_unflagged"] = "true";
-			if(isset($_POST["mark_flagged_x"])) 
-				$_POST["mark_flagged"] = "true";
-			if(isset($_POST["mark_deleted_x"])) 
-				$_POST["mark_deleted"] = "true";
+			$this->timeCounter = microtime(true);
 
 			$this->displayCharset	= $GLOBALS['egw']->translation->charset();
 			$this->bofelamimail     =& CreateObject('felamimail.bofelamimail',$this->displayCharset);
+
 			$this->bofilter		=& CreateObject('felamimail.bofilter');
 			$this->bopreferences	=& CreateObject('felamimail.bopreferences');
 			$this->preferences	= $this->bopreferences->getPreferences();
 			$this->botranslation	=& CreateObject('phpgwapi.translation');
 
-			if(isset($_POST["mailbox"]) && 
-				$_GET["menuaction"] == "felamimail.uifelamimail.handleButtons" &&
-				empty($_POST["mark_unread"]) &&
-				empty($_POST["mark_read"]) &&
-				empty($_POST["mark_unflagged"]) &&
-				empty($_POST["mark_flagged"]) &&
-				empty($_POST["mark_deleted"]))
-			{
-				if ($_POST["folderAction"] == "changeFolder")
-				{
-					// change folder
-					$this->bofelamimail->sessionData['mailbox']	= $_POST["mailbox"];
-					$this->bofelamimail->sessionData['startMessage']= 1;
-					$this->bofelamimail->sessionData['sort']	= $this->preferences['sortOrder'];
-					$this->bofelamimail->sessionData['activeFilter']= -1;
-				}
-				elseif($_POST["folderAction"] == "moveMessage")
-				{
-					//print "move messages<br>";
-					$this->bofelamimail->sessionData['mailbox'] 	= urldecode($_POST["oldMailbox"]);
-
-//					$this->bofelamimail->sessionData['startMessage']= 1;
-					if (is_array($_POST["msg"]))
-					{
-						// we need to initialize the classes first
-						$this->moveNeeded = "1";
-					}
-				}
-			}
-
-//			elseif(isset($_POST["mailbox"]) &&
-//				$_GET["menuaction"] == "felamimail.uifelamimail.handleButtons" &&
-//				!empty($_POST["mark_deleted"]))
-//			{
-				// delete messages
-//				$this->bofelamimail->sessionData['startMessage']= 1;
-//			}
-//			elseif($_GET["menuaction"] == "felamimail.uifelamimail.deleteMessage")
-//			{
-				// delete 1 message from the mail reading window
-//				$this->bofelamimail->sessionData['startMessage']= 1;
-//			}
-			elseif(isset($_POST["filter"]) || isset($_GET["filter"]))
-			{
-				// new search filter defined, lets start with message 1
-				$this->bofelamimail->sessionData['startMessage']= 1;
-			}
-
-			// navigate for and back
-			if(isset($_GET["startMessage"]))
-			{
-				$this->bofelamimail->sessionData['startMessage'] = $_GET["startMessage"];
-			}
-			
 			$this->bofelamimail->saveSessionData();
-			
+
 			$this->mailbox 		= $this->bofelamimail->sessionData['mailbox'];
 			$this->startMessage 	= $this->bofelamimail->sessionData['startMessage'];
 			$this->sort 		= $this->bofelamimail->sessionData['sort'];
-			#$this->filter 		= $this->bofelamimail->sessionData['activeFilter'];
+			$this->sortReverse 	= $this->bofelamimail->sessionData['sortReverse'];
+	#		$this->filter 		= $this->bofelamimail->sessionData['activeFilter'];
 
-			#$this->cats			=& CreateObject('phpgwapi.categories');
-			#$this->nextmatchs		=& CreateObject('phpgwapi.nextmatchs');
 			$this->t			=& CreateObject('phpgwapi.Template',EGW_APP_TPL);
 			#$this->grants[$this->account]	= EGW_ACL_READ + EGW_ACL_ADD + EGW_ACL_EDIT + EGW_ACL_DELETE;
 			// this need to fixed
 			// this does not belong to here
+
 			if($_GET['menuaction'] != 'felamimail.uifelamimail.hookAdmin' &&
-				 $_GET['menuaction'] != 'felamimail.uifelamimail.changeFolder')
-			{
-				$this->connectionStatus = $this->bofelamimail->openConnection();
+				 $_GET['menuaction'] != 'felamimail.uifelamimail.changeFolder') {
+				$this->connectionStatus = $this->bofelamimail->openConnection($this->icServerID);
 			}
 
 			$this->rowColor[0] = $GLOBALS['egw_info']["theme"]["row_on"];
@@ -131,6 +73,7 @@
 
 			$this->dataRowColor[0] = $GLOBALS['egw_info']["theme"]["bg01"];
 			$this->dataRowColor[1] = $GLOBALS['egw_info']["theme"]["bg02"];
+			#print __LINE__ . ': ' . (microtime(true) - $this->timeCounter) . '<br>';
 		}
 
 		function addVcard()
@@ -139,7 +82,7 @@
 			$partID 	= $_GET['partID'];
 			$attachment = $this->bofelamimail->getAttachment($messageID,$partID);
 			
-			$tmpfname = tempnam ($GLOBALS['egw_info']['server']['temp_dir'], "phpgw_");
+			$tmpfname = tempnam ($GLOBALS['egw_info']['server']['temp_dir'], "egw_");
 			$fp = fopen($tmpfname, "w");
 			fwrite($fp, $attachment['attachment']);
 			fclose($fp);
@@ -150,16 +93,8 @@
 			$entry['access'] = 'private';
 			$entry['tid'] = 'n';
 			
-			#_debug_array($entry);
-			#print "<br><br>";
-			
 			print quoted_printable_decode($entry['fn'])."<br>";
 			
-			#$boaddressbook =& CreateObject('addressbook.boaddressbook');
-			#$soaddressbook =& CreateObject('addressbook.soaddressbook');
-			#$soaddressbook->add_entry($entry);
-			#$ab_id = $boaddressbook->get_lastid();
-			
 			unlink($tmpfname);
 			
 			$GLOBALS['egw']->common->egw_exit();
@@ -186,7 +121,7 @@
 			// change folder
 			$this->bofelamimail->sessionData['mailbox']	= urldecode($_GET["mailbox"]);
 			$this->bofelamimail->sessionData['startMessage']= 1;
-			$this->bofelamimail->sessionData['sort']	= $this->preferences['sortOrder'];
+			$this->bofelamimail->sessionData['sort']	= $this->preferences->preferences['sortOrder'];
 			$this->bofelamimail->sessionData['activeFilter']= -1;
 
 			$this->bofelamimail->saveSessionData();
@@ -237,22 +172,26 @@
 			$refreshURL = $GLOBALS['egw']->link('/index.php',$linkData);
 
 			print "<script type=\"text/javascript\">
-			opener.location.href = '".$refreshURL."';
+			opener.location.href = '" .$refreshURL. "';
 			window.close();</script>";
 		}
 		
 		function display_app_header()
 		{
-			if(!@is_object($GLOBALS['egw']->js))
-			{
+			if(!@is_object($GLOBALS['egw']->js)) {
 				$GLOBALS['egw']->js =& CreateObject('phpgwapi.javascript');
 			}
+			if(!@is_object($GLOBALS['egw']->html)) {
+				$GLOBALS['egw']->html =& CreateObject('phpgwapi.html');
+			}
 			#$GLOBALS['egw']->js->validate_file('foldertree','foldertree');
 			$GLOBALS['egw']->js->validate_file('dhtmlxtree','js/dhtmlXCommon');
 			$GLOBALS['egw']->js->validate_file('dhtmlxtree','js/dhtmlXTree');
 			$GLOBALS['egw']->js->validate_file('jscode','viewMainScreen','felamimail');
 			$GLOBALS['egw_info']['flags']['include_xajax'] = True;
+
 			$GLOBALS['egw']->common->egw_header();
+
 			echo parse_navbar();
 		}
 	
@@ -375,22 +314,24 @@
 		{
 			#printf ("this->uifelamimail->viewMainScreen() start: %s<br>",date("H:i:s",mktime()));
 			$bopreferences		=& CreateObject('felamimail.bopreferences');
-			$preferences		= $bopreferences->getPreferences();
 			$bofilter		=& CreateObject('felamimail.bofilter');
-			$mailPreferences	= $bopreferences->getPreferences();
 			$uiwidgets		=& CreateObject('felamimail.uiwidgets');
 
-			$urlMailbox = urlencode($this->mailbox);
+			$preferences		=& $bopreferences->getPreferences();
+			$urlMailbox		=  urlencode($this->mailbox);
+
+			$imapServer =& $preferences->getIncomingServer(0);
+
+			$maxMessages		=&  $GLOBALS['egw_info']['user']['preferences']['common']['maxmatchs'];
+			$userPreferences	=&  $GLOBALS['egw_info']['user']['preferences']['felamimail'];
 			
-			$maxMessages = $GLOBALS['egw_info']["user"]["preferences"]["common"]["maxmatchs"];
-			
-		
 			$this->display_app_header();
-			
+
 			$this->t->set_file(array("body" => 'mainscreen.tpl'));
 			$this->t->set_block('body','main');
 			$this->t->set_block('body','status_row_tpl');
-			$this->t->set_block('body','header_row');
+			$this->t->set_block('body','table_header_felamimail');
+			$this->t->set_block('body','table_header_outlook');
 			$this->t->set_block('body','error_message');
 			$this->t->set_block('body','quota_block');
 			$this->t->set_block('body','subject_same_window');
@@ -401,77 +342,61 @@
 			$this->t->set_var('oldMailbox',$urlMailbox);
 			$this->t->set_var('image_path',EGW_IMAGES);
 			#printf ("this->uifelamimail->viewMainScreen() Line 272: %s<br>",date("H:i:s",mktime()));
-			// ui for the quotas
-			if($quota = $this->bofelamimail->getQuotaRoot())
-			{
-				if($quota['limit'] == 0)
-				{
-					$quotaPercent=100;
-				}
-				else
-				{
-					$quotaPercent=round(($quota['usage']*100)/$quota['limit']);
-				}
-				$quotaLimit=$this->show_readable_size($quota['limit']*1024);
-				$quotaUsage=$this->show_readable_size($quota['usage']*1024);
 
-				$this->t->set_var('leftWidth',$quotaPercent);
-				if($quotaPercent > 90)
-				{
-					$this->t->set_var('quotaBG','red');
-				}
-				elseif($quotaPercent > 80)
-				{
-					$this->t->set_var('quotaBG','yellow');
-				}
-				else
-				{
-					$this->t->set_var('quotaBG','#66ff66');
-				}
-				
-				if($quotaPercent > 50)
-				{
-					$this->t->set_var('quotaUsage_right','');
-					$this->t->set_var('quotaUsage_left',$quotaUsage .'/'.$quotaLimit);
-				}
-				else
-				{
-					$this->t->set_var('quotaUsage_left','');
-					$this->t->set_var('quotaUsage_right',$quotaUsage .'/'.$quotaLimit);
-				}
-				
-				$this->t->parse('quota_display','quota_block',True);
+			// display a warning if vacation notice is active
+			if(is_a($imapServer,'defaultimap') && $imapServer->enableSieve) {
+				$this->bosieve		=& CreateObject('felamimail.bosieve',$imapServer);
+				$this->bosieve->retrieveRules($this->bosieve->scriptName);
+				$vacation = $this->bosieve->getVacation($this->bosieve->scriptName);
+			}
+			if(is_array($vacation) && $vacation['status'] == 'on')
+			{
+				$this->t->set_var('vacation_warning',
+					$GLOBALS['egw']->html->image('phpgwapi','dialog_warning',false,'style="vertical-align: middle; width: 16px;"').lang('Vacation notice is active'));
 			}
 			else
 			{
+				$this->t->set_var('vacation_warning','&nbsp;');
+			}
+
+			// ui for the quotas
+			if($this->connectionStatus !== false) {
+				$quota = $this->bofelamimail->getQuotaRoot();
+			} else {
+				$quota['limit'] = 'NOT SET';
+			}
+
+			if($quota !== false && $quota['limit'] != 'NOT SET') {
+				$quotaDisplay = $uiwidgets->quotaDisplay($quota['usage'], $quota['limit']);
+				$this->t->set_var('quota_display', $quotaDisplay);
+			} else {
 				$this->t->set_var('quota_display','&nbsp;');
 			}
-			
-			$linkData = array
-			(
+
+			$linkData = array (
 				'menuaction'    => 'felamimail.uicompose.compose'
 			);
-			$urlCompose = "egw_openWindowCentered('".$GLOBALS['egw']->link('/index.php',$linkData)."','test',700,750);";
+			$urlCompose = "egw_openWindowCentered('".$GLOBALS['egw']->link('/index.php',$linkData)."','compose', 700, 750);";
 
 			$navbarImages = array(
-				'mail_new'	=> array(
+				'new'			=> array(
 					'action'	=> $urlCompose,
 					'tooltip'	=> lang('compose'),
 				),
 				'read_small'		=> array(
-					'action'	=> "flagMessages('read',xajax.getFormValues('formMessageList'))",
+					'action'	=> "flagMessages('read')",
 					'tooltip'	=> lang('mark selected as read'),
 				),
 				'unread_small'		=> array(
-					'action'	=> "flagMessages('unread',xajax.getFormValues('formMessageList'))",
+					'action'	=> "flagMessages('unread')",
 					'tooltip'	=> lang('mark selected as unread'),
 				),
 				'unread_flagged_small'	=> array(
-					'action'	=> "flagMessages('flagged',xajax.getFormValues('formMessageList'))",
+					'action'	=> "flagMessages('flagged')",
 					'tooltip'	=> lang('mark selected as flagged'),
 				),
 				'read_flagged_small'	=> array(
-					'action'	=> "flagMessages('unflagged',xajax.getFormValues('formMessageList'))",
+					'action'	=> "flagMessages('unflagged')",
 					'tooltip'	=> lang('mark selected as unflagged'),
 				),
 				'delete'		=> array(
@@ -479,11 +404,10 @@
 					'tooltip'	=> lang('mark as deleted'),
 				),
 			);
-			foreach($navbarImages as $buttonName => $buttonInfo)
-			{
+			
+			foreach($navbarImages as $buttonName => $buttonInfo) {
 				$navbarButtons .= $uiwidgets->navbarButton($buttonName, $buttonInfo['action'], $buttonInfo['tooltip']);
 			}
-			#$navbarButtons .= $uiwidgets->navbarSeparator();
 			$this->t->set_var('navbarButtonsLeft',$navbarButtons);
 
 			$navbarImages = array(
@@ -505,11 +429,9 @@
 				),
 			);
 			$navbarButtons  = '';
-			foreach($navbarImages as $buttonName => $buttonInfo)
-			{
+			foreach($navbarImages as $buttonName => $buttonInfo) {
 				$navbarButtons .= $uiwidgets->navbarButton($buttonName, $buttonInfo['action'], $buttonInfo['tooltip'],'right');
 			}
-			#$navbarButtons .= $uiwidgets->navbarSeparator();
 			$this->t->set_var('navbarButtonsRight',$navbarButtons);
 
 			// set the images
@@ -529,14 +451,15 @@
 				'previous_kde',
 				'next_kde',
 				'finnish_kde',
+				'ajax-loader',
 			);
 
-			foreach ($listOfImages as $image) 
-			{
-				$this->t->set_var($image,$GLOBALS['egw']->common->image('felamimail',$image));
+			foreach ($listOfImages as $image) {
+				$this->t->set_var($image, $GLOBALS['egw']->common->image('felamimail', $image));
 			}
+			$this->t->set_var('img_clear_left', $GLOBALS['egw']->html->image('felamimail', 'clear_left', lang('clear search'), 'style="margin-left:5px; cursor: pointer;" onclick="fm_clearSearch()"'));
 			// refresh settings
-			$refreshTime = $preferences['refreshTime'];
+			$refreshTime = $userPreferences['refreshTime'];
 			$this->t->set_var('refreshTime',$refreshTime*60*1000);
 			
 			#// set the url to open when refreshing
@@ -561,263 +484,183 @@
 			{
 				// sort by date newest first
 				case '0':
-					$dateSort	= '1';
-					$dateCSS	= 'text_small_bold';
-					break;
-				// sort by date oldest first
-				case '1':
-					$dateSort	= '0';
 					$dateCSS	= 'text_small_bold';
 					break;
 
 				// sort by from z->a
 				case '2':
-					$fromSort	= '3';
 					$fromCSS	= 'text_small_bold';
 					break;
 				// sort by from a->z
 				case '3':
-					$fromSort	= '2';
-					$fromCSS	= 'text_small_bold';
-					break;
-
-				// sort by subject z->a
-				case '4':
-					$subjectSort	= '5';
 					$subjectCSS	= 'text_small_bold';
 					break;
-				// sort by subject a->z
-				case '5':
-					$subjectSort	= '4';
-					$subjectCSS	= 'text_small_bold';
-					break;
-
 				// sort by size z->a
 				case '6':
-					$sizeSort	= '7';
-					$sizeCSS	= 'text_small_bold';
-					break;
-				// sort by subject a->z
-				case '7':
-					$sizeSort	= '6';
 					$sizeCSS	= 'text_small_bold';
 					break;
 			}
 
 			// sort by date
-			$linkData = array
-			(
-				'menuaction'	=> 'felamimail.uifelamimail.changeSorting',
-				'startMessage'	=> 1,
-				'sort'		=> $dateSort
-			);
-			$this->t->set_var('url_sort_date',$GLOBALS['egw']->link('/index.php',$linkData));
-			$this->t->set_var('css_class_date',$dateCSS);
+			$this->t->set_var('css_class_date', $dateCSS);
 		
 			// sort by from
-			$linkData = array
-			(
-				'menuaction'	=> 'felamimail.uifelamimail.changeSorting',
-				'startMessage'	=> 1,
-				'sort'		=> $fromSort
-			);
-			$this->t->set_var('url_sort_from',$GLOBALS['egw']->link('/index.php',$linkData));
-			$this->t->set_var('css_class_from',$fromCSS);
+			$this->t->set_var('css_class_from', $fromCSS);
 		
 			// sort by subject
-			$linkData = array
-			(
-				'menuaction'	=> 'felamimail.uifelamimail.changeSorting',
-				'startMessage'	=> 1,
-				'sort'		=> $subjectSort
-			);
-			$this->t->set_var('url_sort_subject',$GLOBALS['egw']->link('/index.php',$linkData));
-			$this->t->set_var('css_class_subject',$subjectCSS);
+			$this->t->set_var('css_class_subject', $subjectCSS);
 			
 			// sort by size
-			$linkData = array
-			(
-				'menuaction'	=> 'felamimail.uifelamimail.changeSorting',
-				'startMessage'	=> 1,
-				'sort'		=> $sizeSort
-			);
-			$this->t->set_var('url_sort_size',$GLOBALS['egw']->link('/index.php',$linkData));
-			$this->t->set_var('css_class_size',$sizeCSS);
+			$this->t->set_var('css_class_size', $sizeCSS);
 			
-			// create the filter ui
-			$filterList = $bofilter->getFilterList();
-			$activeFilter = (isset($this->bofelamimail->sessionData['activeFilter'])?$this->bofelamimail->sessionData['activeFilter']:-1);
-			// -1 == no filter selected
-			if($activeFilter == -1)
-				$filterUI .= "<option value=\"-1\" selected>".lang('no filter')."</option>";
-			else
-				$filterUI .= "<option value=\"-1\">".lang('no filter')."</option>";
-			while(list($key,$value) = @each($filterList))
-			{
-				$selected="";
-				if($activeFilter == $key) $selected="selected";
-				$filterUI .= "<option value=".$key." $selected>".$value['filterName']."</option>";
+			#_debug_array($this->bofelamimail->sessionData['messageFilter']);
+			if(!empty($this->bofelamimail->sessionData['messageFilter']['string'])) {
+				$this->t->set_var('quicksearch', $this->bofelamimail->sessionData['messageFilter']['string']);
 			}
-			$this->t->set_var('filter_options',$filterUI);
-			// 0 == quicksearch
-			if($activeFilter == '0')
-				$this->t->set_var('quicksearch',$filterList[0]['subject']);
 			
-			if($this->connectionStatus != 'True')
-			{
-				$this->t->set_var('message',$this->connectionStatus);
-				$this->t->parse('header_rows','error_message',True);
-			}
-			else
-			{
-				#$folders = $this->bofelamimail->getFolderList('true');
+			$defaultSearchType = (isset($this->bofelamimail->sessionData['messageFilter']['type']) ? $this->bofelamimail->sessionData['messageFilter']['type'] : 'quick');
+			$defaultSelectStatus = (isset($this->bofelamimail->sessionData['messageFilter']['status']) ? $this->bofelamimail->sessionData['messageFilter']['status'] : 'any');
 
-				$headers = $this->bofelamimail->getHeaders($this->startMessage, $maxMessages, $this->sort);
+			$searchTypes = array(
+				'quick'		=> 'quicksearch',
+				'subject'	=> 'subject',
+				'body'		=> 'message',
+				'from'		=> 'from',
+				'to'		=> 'to',
+				'cc'		=> 'cc',
+			);
+			$selectSearchType = $GLOBALS['egw']->html->select('searchType', $defaultSearchType, $searchTypes, false, "style='width:100%;' id='searchType' onchange='document.getElementById(\"quickSearch\").focus(); document.getElementById(\"quickSearch\").value=\"\" ;return false;'");
+			$this->t->set_var('select_search', $selectSearchType);
+			
+			$statusTypes = array(
+				'any'		=> 'any status',
+				'flagged'	=> 'flagged',
+				'unseen'	=> 'unread',
+				'answered'	=> 'replied',
+				'seen'		=> 'read',
+				'deleted'	=> 'deleted',
+			);
+			$selectStatus = $GLOBALS['egw']->html->select('status', $defaultSelectStatus, $statusTypes, false, "style='width:100%;' onchange='javascript:quickSearch();' id='status'");
+			$this->t->set_var('select_status', $selectStatus);
+
+			if($this->connectionStatus === false) {
+				$this->t->set_var('connection_error_message', lang($this->bofelamimail->getErrorMessage()));
+				$this->t->set_var('message', '&nbsp;');
+				$this->t->parse('header_rows','error_message',True);
+			} else {
+				$headers = $this->bofelamimail->getHeaders($this->mailbox, $this->startMessage, $maxMessages, $this->sort, $this->sortReverse, $this->bofelamimail->sessionData['messageFilter']);
 
  				$headerCount = count($headers['header']);
 					
  				// if there aren't any messages left (eg. after delete or move) 
  				// adjust $this->startMessage  
- 				if ($headerCount==0 && $this->startMessage > $maxMessages)
- 				{
+ 				if ($headerCount==0 && $this->startMessage > $maxMessages) {
  					$this->startMessage = $this->startMessage - $maxMessages;
 					$headers = $this->bofelamimail->getHeaders($this->startMessage, $maxMessages, $this->sort);
 					$headerCount = count($headers['header']);
 				}
 				
-
-				if ($mailPreferences['sent_folder'] == $this->mailbox)
-				{
+				if ($userPreferences['sentFolder'] == $this->mailbox || $userPreferences['draftFolder'] == $this->mailbox) {
 					$this->t->set_var('lang_from',lang("to"));
-				}
-				else
-				{
+				} else {
 					$this->t->set_var('lang_from',lang("from"));
 				}
 				$msg_icon_sm = $GLOBALS['egw']->common->image('felamimail','msg_icon_sm');
-		
-				$this->t->set_var('header_rows',$uiwidgets->messageTable($headers,
-					$mailPreferences['sent_folder'] == $this->mailbox,$preferences['messageNewWindow']));
+
+				$this->t->set_var('header_rows',
+					$uiwidgets->messageTable(
+						$headers,
+						($userPreferences['sentFolder'] == $this->mailbox || $userPreferences['draftFolder'] == $this->mailbox),
+						$userPreferences['message_newwindow'],
+						$userPreferences['rowOrderStyle']
+					)
+				);
 
 				$firstMessage = $headers['info']['first'];
 				$lastMessage = $headers['info']['last'];
 				$totalMessage = $headers['info']['total'];
 				$langTotal = lang("total");		
-			}
-			
-			$this->t->set_var('maxMessages',$i);
-			if($_GET["select_all"] == "select_all")
-			{
-				$this->t->set_var('checkedCounter',$i);
-			}
-			else
-			{
-				$this->t->set_var('checkedCounter','0');
-			}
-			
-			// set the select all/nothing link
-			if($_GET["select_all"] == "select_all")
-			{
-				// link to unselect all messages
-				$linkData = array
-				(
-					'menuaction'	=> 'felamimail.uifelamimail.viewMainScreen'
-				);
-				$selectLink = sprintf("<a class=\"body_link\" href=\"%s\">%s</a>",
-							$GLOBALS['egw']->link('/index.php',$linkData),
-							lang("Unselect All"));
-				$this->t->set_var('change_folder_checked','');
-				$this->t->set_var('move_message_checked','checked');
-			}
-			else
-			{
-				// link to select all messages
-				$linkData = array
-				(
-					'select_all'	=> 'select_all',
-					'menuaction'	=> 'felamimail.uifelamimail.viewMainScreen'
-				);
-				$selectLink = sprintf("<a class=\"body_link\" href=\"%s\">%s</a>",
-							$GLOBALS['egw']->link('/index.php',$linkData),
-							lang("Select all"));
-				$this->t->set_var('change_folder_checked','checked');
-				$this->t->set_var('move_message_checked','');
-			}
-			$this->t->set_var('select_all_link',$selectLink);
 			
 
-			// create the links for the delete options
-			// "delete all" in the trash folder
-			// "compress folder" in normal folders
-/*			if ($mailPreferences['trash_folder'] == $this->mailbox &&
-					$mailPreferences['deleteOptions'] == "move_to_trash")
-			{
-				$linkData = array
-				(
-					'menuaction'	=> 'felamimail.uifelamimail.compressFolder'
-				);
-				$trashLink = sprintf("<a class=\"body_link\" href=\"%s\">%s</a>",
-							$GLOBALS['egw']->link('/index.php',$linkData),
-							lang("delete all"));
-				
-				$this->t->set_var('trash_link',$trashLink);
-			}
-			elseif($mailPreferences['deleteOptions'] == "mark_as_deleted")
-			{
-				$linkData = array
-				(
-					'menuaction'	=> 'felamimail.uifelamimail.compressFolder'
-				);
-				$trashLink = sprintf("<a class=\"body_link\" href=\"%s\">%s</a>",
-							$GLOBALS['egw']->link('/index.php',$linkData),
-							lang("compress folder"));
-				$this->t->set_var('trash_link',$trashLink);
-			}*/
+				$this->t->set_var('maxMessages',$i);
+				if($_GET["select_all"] == "select_all") {
+					$this->t->set_var('checkedCounter',$i);
+				} else {
+					$this->t->set_var('checkedCounter','0');
+				}
 			
+				// set the select all/nothing link
+				if($_GET["select_all"] == "select_all") {
+					// link to unselect all messages
+					$linkData = array
+					(
+						'menuaction'	=> 'felamimail.uifelamimail.viewMainScreen'
+					);
+					$selectLink = sprintf("<a class=\"body_link\" href=\"%s\">%s</a>",
+								$GLOBALS['egw']->link('/index.php',$linkData),
+								lang("Unselect All"));
+					$this->t->set_var('change_folder_checked','');
+					$this->t->set_var('move_message_checked','checked');
+				} else {
+					// link to select all messages
+					$linkData = array
+					(
+						'select_all'	=> 'select_all',
+						'menuaction'	=> 'felamimail.uifelamimail.viewMainScreen'
+					);
+					$selectLink = sprintf("<a class=\"body_link\" href=\"%s\">%s</a>",
+								$GLOBALS['egw']->link('/index.php',$linkData),
+								lang("Select all"));
+					$this->t->set_var('change_folder_checked','checked');
+					$this->t->set_var('move_message_checked','');
+				}
+				$this->t->set_var('select_all_link',$selectLink);
 			
-			$this->t->set_var('message',lang("Viewing messages")." <b>$firstMessage</b> - <b>$lastMessage</b> ($totalMessage $langTotal)");
-			if($firstMessage > 1)
-			{
-				$linkData = array
-				(
-					'menuaction'	=> 'felamimail.uifelamimail.viewMainScreen',
-					'startMessage'	=> $this->startMessage - $maxMessages
-				);
-				$link = $GLOBALS['egw']->link('/index.php',$linkData);
-				$this->t->set_var('link_previous',"<a class=\"body_link\" href=\"$link\">".lang("previous")."</a>");
-			}
-			else
-			{
-				$this->t->set_var('link_previous',lang("previous"));
-			}
-			
-			if($totalMessage > $lastMessage)
-			{
-				$linkData = array
-				(
-					'menuaction'	=> 'felamimail.uifelamimail.viewMainScreen',
-					'startMessage'	=> $this->startMessage + $maxMessages
-				);
-				$link = $GLOBALS['egw']->link('/index.php',$linkData);
-				$this->t->set_var('link_next',"<a class=\"body_link\" href=\"$link\">".lang("next")."</a>");
-			}
-			else
-			{
-				$this->t->set_var('link_next',lang("next"));
-			}
-			$this->t->parse('status_row','status_row_tpl',True);
-			
-			$folderObjects = $this->bofelamimail->getFolderObjects(true, false);
-			$folderTree = $uiwidgets->createHTMLFolder
-			(
-				$folderObjects, 
-				$this->mailbox, 
-				lang('IMAP Server'), 
-				$mailPreferences['username'].'@'.$mailPreferences['imapServerAddress'],
-				'divFolderTree',
-				FALSE
-			);
+				$this->t->set_var('message',lang("Viewing messages")." <b>$firstMessage</b> - <b>$lastMessage</b> ($totalMessage $langTotal)");
+				if($firstMessage > 1) {
+					$linkData = array
+					(
+						'menuaction'	=> 'felamimail.uifelamimail.viewMainScreen',
+						'startMessage'	=> $this->startMessage - $maxMessages
+					);
+					$link = $GLOBALS['egw']->link('/index.php',$linkData);
+					$this->t->set_var('link_previous',"<a class=\"body_link\" href=\"$link\">".lang("previous")."</a>");
+				} else {
+					$this->t->set_var('link_previous',lang("previous"));
+				}
 
+				if($totalMessage > $lastMessage) {
+					$linkData = array (
+						'menuaction'	=> 'felamimail.uifelamimail.viewMainScreen',
+						'startMessage'	=> $this->startMessage + $maxMessages
+					);
+					$link = $GLOBALS['egw']->link('/index.php',$linkData);
+					$this->t->set_var('link_next',"<a class=\"body_link\" href=\"$link\">".lang("next")."</a>");
+				} else {
+					$this->t->set_var('link_next',lang("next"));
+				}
+				$this->t->parse('status_row','status_row_tpl',True);
+				//print __LINE__ . ': ' . (microtime(true) - $this->timeCounter) . '<br>';
+			
+				$folderObjects = $this->bofelamimail->getFolderObjects(true, false);
+				//print __LINE__ . ': ' . (microtime(true) - $this->timeCounter) . '<br>';
+				$folderStatus = $this->bofelamimail->getFolderStatus($this->mailbox);
+				//print __LINE__ . ': ' . (microtime(true) - $this->timeCounter) . '<br>';
+
+				$folderTree = $uiwidgets->createHTMLFolder
+				(
+					$folderObjects, 
+					$this->mailbox, 
+					$folderStatus['unseen'],
+					lang('IMAP Server'), 
+					$imapServer->username.'@'.$imapServer->host,
+					'divFolderTree',
+					FALSE
+				);
+				//print __LINE__ . ': ' . (microtime(true) - $this->timeCounter) . '<br>';
+				$this->bofelamimail->closeConnection();
+
+			}
 			$this->t->set_var('current_mailbox',$current_mailbox);
 			$this->t->set_var('folder_tree',$folderTree);
 
@@ -827,16 +670,7 @@
 			(
 				'menuaction'    => 'felamimail.uicompose.compose'
 			);
-			#if($preferences['messageNewWindow'])
-			#{
-				#$this->t->set_var('url_compose_empty',"javascript:displayMessage('".$GLOBALS['egw']->link('/index.php',$linkData)."','".
-				#	($preferences['messageNewWindow'] == 1 ? 'displayMessage' : '_blank')."');");
-				$this->t->set_var('url_compose_empty',"egw_openWindowCentered('".$GLOBALS['egw']->link('/index.php',$linkData)."','test',700,egw_getWindowOuterHeight());");
-			#}
-			#else
-			#{
-			#	$this->t->set_var('url_compose_empty',$GLOBALS['egw']->link('/index.php',$linkData));
-			#}
+			$this->t->set_var('url_compose_empty',"egw_openWindowCentered('".$GLOBALS['egw']->link('/index.php',$linkData)."','test',700,egw_getWindowOuterHeight());");
 
 
 			$linkData = array
@@ -859,16 +693,21 @@
 
 			$this->t->set_var('lang_mark_messages_as',lang('mark messages as'));
 			$this->t->set_var('lang_delete',lang('delete'));
-																																																																																							
+
+			switch($GLOBALS['egw_info']['user']['preferences']['felamimail']['rowOrderStyle']) {
+				case 'outlook':
+					$this->t->parse('messageListTableHeader','table_header_outlook',True);
+					break;
+				default:
+					$this->t->parse('messageListTableHeader','table_header_felamimail',True);
+					break;
+			}
+			//print __LINE__ . ': ' . (microtime(true) - $this->timeCounter) . '<br>';
+			
 			$this->t->parse("out","main");
 			print $this->t->get('out','main');
 			
-			if($this->connectionStatus == 'True')
-			{
-				$this->bofelamimail->closeConnection();
-			}
 			$GLOBALS['egw']->common->egw_footer();
-			
 		}
 
 		function array_merge_replace( $array, $newValues ) 
@@ -954,7 +793,7 @@
 			$this->t->set_var('lang_date',lang("date"));
 			$this->t->set_var('lang_status',lang('status'));
 			$this->t->set_var('lang_size',lang("size"));
-			$this->t->set_var('lang_quicksearch',lang("Quicksearch"));
+			$this->t->set_var('lang_search',lang("search"));
 			$this->t->set_var('lang_replied',lang("replied"));
 			$this->t->set_var('lang_read',lang("read"));
 			$this->t->set_var('lang_unread',lang("unread"));
@@ -967,11 +806,19 @@
 			$this->t->set_var('lang_no_filter',lang("no filter"));
 			$this->t->set_var('lang_connection_failed',lang("The connection to the IMAP Server failed!!"));
 			$this->t->set_var('lang_select_target_folder',lang("Simply click the target-folder"));
+			$this->t->set_var('lang_updating_message_status',lang("updating message status"));
+			$this->t->set_var('lang_loading',lang('loading'));
+			$this->t->set_var('lang_deleting_messages',lang('deleting messages'));
 			$this->t->set_var('lang_open_all',lang("open all"));
 			$this->t->set_var('lang_close_all',lang("close all"));
 			$this->t->set_var('lang_moving_messages_to',lang('moving messages to'));
 			$this->t->set_var('lang_empty_trash',lang('empty trash'));
 			$this->t->set_var('lang_compress_folder',lang('compress folder'));
+			$this->t->set_var('lang_skipping_forward',lang('skipping forward'));
+			$this->t->set_var('lang_skipping_previous',lang('skipping previous'));
+			$this->t->set_var('lang_jumping_to_start',lang('jumping to start'));
+			$this->t->set_var('lang_jumping_to_end',lang('jumping to end'));
+			$this->t->set_var('lang_updating_view',lang('updating view'));
 		}
 	}
 ?>
