@@ -12,7 +12,7 @@
 	* option) any later version.                                                *
 	\***************************************************************************/
 
-	/* $Id: class.uipreferences.inc.php 20036 2005-11-28 16:16:06Z lkneschke $ */
+	/* $Id: class.uipreferences.inc.php 23423 2007-02-15 09:44:40Z lkneschke $ */
 
 	class uipreferences
 	{
@@ -20,8 +20,11 @@
 		var $public_functions = array
 		(
 			'addACL'		=> 'True',
+			'editAccountData'	=> 'True',
 			'editForwardingAddress'	=> 'True',
+			'editSignature'		=> 'True',
 			'listFolder'		=> 'True',
+			'listSignatures'	=> 'True',
 			'showHeader'		=> 'True',
 			'getAttachment'		=> 'True'
 		);
@@ -29,15 +32,16 @@
 		function uipreferences()
 		{
 			$this->t = $GLOBALS['egw']->template;
-			#$this->t->egroupware_hack = False;
+			$this->charset = $GLOBALS['egw']->translation->charset();
+
 			$this->bofelamimail	=& CreateObject('felamimail.bofelamimail',$GLOBALS['egw']->translation->charset());
+			$this->bopreferences	=& CreateObject('felamimail.bopreferences');
 			$this->uiwidgets	=& CreateObject('felamimail.uiwidgets');
-			$this->bofelamimail->openConnection('',OP_HALFOPEN);
+			$this->bofelamimail->openConnection();
 			
 			
 			$this->rowColor[0] = $GLOBALS['egw_info']["theme"]["bg01"];
 			$this->rowColor[1] = $GLOBALS['egw_info']["theme"]["bg02"];
-
 		}
 		
 		function addACL()
@@ -61,13 +65,35 @@
 			{
 				$GLOBALS['egw']->js =& CreateObject('phpgwapi.javascript');
 			}
-			$GLOBALS['egw']->js->validate_file('tabs','tabs');
-			$GLOBALS['egw']->js->validate_file('dhtmlxtree','js/dhtmlXCommon');
-			$GLOBALS['egw']->js->validate_file('dhtmlxtree','js/dhtmlXTree');
-			$GLOBALS['egw']->js->validate_file('jscode','listFolder','felamimail');
-			$GLOBALS['egw']->js->set_onload('javascript:initAll();');
+			
+			switch($_GET['menuaction'])
+			{
+				case 'felamimail.uipreferences.editSignature':
+					$GLOBALS['egw']->js->validate_file('jscode','listSignatures','felamimail');
+					#$GLOBALS['egw']->js->set_onload('fm_initEditLayout();');
+					break;
+				case 'felamimail.uipreferences.editAccountData':
+					$GLOBALS['egw']->js->validate_file('jscode','editAccountData','felamimail');
+					$GLOBALS['egw']->js->set_onload('javascript:initEditAccountData();');
+					break;
+
+				case 'felamimail.uipreferences.listSignatures':
+					$GLOBALS['egw']->js->validate_file('jscode','listSignatures','felamimail');
+					#$GLOBALS['egw']->js->set_onload('javascript:initEditAccountData();');
+					break;
+
+				case 'felamimail.uipreferences.listFolder':
+				case 'felamimail.uipreferences.addACL':
+					$GLOBALS['egw']->js->validate_file('tabs','tabs');
+					$GLOBALS['egw']->js->validate_file('dhtmlxtree','js/dhtmlXCommon');
+					$GLOBALS['egw']->js->validate_file('dhtmlxtree','js/dhtmlXTree');
+					$GLOBALS['egw']->js->validate_file('jscode','listFolder','felamimail');
+					$GLOBALS['egw']->js->set_onload('javascript:initAll();');
+					break;
+			}
 			
 			$GLOBALS['egw_info']['flags']['include_xajax'] = True;
+						
 			$GLOBALS['egw']->common->egw_header();
 			if($_displayNavbar == TRUE)
 				echo parse_navbar();
@@ -75,24 +101,24 @@
 		
 		function editForwardingAddress()
 		{
-			$config =& CreateObject('phpgwapi.config','felamimail');
-			$config->read_repository();
-			$profileID = $config->config_data['profileID'];
-			$boEMailAdmin	=& CreateObject('emailadmin.bo',$profileID);
-
-			if($_POST['save'])
-			{
-				//_debug_array($_POST);_debug_array($_POST);_debug_array($_POST);
-				$boEMailAdmin->saveSMTPForwarding($GLOBALS['egw_info']['user']['account_id'],$_POST['forwardingAddress'],$_POST['keepLocalCopy']);
+			$bofelamimail	=& CreateObject('felamimail.bofelamimail',$GLOBALS['egw']->translation->charset());
+			$mailPrefs	= $bofelamimail->getMailPreferences();
+			$ogServer	= $mailPrefs->getOutgoingServer(0);
+			
+			if(!is_a($ogServer, 'defaultsmtp') || !$ogServer->editForwardingAddress) {
+				die('You should not be here!');
 			}
-			elseif($_POST['cancel'])
-			{
+			
+			if($_POST['save']) {
+				//_debug_array($_POST);_debug_array($_POST);_debug_array($_POST);
+				$ogServer->saveSMTPForwarding($GLOBALS['egw_info']['user']['account_id'],$_POST['forwardingAddress'],$_POST['keepLocalCopy']);
+			} elseif($_POST['cancel']) {
 				ExecMethod('felamimail.uifelamimail.viewMainScreen');
 				return;
 			}
 			
-			$userData	= $boEMailAdmin->getUserData($GLOBALS['egw_info']['user']['account_id'],false);
-			#_debug_array($userData);
+			$userData = $ogServer->getUserData($GLOBALS['egw_info']['user']['account_id']);
+
 			$this->display_app_header(TRUE);
 
 			$this->t->set_file(array("body" => "edit_forwarding_address.tpl"));
@@ -100,16 +126,192 @@
 
 			$this->translate();
 
-			$linkData = array
-			(
+			$linkData = array (
 				'menuaction'    => 'felamimail.uipreferences.editForwardingAddress'
 			);
 			$this->t->set_var('form_action',$GLOBALS['egw']->link('/index.php',$linkData));
-			$this->t->set_var('forwarding_address',$userData['mailRoutingAddress'][0]);
+			$this->t->set_var('forwarding_address',$userData['mailForwardingAddress'][0]);
+			
 			#deliveryMode checked_keep_local_copy
-			if($userData['deliveryMode'] != 'forwardOnly')
+			if($userData['deliveryMode'] != 'forwardOnly') {
 				$this->t->set_var('checked_keep_local_copy','checked');
+			}
 
+			$this->t->parse("out","main");
+			
+			print $this->t->get('out','main');
+		}
+		
+		function editSignature() {
+			$signatureID = (int)$_GET['signatureID'];
+			
+			if($signatureID >= 0) {
+				$signatureData = $this->bopreferences->getSignature($signatureID);
+			}
+
+			$this->display_app_header(false);
+			
+			$this->t->set_file(array('body' => 'preferences_edit_signature.tpl'));
+			$this->t->set_block('body','main');
+
+			$this->translate();
+
+			$linkData = array
+			(
+				'menuaction'    => 'felamimail.uipreferences.editSignature'
+			);
+			$this->t->set_var('form_action',$GLOBALS['egw']->link('/index.php',$linkData));
+
+			$this->t->set_var('description', ($signatureID >= 0 ? @htmlspecialchars($signatureData['description'], ENT_QUOTES, $this->charset) : ''));
+			
+			$this->t->set_var('signatureID', $signatureID);
+
+			$style="width:100%; border:0px; height:150px;";
+			$this->t->set_var('tinymce',$GLOBALS['egw']->html->fckEditorQuick(
+				'signature', 'simple', 
+				($signatureID >= 0 ? $signatureData['signature'] : ''), 
+				'150px')
+			);
+
+			$this->t->set_var('checkbox_isDefaultSignature',$GLOBALS['egw']->html->checkbox(
+				'isDefaultSignature',
+				$signatureData['defaultsignature'],
+				'true',
+				'id="isDefaultSignature"'
+				)
+			);
+
+			$this->t->parse("out","main");
+			print $this->t->get('out','main');
+		}
+		
+		function editAccountData()
+		{
+			$boPreferences	=& CreateObject('felamimail.bopreferences');
+			$preferences =& $boPreferences->getPreferences();
+			
+			if(!$preferences->userDefinedAccounts) {
+				die('you are not allowed to be here');
+			}
+
+			if($_POST['save'] || $_POST['apply']) {
+				// IMAP connection settings
+				$icServer =& CreateObject('emailadmin.defaultimap');
+				if(is_array($_POST['ic'])) {
+					foreach($_POST['ic'] as $key => $value) {
+						switch($key) {
+							case 'validatecert':
+								$icServer->$key = ($value != 'dontvalidate');
+								break;
+								
+							case 'enableSieve':
+								$icServer->$key = ($value == 'enableSieve');
+								break;
+							
+							default:
+								$icServer->$key = $value;
+								break;
+						}
+					}
+				}
+				
+				// SMTP connection settings
+				$ogServer =& CreateObject('emailadmin.defaultsmtp');
+				if(is_array($_POST['og'])) {
+					foreach($_POST['og'] as $key => $value) {
+						$ogServer->$key = $value;
+					}
+				}
+
+				// identity settings
+				$identity =& CreateObject('emailadmin.ea_identity');
+				if(is_array($_POST['identity'])) {
+					foreach($_POST['identity'] as $key => $value) {
+						$identity->$key = $value;
+					}
+				}
+
+				if((int)$_POST['active']) {
+					$boPreferences->saveAccountData($icServer, $ogServer, $identity);
+					$boPreferences->setProfileActive(true);
+				} else {
+					$boPreferences->setProfileActive(false);
+				}
+				
+				if($_POST['save']) {
+					ExecMethod('felamimail.uifelamimail.viewMainScreen');
+					return;
+				}
+			} elseif($_POST['cancel']) {
+				ExecMethod('felamimail.uifelamimail.viewMainScreen');
+				return;
+			}
+
+			$this->display_app_header(TRUE);
+			
+			$this->t->set_file(array("body" => "edit_account_data.tpl"));
+			$this->t->set_block('body','main');
+
+			$this->translate();
+
+			$accountData	= $boPreferences->getAccountData($preferences);
+			$icServer =& $accountData['icServer'];
+			$ogServer =& $accountData['ogServer'];
+			$identity =& $accountData['identity'];
+			#_debug_array($icServer);
+			foreach($icServer as $key => $value) {
+				if(is_object($value) || is_array($value)) {
+					continue;
+				}
+				switch($key) {
+					case 'encryption':
+						$this->t->set_var('checked_ic_'. $key .'_'. $value, 'checked');
+						break;
+						
+					case 'enableSieve':
+						$this->t->set_var('checked_ic_'.$key,($value ? 'checked' : ''));
+						break;
+
+					case 'validatecert':
+						$this->t->set_var('checked_ic_'.$key,($value ? '' : 'checked'));
+						break;
+						
+					default:
+						$this->t->set_var("ic[$key]", $value);
+						break;
+				}
+			}
+
+			foreach($ogServer as $key => $value) {
+				if(is_object($value) || is_array($value)) {
+					continue;
+				}
+				#print "$key => $value<bR>";
+				switch($key) {
+					case 'smtpAuth':
+						$this->t->set_var('checked_og_'.$key,($value ? 'checked' : ''));
+					default:
+						$this->t->set_var("og[$key]", $value);
+				}
+			}
+
+			foreach($identity as $key => $value) {
+				if(is_object($value) || is_array($value)) {
+					continue;
+				}
+				switch($key) {
+					default:
+						$this->t->set_var("identity[$key]", $value);
+				}
+			}
+
+			$this->t->set_var('checked_active',($accountData['active'] ? 'checked' : ''));
+			
+			$linkData = array
+			(
+				'menuaction'    => 'felamimail.uipreferences.editAccountData'
+			);
+			$this->t->set_var('form_action',$GLOBALS['egw']->link('/index.php',$linkData));
 
 			$this->t->parse("out","main");
 			print $this->t->get('out','main');
@@ -229,12 +431,14 @@
 			#$this->t->set_var('acl_url',$GLOBALS['egw']->link('/index.php',$linkData));
 			
 			// folder select box
+			$icServer = $mailPrefs->getIncomingServer(0);
 			$folderTree = $this->uiwidgets->createHTMLFolder
 			(
 				$folderList, 
 				$this->selectedFolder, 
+				0,
 				lang('IMAP Server'), 
-				$mailPrefs['username'].'@'.$mailPrefs['imapServerAddress'],
+				$icServer->username.'@'.$icServer->host,
 				'divFolderTree',
 				TRUE
 			);
@@ -301,7 +505,42 @@
 			$this->t->set_var('mailboxNameShort',$mailBoxName);
 			$this->t->set_var('mailboxName',$mailBoxName);			
 			$this->t->set_var('folderName',$this->selectedFolder);
-			$this->t->set_var('imap_server',$mailPrefs['imapServerAddress']);
+			$this->t->set_var('imap_server',$icServer->host);
+			
+			$this->t->pparse("out","main");			
+			$this->bofelamimail->closeConnection();
+		}
+		
+		function listSignatures()
+		{
+			$this->display_app_header(TRUE);
+
+			$this->t->set_file(array("body" => "preferences_list_signatures.tpl"));
+			$this->t->set_block('body','main');
+
+			$this->translate();
+			
+			#print "<pre>";print_r($folderList);print "</pre>";
+			// set the default values for the sort links (sort by subject)
+			$linkData = array
+			(
+				'menuaction'    => 'felamimail.uipreferences.listFolder'
+			);
+			$this->t->set_var('form_action', $GLOBALS['egw']->link('/index.php',$linkData));
+
+			$linkData = array
+			(
+				'menuaction'    => 'felamimail.uipreferences.editSignature',
+				'signatureID'	=> '-1'
+			);
+			$this->t->set_var('url_addSignature', $GLOBALS['egw']->link('/index.php',$linkData));
+			
+			$this->t->set_var('url_image_add',$GLOBALS['egw']->common->image('phpgwapi','new'));
+			$this->t->set_var('url_image_delete',$GLOBALS['egw']->common->image('phpgwapi','delete'));
+			
+			$signatures = $this->bopreferences->getListOfSignatures();
+			
+			$this->t->set_var('table', $this->uiwidgets->createSignatureTable($signatures));
 			
 			$this->t->pparse("out","main");			
 			$this->bofelamimail->closeConnection();
@@ -338,19 +577,41 @@
 			$this->t->set_var('lang_add',lang("add"));
 			$this->t->set_var('lang_delete_selected',lang("delete selected"));
 			$this->t->set_var('lang_cancel',lang("close"));
-			$this->t->set_var('lang_ACL',lang("ACL"));
+			$this->t->set_var('lang_ACL',lang('ACL'));
 			$this->t->set_var('lang_save',lang('save'));
 			$this->t->set_var('lang_cancel',lang('cancel'));
-			$this->t->set_var('lang_Overview',lang("Overview"));
+			$this->t->set_var('lang_Overview',lang('Overview'));
 			$this->t->set_var('lang_edit_forwarding_address',lang('edit email forwarding address'));
-			$this->t->set_var('lang_forwarding_address',lang("email forwarding address"));
-			$this->t->set_var('lang_keep_local_copy',lang("keep local copy of email"));
+			$this->t->set_var('lang_forwarding_address',lang('email forwarding address'));
+			$this->t->set_var('lang_keep_local_copy',lang('keep local copy of email'));
+			$this->t->set_var('hostname_address',lang('hostname / address'));
+			$this->t->set_var('lang_username',lang('username'));
+			$this->t->set_var('lang_password',lang('password'));
+			$this->t->set_var('lang_port',lang('port'));
+			$this->t->set_var('lang_apply',lang('apply'));
+			$this->t->set_var('lang_use_costum_settings',lang('use custom settings'));
+			$this->t->set_var('lang_identity',lang('identity'));
+			$this->t->set_var('lang_name',lang('name'));
+			$this->t->set_var('lang_organization',lang('organization'));
+			$this->t->set_var('lang_emailaddress',lang('emailaddress'));
+			$this->t->set_var('lang_encrypted_connection',lang('encrypted connection'));
+			$this->t->set_var('lang_do_not_validate_certificate',lang('do not validate certificate'));
+			$this->t->set_var("lang_incoming_server",lang('incoming mail server(IMAP)'));
+			$this->t->set_var("lang_outgoing_server",lang('outgoing mail server(SMTP)'));
+			$this->t->set_var("auth_required",lang('authentication required'));
+			$this->t->set_var('lang_add_acl',lang('add acl'));
+			$this->t->set_var('lang_foldername',lang('foldername'));
+			$this->t->set_var('lang_description',lang('description'));
+			$this->t->set_var('lang_really_delete_signatures',lang('Do you really want to delete the selected signatures?'));
+			$this->t->set_var('lang_no_encryption',lang('no encryption'));
+			$this->t->set_var('lang_default_signature',lang('default signature'));
+			$this->t->set_var('lang_server_supports_sieve',lang('server supports mailfilter(sieve)'));
 			
 			$this->t->set_var("th_bg",$GLOBALS['egw_info']["theme"]["th_bg"]);
 			$this->t->set_var("bg01",$GLOBALS['egw_info']["theme"]["bg01"]);
 			$this->t->set_var("bg02",$GLOBALS['egw_info']["theme"]["bg02"]);
 			$this->t->set_var("bg03",$GLOBALS['egw_info']["theme"]["bg03"]);
 		}
-}
+	}
 
 ?>
