@@ -1,8 +1,6 @@
 <?php
 	/***************************************************************************\
-	* EGroupWare - FeLaMiMail                                                   *
-	* http://www.linux-at-work.de                                               *
-	* http://www.phpgw.de                                                       *
+	* eGroupWare - FeLaMiMail                                                   *
 	* http://www.egroupware.org                                                 *
 	* Written by : Lars Kneschke [lkneschke@linux-at-work.de]                   *
 	* -------------------------------------------------                         *
@@ -35,7 +33,7 @@
 	* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.		    *
 	\***************************************************************************/
 
-	/* $Id: class.uiwidgets.inc.php 22170 2006-07-24 09:15:40Z lkneschke $ */
+	/* $Id: class.uiwidgets.inc.php 25198 2008-03-27 08:54:48Z leithoff $ */
 
 	/**
 	* a class containing javascript enhanced html widgets
@@ -57,6 +55,16 @@
 			$template =& CreateObject('phpgwapi.Template',EGW_APP_TPL);
 			$this->template = $template;
 			$this->template->set_file(array("body" => 'uiwidgets.tpl'));
+			$this->charset = $GLOBALS['egw']->translation->charset();
+			
+			if (!is_object($GLOBALS['egw']->html)) {
+				$GLOBALS['egw']->html = CreateObject('phpgwapi.html');
+			}
+		}
+		
+		function encodeFolderName($_folderName)
+		{
+			return $GLOBALS['egw']->translation->convert($_folderName, 'UTF7-IMAP', $this->charset);
 		}
 
 		/**
@@ -67,40 +75,37 @@
 		*
 		* @param _folders array containing the list of folders
 		* @param _selected string containing the selected folder
+		* @param _selectedFolderCount integer contains the count of unread messages in the selected folder
 		* @param _topFolderName string containing the top folder name
 		* @param _topFolderDescription string containing the description for the top folder
 		* @param _formName string name of the sorounding form
 		* @param _hiddenVar string hidden form value, transports the selected folder
+		* @param _useDisplayCharset bool use displaycharset for foldernames (used by uisieve only)
 		*
 		* @return string the html code, to be added into the template
 		*/
-		function createHTMLFolder($_folders, $_selected, $_topFolderName, $_topFolderDescription, $_divName, $_displayCheckBox)
-		{
-			$allFolders = array();
-			
+		function createHTMLFolder($_folders, $_selected, $_selectedFolderCount, $_topFolderName, $_topFolderDescription, $_divName, $_displayCheckBox, $_useDisplayCharset = false) {
 			// create a list of all folders, also the ones which are not subscribed
- 			foreach($_folders as $key => $obj)
-			{
+ 			foreach($_folders as $key => $obj) {
 				$folderParts = explode($obj->delimiter,$key);
-				if(is_array($folderParts))
-				{
+				if(is_array($folderParts)) {
 					$partCount = count($folderParts);
 					$string = '';
-					for($i = 0; $i < $partCount-1; $i++)
-					{
+					for($i = 0; $i < $partCount-1; $i++) {
 						if(!empty($string)) $string .= $obj->delimiter;
 						$string .= $folderParts[$i];
-						if(!$allFolders[$string])
-						{	
-							$allFolders[$string] = $obj;
-							unset($allFolders[$string]->name);
-							unset($allFolders[$string]->attributes);
-							unset($allFolders[$string]->counter);
+						if(!$allFolders[$string]) {	
+							$allFolders[$string] = clone($obj);
+							$allFolders[$string]->folderName = $string;
+							$allFolders[$string]->shortFolderName = array_pop(explode($obj->delimiter, $string));
+							$allFolders[$string]->displayName = $this->encodeFolderName($allFolders[$string]->folderName);
+							$allFolders[$string]->shortDisplayName = $this->encodeFolderName($allFolders[$string]->shortFolderName);
 						}
 					}
 				}
 				$allFolders[$key] = $obj;
 			}
+
 			$folderImageDir = $GLOBALS['egw_info']['server']['webserver_url'].'/phpgwapi/templates/default/images/';
 			
 			// careful! "d = new..." MUST be on a new line!!!
@@ -108,17 +113,19 @@
 			$folder_tree_new .= "<script type='text/javascript'>";
 			$folder_tree_new .= "tree=new dhtmlXTreeObject('$_divName','100%','100%',0);";
 			$folder_tree_new .= "tree.setImagePath('$folderImageDir/dhtmlxtree/');";
-			if($_displayCheckBox)
-			{
+			if($_displayCheckBox) {
 				$folder_tree_new .= "tree.enableCheckBoxes(1);";
 				$folder_tree_new .= "tree.setOnCheckHandler('onCheckHandler');";
 			}
 			
-			$folder_tree_new .= "tree.insertNewItem(0,'--topfolder--','$_topFolderName',onNodeSelect,'thunderbird.png','thunderbird.png','thunderbird.png','CHILD,TOP');\n";
+			#$topFolderBase64 = base64_encode('--topfolder--');
+			$topFolderBase64 = '--topfolder--';
+			$folder_tree_new .= "tree.insertNewItem(0,'$topFolderBase64','$_topFolderName',onNodeSelect,'thunderbird.png','thunderbird.png','thunderbird.png','CHILD,TOP');\n";
 			
 			#foreach($_folders as $key => $obj)
-			foreach($allFolders as $longName => $obj)
-			{	
+			#_debug_array($allFolders);
+			foreach($allFolders as $longName => $obj) {	
+				$messageCount = '';
 				$image1 = "'folderClosed.gif'";
 				$image2 = "0";
 				$image3 = "0";
@@ -132,57 +139,101 @@
 				$parentName = implode((array)$folderParts,$obj->delimiter);
 				if(empty($parentName)) $parentName = '--topfolder--';
 				
- 				if( @$obj->counter->unseen > 0 )
-				{
- 					$messageCount = "&nbsp;(".$obj->counter->unseen.")";
-				}
- 				else
- 				{
-					$messageCount = "";
-				}
-
 				$entryOptions = 'CHILD,CHECKED';
 
+				$displayName	= @htmlspecialchars($obj->shortDisplayName, ENT_QUOTES, $this->charset);
+				$userData	= $displayName;
+
+				$parentName	= @htmlspecialchars($parentName, ENT_QUOTES, $this->charset);
+
 				// highlight currently selected mailbox
-				if ($_selected == $longName)
-				{
+				if ($_selected == $longName) {
 					$entryOptions .= ',SELECT';
+					if($_selectedFolderCount > 0) {
+						$messageCount = "&nbsp;($_selectedFolderCount)";
+						$displayName = "<b>$displayName&nbsp;($_selectedFolderCount)</b>";
+					}
 				}
 				
-				$folder_name = $shortName.$messageCount;
-				
+				if($_useDisplayCharset == true) {
+					$folderName	= $GLOBALS['egw']->translation->convert($obj->folderName, 'UTF7-IMAP', $this->charset);
+					$folderName	= @htmlspecialchars($folderName, ENT_QUOTES, $this->charset);
+				} else {
+					$folderName	= @htmlspecialchars($obj->folderName, ENT_QUOTES, $this->charset);
+				}
 				// give INBOX a special foldericon
-				if ($longName == 'INBOX')
-				{
+				if ($folderName == 'INBOX') {
 					$image1 = "'kfm_home.png'";
 					$image2 = "'kfm_home.png'";
 					$image3 = "'kfm_home.png'";
 				}
-				
-				$parentName = @htmlspecialchars($parentName, ENT_QUOTES, $this->charset);
-				$longName = @htmlspecialchars($longName, ENT_QUOTES, $this->charset);
-				$folder_name = @htmlspecialchars($folder_name, ENT_QUOTES, $this->charset);
 
-				$folder_tree_new .= "tree.insertNewItem('$parentName','$longName','$folder_name',onNodeSelect,$image1,$image2,$image3,'$entryOptions');\n";
-				if($_displayCheckBox)
-					$folder_tree_new .= "tree.setCheck('$longName','".(int)$obj->subscribed."');";
+				$search		= array('\\');
+				$replace	= array('\\\\');
+				$parentName	= str_replace($search, $replace, $parentName);
+				$folderName	= str_replace($search, $replace, $folderName);
+
+				$folder_tree_new .= "tree.insertNewItem('$parentName','$folderName','$displayName',onNodeSelect,$image1,$image2,$image3,'$entryOptions');";
+				$folder_tree_new .= "tree.setUserData('$folderName','folderName', '$userData');";
+				if($_displayCheckBox) {
+					$folder_tree_new .= "tree.setCheck('$folderName','".(int)$obj->subscribed."');";
+				}
 			}
-
+			
 			$selected = @htmlspecialchars($_selected, ENT_QUOTES, $this->charset);
+			#$selected = base64_encode($_selected);
+
 			$folder_tree_new.= "tree.closeAllItems(0);tree.openItem('$selected');</script>";
 			
 			return $folder_tree_new;
 		}
+		
+		function createSignatureTable($_signatureList) 
+		{
+			$linkData = array
+			(
+				'menuaction'    => 'felamimail.uipreferences.editSignature'
+			);
+			$urlEditSignature = $GLOBALS['egw']->link('/index.php',$linkData);
+			
+			if(is_array($_signatureList) && !empty($_signatureList)) {
+				foreach($_signatureList as $signature) {
+					$description = ($signature['defaultsignature'] == true) ? $signature['description'] .' ('. lang('default') .')' : $signature['description'];
+					$tableRows[] = array(
+						'1'	=> $GLOBALS['egw']->html->checkbox('signatureID', false, $signature['signatureid']),
+						'.1'	=> 'style="width:30px"',
+						'2'	=> '<a href="" onclick="egw_openWindowCentered(\''. $urlEditSignature ."&signatureID=".$signature['signatureid']. '\',\'felamiMailACL\',\'600\',\'230\'); return false;">'. @htmlspecialchars($description, ENT_QUOTES, $this->charset) .'</a>',
+					);
+				}
+				
+				return $GLOBALS['egw']->html->table($tableRows, 'style="width:100%;"');
+			}
+			
+			return '';
+		}
 
-		function messageTable($_headers, $_isSentFolder, $_readInNewWindow)
+		// $_folderType 0: normal imap folder 1: sent folder 2: draft folder
+		// $_rowStyle felamimail or outlook
+		function messageTable($_headers, $_folderType, $_readInNewWindow, $_rowStyle='felamimail')
 		{
 			$this->t =& CreateObject('phpgwapi.Template',EGW_APP_TPL);
 			$this->t->set_file(array("body" => 'mainscreen.tpl'));
-			$this->t->set_block('body','header_row');
+			$this->t->set_block('body','header_row_felamimail');
+			$this->t->set_block('body','header_row_outlook');
 			$this->t->set_block('body','message_table');
+			$timestamp7DaysAgo =
+				mktime(date("H"), date("i"), date("s"), date("m"), date("d")-7, date("Y"));
+			$timestampNow =
+				mktime(date("H"), date("i"), date("s"), date("m"), date("d"), date("Y"));
+			$dateToday = date("Y-m-d");
+                                                                                                                
 
+			$i=0;
 			foreach((array)$_headers['header'] as $header)
 			{
+				#_debug_array($header);
+				#if($i<10) {$i++;continue;}
+				#if($i>20) {continue;} $i++;
 				// create the listing of subjects
 				$maxSubjectLength = 60;
 				$maxAddressLength = 20;
@@ -195,162 +246,151 @@
 				if(!empty($header['answered'])) $flags .= "A";
 				if(!empty($header['deleted'])) $flags .= "D";
 				if(!empty($header['seen'])) $flags .= "S";
+				
+				$this->t->set_var('row_text', '');
 
-				switch($flags)
-				{
-					case "":
-						$this->t->set_var('imageName','unread_small.png');
-						$this->t->set_var('row_text',lang('new'));
-						$maxAddressLength = $maxAddressLengthBold;
-						$maxSubjectLength = $maxSubjectLengthBold;
-						break;
-					case "D":
-					case "DS":
-					case "ADS":
-						$this->t->set_var('imageName','unread_small.png');
-						$this->t->set_var('row_text',lang('deleted'));
-						break;
-					case "F":
-						$this->t->set_var('imageName','unread_flagged_small.png');
-						$this->t->set_var('row_text',lang('new'));
-						$maxAddressLength = $maxAddressLengthBold;
-						break;
-					case "FS":
-						$this->t->set_var('imageName','read_flagged_small.png');
-						$this->t->set_var('row_text',lang('replied'));
-						break;
-					case "FAS":
-						$this->t->set_var('imageName','read_answered_flagged_small.png');
-						$this->t->set_var('row_text',lang('replied'));
-						break;
-					case "S":
-					case "RS":
-						$this->t->set_var('imageName','read_small.png');
-						$this->t->set_var('row_text',lang('read'));
-						break;
-					case "R":
-						$this->t->set_var('imageName','recent_small.gif');
-						$this->t->set_var('row_text','*'.lang('recent').'*');
-						$maxAddressLength = $maxAddressLengthBold;
-						break;
-					case "RAS":
-					case "AS":
-						$this->t->set_var('imageName','read_answered_small.png');
-						$this->t->set_var('row_text',lang('replied'));
-						#$maxAddressLength = $maxAddressLengthBold;
-						break;
-					default:
-						$this->t->set_var('row_text',$flags);
-						break;
+				// the status icon
+				if($header['deleted']) {
+					$this->t->set_var('image_url',$GLOBALS['egw']->html->image('felamimail','kmmsgdel'));
+				} elseif($header['recent']) {
+					$this->t->set_var('image_url',$GLOBALS['egw']->html->image('felamimail','kmmsgnew'));
+				} elseif($header['answered']) {
+					$this->t->set_var('image_url',$GLOBALS['egw']->html->image('felamimail','kmmsgreplied'));
+				} elseif($header['seen']) {
+					$this->t->set_var('image_url',$GLOBALS['egw']->html->image('felamimail','kmmsgread'));
+				} else {
+					$this->t->set_var('image_url',$GLOBALS['egw']->html->image('felamimail','kmmsgunseen'));
 				}
-				#_debug_array($GLOBALS[phpgw_info]);
-				if (!empty($header['subject']))
-				{
-					// filter out undisplayable characters
-					$search = array('[\016]','[\017]',
-						'[\020]','[\021]','[\022]','[\023]','[\024]','[\025]','[\026]','[\027]',
-						'[\030]','[\031]','[\032]','[\033]','[\034]','[\035]','[\036]','[\037]');
-					$replace = '';
-			
-					$header['subject'] = preg_replace($search,$replace,$header['subject']);
 
+				// the css for this row
+				if($header['deleted']) {
+					$this->t->set_var('row_css_class','header_row_D');
+				} elseif($header['recent'] && !$header['seen']) {
+					$this->t->set_var('row_css_class','header_row_R');
+				} elseif($header['flagged']) {
+					if($header['seen']) {
+						$this->t->set_var('row_css_class','header_row_FS');
+					} else {
+						$this->t->set_var('row_css_class','header_row_F');
+					}
+				} elseif($header['seen']) {
+					$this->t->set_var('row_css_class','header_row_S');
+				} else {
+					$this->t->set_var('row_css_class','header_row_');
+				}
+				
+				// filter out undisplayable characters
+				$search = array('[\016]','[\017]',
+					'[\020]','[\021]','[\022]','[\023]','[\024]','[\025]','[\026]','[\027]',
+					'[\030]','[\031]','[\032]','[\033]','[\034]','[\035]','[\036]','[\037]');
+				$replace = '';
+		
+				$header['subject'] = preg_replace($search,$replace,$header['subject']);
+				$header['subject'] = @htmlspecialchars($header['subject'],ENT_QUOTES,$this->displayCharset);
+				// curly brackets get messed up by the template!
+				$header['subject'] = str_replace(array('{','}'),array('&#x7B;','&#x7D;'),$header['subject']);
+				
+				if (!empty($header['subject'])) {
 					// make the subject shorter if it is to long
 					$fullSubject = $header['subject'];
 					#if(strlen($header['subject']) > $maxSubjectLength)
 					#{
 					#	$header['subject'] = substr($header['subject'],0,$maxSubjectLength)."...";
 					#}
-					$header['subject'] = @htmlspecialchars($header['subject'],ENT_QUOTES,$this->displayCharset);
-					if($header['attachments'] == "true")
-					{
-						$image = '<img src="'.$GLOBALS['egw']->common->image('felamimail','attach').'" border="0" style="width:12px;">';
-
-						$header['attachment'] = $image;
-					}
 					$this->t->set_var('header_subject', $header['subject']);
-					$this->t->set_var('attachments', $header['attachment']);
-					$this->t->set_var('full_subject',@htmlspecialchars($fullSubject,ENT_QUOTES,$this->displayCharset));
+					#$this->t->set_var('attachments', $header['attachment']);
+					$this->t->set_var('full_subject', $fullSubject);
+				} else {
+					$this->t->set_var('header_subject', @htmlspecialchars('('. lang('no subject') .')', ENT_QUOTES, $this->displayCharset));
 				}
-				else
-				{
-					$this->t->set_var('header_subject',@htmlentities("(".lang('no subject').")",ENT_QUOTES,$this->displayCharset));
+
+#				_debug_array($header);
+				if($header['mimetype'] == 'multipart/mixed' || 
+				   $header['mimetype'] == 'multipart/related' ||
+				   substr($header['mimetype'],0,11) == 'application' ||
+				   substr($header['mimetype'],0,5) == 'audio') {
+					$image = $GLOBALS['egw']->html->image('felamimail','attach');
+					$this->t->set_var('attachment_image', $image);
+				} else {
+					$this->t->set_var('attachment_image', '&nbsp;');
 				}
 			
-				if ($_isSentFolder)
-				{
-					if (!empty($header['to_name']))
-					{
+				if ($_folderType > 0) {
+					// sent or drafts folder
+					if (!empty($header['to_name'])) {
 						$sender_name	= $header['to_name'];
 						$full_address	= $header['to_name'].' <'.$header['to_address'].'>';
-					}
-					else
-					{
+					} else {
 						$sender_name	= $header['to_address'];
 						$full_address	= $header['to_address'];
 					}
-					#$this->t->set_var('lang_from',lang("to"));
-				}
-				else
-				{
-					if (!empty($header['sender_name']))
-					{
+				} else {
+					if (!empty($header['sender_name'])) {
 						$sender_name	= $header['sender_name'];
 						$full_address	= $header['sender_name'].' <'.$header['sender_address'].'>';
-					}
-					else
-					{
+					} else {
 						$sender_name	= $header['sender_address'];
 						$full_address	= $header['sender_address'];
 					}
-					#$this->t->set_var('lang_from',lang("from"));
 				}
-				#if(strlen($sender_name) > $maxAddressLength)
-				#{
-				#	$sender_name = substr($sender_name,0,$maxAddressLength)."...";
-				#}
-				$this->t->set_var('sender_name',$sender_name);
-				$this->t->set_var('full_address',$full_address);
-			
-				$this->t->set_var('message_counter',$i);
-				$this->t->set_var('message_uid',$header['uid']);
 
-				$this->t->set_var('date',$header['date']);
-				$this->t->set_var('size',$this->show_readable_size($header['size']));
-
-				$linkData = array
-				(
-					'menuaction'    => 'felamimail.uidisplay.display',
-					'showHeader'	=> 'false',
-					'uid'			=> $header['uid']
-				);
-				$windowName = ($_readInNewWindow == 1 ? 'displayMessage' : 'displayMessage_'.$header['uid']);
-				$this->t->set_var('url_read_message',"egw_openWindowCentered('".$GLOBALS['egw']->link('/index.php',$linkData)."','$windowName',700,egw_getWindowOuterHeight());");
+				$this->t->set_var('sender_name', @htmlspecialchars($sender_name, ENT_QUOTES, $this->charset));
+				$this->t->set_var('full_address', @htmlspecialchars($full_address, ENT_QUOTES, $this->charset));
 			
-				if($_isSentFolder)
-				{
-					if(!empty($header['to_name']))
-					{
+				$this->t->set_var('message_counter', $i);
+				$this->t->set_var('message_uid', $header['uid']);
+
+				if ($dateToday == date('Y-m-d', $header['date'])) {
+					$this->t->set_var('date', $GLOBALS['egw']->common->show_date($header['date'],'H:i:s'));
+				} else {
+					$this->t->set_var('date', $GLOBALS['egw']->common->show_date($header['date'],$GLOBALS['egw_info']['user']['preferences']['common']['dateformat']));
+				}
+				
+				$this->t->set_var('size', $this->show_readable_size($header['size']));
+
+				if($_folderType == 2) {
+					$linkData = array (
+						'menuaction'    => 'felamimail.uicompose.composeFromDraft',
+						'icServer'	=> 0,
+						'folder'	=> base64_encode($GLOBALS['egw_info']['user']['preferences']['felamimail']['draftFolder']),
+						'uid'		=> $header['uid'],
+						'id'		=> $header['id'],
+					);
+					$this->t->set_var('url_read_message', $GLOBALS['egw']->link('/index.php',$linkData));
+
+					$windowName = 'composeFromDraft_'.$header['uid'];
+					$this->t->set_var('read_message_windowName', $windowName);
+				} else {
+				#	_debug_array($header);
+					$linkData = array (
+						'menuaction'    => 'felamimail.uidisplay.display',
+						'showHeader'	=> 'false',
+						'uid'		=> $header['uid'],
+						'id'		=> $header['id'],
+					);
+					$this->t->set_var('url_read_message', $GLOBALS['egw']->link('/index.php',$linkData));
+
+					$windowName = ($_readInNewWindow == 1 ? 'displayMessage' : 'displayMessage_'.$header['uid']);
+					$this->t->set_var('read_message_windowName', $windowName);
+				}
+			
+				if($_folderType > 0) {
+					// sent or draft folder
+					if(!empty($header['to_name'])) {
 						list($mailbox, $host) = explode('@',$header['to_address']);
 						$senderAddress  = imap_rfc822_write_address($mailbox,
 								$host,
 								$header['to_name']);
-					}
-					else
-					{
+					} else {
 						$senderAddress  = $header['to_address'];
 					}
-				}
-				else
-				{
-					if(!empty($header['sender_name']))
-					{
+				} else {
+					if(!empty($header['sender_name'])) {
 						list($mailbox, $host) = explode('@',$header['sender_address']);
 						$senderAddress  = imap_rfc822_write_address($mailbox,
 								$host,
 								$header['sender_name']);
-					}
-					else
-					{
+					} else {
 						$senderAddress  = $header['sender_address'];
 					}
 				}
@@ -365,10 +405,10 @@
 
 				$linkData = array
 				(
-					'menuaction'    => 'addressbook.uiaddressbook.add_email',
-					'add_email'	=> urlencode($header['sender_address']),
-					'name'		=> urlencode($header['sender_name']),
-					'referer'	=> urlencode($_SERVER['PHP_SELF'].'?'.$_SERVER['QUERY_STRING'])
+					'menuaction'   		=> 'addressbook.uicontacts.edit',
+					'presets[email]'	=> urlencode($header['sender_address']),
+					'presets[n_given]'	=> urlencode($header['sender_name']),
+					'referer'		=> urlencode($_SERVER['PHP_SELF'].'?'.$_SERVER['QUERY_STRING'])
 				);
 				//TODO: url_add_to_addressbook isn't in any of the templates. 
 				//If you want to use it, you need to adopt syntax to the new addressbook (popup)
@@ -376,9 +416,15 @@
 				$this->t->set_var('msg_icon_sm',$msg_icon_sm);
 				
 				$this->t->set_var('phpgw_images',EGW_IMAGES);
-				$this->t->set_var('row_css_class','header_row_'.$flags);
 		
-				$this->t->parse('message_rows','header_row',True);
+				switch($_rowStyle) {
+					case 'outlook':
+						$this->t->parse('message_rows','header_row_outlook',True);
+						break;
+					default:
+						$this->t->parse('message_rows','header_row_felamimail',True);
+						break;
+				}
 			}
 			$this->t->parse("out","message_table");
 			
@@ -433,7 +479,7 @@
 			$image = $GLOBALS['egw']->common->image('felamimail',$_imageName);
 			$float = $_float == 'right' ? 'right' : 'left';
 			
-			return "<div class='navButton' style='float:$float;' onmousedown='this.className=\"navButtonActive\";' onmouseup='this.className=\"navButtonHover\";' onmouseout='this.className=\"navButton\";' onclick=\"$_imageAction\"><img style='width:16px; height:16px;' title='$_toolTip' src='$image' ></div>\n";
+			return "<div class='navButton' style='float:$float;' onmousedown='this.className=\"navButtonActive\";' onmouseup='this.className=\"navButtonHover\";' onmouseout='this.className=\"navButton\";' onclick=\"$_imageAction\"><img style='width:16px; height:16px;' title='$_toolTip' src='$image' ></div>";
 		}
 
 		function navbarSeparator()
@@ -518,5 +564,48 @@
 				'text'	=> $_text
 			);
 		}
+		
+		function quotaDisplay($_usage, $_limit) 
+		{
+			$this->t =& CreateObject('phpgwapi.Template',EGW_APP_TPL);
+			$this->t->set_file(array("body" => 'mainscreen.tpl'));
+			$this->t->set_block('body','quota_block');
+
+			if($_limit == 0) {
+				$quotaPercent=100;
+			} else {
+				$quotaPercent=round(($_usage*100)/$_limit);
+			}
+				
+			$quotaLimit=$this->show_readable_size($_limit*1024);
+			$quotaUsage=$this->show_readable_size($_usage*1024);
+
+			$this->t->set_var('leftWidth',$quotaPercent);
+
+			if($quotaPercent > 90 && $_limit>0) {
+				$this->t->set_var('quotaBG','red');
+			} elseif($quotaPercent > 80 && $_limit>0) {
+				$this->t->set_var('quotaBG','yellow');
+			} else {
+				$this->t->set_var('quotaBG','#66ff66');
+			}
+				
+			if($_limit > 0) {
+				$quotaText = $quotaUsage .'/'.$quotaLimit;
+			} else {
+				$quotaText = $quotaUsage;
+			}
+				
+			if($quotaPercent > 50) {
+				$this->t->set_var('quotaUsage_left', $quotaText);
+				$this->t->set_var('quotaUsage_right','');
+			} else {
+				$this->t->set_var('quotaUsage_left','');
+				$this->t->set_var('quotaUsage_right', $quotaText);
+			}
+			
+			$this->t->parse('out','quota_block');	
+			return $this->t->get('out','quota_block');
+		}
 	}
-?>
\ No newline at end of file
+?>
