@@ -8,7 +8,7 @@
 	* Free Software Foundation; version 2 of the License                       *
 	\**************************************************************************/
 
-	/* $Id: hook_notifywindow.inc.php 18876 2005-07-23 15:52:49Z ralfbecker $ */
+	/* $Id: hook_notifywindow.inc.php 23418 2007-02-14 12:49:47Z lkneschke $ */
 
 	$d1 = strtolower(substr(APP_INC,0,3));
 	if($d1 == 'htt' || $d1 == 'ftp' )
@@ -24,7 +24,7 @@
 
 		$my_msg_bootstrap =& CreateObject("felamimail.bofelamimail");
 
-		$connectionStatus = $my_msg_bootstrap->openConnection('INBOX',OP_READONLY);
+		$connectionStatus = $my_msg_bootstrap->openConnection();
 
 		$folderStatus = $my_msg_bootstrap->getFolderStatus('INBOX');
 		#_debug_array($folderStatus);
