@@ -9,25 +9,23 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: hook_settings.inc.php 21313 2006-04-09 17:58:38Z lkneschke $ */
-
-	$this->bofelamimail =& CreateObject('felamimail.bofelamimail',$GLOBALS['egw']->translation->charset());
-	$this->bofelamimail->openConnection('',OP_HALFOPEN);
-	$folderObjects = $this->bofelamimail->getFolderObjects();
+	/* $Id: hook_settings.inc.php 23428 2007-02-16 13:38:42Z jaytraxx $ */
 	$folderList = array();
-	foreach($folderObjects as $folderName => $folderInfo)
-	{
-		#_debug_array($folderData);
-		#$folderParts = explode($folderInfo->delimiter,$folderName);
-		#if(count($folderParts) > 1)
-		#{
-		#}
-		$folderList[$folderName] = $folderName;
+	
+	$this->bofelamimail =& CreateObject('felamimail.bofelamimail',$GLOBALS['egw']->translation->charset());
+	if($this->bofelamimail->openConnection()) {
+		$folderObjects = $this->bofelamimail->getFolderObjects();
+		foreach($folderObjects as $folderName => $folderInfo) {
+			#_debug_array($folderData);
+			$folderList[$folderName] = $folderInfo->displayName;
+		}
+		$this->bofelamimail->closeConnection();
 	}
 
-	$this->bofelamimail->closeConnection();
-
-	$felamimailConfig = ExecMethod('emailadmin.bo.getUserProfile');
+	$config =& CreateObject('phpgwapi.config','felamimail');
+	$config->read_repository();
+	$felamimailConfig = $config->config_data;
+	unset($config);
 
 	$refreshTime = array(
 		'0' => lang('disabled'),
@@ -69,15 +67,20 @@
 	);
 
 	$deleteOptions = array(
-		'move_to_trash'   => lang('move to trash'),
-		'mark_as_deleted' => lang('mark as deleted'),
-		'remove_immediately' => lang('remove immediately')
+		'move_to_trash'		=> lang('move to trash'),
+		'mark_as_deleted'	=> lang('mark as deleted'),
+		'remove_immediately'	=> lang('remove immediately')
 	);
 
 	$htmlOptions = array(
-		'never_display'   => lang('never display html emails'),
-		'only_if_no_text' => lang('display only when no plain text is available'),
-		'always_display'  => lang('always show html emails')
+		'never_display'		=> lang('never display html emails'),
+		'only_if_no_text'	=> lang('display only when no plain text is available'),
+		'always_display'	=> lang('always show html emails')
+	);
+
+	$rowOrderStyle = array(
+		'felamimail'	=> lang('FeLaMiMail'),
+		'outlook'	=> 'Outlook',
 	);
 
 	$trashOptions = array_merge(
@@ -94,6 +97,14 @@
 		$folderList
 	);
 
+	$draftOptions = array_merge(
+		array(
+			'none' => lang("Don't use draft folder")
+		),
+		$folderList
+	);
+
+
 	/* Settings array for this app */
 	$GLOBALS['settings'] = array(
 		'refreshTime' => array(
@@ -104,16 +115,6 @@
 			'xmlrpc' => True,
 			'admin'  => False
 		),
-		'email_sig' => array(
-			'type'   => 'notify',
-			'label'  => 'email signature',
-			'name'   => 'email_sig',
-			'rows'   => 3,
-			'cols'   => 50,
-			'xmlrpc' => True,
-			'admin'  => False,
-			'help'   => ' ',	// this is to get the substitution help-texts
-		),
 		'sortOrder' => array(
 			'type'   => 'select',
 			'label'  => 'Default sorting order',
@@ -122,6 +123,14 @@
 			'xmlrpc' => True,
 			'admin'  => False
 		),
+		'rowOrderStyle' => array(
+			'type'   => 'select',
+			'label'  => 'row order style',
+			'name'   => 'rowOrderStyle',
+			'values' => $rowOrderStyle,
+			'xmlrpc' => True,
+			'admin'  => False
+		),
 		'mainscreen_showmail' => array(
 			'type'   => 'select',
 			'label'  => 'show new messages on main screen',
@@ -154,6 +163,13 @@
 			'xmlrpc' => True,
 			'admin'  => False
 		),
+		'allowExternalIMGs' => array(
+			'type'   => 'check',
+			'label'  => 'allow images from external sources in html emails',
+			'name'   => 'allowExternalIMGs',
+			'xmlrpc' => True,
+			'admin'  => True
+		),
 		'trashFolder' => array(
 			'type'   => 'select',
 			'label'  => 'trash folder',
@@ -169,69 +185,22 @@
 			'values' => $sentOptions,
 			'xmlrpc' => True,
 			'admin'  => False
+		),
+		'draftFolder' => array(
+			'type'   => 'select',
+			'label'  => 'draft folder',
+			'name'   => 'draftFolder',
+			'values' => $draftOptions,
+			'xmlrpc' => True,
+			'admin'  => False
+		),
+		'sieveScriptName' => array(
+			'type'   => 'input',
+			'label'  => 'sieve script name',
+			'name'   => 'sieveScriptName',
+			'xmlrpc' => True,
+			'admin'  => False
 		)
 	);
 
-	if($felamimailConfig['userDefinedAccounts'] == 'yes')
-	{
-		$selectOptions = array(
-			'no'  => lang('no'),
-			'yes' => lang('yes')
-		);
-		$GLOBALS['settings']['use_custom_settings'] = array(
-			'type'   => 'select',
-			'label'  => 'use custom settings',
-			'name'   => 'use_custom_settings',
-			'values' => $selectOptions,
-			'xmlrpc' => True,
-			'admin'  => False
-		);
-
-		$GLOBALS['settings']['username'] = array(
-			'type'   => 'input',
-			'label'  => 'username',
-			'name'   => 'username',
-			'size'   => 40,
-			'xmlrpc' => True,
-			'admin'  => False
-		);
-		$GLOBALS['settings']['key'] = array(
-			'type'   => 'password',
-			'label'  => 'password',
-			'name'   => 'key',
-			'size'   => 40,
-			'xmlrpc' => True,
-			'admin'  => False
-		);
-		$GLOBALS['settings']['emailAddress'] = array(
-			'type'   => 'input',
-			'label'  => 'EMail Address',
-			'name'   => 'emailAddress',
-			'size'   => 40,
-			'xmlrpc' => True,
-			'admin'  => False
-		);
-		$GLOBALS['settings']['imapServerAddress'] = array(
-			'type'   => 'input',
-			'label'  => 'IMAP Server Address',
-			'name'   => 'imapServerAddress',
-			'size'   => 40,
-			'xmlrpc' => True,
-			'admin'  => False
-		);
-
-		$selectOptions = array(
-			'no'  => lang('IMAP'),
-			'yes' => lang('IMAPS Encryption only'),
-			'imaps-encr-auth' => lang('IMAPS Authentication')
-		);
-		$GLOBALS['settings']['imapServerMode'] = array(
-			'type'   => 'select',
-			'label'  => 'IMAP Server type',
-			'name'   => 'imapServerMode',
-			'values' => $selectOptions,
-			'xmlrpc' => True,
-			'admin'  => False
-		);
-	}
 ?>
