@@ -11,7 +11,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 	
-	/* $Id: hook_sidebox_menu.inc.php 20556 2006-03-14 17:29:55Z ralfbecker $ */
+	/* $Id: hook_sidebox_menu.inc.php 24082 2007-06-12 15:11:52Z leithoff $ */
 
  /*
 	This hookfile is for generating an app-specific side menu used in the idots
@@ -30,11 +30,19 @@
 		'menuaction'    => 'felamimail.uicompose.compose'
 	);
 
-	$file = Array(
-		'Compose' => "javascript:openComposeWindow('".$GLOBALS['egw']->link('/index.php',$linkData)."');",
+	$file = array(
+                array(
+                        'text' => '<a class="textSidebox" href="'.htmlspecialchars($GLOBALS['egw']->link('/index.php',
+                        			  array(
+                        			  	'menuaction' => 'felamimail.uicompose.compose',
+                        			  )
+		                        )).'" target="_blank" onclick="egw_openWindowCentered(\''.$GLOBALS['egw']->link('/index.php',$linkData).'\',\''.lang('compose').'\',700,750); return false;">'.lang('compose'),
+                        'no_lang' => true,
+                    ),
+
 	);
 
-	if($preferences['deleteOptions'] == 'move_to_trash')
+	if($preferences->preferences['deleteOptions'] == 'move_to_trash')
 	{
 		$file += Array(
 			'_NewLine_'	=> '', // give a newline
@@ -42,7 +50,7 @@
 		);
 	}
 	
-	if($preferences['deleteOptions'] == 'mark_as_deleted')
+	if($preferences->preferences['deleteOptions'] == 'mark_as_deleted')
 	{
 		$file += Array(
 			'_NewLine_'		=> '', // give a newline
@@ -54,49 +62,70 @@
 
 	if ($GLOBALS['egw_info']['user']['apps']['preferences'])
 	{
-		$mailPreferences = ExecMethod('felamimail.bopreferences.getPreferences');
+		#$mailPreferences = ExecMethod('felamimail.bopreferences.getPreferences');
 		$menu_title = lang('Preferences');
 		$file = array(
 			'Preferences'		=> $GLOBALS['egw']->link('/index.php','menuaction=preferences.uisettings.index&appname=felamimail'),
-			'Manage Folders'	=> $GLOBALS['egw']->link('/index.php','menuaction=felamimail.uipreferences.listFolder')
 		);
 
-		if($mailPreferences['imapEnableSieve'] == true)
+		if($preferences->userDefinedAccounts)
 		{
 			$linkData = array
 			(
-				'menuaction'	=> 'felamimail.uisieve.editScript',
-				'editmode'	=> 'filter'
+				'menuaction' => 'felamimail.uipreferences.editAccountData',
 			);
-			$file['EMailfilter']	= $GLOBALS['egw']->link('/index.php',$linkData);
+			$file['Manage EMailaccounts'] = $GLOBALS['egw']->link('/index.php',$linkData);
+		}
+
 
 			$linkData = array
 			(
-				'menuaction'	=> 'felamimail.uisieve.editScript',
-				'editmode'	=> 'vacation'
+				'menuaction' => 'felamimail.uipreferences.listSignatures',
 			);
-			$file['Vacation']	= $GLOBALS['egw']->link('/index.php',$linkData);
+			$file['Manage Signatures'] = $GLOBALS['egw']->link('/index.php',$linkData);
+		
+		$file['Manage Folders']	= $GLOBALS['egw']->link('/index.php','menuaction=felamimail.uipreferences.listFolder');
+		
+		$icServer = $preferences->getIncomingServer(0);
+		if(is_a($icServer, 'defaultimap')) {
+			if($icServer->enableSieve) 
+			{
+				$linkData = array
+				(
+					'menuaction'	=> 'felamimail.uisieve.listRules',
+				);
+				$file['filter rules']	= $GLOBALS['egw']->link('/index.php',$linkData);
+
+				$linkData = array
+				(
+					'menuaction'	=> 'felamimail.uisieve.editVacation',
+				);
+				$file['vacation notice']	= $GLOBALS['egw']->link('/index.php',$linkData);
+			}
 		}
-		if($mailPreferences['editForwardingAddress'] == true)
-		{
-			$linkData = array
-			(
-				'menuaction'	=> 'felamimail.uipreferences.editForwardingAddress',
-			);
-			$file['Forwarding']	= $GLOBALS['egw']->link('/index.php',$linkData);
+
+		$ogServer = $preferences->getOutgoingServer(0);
+		if(is_a($ogServer, 'defaultsmtp')) {
+			if($ogServer->editForwardingAddress)
+			{
+				$linkData = array
+				(
+					'menuaction'	=> 'felamimail.uipreferences.editForwardingAddress',
+				);
+				$file['Forwarding']	= $GLOBALS['egw']->link('/index.php',$linkData);
+			}
 		}
 
 		display_sidebox($appname,$menu_title,$file);
 	}
-/* There is nothing to configure in felamimail anymore
-	if ($GLOBALS['egw_info']['user']['apps']['admin'])
+
+/*	if ($GLOBALS['egw_info']['user']['apps']['admin'])
 	{
 		$menu_title = lang('Administration');
 		$file = Array(
 			'Configuration' => $GLOBALS['egw']->link('/index.php','menuaction=felamimail.uifelamimail.hookAdmin')
 		);
 		display_sidebox($appname,$menu_title,$file);
-	}
-*/
+	} */
 }
 ?>
