@@ -5,26 +5,25 @@
 	* --------------------------------------------                             *
 	*  This program is free software; you can redistribute it and/or modify it *
 	*  under the terms of the GNU General Public License as published by the   *
-	*  Free Software Foundation; either version 2 of the License, or (at your  *
-	*  option) any later version.                                              *
+	*  Free Software Foundation; version 2 of the License.                     *
 	\**************************************************************************/
 
-	/* $Id: setup.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: setup.inc.php 24257 2007-07-05 13:02:49Z ralfbecker $ */
 
 	$setup_info['felamimail']['name']      		= 'felamimail';
 	$setup_info['felamimail']['title']     		= 'FeLaMiMail';
-	$setup_info['felamimail']['version']     	= '1.2';
+	$setup_info['felamimail']['version']     	= '1.4';
 	$setup_info['felamimail']['app_order'] 		= 2;
 	$setup_info['felamimail']['enable']    		= 1;
 
 	$setup_info['felamimail']['author']		= 'Lars Kneschke';
 	$setup_info['felamimail']['license']		= 'GPL';
 	$setup_info['felamimail']['description']	=
-		'IMAP emailclient for EGroupware';
+		'IMAP emailclient for eGroupWare';
 	$setup_info['felamimail']['maintainer'] 	= 'Lars Kneschke';
-	$setup_info['felamimail']['maintainer_email'] 	= 'lkneschke@linux-at-work.de';
+	$setup_info['felamimail']['maintainer_email'] 	= 'l.kneschke@metaways.de';
 
-	$setup_info['felamimail']['tables']    = array('egw_felamimail_cache','egw_felamimail_folderstatus','egw_felamimail_displayfilter');
+	$setup_info['felamimail']['tables']    = array('egw_felamimail_cache','egw_felamimail_folderstatus','egw_felamimail_displayfilter','egw_felamimail_accounts','egw_felamimail_signatures');
 
 	/* The hooks this app includes, needed for hooks registration */
 	$setup_info['felamimail']['hooks'][] = 'preferences';
@@ -41,10 +40,40 @@
 	/* Dependencies for this app to work */
 	$setup_info['felamimail']['depends'][] = array(
 		'appname'  => 'phpgwapi',
-		'versions' => Array('1.0.0','1.0.1','1.2')
+		'versions' => Array('1.3','1.4','1.5')
 	);
 	$setup_info['felamimail']['depends'][] = array(
 		'appname'  => 'emailadmin',
-		'versions' => Array('1.2')
+		'versions' => Array('1.3','1.4','1.5')
 	);
+	$setup_info['felamimail']['depends'][] = array(
+		'appname'  => 'egw-pear',
+		'versions' => Array('1.4.000','1.5')
+	);
+	// installation checks for felamimail
+	$setup_info['felamimail']['check_install'] = array(
+		'' => array(
+			'func' => 'pear_check',
+		),
+# get's provided by egw-pear temporarly
+		'Net_Sieve' => array(
+			'func' => 'pear_check',
+		),
+		'Net_IMAP' => array(
+			'func' => 'pear_check',
+		),
+		'Auth_SASL' => array(
+			'func' => 'pear_check',
+		),
+		'imap' => array(
+			'func' => 'extension_check',
+		),
+		'magic_quotes_gpc' => array(
+			'func' => 'php_ini_check',
+			'value' => 0,
+			'verbose_value' => 'Off',
+		),
+	);	
+
+
 
