@@ -9,7 +9,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: tables_current.inc.php 20295 2006-02-15 12:31:25Z  $ */
+  /* $Id: tables_current.inc.php 23423 2007-02-15 09:44:40Z lkneschke $ */
 
 	$phpgw_baseline = array(
 		'egw_felamimail_cache' => array(
@@ -21,10 +21,10 @@
 				'fmail_uid' => array('type' => 'int','precision' => '4','nullable' => False),
 				'fmail_subject' => array('type' => 'text'),
 				'fmail_striped_subject' => array('type' => 'text'),
-				'fmail_sender_name' => array('type' => 'varchar','precision' => '120'),
-				'fmail_sender_address' => array('type' => 'varchar','precision' => '120'),
-				'fmail_to_name' => array('type' => 'varchar','precision' => '120'),
-				'fmail_to_address' => array('type' => 'varchar','precision' => '120'),
+				'fmail_sender_name' => array('type' => 'varchar','precision' => '256'),
+				'fmail_sender_address' => array('type' => 'varchar','precision' => '256'),
+				'fmail_to_name' => array('type' => 'varchar','precision' => '256'),
+				'fmail_to_address' => array('type' => 'varchar','precision' => '256'),
 				'fmail_date' => array('type' => 'int','precision' => '8'),
 				'fmail_size' => array('type' => 'int','precision' => '4'),
 				'fmail_attachments' => array('type' => 'varchar','precision' => '120')
@@ -60,6 +60,47 @@
 			'fk' => array(),
 			'ix' => array(),
 			'uc' => array()
+		),
+		'egw_felamimail_accounts' => array(
+			'fd' => array(
+				'fm_owner' => array('type' => 'int','precision' => '4','nullable' => False),
+				'fm_id' => array('type' => 'auto'),
+				'fm_realname' => array('type' => 'varchar','precision' => '128'),
+				'fm_organization' => array('type' => 'varchar','precision' => '128'),
+				'fm_emailaddress' => array('type' => 'varchar','precision' => '128','nullable' => False),
+				'fm_ic_hostname' => array('type' => 'varchar','precision' => '128','nullable' => False),
+				'fm_ic_port' => array('type' => 'int','precision' => '4','nullable' => False),
+				'fm_ic_username' => array('type' => 'varchar','precision' => '128','nullable' => False),
+				'fm_ic_password' => array('type' => 'varchar','precision' => '128'),
+				'fm_ic_encryption' => array('type' => 'int','precision' => '4','nullable' => False),
+				'fm_og_hostname' => array('type' => 'varchar','precision' => '128','nullable' => False),
+				'fm_og_port' => array('type' => 'int','precision' => '4','nullable' => False),
+				'fm_og_smtpauth' => array('type' => 'bool','nullable' => False),
+				'fm_og_username' => array('type' => 'varchar','precision' => '128'),
+				'fm_og_password' => array('type' => 'varchar','precision' => '128'),
+				'fm_active' => array('type' => 'bool','nullable' => False),
+				'fm_ic_validatecertificate' => array('type' => 'bool','nullable' => False),
+				'fm_ic_enable_sieve' => array('type' => 'bool','precision' => '255'),
+				'fm_ic_sieve_server' => array('type' => 'varchar','precision' => '128'),
+				'fm_ic_sieve_port' => array('type' => 'int','precision' => '4')
+			),
+			'pk' => array('fm_id'),
+			'fk' => array(),
+			'ix' => array('fm_owner'),
+			'uc' => array()
+		),
+		'egw_felamimail_signatures' => array(
+			'fd' => array(
+				'fm_signatureid' => array('type' => 'auto'),
+				'fm_accountid' => array('type' => 'int','precision' => '11'),
+				'fm_signature' => array('type' => 'text'),
+				'fm_description' => array('type' => 'varchar','precision' => '255'),
+				'fm_defaultsignature' => array('type' => 'bool')
+			),
+			'pk' => array('fm_signatureid'),
+			'fk' => array(),
+			'ix' => array(),
+			'uc' => array(array('fm_signatureid','fm_accountid'))
 		)
 	);
 ?>
