@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: tables_update.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: tables_update.inc.php 23741 2007-04-30 10:29:44Z lkneschke $ */
 
 	$test[] = '0.8.2';
 	function felamimail_upgrade0_8_2()
@@ -252,4 +252,177 @@
 	}
 	
 	// next version should be 1.2.001
+
+
+	$test[] = '1.2';
+	function felamimail_upgrade1_2()
+	{
+		$GLOBALS['egw_setup']->oProc->CreateTable('fm_accounts',array(
+			'fd' => array(
+				'fm_owner' => array('type' => 'int','precision' => '4','nullable' => False),
+				'fm_id' => array('type' => 'auto'),
+				'fm_realname' => array('type' => 'varchar','precision' => '128'),
+				'fm_organization' => array('type' => 'varchar','precision' => '128'),
+				'fm_emailaddress' => array('type' => 'varchar','precision' => '128','nullable' => False),
+				'fm_ic_hostname' => array('type' => 'varchar','precision' => '128','nullable' => False),
+				'fm_ic_port' => array('type' => 'int','precision' => '4','nullable' => False),
+				'fm_ic_username' => array('type' => 'varchar','precision' => '128','nullable' => False),
+				'fm_ic_password' => array('type' => 'varchar','precision' => '128'),
+				'fm_ic_encryption' => array('type' => 'bool','nullable' => False),
+				'fm_og_hostname' => array('type' => 'varchar','precision' => '128','nullable' => False),
+				'fm_og_port' => array('type' => 'int','precision' => '4','nullable' => False),
+				'fm_og_smtpauth' => array('type' => 'bool','nullable' => False),
+				'fm_og_username' => array('type' => 'varchar','precision' => '128'),
+				'fm_og_password' => array('type' => 'varchar','precision' => '128')
+			),
+			'pk' => array('fm_id'),
+			'fk' => array(),
+			'ix' => array('fm_owner'),
+			'uc' => array()
+		));
+
+		return $GLOBALS['setup_info']['felamimail']['currentver'] = '1.2.001';
+	}
+
+
+	$test[] = '1.2.001';
+	function felamimail_upgrade1_2_001()
+	{
+		$GLOBALS['egw_setup']->oProc->AddColumn('fm_accounts','fm_active',array(
+			'type' => 'bool',
+			'nullable' => False
+		));
+
+		return $GLOBALS['setup_info']['felamimail']['currentver'] = '1.2.002';
+	}
+
+
+	$test[] = '1.2.002';
+	function felamimail_upgrade1_2_002()
+	{
+		$GLOBALS['egw_setup']->oProc->AddColumn('fm_accounts','fm_validatecertificate',array(
+			'type' => 'bool',
+			'nullable' => False
+		));
+
+		return $GLOBALS['setup_info']['felamimail']['currentver'] = '1.2.003';
+	}
+
+	$test[] = '1.2.003';
+	function felamimail_upgrade1_2_003()
+	{
+		$GLOBALS['egw_setup']->oProc->RenameColumn('fm_accounts','fm_validatecertificate','fm_ic_validatecertificate');
+
+		return $GLOBALS['setup_info']['felamimail']['currentver'] = '1.2.004';
+	}
+
+	$test[] = '1.2.004';
+	function felamimail_upgrade1_2_004()
+	{
+		$GLOBALS['egw_setup']->oProc->query('delete from egw_felamimail_folderstatus',__LINE__,__FILE__);
+
+		return $GLOBALS['setup_info']['felamimail']['currentver'] = '1.3.000';
+	}
+
+	$test[] = '1.3.000';
+	function felamimail_upgrade1_3_000()
+	{
+		$GLOBALS['egw_setup']->oProc->AlterColumn('egw_felamimail_cache','fmail_sender_name',array(
+			'type' => 'varchar',
+			'precision' => '256'
+		));
+		$GLOBALS['egw_setup']->oProc->AlterColumn('egw_felamimail_cache','fmail_sender_address',array(
+			'type' => 'varchar',
+			'precision' => '256'
+		));
+		$GLOBALS['egw_setup']->oProc->AlterColumn('egw_felamimail_cache','fmail_to_name',array(
+			'type' => 'varchar',
+			'precision' => '256'
+		));
+		$GLOBALS['egw_setup']->oProc->AlterColumn('egw_felamimail_cache','fmail_to_address',array(
+			'type' => 'varchar',
+			'precision' => '256'
+		));
+
+		return $GLOBALS['setup_info']['felamimail']['currentver'] = '1.3.001';
+	}
+
+	$test[] = '1.3.001';
+	function felamimail_upgrade1_3_001()
+	{
+		$GLOBALS['egw_setup']->oProc->RenameTable('fm_accounts','egw_felamimail_accounts');
+
+		return $GLOBALS['setup_info']['felamimail']['currentver'] = '1.3.002';
+	}
+
+
+	$test[] = '1.3.002';
+	function felamimail_upgrade1_3_002()
+	{
+		$GLOBALS['egw_setup']->oProc->CreateTable('egw_felamimail_signatures',array(
+			'fd' => array(
+				'fm_signatureid' => array('type' => 'auto'),
+				'fm_accountid' => array('type' => 'int','precision' => '11'),
+				'fm_signature' => array('type' => 'text'),
+				'fm_description' => array('type' => 'varchar','precision' => '255')
+			),
+			'pk' => array('fm_signatureid'),
+			'fk' => array(),
+			'ix' => array(),
+			'uc' => array(array('fm_signatureid','fm_accountid'))
+		));
+
+		return $GLOBALS['setup_info']['felamimail']['currentver'] = '1.3.003';
+	}
+
+
+	$test[] = '1.3.003';
+	function felamimail_upgrade1_3_003()
+	{
+		$GLOBALS['egw_setup']->oProc->AlterColumn('egw_felamimail_accounts','fm_ic_encryption',array(
+			'type' => 'int',
+			'precision' => '4',
+			'nullable' => False
+		));
+
+		return $GLOBALS['setup_info']['felamimail']['currentver'] = '1.3.004';
+	}
+
+
+	$test[] = '1.3.004';
+	function felamimail_upgrade1_3_004()
+	{
+		$GLOBALS['egw_setup']->oProc->AddColumn('egw_felamimail_signatures','fm_defaultsignature',array(
+			'type' => 'bool'
+		));
+
+		return $GLOBALS['setup_info']['felamimail']['currentver'] = '1.3.005';
+	}
+
+
+	$test[] = '1.3.005';
+	function felamimail_upgrade1_3_005()
+	{
+		$GLOBALS['egw_setup']->oProc->AddColumn('egw_felamimail_accounts','fm_ic_enable_sieve',array(
+			'type' => 'bool',
+			'precision' => '255'
+		));
+		$GLOBALS['egw_setup']->oProc->AddColumn('egw_felamimail_accounts','fm_ic_sieve_server',array(
+			'type' => 'varchar',
+			'precision' => '128'
+		));
+		$GLOBALS['egw_setup']->oProc->AddColumn('egw_felamimail_accounts','fm_ic_sieve_port',array(
+			'type' => 'int',
+			'precision' => '4'
+		));
+
+		return $GLOBALS['setup_info']['felamimail']['currentver'] = '1.3.006';
+	}
+
+
+	$test[] = '1.3.006';
+	function felamimail_upgrade1_3_006()
+	{
+		return $GLOBALS['setup_info']['felamimail']['currentver'] = '1.4';
+	}
 ?>
