@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.uifilemanager.inc.php 22445 2006-09-16 22:12:24Z omgs $ */
+	/* $Id: class.uifilemanager.inc.php 24009 2007-06-04 06:43:09Z ralfbecker $ */
 
 	class uifilemanager
 	{
@@ -30,6 +30,7 @@
 		var $lesspath;
 		var $readable_groups;
 		var $files_array;
+		var $dirs_options;
 		var $numoffiles;
 		var $dispsep;
 
@@ -84,7 +85,7 @@
 		{
 			//			error_reporting(8);
 			$GLOBALS['egw']->browser =& CreateObject('phpgwapi.browser');
-			
+
 			$this->dateformat=$GLOBALS['egw_info']['user']['preferences']['common']['dateformat'];
 
 			$this->now = date('Y-m-d');
@@ -638,7 +639,8 @@
 					}
 
 					# Checkboxes
-					if(!$this->rename_x && !$this->edit_comments_x && $this->path != $this->bo->fakebase && $this->path != '/')
+					//if(!$this->rename_x && !$this->edit_comments_x && $this->path != $this->bo->fakebase && $this->path != '/')
+					if(!$this->rename_x && !$this->edit_comments_x && $this->path != '/')
 					{
 						$cbox='<input type="checkbox" name="fileman['.$i.']" value="'.$files['name'].'">';
 						$this->t->set_var('actions',$cbox);
@@ -708,13 +710,14 @@
 					# File size
 					if($this->prefs['size'])
 					{
-						$tmp_arr=array(
-							'string'	=> $files['directory'] . '/' . $files['name'],
-							'relatives'	=> array(RELATIVE_NONE)
-						);
-						if($files['mime_type'] != 'Directory') $tmp_arr['checksubdirs'] = false;
-
-						$size = $this->bo->vfs->get_size($tmp_arr);
+						// KL to fetch the size of the object here is just WRONG, since the array may be already sorted by size
+						//$tmp_arr=array(
+						//	'string'	=> $files['directory'] . '/' . $files['name'],
+						//	'relatives'	=> array(RELATIVE_NONE)
+						//;
+						//if($files['mime_type'] != 'Directory') $tmp_arr['checksubdirs'] = false;
+						//$size = $this->bo->vfs->get_size($tmp_arr);
+						$size = $files['size'];
 
 						$col_data=$this->bo->borkb($size);
 
@@ -749,7 +752,9 @@
 					# Owner name
 					if($this->prefs['owner'])
 					{
-						$this->t->set_var('col_data',$GLOBALS['egw']->accounts->id2name($files['owner_id']));
+						// KL to fetch the name of the object here is just WRONG, since the array may be already sorted by id
+						//$this->t->set_var('col_data',$GLOBALS['egw']->accounts->id2name($files['owner_id']));
+						$this->t->set_var('col_data',$files['owner_name']);
 						$this->t->parse('columns','column',True);
 					}
 
@@ -759,7 +764,9 @@
 						$this->html_table_col_begin();
 						if($files['createdby_id'])
 						{
-							$col_data=$GLOBALS['egw']->accounts->id2name($files['createdby_id']);
+							// KL to fetch the name of the object here is just WRONG, since the array may be already sorted by id
+							//$col_data=$GLOBALS['egw']->accounts->id2name($files['createdby_id']);
+							$col_data=$files['createdby_name'];
 						}
 						else $col_data='';
 
@@ -772,7 +779,9 @@
 					{
 						if($files['modifiedby_id'])
 						{
-							$col_data=$GLOBALS['egw']->accounts->id2name($files['modifiedby_id']);
+							// KL to fetch the name of the object here is just WRONG, since the array may be already sorted by id
+							//$col_data=$GLOBALS['egw']->accounts->id2name($files['modifiedby_id']);
+							$col_data=$files['modifiedby_name'];
 						}
 						else $col_data='';
 						$this->t->set_var('col_data',$col_data);
@@ -882,20 +891,11 @@
 				{
 					$this->bo->vfs->mkdir(array('string' => $this->bo->homedir, 'relatives' => array(RELATIVE_NONE)));
 				}
-
-				$ls_array = $this->bo->vfs->ls(array(
-					'string' => $this->bo->homedir,
-					'relatives' => array(RELATIVE_NONE),
-					'checksubdirs' => False,
-					'nofiles' => True
-				));
-				$this->files_array[] = $ls_array[0];
-				$this->numoffiles++;
-
 				reset($this->readable_groups);
+				// create the directorys of the readableGroups if they do not exist
 				while(list($num, $group_array) = each($this->readable_groups))
 				{
-					# If the group doesn't have access to this app, we don't show it
+					# If the group doesn't have access to this app, we don't show it, and do not appkly any action here
 					if(!$this->groups_applications[$group_array['account_name']][$this->bo->appname]['enabled'])
 					{
 						continue;
@@ -908,52 +908,124 @@
 							'string' => $this->bo->fakebase.'/'.$group_array['account_name'],
 							'relatives' => array(RELATIVE_NONE)
 						));
-
 						// FIXME we just created a fresh group dir so we know there nothing in it so we have to remove all existing content
-
 						$this->bo->vfs->override_acl = 0;
-
 						$this->bo->vfs->set_attributes(array('string' => $this->bo->fakebase.'/'.$group_array['account_name'],'relatives'	=> array(RELATIVE_NONE),'attributes' => array('owner_id' => $group_array['account_id'],'createdby_id' => $group_array['account_id'])));
 					}
-
-					$ls_array = $this->bo->vfs->ls(array('string' => $this->bo->fakebase.'/'.$group_array['account_name'],'relatives'	=> array(RELATIVE_NONE),'checksubdirs' => False,'nofiles' => True));
-
-					$this->files_array[] = $ls_array[0];
-
-					$this->numoffiles++;
 				}
 			}
-			else
-			{
-				$ls_array = $this->bo->vfs->ls(array(
-					'string' => $this->path,
-					'relatives'	=> array(RELATIVE_NONE),
-					'checksubdirs' => False,
-					'nofiles'	=> False,
-					'orderby'	=> $this->sortby
-				));
 
-				if($phpwh_debug)
-				{
-					echo '# of files found in "'.$this->path.'" : '.count($ls_array).'<br>'."\n";
-				}
-
-				while(list($num, $file_array) = each($ls_array))
-				{
-					$this->numoffiles++;
-					$this->files_array[] = $file_array;
-					if($phpwh_debug)
+            // read the list of the existing directorys/files
+            $ls_array = $this->bo->vfs->ls(array(
+                'string' => $this->path,
+                'relatives' => array(RELATIVE_NONE),
+                'checksubdirs' => false,
+                'nofiles'   => false,
+                'orderby'   => $this->sortby
+            ));
+            $heimatverz=explode('/',$this->bo->homedir);
+            // process the list: check if we are allowed to read it, get the real size, and count the files/dirs
+            while(list($num, $file_array) = each($ls_array))
+            {
+                if($this->path == $this->bo->fakebase)
+                {
+					if ($file_array['name'] && (array_key_exists($file_array['name'],$this->readable_groups) || $this->bo->fakebase.'/'.$file_array['name']  == $this->bo->homedir || $file_array['name'] == $heimatverz[2]))
 					{
-						echo 'Filename: '.$file_array['name'].'<br>'."\n";
+						if(!$this->groups_applications[$file_array['name']][$this->bo->appname]['enabled'] && $this->bo->fakebase.'/'.$file_array['name']  != $this->bo->homedir && $file_array['name'] != $heimatverz[2])
+						{
+							continue;
+						}
 					}
+                    if ($file_array['name'] && !array_key_exists($file_array['name'],$this->readable_groups) && !($this->bo->fakebase.'/'.$file_array['name']  == $this->bo->homedir || $file_array['name'] == $heimatverz[2]))
+                    {
+                        continue;
+                    }
 				}
-			}
+				// get additional info, which was not retrieved meeting our needs -> size, ids
+                if($this->prefs['size'])
+                {
+                    //KL get the real size of the object
+                    $tmp_arr=array(
+                        'string'    => $file_array['directory'] . '/' . $file_array['name'],
+                        'relatives' => array(RELATIVE_NONE)
+                    );
+                    if($file_array['mime_type'] != 'Directory') $tmp_arr['checksubdirs'] = false;
+                    $file_array['size']=$this->bo->vfs->get_size($tmp_arr);
+                    // KL got the real size
+                }
+                if($this->prefs['owner'])
+                {
+                    $file_array['owner_name']=$GLOBALS['egw']->accounts->id2name($file_array['owner_id']);
+                }
 
-			if(!is_array($this->files_array))
+                # Creator name
+                if($this->prefs['createdby_id'])
+                {
+                    if($file_array['createdby_id'])
+                    {
+                        //$col_data=$GLOBALS['egw']->accounts->id2name($files['createdby_lid']);
+                        $file_array['createdby_name']=$GLOBALS['egw']->accounts->id2name($file_array['createdby_id']);
+                    }
+                    else
+                    {
+                        $file_array['createdby_name']='';
+                    }
+                }
+
+                # Modified by name
+                if($this->prefs['modifiedby_id'])
+                {
+                    if($file_array['modifiedby_id'])
+                    {
+                        $file_array['modifiedby_name']=$GLOBALS['egw']->accounts->id2name($file_array['modifiedby_id']);
+                    }
+                    else
+                    {
+                        $file_array['modifiedby_name']='';
+                    }
+                }
+				// got additional info
+                $this->numoffiles++;
+                $this->files_array[] = $file_array;
+                if($phpwh_debug)
+                {
+                    echo 'Filename: '.$file_array['name'].'<br>'."\n";
+                }
+            }
+
+
+			if( !is_array($this->files_array) )
 			{
 				$this->files_array = array();
 			}
-			// end file count
+			else
+			{
+				// KL sorting by multisort, if sort-param is set.
+				if ($this->sortby)
+				{
+					$mysorting=$this->sortby;
+					if ($mysorting=='owner')
+					{
+						$mysorting='owner_name';
+					}
+					elseif ($mysorting=='createdby_id')
+					{
+						$mysorting='createdby_name';
+					}
+					elseif($mysorting=='modifiedby_id')
+					{
+						$mysorting='modifiedby_name';
+					}
+					foreach ($this->files_array as $key => $row) {
+					   $file[$key]  = $row[$mysorting];
+					}
+
+					// cast and sort file as container of the sort-key-column ascending to sort
+					//  $files_array (as last Param), by the common key
+					array_multisort(array_map('strtolower',$file), SORT_ASC,  $this->files_array);
+				}
+				// KL sorting done
+			}
 		}
 
 		function toolbar($type)
@@ -992,8 +1064,8 @@
 					//$toolbar.='<input id="fmInputLocation" type="text" size="20" disabled="disabled" name="location" value="'.$this->disppath.'"/>&nbsp;';
 					$current_option='<option>'.$this->disppath.'</option>';
 					// selectbox for change/move/and copy to
-					$dirs_options=$this->all_other_directories_options();
-					$toolbar.='<select name="cdtodir" onChange="document.formfm.changedir.value=\'true\';document.formfm.submit()">'.$current_option.$dirs_options.'</select>
+					$this->dirs_options=$this->all_other_directories_options();
+					$toolbar.='<select name="cdtodir" onChange="document.formfm.changedir.value=\'true\';document.formfm.submit()">'.$current_option.$this->dirs_options.'</select>
 					<input type="hidden" name="changedir" value="false"></td>
 					';
 					$toolbar.=$this->inputImage('goto','goto',lang('Quick jump to'));
@@ -1046,6 +1118,19 @@
 						}
 						$toolbar.='<td><img alt="spacer" src="'.$GLOBALS['egw']->common->image('filemanager','spacer').'" height="27" width="1"></td>';
 					}
+					else
+					{
+						if ($this->path = $this->bo->fakebase)
+						{
+							$toolbar.='<td><img alt="spacer" src="'.$GLOBALS['egw']->common->image('phpgwapi','buttonseparator').'" height="27" width="8"></td>';
+							$toolbar.='
+							<td><img alt="spacer" src="'.$GLOBALS['egw']->common->image('filemanager','spacer').'" height="27" width="1"></td>';
+							if(!$this->rename_x)
+							{
+								$toolbar.=$this->inputImage('edit_comments','edit_comments',lang('Edit comments'));
+							}
+						}
+					}
 
 					//	$toolbar.='</tr></table>';
 					if(!$this->rename_x && !$this->edit_comments_x)
@@ -1056,8 +1141,8 @@
 							$toolbar3.='<td><img alt="spacer" src="'.$GLOBALS['egw']->common->image('phpgwapi','buttonseparator').'" height="27" width="8"></td>';
 							$toolbar3.='<td><img alt="spacer" src="'.$GLOBALS['egw']->common->image('filemanager','spacer').'" height="27" width="1"></td>';
 
-							$dirs_options=$this->all_other_directories_options();
-							$toolbar3.='<td><select name="todir">'.$dirs_options.'</select></td>';
+							if(!($this->dirs_options)) $this->dirs_options=$this->all_other_directories_options();
+							$toolbar3.='<td><select name="todir">'.$this->dirs_options.'</select></td>';
 
 							$toolbar3.=$this->inputImage('copy_to','copy_to',lang('Copy to'));
 							$toolbar3.=$this->inputImage('move_to','move_to',lang('Move to'));
@@ -1345,7 +1430,7 @@
 				}
 
 				/* TODO is this right or should it be a single $ ? */
-				if($$this->newfile_or_dir[strlen($this->newfile_or_dir)-1] == ' ' || $this->newfile_or_dir[0] == ' ')
+				if($this->newfile_or_dir[strlen($this->newfile_or_dir)-1] == ' ' || $this->newfile_or_dir[0] == ' ')
 				{
 					$this->messages[]= $GLOBALS['egw']->common->error_list(array(lang('Cannot create directory because it begins or ends in a space')));
 				}
@@ -1688,6 +1773,7 @@
 		{
 			if($this->file) //FIXME
 			{
+				$mime_type='unknown';
 				$ls_array = $this->bo->vfs->ls(array(
 					'string'	=> $this->path.'/'.$this->file,//FIXME
 					'relatives'	=> array(RELATIVE_ALL),
@@ -1699,19 +1785,29 @@
 				{
 					$mime_type = $ls_array[0]['mime_type'];
 				}
-				elseif($this->prefs['viewtextplain'])
+                else
+                {
+					$parts = explode('.',$this->file);
+					$_ext = array_pop($parts);
+					$mime_type = ExecMethod('phpgwapi.mime_magic.ext2mime',$_ext);
+                }
+				// check if the prefs are set for viewing unknown extensions as text/plain and
+				// check if the mime_type is unknown, empty or not found (application/octet)
+				// or check if the mimetype contains text, 
+				// THEN set the mime_type text/plain
+				if(($this->prefs['viewtextplain'] && ($mime_type=='' or $mime_type=='unknown' or $mime_type=='application/octet-stream')) or strpos($mime_type, 'text/')!==false)
 				{
+				
 					$mime_type = 'text/plain';
 				}
-				else
-				{
-					list($_first,$_ext) = split("\.",$this->file);
-					$mime_type = ExecMethod('phpgwapi.mime_magic.ext2mime',$_ext);
-				}
-				$viewable = array('','text/plain','text/csv','text/html','text/text');
-
+				
+				// we want to define pdfs and text files as viewable
+				$viewable = array('','text/plain','text/csv','text/html','text/text','application/pdf');
+				// we want to view pdfs and text files within the browser
 				if(in_array($mime_type,$viewable) && !$_GET['download'])
 				{
+					// if you add attachment; to the Content-disposition between disposition and filename
+					// you get a download dialog even for viewable files 
 					header('Content-type: ' . $mime_type);
 					header('Content-disposition: filename="' . $this->file . '"');//FIXME
 					Header("Pragma: public");
@@ -1746,77 +1842,92 @@
 		}
 
 		//give back an array with all directories except current and dirs that are not accessable
-		function all_other_directories_options()
-		{
-			# First we get the directories in their home directory
-			$dirs = array();
-			$dirs[] = array('directory' => $this->bo->fakebase, 'name' => $this->bo->userinfo['account_lid']);
+                function all_other_directories_options()
+                {
+                        # First we get the directories in their home directory
+                        $dirs = array();
+                        $dirs[] = array('directory' => $this->bo->fakebase, 'name' => $this->bo->userinfo['account_lid']);
 
-			$tmp_arr=array(
-				'string'	=> $this->bo->homedir,
-				'relatives'	=> array(RELATIVE_NONE),
-				'checksubdirs'	=> True,
-				'mime_type'	=> 'Directory'
-			);
+                        $tmp_arr=array(
+                                'string'        => $this->bo->homedir,
+                                'relatives'     => array(RELATIVE_NONE),
+                                'checksubdirs'  => True,
+                                'mime_type'     => 'Directory'
+                        );
 
-			$ls_array = $this->bo->vfs->ls($tmp_arr);
+                        $ls_array = $this->bo->vfs->ls($tmp_arr);
 
-			while(list($num, $dir) = each($ls_array))
-			{
-				$dirs[] = $dir;
-			}
+                        while(list($num, $dir) = each($ls_array))
+                        {
+                                $dirs[] = $dir;
+                        }
 
 
-			# Then we get the directories in their readable groups' home directories
-			reset($this->readable_groups);
-			while(list($num, $group_array) = each($this->readable_groups))
-			{
-				# Don't list directories for groups that don't have access
-				if(!$this->groups_applications[$group_array['account_name']][$this->bo->appname]['enabled'])
-				{
-					continue;
-				}
+                        # Then we get the directories in their readable groups' home directories
+                        reset($this->readable_groups);
+                        while(list($num, $group_array) = each($this->readable_groups))
+                        {
+                                # Don't list directories for groups that don't have access
+                                if(!$this->groups_applications[$group_array['account_name']][$this->bo->appname]['enabled'])
+                                {
+                                        continue;
+                                }
 
-				$dirs[] = array('directory' => $this->bo->fakebase, 'name' => $group_array['account_name']);
+                                $dirs[] = array('directory' => $this->bo->fakebase, 'name' => $group_array['account_name']);
 
-				$tmp_arr=array(
-					'string'	=> $this->bo->fakebase.'/'.$group_array['account_name'],
-					'relatives'	=> array(RELATIVE_NONE),
-					'checksubdirs'	=> True,
-					'mime_type'	=> 'Directory'
-				);
+                                $tmp_arr=array(
+                                        'string'        => $this->bo->fakebase.'/'.$group_array['account_name'],
+                                        'relatives'     => array(RELATIVE_NONE),
+                                        'checksubdirs'  => True,
+                                        'mime_type'     => 'Directory'
+                                );
 
-				$ls_array = $this->bo->vfs->ls($tmp_arr);
-				while(list($num, $dir) = each($ls_array))
-				{
-					$dirs[] = $dir;
-				}
-			}
+                                $ls_array = $this->bo->vfs->ls($tmp_arr);
+                                while(list($num, $dir) = each($ls_array))
+                                {
+                                        $dirs[] = $dir;
+                                }
+                        }
 
-			reset($dirs);
-			while(list($num, $dir) = each($dirs))
-			{
-				if(!$dir['directory'])
-				{
-					continue;
-				}
+                        reset($dirs);
+			// key for the sorted array
+			$i=0;
 
-				# So we don't display //
-				if($dir['directory'] != '/')
-				{
-					$dir['directory'] .= '/';
-				}
+                        while(list($num, $dir) = each($dirs))
+                        {
+                                if(!$dir['directory'])
+                                {
+                                        continue;
+                                }
 
-				# No point in displaying the current directory, or a directory that doesn't exist
-				if((($dir['directory'] . $dir['name']) != $this->path) && $this->bo->vfs->file_exists(array('string' => $dir['directory'] . $dir['name'],'relatives' => array(RELATIVE_NONE))))
-				{
+                                # So we don't display //
+                                if($dir['directory'] != '/')
+                                {
+                                        $dir['directory'] .= '/';
+                                }
+
+                                # No point in displaying the current directory, or a directory that doesn't exist
+                                if((($dir['directory'] . $dir['name']) != $this->path) && $this->bo->vfs->file_exists(array('string' => $dir['directory'] . $dir['name'],'relatives' => array(RELATIVE_NONE))))
+                                {
+                                        //FIXME replace the html_form_option function
+                                        //$options .= $this->html_form_option($dir['directory'] . $dir['name'], $dir['directory'] . $dir['name']);
+					// set the content of the sorted array
+					$i++;
+					$dirs_sorted[$i]=$dir['directory'] . $dir['name'];
+                                }
+                        }
+			// sort the directory optionlist
+			natcasesort($dirs_sorted);
+
+			// set the optionlist
+			foreach ($dirs_sorted as $key => $row) {
 					//FIXME replace the html_form_option function
-					$options .= $this->html_form_option($dir['directory'] . $dir['name'], $dir['directory'] . $dir['name']);
-				}
+					//$options .= $this->html_form_option($dir['directory'] . $dir['name'], $dir['directory'] . $dir['name']);
+					$options .= $this->html_form_option($row, $row);
 			}
 
-			return $options;
-		}
+                        return $options;
+                }
 
 		/* seek icon for mimetype else return an unknown icon */
 		function mime_icon($mime_type, $size=16)
