@@ -9,11 +9,11 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: setup.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: setup.inc.php 23741 2007-04-30 10:29:44Z lkneschke $ */
 
 	$setup_info['filemanager']['name']    = 'filemanager';
 	$setup_info['filemanager']['title']   = 'Filemanager';
-	$setup_info['filemanager']['version'] = '1.2';
+	$setup_info['filemanager']['version'] = '1.4';
 	$setup_info['filemanager']['app_order'] = 6;
 	$setup_info['filemanager']['enable']  = 1;
 
@@ -28,6 +28,17 @@
 	/* Dependencies for this app to work */
 	$setup_info['filemanager']['depends'][] = array(
 		'appname' => 'phpgwapi',
-		'versions' => array('1.0.0','1.0.1','1.2')
+		'versions' => array('1.3','1.4','1.5')
+	);
+
+	// installation checks for filemanager
+	$setup_info['filemanager']['check_install'] = array(
+		'' => array(
+			'func' => 'pear_check',
+			'from' => 'Filemanager',
+		),
+		'HTTP_WebDAV_Server' => array(
+			'func' => 'pear_check',
+			'from' => 'Filemanager',
+		),
 	);
-?>
