@@ -1,16 +1,14 @@
 <?php
-  /**************************************************************************\
-  * eGroupWare - InfoLog: CSV - Import                                       *
-  * http://www.egroupware.org                                                *
-  * Written by Ralf Becker <RalfBecker@outdoor-training.de>                  *
-  * --------------------------------------------                             *
-  *  This program is free software; you can redistribute it and/or modify it *
-  *  under the terms of the GNU General Public License as published by the   *
-  *  Free Software Foundation; either version 2 of the License, or (at your  *
-  *  option) any later version.                                              *
-  \**************************************************************************/
-
-  /* $Id: csv_import.php 22409 2006-09-11 07:17:32Z ralfbecker $ */
+/**
+ * InfoLog - CSV import
+ *
+ * @link http://www.egroupware.org
+ * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @package infolog
+ * @copyright (c) 2003-6 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+ * @version $Id: csv_import.php 23926 2007-05-23 21:39:52Z lkneschke $
+ */
 
 	$GLOBALS['egw_info']['flags'] = array(
 		'currentapp' => 'infolog',
@@ -87,7 +85,7 @@ function addr_id( $n_family,$n_given=null,$org_name=null )
 	}
 	if (is_null($n_given) && is_null($org_name))	// just one name given, check against fn (= full name)
 	{
-		$addrs = $contacts->read( 0,0,array('id'),'',"fn=$n_family",'','fn' );
+		$addrs = $contacts->read( 0,0,array('id'),'',"n_fn=$n_family",'','n_fn' );
 	}
 	if (count($addrs))
 	{
