@@ -1,24 +1,17 @@
 <?php
-	/**************************************************************************\
-	* eGroupWare - InfoLog Admin-, Preferences- and SideboxMenu-Hooks          *
-	* http://www.eGroupWare.org                                                *
-	* Written and (c) by Ralf Becker <RalfBecker@outdoor-training.de>          *
-	* -------------------------------------------------------                  *
-	*  This program is free software; you can redistribute it and/or modify it *
-	*  under the terms of the GNU General Public License as published by the   *
-	*  Free Software Foundation; either version 2 of the License, or (at your  *
-	*  option) any later version.                                              *
-	\**************************************************************************/
-
-	/* $Id: class.admin_prefs_sidebox_hooks.inc.php 19865 2005-11-18 16:12:29Z ralfbecker $ */
+/**
+ * InfoLog - Admin-, Preferences- and SideboxMenu-Hooks
+ *
+ * @link http://www.egroupware.org
+ * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @package infolog
+ * @copyright (c) 2003-6 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+ * @version $Id: class.admin_prefs_sidebox_hooks.inc.php 24159 2007-06-21 18:49:57Z ralfbecker $
+ */
 
 /**
  * Class containing admin, preferences and sidebox-menus (used as hooks)
- *
- * @package infolog
- * @author Ralf Becker <RalfBecker@outdoor-training.de>
- * @copyright (c) by Ralf Becker <RalfBecker@outdoor-training.de>
- * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  */
 class admin_prefs_sidebox_hooks
 {
@@ -83,6 +76,28 @@ class admin_prefs_sidebox_hooks
 			}
 		}
 	}
+	
+	/**
+	 * Verification hook called if settings / preferences get stored
+	 * 
+	 * Installs a task to send async infolog notifications at 2h everyday
+	 *
+	 * @param array $data
+	 */
+	function verify_settings($data)
+	{
+		if ($data['prefs']['notify_due_delegated'] || $data['prefs']['notify_due_responsible'] ||
+			$data['prefs']['notify_start_delegated'] || $data['prefs']['notify_start_responsible'])
+		{
+			require_once(EGW_API_INC.'/class.asyncservice.inc.php');
+			
+			$async =& new asyncservice();
+			//$async->cancel_timer('infolog-async-notification');
+			
+			if (!$async->read('infolog-async-notification'))
+			{
+				$async->set_timer(array('hour' => 2),'infolog-async-notification','infolog.boinfolog.async_notification',null);
+			}
+		}
+	}
 }
-
-?>
