@@ -1,15 +1,15 @@
 <?php
-  /**************************************************************************\
-  * eGroupWare                                                               *
-  * http://www.egroupware.org                                                *
-  * --------------------------------------------                             *
-  *  This program is free software; you can redistribute it and/or modify it *
-  *  under the terms of the GNU General Public License as published by the   *
-  *  Free Software Foundation; either version 2 of the License, or (at your  *
-  *  option) any later version.                                              *
-  \**************************************************************************/
-
-  /* $Id: tables_current.inc.php 20601 2006-03-17 20:57:23Z ralfbecker $ */
+/**
+ * InfoLog - Setup
+ *
+ * @link http://www.egroupware.org
+ * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @package infolog
+ * @subpackage setup
+ * @copyright (c) 2003-6 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+ * @version $Id: tables_current.inc.php 23926 2007-05-23 21:39:52Z lkneschke $
+ */
 
 	$phpgw_baseline = array(
 		'egw_infolog' => array(
@@ -39,7 +39,8 @@
 				'info_price' => array('type' => 'float','precision' => '8'),
 				'info_percent' => array('type' => 'int','precision' => '2','default' => '0'),
 				'info_datecompleted' => array('type' => 'int','precision' => '8'),
-				'info_location' => array('type' => 'varchar','precision' => '255')
+				'info_location' => array('type' => 'varchar','precision' => '255'),
+				'info_custom_from' => array('type' => 'int','precision' => '1')
 			),
 			'pk' => array('info_id'),
 			'fk' => array(),
