@@ -1,15 +1,15 @@
 <?php
-  /**************************************************************************\
-  * eGroupWare - Setup                                                     *
-  * http://www.egroupware.org                                              *
-  * --------------------------------------------                             *
-  *  This program is free software; you can redistribute it and/or modify it *
-  *  under the terms of the GNU General Public License as published by the   *
-  *  Free Software Foundation; either version 2 of the License, or (at your  *
-  *  option) any later version.                                              *
-  \**************************************************************************/
-
-  /* $Id: tables_update.inc.php 22504 2006-09-26 04:54:53Z ralfbecker $ */
+/**
+ * InfoLog - Setup
+ *
+ * @link http://www.egroupware.org
+ * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @package infolog
+ * @subpackage setup
+ * @copyright (c) 2003-6 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+ * @version $Id: tables_update.inc.php 23926 2007-05-23 21:39:52Z lkneschke $
+ */
 
 	$test[] = '0.9.11';
 	function infolog_upgrade0_9_11()
@@ -556,3 +556,21 @@
 
 		return $GLOBALS['setup_info']['infolog']['currentver'] = '1.2.004';
 	}
+
+	$test[] = '1.2.004';
+	function infolog_upgrade1_2_004()
+	{
+		// column to save if from contains a custom text
+		$GLOBALS['egw_setup']->oProc->AddColumn('egw_infolog','info_custom_from',array(
+			'type' => 'int',
+			'precision' => '1',
+		));
+
+		return $GLOBALS['setup_info']['infolog']['currentver'] = '1.3.001';
+	}
+
+	$test[] = '1.3.001';
+	function infolog_upgrade1_3_001()
+	{
+		return $GLOBALS['setup_info']['infolog']['currentver'] = '1.4';
+	}
