@@ -11,7 +11,7 @@
 	* Free Software Foundation; version 2 of the License.                       *
 	\***************************************************************************/
 	
-	/* $Id: class.uimydms.inc.php 22772 2006-10-29 16:57:56Z lkneschke $ */
+	/* $Id: class.uimydms.inc.php 22794 2006-11-06 05:53:11Z lkneschke $ */
 
 	require_once(EGW_SERVER_ROOT.'/mydms/inc/inc.Settings.php');
 	require_once(EGW_SERVER_ROOT.'/mydms/inc/inc.DBAccess.php');
@@ -205,11 +205,15 @@
 			);
 			$xmlInitialLoadURL = $GLOBALS['egw']->link('/index.php',$linkData);
 				
-			if($selectedFolderID == 1)
+			if($selectedFolderID == 1) {
 				$folder_tree_new .= "tree.selectItem('$folderID',false);";
+			}
 
 			$folder_tree_new .= "tree.loadXML('$xmlInitialLoadURL');";
-			
+
+			if($selectedFolderID == 1) {
+				$folder_tree_new .= "tree.openItem('1');";
+			}
 
 			$folder_tree_new.= '</script>';
 
