@@ -9,7 +9,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: tables_update.inc.php 20143 2005-12-16 06:00:18Z lkneschke $ */
+  /* $Id: tables_update.inc.php 23741 2007-04-30 10:29:44Z lkneschke $ */
 
 	$test[] = '0.1.0.001';
 	function mydms_upgrade0_1_0_001()
@@ -17,4 +17,12 @@
 		$GLOBALS['setup_info']['mydms']['currentver'] = '1.2.000';
 		return $GLOBALS['setup_info']['mydms']['currentver'];
 	}
+
+
+	$test[] = '1.2.000';
+	function mydms_upgrade1_2_000()
+	{
+		$GLOBALS['setup_info']['mydms']['currentver'] = '1.4';
+		return $GLOBALS['setup_info']['mydms']['currentver'];
+	}
 ?>
