@@ -12,13 +12,20 @@
 	* http://www.goldenglair.com                                               *
 	\**************************************************************************/
 
-	/* $Id: hook_home.inc.php 19414 2005-10-14 13:57:59Z ralfbecker $ */
-
+	/* $Id: hook_home.inc.php 24110 2007-06-15 05:59:29Z nelius_weiss $ */
+	
 	$showevents = (int)$GLOBALS['egw_info']['user']['preferences']['news_admin']['homeShowLatest'];
 	if($showevents > 0)
 	{
+		$d1 = strtolower(substr(EGW_APP_INC,0,3));
+    		if($d1 == 'htt' || $d1 == 'ftp' ) {
+        	    echo 'Failed attempt to break in via an old Security Hole!<br>'."\n";
+        	    $GLOBALS['egw']->common->egw_exit();
+    		}
+        	unset($d1);
+
 		$GLOBALS['egw']->translation->add_app('news_admin');
-		$title = lang('News Admin');
+		$title = lang('News');
 		$portalbox =& CreateObject('phpgwapi.listbox',array(
 			'title'     => $title,
 			'primary'   => $GLOBALS['egw_info']['theme']['navbar_bg'],
@@ -39,31 +46,39 @@
 		$GLOBALS['portal_order'][] = $app_id;
 
 		$news =& CreateObject('news_admin.uinews');
-
-		$newslist = $news->bo->get_newslist('all',0,'','',$latestcount,True);
-
+		$newslist = $news->search("");
 		$image_path = $GLOBALS['egw']->common->get_image_path('news_admin');
 
+		$text = "<ul>";
 		if(is_array($newslist))
 		{
+			$newscount = 0;
 			foreach($newslist as $newsitem)
 			{
-				$text = $newsitem['subject'];
+				$newscount++;
+				if ( $newscount > $latestcount ) break;
+				$text .= "<li><b>" . '<a href="'.$GLOBALS['egw']->link('/index.php',array(
+					'menuaction' => 'news_admin.uinews.edit',
+					'news_id' => $newsitem['news_id'],
+				)).'" onclick="window.open(this.href,\'_blank\',\'dependent=yes,width=700,height=580,scrollbars=yes,status=yes\'); 
+				return false;">'.$newsitem['news_headline'].'</a></b>';
 				if($showevents == 1)
 				{
-					$text .= ' - ' . lang('Submitted by') . ' ' . $GLOBALS['egw']->common->grab_owner_name($newsitem['submittedby']) . ' ' . lang('on') . ' ' . $GLOBALS['egw']->common->show_date($newsitem['date']);
+					$text .= ' - ' . lang('Submitted by') . ' ' . $GLOBALS['egw']->common->grab_owner_name($newsitem['news_submittedby']) . ' ' . lang('on') . ' ' . $GLOBALS['egw']->common->show_date($newsitem['news_date']) . "</b>";
+					$text .= "<br />" . $newsitem['news_teaser'] . "</li><br />";
+				}
+				else
+				{
+    					$text .= "</li>";
 				}
-				$portalbox->data[] = array(
-					'text' => $text,
-					'link' => $GLOBALS['egw']->link('/index.php','menuaction=news_admin.uinews.read_news&news_id=' . $newsitem['id'])
-				);
 			}
-			unset($text);
 		}
 		else
 		{
-			$portalbox->data[] = array('text' => lang('no news'));
+			$text .= lang('no news');
 		}
+		
+		$text .= "</ul>";
 
 		$GLOBALS['portal_order'][] = $app_id;
 		$var = Array(
@@ -81,7 +96,7 @@
 
 		$tmp = "\r\n"
 			. '<!-- start News Admin -->' . "\r\n"
-			. $portalbox->draw()
+			. $portalbox->draw($text)
 			. '<!-- end News Admin -->'. "\r\n";
 		print $tmp;
 	}
