@@ -12,7 +12,7 @@
 	* http://www.goldenglair.com                                               *
 	\**************************************************************************/
 
-	/* $Id: hook_sidebox_menu.inc.php 22373 2006-08-30 06:37:38Z ralfbecker $ */
+	/* $Id: hook_sidebox_menu.inc.php 23480 2007-03-05 06:17:33Z lkneschke $ */
 {
 
  /*
@@ -27,8 +27,14 @@
 
 	$menu_title = $GLOBALS['egw_info']['apps'][$appname]['title'] . ' '. lang('Menu');
 	$file = Array(
-		'read news' => $GLOBALS['egw']->link('/news_admin/index.php'),
-		'Add New Article' => $GLOBALS['egw']->link('/index.php','menuaction=news_admin.uinews.add')
+		array(
+			'text' => '<a class="textSidebox" href="'.$GLOBALS['egw']->link('/index.php',array('menuaction' => 'news_admin.uinews.edit')).
+				'" onclick="window.open(this.href,\'_blank\',\'dependent=yes,width=700,height=580,scrollbars=yes,status=yes\'); 
+				return false;">'.lang('Add').'</a>',
+			'no_lang' => true,
+			'link' => false
+		),
+		'Read news' => $GLOBALS['egw']->link('/index.php',array('menuaction' => 'news_admin.uinews.index')),
 	);
 	display_sidebox($appname,$menu_title,$file);
 
@@ -42,11 +48,10 @@
 	{
 		$title = lang('Administration');
 		$file = Array(
-			'News Administration'  => $GLOBALS['egw']->link('/index.php','menuaction=news_admin.uinews.write_news'),
 			'Site Configuration' => $GLOBALS['egw']->link('/index.php','menuaction=admin.uiconfig.index&appname=' . $appname),
-			'global categories' => $GLOBALS['egw']->link('/index.php','menuaction=admin.uicategories.index&appname=' . $appname),
-			'configure access permissions' => $GLOBALS['egw']->link('/index.php','menuaction=news_admin.uiacl.acllist'),
-			'configure rss exports' => $GLOBALS['egw']->link('/index.php','menuaction=news_admin.uiexport.exportlist')
+			'Global categories' => $GLOBALS['egw']->link('/index.php','menuaction=admin.uicategories.index&appname=' . $appname),
+			'Configure access permissions' => $GLOBALS['egw']->link('/index.php','menuaction=news_admin.uiacl.acllist'),
+			'Configure RSS exports' => $GLOBALS['egw']->link('/index.php','menuaction=news_admin.uiexport.exportlist')
 		);
 
 		display_sidebox($appname,$title,$file);
