@@ -9,7 +9,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: notify.php 20295 2006-02-15 12:31:25Z  $ */
+  /* $Id: notify.php 22864 2006-11-22 23:06:05Z milosch $ */
 
 	$egw_info = array();
 	$GLOBALS['egw_info']['flags'] = array(
@@ -18,7 +18,7 @@
 		'disable_Template_class' => True,
 		'currentapp' => 'notifywindow'
 	);
-	include('header.inc.php');
+	include('./header.inc.php');
 	$charSet = $GLOBALS['egw']->translation->charset();
 ?>
 <html>
