@@ -13,15 +13,15 @@
 *  option) any later version.                                              *
 \**************************************************************************/
 
-	/* $Id: class.bokb.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: class.bokb.inc.php 24717 2007-11-27 17:23:40Z pbf $ */
 
 	/**
 	* Business logic layer of the Knowledge Base
 	* 
-	* Last Editor:	$Author: $
+	* Last Editor:	$Author: pbf $
 	* @author		Alejandro Pedraza
 	* @package		phpbrain
-	* @version		$Revision: 20295 $
+	* @version		$Revision: 24717 $
 	* @license		GPL
 	**/
 	class bokb
@@ -30,7 +30,7 @@
 		* Data manipulation object
 		*
 		* @access	private
-		* @var		object so
+		* @var		so
 		*/
 		var $so;
 
@@ -38,7 +38,7 @@
 		* Categories object
 		*
 		* @access	public
-		* @var		object categories
+		* @var		categories
 		*/
 		var $categories_obj;
 
@@ -280,7 +280,7 @@
 			if (!$this->admin_config['publish_questions']) $this->admin_config['publish_questions'] = 'True';
 			
 			$this->start			= get_var('start', 'any', 0);
-			$this->query			= urldecode(get_var('query', 'any', ''));
+			$GLOBALS['query'] = $this->query			= urldecode(get_var('query', 'any', ''));
 			$this->sort				= get_var('sort', 'any', '');
 			$this->order			= get_var('order', 'any', '');
 			$this->publish_filter	= get_var('publish_filter', 'any', 'all');
@@ -333,7 +333,7 @@
 		*/
 		function select_category($category_selected = '')
 		{
-			return $this->categories_obj->formated_list('select', 'all', $category_selected , True);
+			return $this->categories_obj->formatted_list('select', 'all', $category_selected , True);
 		}
 
 		/**
@@ -396,7 +396,7 @@
 		**/
 		function search_articles($category_id, $publish_filter = False, $permissions=0, $questions=False)
 		{
-			$search = $questions? 'unanswered_questions' : 'search_articles';
+			$search = $questions ? 'unanswered_questions' : 'search_articles';
 			if (!$permissions) $permissions = $this->read_right;
 
 			$owners = $this->accessible_owners($permissions);
@@ -1141,6 +1141,7 @@
 			if ($test[0]['name'])
 			{
 				// the file is in the server, proceed to rm it
+				$GLOBALS['phpgw']->vfs->override_acl = 1; // No acl set in upload (has edit rights)
 				$remove = $GLOBALS['phpgw']->vfs->rm(array(
 					'string'	=> '/kb/' . $file,
 					'relatives'	=> array(RELATIVE_NONE)
