@@ -13,15 +13,15 @@
 *  option) any later version.                                              *
 \**************************************************************************/
 
-	/* $Id: class.uikb.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: class.uikb.inc.php 24717 2007-11-27 17:23:40Z pbf $ */
 	
 	/**
 	* Presentation layer of the Knowledge Base
 	*
-	* Last Editor:	$Author: $
+	* Last Editor:	$Author: pbf $
 	* @author		Alejandro Pedraza
 	* @package		phpbrain
-	* @version		$Revision: 20295 $
+	* @version		$Revision: 24717 $
 	* @license		GPL
 	*/
 	class uikb
@@ -499,7 +499,7 @@
 				'lang_asc'			=> lang('Ascendent'),
 				'lang_search'		=> lang('search'),
 				'form_action'		=> $this->link('menuaction=phpbrain.uikb.index'),
-				'select_categories'	=> $this->bo->categories_obj->formated_list('select', 'all', '', True)
+				'select_categories'	=> $this->bo->categories_obj->formatted_list('select', 'all', '', True)
 			));
 			if ($this->sitemgr)
 			{
@@ -729,6 +729,7 @@
 				'lang_upload'			=> lang('upload'),
 				'lang_attach_file'		=> lang('Attach file'),
 				'lang_delete'			=> lang('delete'),
+				'lang_confirm_delete'   => lang('Are you sure?'),
 				'img_printer'			=> $GLOBALS['phpgw']->common->image('phpbrain', 'articleprint'),
 				'href_printer'			=> $this->link('menuaction=phpbrain.uikb.view_article&art_id='. $article_id .'&printer=1'),
 				'img_mail'				=> $GLOBALS['phpgw']->common->image('phpbrain', 'mail'),
@@ -1171,7 +1172,7 @@
 				'left'				=> $this->nextmatchs->left($this->link, $this->bo->start, $this->bo->num_rows, 'menuaction.phpbrain.uikb.pop_search&query=' . $this->bo->query),
 				'right'				=> $this->nextmatchs->right($this->link, $this->bo->start, $this->bo->num_rows, 'menuaction.phpbrain.uikb.pop_search&query=' . $this->bo->query),
 				'num_regs'			=> $this->nextmatchs->show_hits($this->bo->num_rows, $this->bo->start),
-				'select_categories'	=> $this->bo->categories_obj->formated_list('select', 'all', '', True)
+				'select_categories'	=> $this->bo->categories_obj->formatted_list('select', 'all', '', True)
 			));
 
 			foreach ($articles_list as $article)
@@ -1332,8 +1333,13 @@
 				$category_selected = $question['cat_id'];
 			}
 			
-			$html = CreateObject('phpgwapi.html');
-			$content = $html->htmlarea('exec[text]', $content);
+			if (!is_object($GLOBALS['egw']->html))
+			{
+				require_once(EGW_API_INC.'/class.html.inc.php');
+				$GLOBALS['egw']->html = new html;
+			}
+			
+			$content = $GLOBALS['egw']->html->fckEditor('exec[text]', $content, $GLOBALS['egw_info']['user']['preferences']['phpbrain']['rtfEditorFeatures'],array('toolbar_expanded' =>'true'),'400px','100%',$this->bo->admin_config['upload_dir'] ? $this->bo->admin_config['upload_dir'] : null);
 	
 			// Finally, fill the input fields
 			if (!$this->sitemgr)
@@ -1359,9 +1365,9 @@
 				'message'			=> "<tr><td colspan=2 align=center style='color:red'>" . $this->message . "</td></tr>",
 				'hidden_fields'		=> $hidden_fields,
 				'form_action'		=> $this->link('menuaction=phpbrain.uikb.edit_article'. $extra),
-				'value_title'		=> $title,
-				'value_topic'		=> $topic,
-				'value_keywords'	=> $keywords,
+				'value_title'		=> htmlspecialchars($title),
+				'value_topic'		=> htmlspecialchars($topic),
+				'value_keywords'	=> htmlspecialchars($keywords),
 				'value_text'		=> $content,
 				'btn_save'			=> $btn_save,
 				'btn_cancel'		=> $btn_cancel
@@ -1601,7 +1607,7 @@
 				'left'					=> $this->nextmatchs->left($this->link, $this->bo->start, $this->bo->num_rows, 'menuaction.phpbrain.uikb.maintain_articles&cat='. $actual_category . '&publish_filter=' . $this->bo->publish_filter . '&query=' . $this->bo->query),
 				'right'					=> $this->nextmatchs->right($this->link, $this->bo->start, $this->bo->num_rows, 'menuaction.phpbrain.uikb.maintain_articles&cat='. $actual_category .'&publish_filter=' . $this->bo->publish_filter . '&query=' . $this->bo->query),
 				'num_regs'				=> $this->nextmatchs->show_hits($this->bo->num_rows, $this->bo->start),
-				'select_categories'		=> $this->bo->categories_obj->formated_list('select', 'all', $actual_category, True),
+				'select_categories'		=> $this->bo->categories_obj->formatted_list('select', 'all', $actual_category, True),
 				'select_publish'		=> $select_publish,
 				'lang_publish_selected'	=> lang('Publish selected'),
 				'lang_delete_selected'	=> lang('Delete selected')
@@ -1803,7 +1809,7 @@
 				'left'					=> $this->nextmatchs->left($this->link, $this->bo->start, $this->bo->num_rows, 'menuaction.phpbrain.uikb.maintain_questions&cat='. $actual_category . '&publish_filter=' . $this->bo->publish_filter . '&query=' . $this->bo->query),
 				'right'					=> $this->nextmatchs->right($this->link, $this->bo->start, $this->bo->num_rows, 'menuaction.phpbrain.uikb.maintain_questions&cat='. $actual_category .'&publish_filter=' . $this->bo->publish_filter . '&query=' . $this->bo->query),
 				'num_regs'				=> $this->nextmatchs->show_hits($this->bo->num_rows, $this->bo->start),
-				'select_categories'		=> $this->bo->categories_obj->formated_list('select', 'all', $actual_category, True),
+				'select_categories'		=> $this->bo->categories_obj->formatted_list('select', 'all', $actual_category, True),
 				'lang_publish_selected'	=> lang('Publish selected'),
 				'lang_delete_selected'	=> lang('Delete selected')
 			));
