@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: setup.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: setup.inc.php 24352 2007-08-01 15:09:11Z jgordor $ */
 
 	/* Basic information about this app */
 	$setup_info['phpbrain']['name']      = 'phpbrain';
@@ -22,14 +22,13 @@
 	$setup_info['phpbrain']['note']   = 'Knowledge Base repository';
 	$setup_info['phpbrain']['license']  = 'GPL';
 	$setup_info['phpbrain']['description'] = 'Searchable Knowledge Base.';
-	$setup_info['phpbrain']['maintainer'] = 'Alejandro Pedraza';
-	$setup_info['phpbrain']['maintainer_email'] = 'alpeb@users.sourceforge.net';
 
 	/* The hooks this app includes, needed for hooks registration */
 	$setup_info['phpbrain']['hooks'][] = 'about';
 	$setup_info['phpbrain']['hooks'][] = 'admin';
 	$setup_info['phpbrain']['hooks'][] = 'add_def_pref';
 	$setup_info['phpbrain']['hooks'][] = 'config';
+	$setup_info['phpbrain']['hooks'][] = 'config_validate';
 	$setup_info['phpbrain']['hooks'][] = 'preferences';
 	$setup_info['phpbrain']['hooks'][] = 'settings';
 	$setup_info['phpbrain']['hooks'][] = 'sidebox_menu';
@@ -47,7 +46,7 @@
 	/* Dependencies for this app to work */
 	$setup_info['phpbrain']['depends'][] = array(
 		'appname' => 'phpgwapi',
-		'versions' => Array('1.0.0','1.0.1','1.2')
+		'versions' => Array('1.2','1.3','1.4','1.5')
 	);
 
 
