@@ -210,18 +210,27 @@ class ADODB2_postgres extends ADODB_DataDict {
 	{
 		if ($dropflds && !is_array($dropflds)) $dropflds = explode(',',$dropflds);
 		$copyflds = array();
-		foreach($this->MetaColumns($tabname) as $fld) {
+		foreach(($meta=$this->MetaColumns($tabname)) as $fld) {
 			if (!$dropflds || !in_array($fld->name,$dropflds)) {
 				// we need to explicit convert varchar to a number to be able to do an AlterColumn of a char column to a nummeric one
 				if (preg_match('/'.$fld->name.' (I|I2|I4|I8|N|F)/i',$tableflds,$matches) && 
 					in_array($fld->type,array('varchar','char','text','bytea'))) {
 					$copyflds[] = "to_number($fld->name,'S9999999999999D99')";
+				} elseif (preg_match('/'.$fld->name.' ([\w]+)/i',$tableflds,$matches) &&
+					strtoupper($fld->type) != ($type = $this->ActualType($matches[1]))) {
+					if ($type == 'BYTEA' && $fld->type == 'text') {
+						$copyflds[] = "DECODE($fld->name, 'escape')";
+					} elseif ($fld->type == 'bytea' && $type == 'TEXT') {
+						$copyflds[] = "ENCODE($fld->name, 'escape')";
+					} else {
+						$copyflds[] = "CAST($fld->name AS $type)";
+					}
 				} else {
 					$copyflds[] = $fld->name;
 				}
 				// identify the sequence name and the fld its on
 				if ($fld->primary_key && $fld->has_default && 
-					preg_match("/nextval\('([^']+)'::text\)/",$fld->default_value,$matches)) {
+					preg_match("/nextval\('([^']+)'::(text|regclass)\)/",$fld->default_value,$matches)) {
 					$seq_name = $matches[1];
 					$seq_fld = $fld->name;
 				}
@@ -286,7 +295,7 @@ class ADODB2_postgres extends ADODB_DataDict {
 		$seq = $this->connection->GetOne("SELECT relname FROM pg_class WHERE NOT relname ~ 'pg_.*' AND relname LIKE $tabname AND relkind='S'");
 
 		// check if a tables depends on the sequenz and it therefor cant and dont need to be droped separatly
-		if (!$seq || $this->connection->GetOne("SELECT relname FROM pg_class JOIN pg_depend ON pg_class.relfilenode=pg_depend.objid WHERE relname='$seq' AND relkind='S' AND deptype='i'")) {
+		if (!$seq || $this->connection->GetOne("SELECT relname FROM pg_class JOIN pg_depend ON pg_class.oid=pg_depend.objid WHERE relname='$seq' AND relkind='S' AND refclassid = (SELECT oid FROM pg_class WHERE relname = 'pg_class')")) {
 			return False;
 		}
 		return "DROP SEQUENCE ".$seq;
@@ -357,4 +366,4 @@ CREATE [ UNIQUE ] INDEX index_name ON table
 		return $sql;
 	}
 }
-?>
\ No newline at end of file
+?>
