@@ -12,7 +12,7 @@
   * any later version.                                                       *
   \**************************************************************************/
 
-  /* $Id: class.Template.inc.php 16349 2004-08-09 21:28:47Z reinerj $ */
+  /* $Id: class.Template.inc.php 23374 2007-02-01 15:36:39Z lkneschke $ */
 
 	class Template
 	{
@@ -401,7 +401,8 @@
 				{
 //					$new_root = str_replace($GLOBALS['phpgw_info']['server']['template_set'],'default',$root);
 //					$new_root = substr($root, 0, strrpos($root, $GLOBALS['phpgw_info']['server']['template_set'])).'default';
-					$new_root = substr($root, 0, strlen($root) - strlen($GLOBALS['phpgw_info']['server']['template_set'])) . 'default';
+//					$new_root = substr($root, 0, strlen($root) - strlen($GLOBALS['phpgw_info']['server']['template_set'])) . 'default';
+					$new_root = dirname($root) . DIRECTORY_SEPARATOR . 'default';
 					$new_filename = $this->filename(str_replace($root.'/','',$new_filename),$new_root,2);
 				}
 			}
