@@ -21,7 +21,7 @@
   * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
   \**************************************************************************/
 
-  /* $Id: class.acl.inc.php 20295 2006-02-15 12:31:25Z  $ */
+  /* $Id: class.acl.inc.php 23112 2006-12-25 11:02:54Z ralfbecker $ */
 
 	/**
 	 * Access Control List System
@@ -53,7 +53,9 @@
 		 */
 		var $data = Array();
 		/**
-		 * @var object/db $db internal copy of the db-object
+		 * internal copy of the db-object
+		 * 
+		 * @var egw_db
 		 */
 		var $db;
 		/**
@@ -151,19 +153,14 @@
 			{
 				$this->acl();
 			}
- 			$acl_acc_list = array_values((array)$this->get_location_list_for_id('phpgw_group', 1, $this->account_id)); 
- 			array_unshift($acl_acc_list,$this->account_id,0); 
+			$acl_acc_list = $GLOBALS['egw']->accounts->memberships($this->account_id,true);
+ 			@array_unshift($acl_acc_list,$this->account_id); 
 			$this->db->select($this->table_name,'*',array('acl_account' => $acl_acc_list ),__LINE__,__FILE__); 
  
 			$this->data = Array();
-			while(($row = $this->db->row(true)))
+			while(($row = $this->db->row(true,'acl_')))
 			{
-				$this->data[] = array(
-					'appname'  => $row['acl_appname'],
-					'location' => $row['acl_location'], 
-					'account'  => $row['acl_account'], 
-					'rights'   => $row['acl_rights'],
-				);
+				$this->data[$row['appname'].'-'.$row['location'].'-'.$row['account']] = $row;
 			}
 			return $this->data;
 		}
@@ -196,12 +193,13 @@
 		{
 			if (!$appname) $appname = $GLOBALS['egw_info']['flags']['currentapp'];
 
-			$this->data[] = array(
+			$row = array(
 				'appname'  => $appname, 
 				'location' => $location, 
 				'account'  => (int) $this->account_id, 
 				'rights'   => (int) $rights
 			);
+			$this->data[$row['appname'].'-'.$row['location'].'-'.$row['account']] = $row;
 
 			return $this->data;
 		}
@@ -210,7 +208,7 @@
 		 * Delete ACL record in the repository of the class
 		 *
 		 * @param string $appname appname or '' for $GLOBALS['egw_info']['flags']['currentapp']
-		 * @param string $location location
+		 * @param string/boolean $location location or false for all locations
 		 * @return array all ACL records from $this->data.
 		 */
 		function delete($appname,$location)
@@ -219,7 +217,9 @@
 
 			foreach($this->data as $idx => $value)
 			{
-				if ($this->data[$idx]['appname'] == $appname && $this->data[$idx]['location'] == $location && $this->data[$idx]['account'] == $this->account_id)
+				if ($value['appname'] == $appname && 
+					($location === false || $value['location'] == $location) && 
+					$value['account'] == $this->account_id)
 				{
 					unset($this->data[$idx]);
 				}
@@ -696,10 +696,11 @@
 		/**
 		 * Read the grants other users gave $this->account_id for $app, group ACL is taken into account
 		 *
-		 * @param string $app optional defaults to $GLOBALS['egw_info']['flags']['currentapp'];
+		 * @param string $app optional defaults to $GLOBALS['egw_info']['flags']['currentapp']
+		 * @param boolean $enum_group_acls=true should group acls be returned for all members of that group, default yes
 		 * @return array with account-ids (of owners) and granted rights as values
 		 */
-		function get_grants($app='')
+		function get_grants($app='',$enum_group_acls=true)
 		{
 			if (!$app) $app = $GLOBALS['egw_info']['flags']['currentapp'];
 
@@ -709,7 +710,7 @@
 				$memberships[] = $group['account_id'];
 			}
 			$db2 = clone($this->db);
-			$db2->select($this->table_name,array('acl_account','acl_rights'),array(
+			$db2->select($this->table_name,array('acl_account','acl_rights','acl_location'),array(
 				'acl_appname'  => $app,
 				'acl_location' => $memberships,
 			),__LINE__,__FILE__);
@@ -717,50 +718,41 @@
 			$grants = $accounts = Array();
 			while ($db2->next_record())
 			{
-				$grantor = $db2->f('acl_account');
-				$rights = $db2->f('acl_rights');
+				$grantor    = $db2->f('acl_account');
+				$rights     = $db2->f('acl_rights');
+				$granted_to = (int) $db2->f('acl_location');
+				
+				if(!isset($grants[$grantor]))
+				{
+					$grants[$grantor] = 0;
+				}
+				$grants[$grantor] |= $rights;
+				
+				// if the right is granted from a group and we enummerated group ACL's
+				if ($GLOBALS['egw']->accounts->get_type($grantor) == 'g' && $enum_group_acls)
+				{
+					// return the grant for each member of the group
+					foreach((array)$GLOBALS['egw']->accounts->member($grantor) as $member)
+					{
+						if (!$member) continue;	// can happen if group has no members
 
-				if(!isset($accounts[$grantor]))
-				// cache the group-members for performance
-				{
-					// if $grantor is a group, get its members
-					$members = $this->get_ids_for_location($grantor,1,'phpgw_group');
-					if(!$members)
-					{
-						$accounts[$grantor] = Array($grantor);
-						$is_group[$grantor] = False;
+						// Don't allow to override private with group ACL's!
+						$rights &= ~EGW_ACL_PRIVATE;
+
+						$grantor = $member['account_id'];
+
+						if(!isset($grants[$grantor]))
+						{
+							$grants[$grantor] = 0;
+						}
+						$grants[$grantor] |= $rights;
 					}
-					else
-					{
-						$accounts[$grantor] = $members;
-						$is_group[$grantor] = True;
-					}
-				}
-				if(@$is_group[$grantor])
-				{
-					// Don't allow to override private!
-					$rights &= (~ EGW_ACL_PRIVATE);
-					if(!isset($grants[$grantor]))
-					{
-						$grants[$grantor] = 0;
-					}
-					$grants[$grantor] |= $rights;
-					if(!!($rights & EGW_ACL_READ))
-					{
-						$grants[$grantor] |= EGW_ACL_READ;
-					}
-				}
-				foreach($accounts[$grantor] as $grantors)
-				{
-					if(!isset($grants[$grantors]))
-					{
-						$grants[$grantors] = 0;
-					}
-					$grants[$grantors] |= $rights;
 				}
 			}
+			// user has implizit all rights on own data
 			$grants[$GLOBALS['egw_info']['user']['account_id']] = ~0;
 
+			//echo "acl::get_grants('$app',$enum_group_acls) ".function_backtrace(); _debug_array($grants);
 			return $grants;
 		}
 		
