@@ -1,4 +1,4 @@
-<?php 
+<?php
 	/**************************************************************************\
 	* eGroupWare API - Password auth and crypt functions                       *
 	* This file written by Miles Lott <milos@groupwhere.org>                   *
@@ -20,7 +20,7 @@
 	* Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
 	\**************************************************************************/
 
-	/* $Id: class.auth.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: class.auth.inc.php 21891 2006-06-20 09:50:00Z milosch $ */
 
 	if(empty($GLOBALS['egw_info']['server']['auth_type']))
 	{
@@ -48,13 +48,6 @@
 				'M','N','O','P','Q','R','S','T','U','V','W','X','Y','Z'
 			);
 
-			if(!$this->seeded && phpversion() < '4.2.0')
-			{
-				list($usec, $sec) = explode(' ', microtime());
-				mt_srand((float)$sec + ((float)$usec * 100000));
-				$this->seeded = True;
-			}
-
 			for ($i=0; $i<$size; $i++)
 			{
 				$s .= $random_char[mt_rand(1,61)];
@@ -79,17 +72,37 @@
 		}
 
 		/**
-		 * compagres an encrypted password
+		 * compares an encrypted password
 		 *
 		 * encryption type set in setup and calls the appropriate encryption functions
 		 *
 		 * @param $cleartext cleartext password
-		 * @param $encrypted encrypted password
+		 * @param $encrypted encrypted password, can have a {hash} prefix, which overrides $type
 		 * @param $type type of encryption
 		 * @param $username used as optional key of encryption for md5_hmac
 		 */
 		function compare_password($cleartext,$encrypted,$type,$username='')
 		{
+			// allow to specify the hash type to prefix the hash, to easy migrate passwords from ldap
+			$saved_enc = $encrypted;
+			if (preg_match('/^\\{([a-z_5]+)\\}(.+)$/i',$encrypted,$matches))
+			{
+				$type = strtolower($matches[1]);
+				$encrypted = $matches[2];
+				
+				switch($type)	// some hashs are specially "packed" in ldap
+				{
+					case 'md5':
+						$encrypted = implode('',unpack('H*',base64_decode($encrypted)));
+						break;
+					case 'crypt':
+						// nothing to do
+						break;
+					default:
+						$encrypted = $saved_enc;
+					// ToDo: the others ...
+				}
+			}
 			switch($type)
 			{
 				case 'smd5':
@@ -124,10 +137,11 @@
 			$salt = '';
 			switch($type)
 			{
+				default:	// eg. setup >> config never saved
 				case 'des':
 					$salt       = $this->randomstring(2);
 					$_password  = crypt($password, $salt);
-					$e_password = sprintf('%s%s', '{crypt}', $_password);
+					$e_password = '{crypt}'.$_password;
 					break;
 				case 'md5':
 					/* New method taken from the openldap-software list as recommended by
@@ -160,13 +174,36 @@
 					$hash = mhash(MHASH_SHA1, $password . $salt);
 					$e_password = '{SSHA}' . base64_encode($hash . $salt);
 					break;
-				default:
-					return False;
 			}
 			return $e_password;
 		}
+		
+		/**
+		 * Create an ldap hash from an sql hash
+		 *
+		 * @param string $hash
+		 */
+		function hash_sql2ldap($hash)
+		{
+			switch(strtolower($GLOBALS['egw_info']['server']['sql_encryption_type']))
+			{
+				case '':	// not set sql_encryption_type
+				case 'md5':
+					$hash = '{md5}' . base64_encode(pack("H*",$hash));
+					break;
+				case 'crypt':
+					$hash = '{crypt}' . $hash;
+					break;
+			}
+			return $hash;
+		}
 
-		/* Create a password for storage in the accounts table */
+		/**
+		 * Create a password for storage in the accounts table
+		 * 
+		 * @param string $password
+		 * @return string hash
+		 */
 		function encrypt_sql($password)
 		{
 			/* Grab configured type, or default to md5() (old method) */
@@ -241,11 +278,48 @@
 		}
 
 		/**
-		@function smd5_compare
-		@abstract compare SMD5-encrypted passwords for authentication
-		@param $form_val user input value for comparison
-		@param $db_val   stored value (from database)
-		@return boolean	 True on successful comparison
+		 * Checks if a given password is "safe"
+		 *
+		 * @param string $login
+		 * @abstract atm a simple check in length, #digits, #uppercase and #lowercase
+		 * 				could be made more safe using e.g. pecl library cracklib
+		 * 				but as pecl dosn't run on any platform and isn't GPL'd
+		 * 				i haven't implemented it yet
+		 *				Windows compatible check is: 7 char lenth, 1 Up, 1 Low, 1 Num and 1 Special
+		 * @author cornelius weiss <egw at von-und-zu-weiss.de>
+		 * @return mixed false if password is considered "safe" or a string $message if "unsafe"
+		 */
+		function crackcheck($passwd)
+		{
+			if (!preg_match('/.{'. ($noc=7). ',}/',$passwd))
+			{
+				$message = lang('Password must have at least %1 characters',$noc). '<br>';
+			}
+			if(!preg_match('/(.*\d.*){'. ($non=1). ',}/',$passwd))
+			{
+				$message .= lang('Password must contain at least %1 numbers',$non). '<br>';
+			}
+			if(!preg_match('/(.*[[:upper:]].*){'. ($nou=1). ',}/',$passwd))
+			{
+				$message .= lang('Password must contain at least %1 uppercase letters',$nou). '<br>';
+			}
+			if(!preg_match('/(.*[[:lower:]].*){'. ($nol=1). ',}/',$passwd))
+			{
+				$message .= lang('Password must contain at least %1 lowercase letters',$nol). '<br>';
+			}
+			if(!preg_match('/(.*[\\!"#$%&\'()*+,-.\/:;<=>?@\[\]\^_ {|}~`].*){'. ($nol=1). ',}/',$passwd))
+			{
+				$message .= lang('Password must contain at least %1 special characters',$nol). '<br>';
+			}
+			return $message ? $message : false;
+		}
+
+		/**
+		 * compare SMD5-encrypted passwords for authentication
+		 * 
+		 * @param string $form_val user input value for comparison
+		 * @param string $db_val stored value (from database)
+		 * @return boolean True on successful comparison
 		*/
 		function smd5_compare($form_val,$db_val)
 		{
@@ -267,11 +341,11 @@
 		}
 
 		/**
-		@function sha_compare
-		@abstract compare SHA-encrypted passwords for authentication
-		@param $form_val user input value for comparison
-		@param $db_val   stored value (from database)
-		@return boolean	 True on successful comparison
+		 * compare SHA-encrypted passwords for authentication
+		 * 
+		 * @param string $form_val user input value for comparison
+		 * @param string $db_val   stored value (from database)
+		 * @return boolean True on successful comparison
 		*/
 		function sha_compare($form_val,$db_val)
 		{
@@ -288,11 +362,11 @@
 		}
 
 		/**
-		@function ssha_compare
-		@abstract compare SSHA-encrypted passwords for authentication
-		@param $form_val user input value for comparison
-		@param $db_val   stored value (from database)
-		@return boolean	 True on successful comparison
+		 * compare SSHA-encrypted passwords for authentication
+		 * 
+		 * @param string $form_val user input value for comparison
+		 * @param string $db_val   stored value (from database)
+		 * @return boolean	 True on successful comparison
 		*/
 		function ssha_compare($form_val,$db_val)
 		{
@@ -312,12 +386,12 @@
 		}
 
 		/**
-		@function crypt_compare
-		@abstract compare crypted passwords for authentication whether des,ext_des,md5, or blowfish crypt
-		@param $form_val user input value for comparison
-		@param $db_val   stored value (from database)
-		@param $type     crypt() type
-		@return boolean	 True on successful comparison
+		 * compare crypted passwords for authentication whether des,ext_des,md5, or blowfish crypt
+		 * 
+		 * @param string $form_val user input value for comparison
+		 * @param string $db_val   stored value (from database)
+		 * @param string $type     crypt() type
+		 * @return boolean	 True on successful comparison
 		*/
 		function crypt_compare($form_val,$db_val,$type)
 		{
@@ -341,13 +415,13 @@
 		}
 
 		/**
-		@function md5_hmac_compare
-		@abstract compare md5_hmac-encrypted passwords for authentication (see RFC2104)
-		@param $form_val user input value for comparison
-		@param $db_val   stored value (from database)
-		@param $key       key for md5_hmac-encryption (username for imported smf users)
-		@return boolean	 True on successful comparison
-		*/
+		 * compare md5_hmac-encrypted passwords for authentication (see RFC2104)
+		 * 
+		 * @param string $form_val user input value for comparison
+		 * @param string $db_val   stored value (from database)
+		 * @param string $key       key for md5_hmac-encryption (username for imported smf users)
+		 * @return boolean	 True on successful comparison
+		 */
 		function md5_hmac_compare($form_val,$db_val,$key)
 		{
 			$key = str_pad(strlen($key) <= 64 ? $key : pack('H*', md5($key)), 64, chr(0x00));
