@@ -21,7 +21,7 @@
 	* Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
 	\**************************************************************************/
 
-	/* $Id: class.auth_sqlssl.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: class.auth_sqlssl.inc.php 24096 2007-06-13 15:38:21Z ralfbecker $ */
 
 	class auth_
 	{
@@ -49,7 +49,7 @@
 				'account_type'   => 'u',
 			),__LINE__,__FILE__);
 			
-			if (!$this->db->next_record() || $GLOBALS['egw_info']['server']['case_sensitive_username'] && $db->f('account_lid') != $username)
+			if (!$this->db->next_record() || $GLOBALS['egw_info']['server']['case_sensitive_username'] && $this->db->f('account_lid') != $username)
 			{
 				return false;
 			}
