@@ -22,7 +22,7 @@
   * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
   \**************************************************************************/
 
-  /* $Id: class.browser.inc.php 15134 2004-05-05 12:06:13Z reinerj $ */
+  /* $Id: class.browser.inc.php 23741 2007-04-30 10:29:44Z lkneschke $ */
 
 	class browser
 	{
@@ -76,23 +76,23 @@
 			/*
 				Determine platform
 			*/
-			if(strstr($HTTP_USER_AGENT,'Win'))
+			if(strpos($HTTP_USER_AGENT,'Win') !== false)
 			{
 				$this->BROWSER_PLATFORM='Win';
 			}
-			elseif(strstr($HTTP_USER_AGENT,'Mac'))
+			elseif(strpos($HTTP_USER_AGENT,'Mac') !== false)
 			{
 				$this->BROWSER_PLATFORM='Mac';
 			}
-			elseif(strstr($HTTP_USER_AGENT,'Linux'))
+			elseif(strpos($HTTP_USER_AGENT,'Linux') !== false)
 			{
 				$this->BROWSER_PLATFORM='Linux';
 			}
-			elseif(strstr($HTTP_USER_AGENT,'Unix'))
+			elseif(strpos($HTTP_USER_AGENT,'Unix') !== false)
 			{
 				$this->BROWSER_PLATFORM='Unix';
 			}
-			elseif(strstr($HTTP_USER_AGENT,'Beos'))
+			elseif(strpos($HTTP_USER_AGENT,'Beos') !== false)
 			{
 				$this->BROWSER_PLATFORM='Beos';
 			}
