@@ -23,7 +23,7 @@
 	* along with this library; if not, write to the Free Software Foundation,  *
 	* Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
 	\**************************************************************************/
-	/* $Id: class.categories.inc.php 21368 2006-04-14 09:53:05Z ralfbecker $ */
+	/* $Id: class.categories.inc.php 25149 2008-03-22 09:47:09Z ralfbecker $ */
 
 	/**
 	 * class to manage categories in eGroupWare
@@ -36,6 +36,9 @@
 	{
 		var $account_id;
 		var $app_name;
+		/**
+		 * @var egw_db
+		 */
 		var $db;
 		var $total_records;
 		var $grants;
@@ -56,7 +59,11 @@
 			$this->app_name		= $app_name;
 			$this->db			= clone($GLOBALS['egw']->db);
 			$this->db->set_app('phpgwapi');
-			$this->grants		= $GLOBALS['egw']->acl->get_grants($app_name);
+			if($app_name == 'addressbook' && $GLOBALS['egw_info']['server']['account_repository'] == 'ldap') {
+				$this->grants = $GLOBALS['egw']->acl->get_grants($app_name, false);
+			} else {
+				$this->grants = $GLOBALS['egw']->acl->get_grants($app_name);
+			}
 		}
 
 		/**
@@ -446,13 +453,6 @@
 			}
 			return $s;
 		}
-		/**
-		 * @deprecated use formatted_list
-		 */
-		function formated_list($format,$type='',$selected = '',$globals = False,$site_link = 'site')
-		{
-			return $this->formatted_list($format,$type,$selected,$globals,$site_link);
-		}
 
 		/**
 		 * add a category
@@ -467,11 +467,19 @@
 				$values['level'] = $this->id2name($values['parent'],'level')+1;
 				$values['main'] = $this->id2name($values['parent'],'main');
 			}
+
+			$values = array_merge(
+				array(
+					'app_name'	=> $this->app_name,
+					'access'	=> 'public',
+				),
+				$values);
+
 			$this->db->insert($this->table,array(
 				'cat_parent'  => $values['parent'],
 				'cat_owner'   => $this->account_id,
 				'cat_access'  => $values['access'],
-				'cat_appname' => $this->app_name,
+				'cat_appname' => $values['app_name'],
 				'cat_name'    => $values['name'],
 				'cat_description' => $values['descr'],
 				'cat_data'    => $values['data'],
@@ -590,26 +598,52 @@
 		}
 
 		/**
-		 * return category id for a given name, only application cat, which are global or owned by the user are returned!
+		 * return category id for a given name
+		 * 
+		 * Cat's with the given name are returned in this order:
+		 * - personal cats first
+		 * - then application global categories
+		 * - global categories
+		 * - cat's of other user
 		 *
 		 * @param string $cat_name cat-name
+		 * @param boolean $strip=false if true, strips 'X-' from category names added by some SyncML clients
 		 * @return int cat-id or 0 if not found
 		 */
-		function name2id($cat_name)
+		function name2id($cat_name,$strip=false)
 		{
 			static $cache = array();	// a litle bit of caching
 			
 			if (isset($cache[$cat_name])) return $cache[$cat_name];
 
-			$this->db->select($this->table,'cat_id',array(
-				'cat_name' => $cat_name,
-				'cat_appname' => $this->app_name,
-				'(cat_owner = '.(int)$this->account_id.' OR cat_owner = -1)',
-			),__LINE__,__FILE__);
+			if ($strip === true)
+			{
+				$strip = 'X-';
+			}
+
+			$cats = array($cat_name);
+			if (isset($strip) && strncmp($strip, $cat_name, strlen($strip)) == 0)
+			{
+				$stripped_cat_name = substr($cat_name, strlen($strip));
+				if (isset($cache[$stripped_cat_name]))
+				{
+					$cache[$cat_name] = $cache[$stripped_cat_name];
+					return $cache[$stripped_cat_name];
+				}
+				$cats[] = $stripped_cat_name;
+			}
+				
+
+			$this->db->select($this->table,array('cat_name','cat_id'),array(
+				'cat_name' => $cats,
+				'cat_appname' => array($this->app_name, 'phpgw'),
+			),__LINE__,__FILE__,0,
+			"ORDER BY cat_name!='$cat_name',(CASE cat_owner WHEN ".(int)$this->account_id." THEN 1 WHEN -1 THEN 2 ELSE 3 END),cat_appname='phpgw'",
+			false,1);
 
 			if (!$this->db->next_record()) return 0;	// cat not found, dont cache it, as it might be created in this request
 
-			return $cache[$cat_name] = (int) $this->db->f('cat_id');
+			return $cache[$this->db->f('cat_name')] = (int) $this->db->f('cat_id');
 		}
 
 		/**
