@@ -25,7 +25,7 @@
 	* Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
 	\**************************************************************************/
 
-	/* $Id: class.common.inc.php 20940 2006-04-05 14:57:07Z ralfbecker $ */
+	/* $Id: class.common.inc.php 24605 2007-10-29 19:46:46Z ralfbecker $ */
 
 	$d1 = strtolower(@substr(EGW_API_INC,0,3));
 	$d2 = strtolower(@substr(EGW_SERVER_ROOT,0,3));
@@ -169,8 +169,10 @@
 			if(empty($_globalUid)) return false;
 			
 			$globalUidParts = explode('-',$_globalUid);
+			array_shift($globalUidParts);	// remove the app name
+			array_pop($globalUidParts);		// remove the install_id
 			
-			return $globalUidParts[1];
+			return implode('-',$globalUidParts);	// return the rest, allowing to have dashs in the id, can happen with LDAP!
 		}
 
 		// This is used for searching the access fields
@@ -199,7 +201,6 @@
 			return $s;
 		}
 
-		// return a array of installed languages
 		/**
 		 * return an array of installed languages
 		 *
@@ -216,9 +217,6 @@
 			return $installedLanguages;
 		}
 
-		// return the preferred language of the users
-		// it's using HTTP_ACCEPT_LANGUAGE (send from the users browser)
-		// and ...(to find out which languages are installed)
 		/**
 		 * return the preferred langugae of the users
 		 *
@@ -232,7 +230,6 @@
 			$supportedLanguages = $this->getInstalledLanguages();
 
 			// find usersupported language
-//			while (list($key,$value) = each($userLanguages))
 			foreach($userLanguages as $key => $value)
 			{
 				// remove everything behind '-' example: de-de
@@ -262,89 +259,36 @@
 		 * Escaped Characters are: '*', '(', ')', ' ', '\', NUL
 		 * It's actually a PHP-Bug, that we have to escape space.
 		 * For all other Characters, refer to RFC2254.
+		 * 
 		 * @param $string either a string to be escaped, or an array of values to be escaped
+		 * @return string
 		 */
 		function ldap_addslashes($string='')
 		{
-			return str_replace(array('\\','*','(',')','\0',' '),array('\\\\','\*','\(','\)','\\0','\20'),$string);
+			// use Lars new ldap class
+			if (!is_object($GLOBALS['egw']->ldap))
+			{
+				$GLOBALS['egw']->ldap =& CreateObject('phpgwapi.ldap');
+			}
+			return ldap::quote($string);
 		}
 
-		// connect to the ldap server and return a handle
 		/**
 		 * connect to the ldap server and return a handle
 		 *
 		 * @param $host ldap host
 		 * @param $dn ldap_root_dn
 		 * @param $passwd ldap_root_pw
+		 * @return resource
 		 */
 		function ldapConnect($host='', $dn='', $passwd='')
 		{
-			if(!function_exists('ldap_connect'))
+			// use Lars new ldap class
+			if (!is_object($GLOBALS['egw']->ldap))
 			{
-				/* log does not exist in setup(, yet) */
-				if(is_object($GLOBALS['egw']->log))
-				{
-					$GLOBALS['egw']->log->message('F-Abort, LDAP support unavailable');
-					$GLOBALS['egw']->log->commit();
-				}
-
-				printf('<b>Error: LDAP support unavailable</b><br>',$host);
-				return False;
+				$GLOBALS['egw']->ldap =& CreateObject('phpgwapi.ldap');
 			}
-
-			if(!$host)
-			{
-				$host = $GLOBALS['egw_info']['server']['ldap_host'];
-			}
-
-			if(!$dn)
-			{
-				$dn = $GLOBALS['egw_info']['server']['ldap_root_dn'];
-			}
-
-			if(!$passwd)
-			{
-				$passwd = $GLOBALS['egw_info']['server']['ldap_root_pw'];
-			}
-
-			// connect to ldap server
-			if(!$ds = ldap_connect($host))
-			{
-				/* log does not exist in setup(, yet) */
-				if(is_object($GLOBALS['egw']->log))
-				{
-					$GLOBALS['egw']->log->message('F-Abort, Failed connecting to LDAP server');
-					$GLOBALS['egw']->log->commit();
-				}
-
-				printf("<b>Error: Can't connect to LDAP server %s!</b><br>",$host);
-				echo function_backtrace(1);
-				return False;
-			}
-
-			if($GLOBALS['egw_info']['server']['ldap_version3'])
-			{
-				if(!ldap_set_option($ds,LDAP_OPT_PROTOCOL_VERSION,3))
-				{
-					$GLOBALS['egw_info']['server']['ldap_version3'] = False;
-				}
-			}
-
-			// bind as admin
-			if(!ldap_bind($ds,$dn,$passwd))
-			{
-				if(is_object($GLOBALS['egw']->log))
-				{
-					$GLOBALS['egw']->log->message('F-Abort, Failed binding to LDAP server');
-					$GLOBALS['egw']->log->commit();
-				}
-
-				printf("<b>Error: Can't bind to LDAP server: %s!</b><br>",$dn);
-				echo function_backtrace(1);
-				return False;
-			}
-
-			return $ds;
+			return $GLOBALS['egw']->ldap->ldapConnect($host,$dn,$passwd);
 		}
 
 		/**
@@ -378,6 +322,10 @@
 				{
 					$GLOBALS['egw']->accounts->save_session_cache();
 				}
+				if (is_object($GLOBALS['egw']->link))
+				{
+					$GLOBALS['egw']->link->save_session_cache();
+				}
 				// call the asyncservice check_run function if it is not explicitly set to cron-only
 				//
 				if (!$GLOBALS['egw_info']['server']['asyncservice'])	// is default
@@ -468,12 +416,12 @@
 				$firstname = $GLOBALS['egw_info']['user']['firstname'];
 				$lastname  = $GLOBALS['egw_info']['user']['lastname'];
 			}
-
+			$is_group = $GLOBALS['egw']->accounts->get_type($accountid ? $accountid : $lid) == 'g';
+			
 			if (empty($firstname)) $firstname = $lid;
-			if (empty($lastname))
+			if (empty($lastname) || $is_group)
 			{
-				$lastname  = $GLOBALS['egw']->accounts->get_type($accountid ? $accountid : $lid) == 'g' ?
-					lang('Group') : lang('User');
+				$lastname  = $is_group ? lang('Group') : lang('User');
 			}
 			$display = $GLOBALS['egw_info']['user']['preferences']['common']['account_display'];
 
@@ -733,15 +681,14 @@
 		*/
 		function list_templates()
 		{
+			$list = array();
 			$d = dir(EGW_SERVER_ROOT . '/phpgwapi/templates');
-			while ($entry=$d->read())
+			while (($entry=$d->read()))
 			{
-				 if ($entry != '..' && is_file(EGW_SERVER_ROOT . '/phpgwapi/templates/' . $entry .'/setup/setup.inc.php')
-				 )
+				if ($entry != '..' && file_exists(EGW_SERVER_ROOT . '/phpgwapi/templates/' . $entry .'/class.'.$entry.'_framework.inc.php'))
 				{
 					$list[$entry]['name'] = $entry;
-					$f = EGW_SERVER_ROOT . '/phpgwapi/templates/' . $entry . '/setup/setup.inc.php';
-					if (file_exists ($f))
+					if (file_exists ($f = EGW_SERVER_ROOT . '/phpgwapi/templates/' . $entry . '/setup/setup.inc.php'))
 					{
 						include($f);
 						$list[$entry]['title'] = $GLOBALS['egw_info']['template'][$entry]['title'];
@@ -752,11 +699,9 @@
 					}
 				}
 			}
-			//_debug_array($GLOBALS['egw_info'][template]);
-			//die();
-			
 			$d->close();
 			ksort($list);
+
 			return $list;
 		}
 
@@ -764,10 +709,12 @@
 		 * get template dir of an application
 		 *
 		 * @param $appname appication name optional can be derived from $GLOBALS['egw_info']['flags']['currentapp'];
+		 * @static 
+		 * @return string/boolean dir or false if no dir is found
 		 */
 		function get_tpl_dir($appname = '')
 		{
-			if (! $appname)
+			if (!$appname)
 			{
 				$appname = $GLOBALS['egw_info']['flags']['currentapp'];
 			}
@@ -793,12 +740,11 @@
 			{
 				$GLOBALS['egw_info']['server']['template_set'] = $GLOBALS['egw_info']['user']['preferences']['common']['template_set'];
 			}
-			elseif ($GLOBALS['egw_info']['server']['template_set'] == 'user_choice' ||
-				!isset($GLOBALS['egw_info']['server']['template_set']))
+			if (!file_exists(EGW_SERVER_ROOT.'/phpgwapi/templates/'.$GLOBALS['egw_info']['server']['template_set'].'/class.'.
+				$GLOBALS['egw_info']['server']['template_set'].'_framework.inc.php'))
 			{
-				$GLOBALS['egw_info']['server']['template_set'] = 'default';
+				$GLOBALS['egw_info']['server']['template_set'] = 'idots';
 			}
-
 			$tpldir         = EGW_SERVER_ROOT . '/' . $appname . '/templates/' . $GLOBALS['egw_info']['server']['template_set'];
 			$tpldir_default = EGW_SERVER_ROOT . '/' . $appname . '/templates/default';
 
@@ -833,7 +779,7 @@
 				while ($f = readdir($d))
 				{
 					$ext = strtolower(strrchr($f,'.'));
-					if (($ext == '.gif' || $ext == '.png') && strstr($f,'navbar') === False)
+					if (($ext == '.gif' || $ext == '.png') && strpos($f,'navbar') === False)
 					{
 						return True;
 					}
@@ -855,12 +801,12 @@
 			}
 			if (empty($GLOBALS['egw_info']['server']['template_set']))
 			{
-				$GLOBALS['egw_info']['server']['template_set'] = 'default';
+				$GLOBALS['egw_info']['server']['template_set'] = 'idots';
 			}
 
 			$imagedir            = EGW_SERVER_ROOT . '/' . $appname . '/templates/'
 				. $GLOBALS['egw_info']['server']['template_set'] . '/images';
-			$imagedir_default    = EGW_SERVER_ROOT . '/' . $appname . '/templates/default/images';
+			$imagedir_default    = EGW_SERVER_ROOT . '/' . $appname . '/templates/idots/images';
 			$imagedir_olddefault = EGW_SERVER_ROOT . '/' . $appname . '/images';
 
 			if ($this->is_image_dir ($imagedir))
@@ -895,12 +841,12 @@
 
 			if (empty($GLOBALS['egw_info']['server']['template_set']))
 			{
-				$GLOBALS['egw_info']['server']['template_set'] = 'default';
+				$GLOBALS['egw_info']['server']['template_set'] = 'idots';
 			}
 
 			$imagedir            = EGW_SERVER_ROOT . '/'.$appname.'/templates/'.$GLOBALS['egw_info']['server']['template_set'].'/images';
-			$imagedir_default    = EGW_SERVER_ROOT . '/'.$appname.'/templates/default/images';
-			$imagedir_olddefault = EGW_SERVER_ROOT . '/'.$appname.'/images';
+			$imagedir_default    = EGW_SERVER_ROOT . '/'.$appname.'/templates/idots/images';
+			$imagedir_olddefault = EGW_SERVER_ROOT . '/'.$appname.'/templates/default/images';
 
 			if ($this->is_image_dir ($imagedir))
 			{
@@ -908,11 +854,11 @@
 			}
 			elseif ($this->is_image_dir ($imagedir_default))
 			{
-				return $GLOBALS['egw_info']['server']['webserver_url'].'/'.$appname.'/templates/default/images';
+				return $GLOBALS['egw_info']['server']['webserver_url'].'/'.$appname.'/templates/idots/images';
 			}
 			elseif ($this->is_image_dir ($imagedir_olddefault))
 			{
-				return $GLOBALS['egw_info']['server']['webserver_url'].'/'.$appname.'/images';
+				return $GLOBALS['egw_info']['server']['webserver_url'].'/'.$appname.'/templates/default/images';
 			}
 			else
 			{
@@ -920,14 +866,25 @@
 			}
 		}
 
+		/**
+		 * Searches and image by a given search order (it maintains a cache of the existing images):
+		 * - image dir of the application for the given template
+		 * - image dir of the application for the default template
+		 * - image dir of the API for the given template
+		 * - image dir of the API for the default template
+		 *
+		 * @param string $appname
+		 * @param string $image
+		 * @return string url of the image
+		 */
 		function find_image($appname,$image)
 		{
 			$imagedir = '/'.$appname.'/templates/'.$GLOBALS['egw_info']['user']['preferences']['common']['template_set'].'/images';
 			
 			if (!@is_array($this->found_files[$appname]))
 			{
-				$imagedir_olddefault = '/'.$appname.'/images';
-				$imagedir_default    = '/'.$appname.'/templates/default/images';
+				$imagedir_olddefault = '/'.$appname.'/templates/default/images';
+				$imagedir_default    = '/'.$appname.'/templates/idots/images';
 				
 				if (@is_dir(EGW_INCLUDE_ROOT.$imagedir_olddefault))
 				{
@@ -1042,6 +999,15 @@
 			return $imgfile;
 		}
 
+		/**
+		 * Searches a appname, template and maybe language and type-specific image
+		 *
+		 * @param string $appname
+		 * @param string $image
+		 * @param string $ext
+		 * @param boolean $use_lang
+		 * @return string url of the image
+		 */
 		function image($appname,$image='',$ext='',$use_lang=True)
 		{
 			if (!is_array($image))
@@ -1075,123 +1041,41 @@
 			return $image_found;
 		}
 
+		/**
+		 * Searches an image of a given type, if not found also without type/extension
+		 *
+		 * @param string $appname
+		 * @param string $image
+		 * @param string $extension
+		 * @return string url of the image
+		 */
 		function image_on($appname,$image,$extension='_on')
 		{
-			$with_extension = $this->image($appname,$image,$extension);
-			$without_extension = $this->image($appname,$image);
-			if($with_extension != '')
+			if (($with_extension = $this->image($appname,$image,$extension)))
 			{
 				return $with_extension;
 			}
-			elseif($without_extension != '')
+			if(($without_extension = $this->image($appname,$image)))
 			{
 				return $without_extension;
 			}
-			else
-			{
-				return '';
-			}
+			return '';
 		}
 
 		/**
-		 * none yet
-		 *
-		 * *someone wanna add some detail here*
+	 	 * prepare an array with variables used to render the navbar
+		 * 
+		 * @deprecated inherit from egw_framework class in your template and use egw_framework::_navbar_vars()
 		 */
 		function navbar()
 		{
-			
-
-			list($first) = each($GLOBALS['egw_info']['user']['apps']);
-			if(is_array($GLOBALS['egw_info']['user']['apps']['admin']) && $first != 'admin')
-			{
-				$newarray['admin'] = $GLOBALS['egw_info']['user']['apps']['admin'];
-				foreach($GLOBALS['egw_info']['user']['apps'] as $index => $value)
-				{
-					if($index != 'admin')
-					{
-						$newarray[$index] = $value;
-					}
-				}
-				$GLOBALS['egw_info']['user']['apps'] = $newarray;
-				reset($GLOBALS['egw_info']['user']['apps']);
-			}
-			unset($index);
-			unset($value);
-			unset($newarray);
-
-			foreach($GLOBALS['egw_info']['user']['apps'] as $app => $data)
-			{
-				if (is_long($app))
-				{
-					continue;
-				}
-
-				if ($app == 'preferences' || $GLOBALS['egw_info']['apps'][$app]['status'] != 2 && $GLOBALS['egw_info']['apps'][$app]['status'] != 3)
-				{
-					$GLOBALS['egw_info']['navbar'][$app]['title'] = $GLOBALS['egw_info']['apps'][$app]['title'];
-					$GLOBALS['egw_info']['navbar'][$app]['url']   = $GLOBALS['egw']->link('/' . $app . '/index.php',$GLOBALS['egw_info']['flags']['params'][$app]);
-					$GLOBALS['egw_info']['navbar'][$app]['name']  = $app;
-
-					// create popup target
-					if ($data['status'] == 4)
-					{
-						$GLOBALS['egw_info']['navbar'][$app]['target'] = ' target="'.$app.'" onClick="'."if (this != '') { window.open(this+'".
-							(strstr($GLOBALS['egw_info']['navbar'][$app]['url'],'?') || 
-							ini_get('session.use_trans_sid') && substr($GLOBALS['egw_info']['server']['sessions_type'],0,4) == 'php4' ?'&':'?').
-							"referer='+encodeURI(location),this.target,'width=800,height=600,scrollbars=yes,resizable=yes'); return false; } else { return true; }".'"';
-					}
-
-					if ($app != $GLOBALS['egw_info']['flags']['currentapp'])
-					{
-						$GLOBALS['egw_info']['navbar'][$app]['icon']  = $this->image($app,Array('navbar','nonav'));
-						$GLOBALS['egw_info']['navbar'][$app]['icon_hover']  = $this->image_on($app,Array('navbar','nonav'),'-over');
-					}
-					else
-					{
-						$GLOBALS['egw_info']['navbar'][$app]['icon']  = $this->image_on($app,Array('navbar','nonav'),'-over');
-						$GLOBALS['egw_info']['navbar'][$app]['icon_hover']  = $this->image($app,Array('navbar','nonav'));
-					}
-
-//					if($GLOBALS['egw_info']['navbar'][$app]['icon'] == '')
-//					{
-//						$GLOBALS['egw_info']['navbar'][$app]['icon']  = $this->image('phpgwapi','nonav');
-//					}
-				}
-			}
-			if ($GLOBALS['egw_info']['flags']['currentapp'] == 'preferences' || $GLOBALS['egw_info']['flags']['currentapp'] == 'about')
-			{
-				$app = $app_title = 'eGroupWare';
-			}
-			else
-			{
-				$app = $GLOBALS['egw_info']['flags']['currentapp'];
-				$app_title = $GLOBALS['egw_info']['apps'][$app]['title'];
-			}
-
-			if ($GLOBALS['egw_info']['user']['apps']['preferences'])	// preferences last
-			{
-				$prefs = $GLOBALS['egw_info']['navbar']['preferences'];
-				unset($GLOBALS['egw_info']['navbar']['preferences']);
-				$GLOBALS['egw_info']['navbar']['preferences'] = $prefs;
-			}
-
-			// We handle this here becuase its special
-			$GLOBALS['egw_info']['navbar']['about']['title'] = lang('About %1',$app_title);
-
-			$GLOBALS['egw_info']['navbar']['about']['url']   = $GLOBALS['egw']->link('/about.php','app='.$app);
-			$GLOBALS['egw_info']['navbar']['about']['icon']  = $this->image('phpgwapi',Array('about','nonav'));
-			$GLOBALS['egw_info']['navbar']['about']['icon_hover']  = $this->image_on('phpgwapi',Array('about','nonav'),'-over');
-
-			$GLOBALS['egw_info']['navbar']['logout']['title'] = lang('Logout');
-			$GLOBALS['egw_info']['navbar']['logout']['url']   = $GLOBALS['egw']->link('/logout.php');
-			$GLOBALS['egw_info']['navbar']['logout']['icon']  = $this->image('phpgwapi',Array('logout','nonav'));
-			$GLOBALS['egw_info']['navbar']['logout']['icon_hover']  = $this->image_on('phpgwapi',Array('logout','nonav'),'-over');
+			$GLOBALS['egw_info']['navbar'] = $GLOBALS['egw']->framework->_get_navbar_vars();
 		}
 
 		/**
 		 * load header.inc.php for an application
 		 *
+		 * @deprecated 
 		 */
 		function app_header()
 		{
@@ -1202,188 +1086,63 @@
 		}
 
 		/**
-		 * load the phpgw header
+		 * load the eGW header
 		 *
+		 * @deprecated use egw_framework::header(), $GLOBALS['egw']->framework->navbar() or better egw_framework::render($content)
 		 */
 		function egw_header()
 		{
-			// add a content-type header to overwrite an existing default charset in apache (AddDefaultCharset directiv)
-			header('Content-type: text/html; charset='.$GLOBALS['egw']->translation->charset());
-
-			ob_end_flush();
-			include_once(EGW_INCLUDE_ROOT . '/phpgwapi/templates/' . $GLOBALS['egw_info']['server']['template_set']
-				. '/head.inc.php');
-			$this->navbar(False);
-			include_once(EGW_INCLUDE_ROOT . '/phpgwapi/templates/' . $GLOBALS['egw_info']['server']['template_set']
-				. '/navbar.inc.php');
-			if (!@$GLOBALS['egw_info']['flags']['nonavbar'] && !@$GLOBALS['egw_info']['flags']['navbar_target'])
+			echo $GLOBALS['egw']->framework->header();
+			
+			if (!$GLOBALS['egw_info']['flags']['nonavbar'])
 			{
-				echo parse_navbar();
+			   echo $GLOBALS['egw']->framework->navbar();
 			}
-		}
+		 }
 
+		/**
+		 * load the eGW footer
+		 *
+		 * @deprecated use egw_framework::footer() or egw_framework::render($content)
+		 */
 		function egw_footer()
 		{
-			if (!defined('EGW_FOOTER'))
-			{
-				define('EGW_FOOTER',True);
-				if (!isset($GLOBALS['egw_info']['flags']['nofooter']) || !$GLOBALS['egw_info']['flags']['nofooter'])
-				{
-					include(EGW_API_INC . '/footer.inc.php');
-				}
+			if(is_object($GLOBALS['egw']->framework)) {
+				echo $GLOBALS['egw']->framework->footer();
 			}
 		}
 
 		/**
 		* Used by template headers for including CSS in the header
 		*
-		* This first loads up the basic global CSS definitions, which support
-		* the selected user theme colors.  Next we load up the app CSS.  This is
-		* all merged into the selected theme's css.tpl file.
-		*
-		* @author Dave Hall (*based* on verdilak? css inclusion code)
+		* @deprecated use framework::_get_css()
+		* @return string
 		*/
 		function get_css()
 		{
-			$tpl =& CreateObject('phpgwapi.Template', $this->get_tpl_dir('phpgwapi'));
-			$tpl->set_file('css', 'css.tpl');
-			$tpl->set_var($GLOBALS['egw_info']['theme']);
-			$app_css = '';
-			if(@isset($_GET['menuaction']))
-			{
-				list($app,$class,$method) = explode('.',$_GET['menuaction']);
-				if(is_array($GLOBALS[$class]->public_functions) &&
-					$GLOBALS[$class]->public_functions['css'])
-				{
-					$app_css .= $GLOBALS[$class]->css();
-				}
-			}
-			if (isset($GLOBALS['egw_info']['flags']['css']))
-			{
-				$app_css .= $GLOBALS['egw_info']['flags']['css'];
-			}
-			$tpl->set_var('app_css', $app_css);
-
-			// search for app specific css file
-			if(@isset($GLOBALS['egw_info']['flags']['currentapp']))
-			{
-				$appname = $GLOBALS['egw_info']['flags']['currentapp'];
-
-				if(file_exists(EGW_SERVER_ROOT . SEP . $appname . SEP
-					. 'templates' . SEP . $GLOBALS['egw_info']['server']['template_set']
-					. SEP . 'app.css')
-				)
-				{
-					$tpl->set_var('css_file', '<LINK href="'.$GLOBALS['egw_info']['server']['webserver_url']
-						. "/$appname/templates/".$GLOBALS['egw_info']['server']['template_set']
-						. "/app.css".'" type=text/css rel=StyleSheet>');
-				}
-				elseif(file_exists(EGW_SERVER_ROOT . SEP . $appname . SEP
-					. 'templates' . SEP . 'default'
-					. SEP . 'app.css')
-				)
-				{
-					$tpl->set_var('css_file', '<LINK href="'.$GLOBALS['egw_info']['server']['webserver_url']
-					."/$appname/templates/default/app.css".'" type=text/css rel=StyleSheet>');
-				}
-			}
-
-			return $tpl->subst('css');
+			return $GLOBALS['egw']->framework->_get_css();
 		}
 
 		/**
 		* Used by the template headers for including javascript in the header
 		*
-		* The method is included here to make it easier to change the js support
-		* in phpgw.  One change then all templates will support it (as long as they
-		* include a call to this method).
-		*
-		* @author Dave Hall (*vaguely based* on verdilak? css inclusion code)
+		* @deprecated use framework::_get_js()
 		* @return string the javascript to be included
 		*/
 		function get_java_script()
 		{
-			$java_script = '';
-			
-			if(!@is_object($GLOBALS['egw']->js))
-			{
-				$GLOBALS['egw']->js =& CreateObject('phpgwapi.javascript');
-			}
-			
-			// always include javascript helper functions
-			$GLOBALS['egw']->js->validate_file('jsapi','jsapi');
-
-			//viniciuscb: in Concisus this condition is inexistent, and in all
-			//pages the javascript globals are inserted. Today, because
-			//filescenter needs these javascript globals, this
-			//include_jsbackend is a must to the javascript globals be
-			//included.
-			if ($GLOBALS['egw_info']['flags']['include_jsbackend'])
-			{
-				if (!$GLOBALS['egw_info']['flags']['nojsapi'])
-				{
-					$GLOBALS['egw']->js->validate_jsapi();
-				}
-				
-				if(@is_object($GLOBALS['egw']->js))
-				{
-					$java_script .= $GLOBALS['egw']->js->get_javascript_globals();
-				}
-			}
-
-			if ($GLOBALS['egw_info']['flags']['include_xajax'])
-			{
-				require_once(EGW_SERVER_ROOT.'/phpgwapi/inc/xajax.inc.php');
-				$xajax =& new xajax($GLOBALS['egw']->link('/xajax.php'));
-				$xajax->registerFunction("doXMLHTTP");
-
-				$java_script .= $xajax->getJavascript();
-			}
-
-			/* this flag is for all javascript code that has to be put before other jscode. 
-			Think of conf vars etc...  (pim@lingewoud.nl) */
-			if (isset($GLOBALS['egw_info']['flags']['java_script_thirst']))
-			{
-				$java_script .= $GLOBALS['egw_info']['flags']['java_script_thirst'] . "\n";
-			}
-			
-			if(@is_object($GLOBALS['egw']->js))
-			{
-				$java_script .= $GLOBALS['egw']->js->get_script_links();
-			}
-
-			if(@isset($_GET['menuaction']))
-			{
-				list($app,$class,$method) = explode('.',$_GET['menuaction']);
-				if(is_array($GLOBALS[$class]->public_functions) &&
-					$GLOBALS[$class]->public_functions['java_script'])
-				{
-					$java_script .= $GLOBALS[$class]->java_script();
-				}
-			}
-			if (isset($GLOBALS['egw_info']['flags']['java_script']))
-			{
-				$java_script .= $GLOBALS['egw_info']['flags']['java_script'] . "\n";
-			}
-			return $java_script;
+			return $GLOBALS['egw']->framework->_get_js();
 		}
 
 		/**
 		* Returns on(Un)Load attributes from js class
 		*
-		*@author Dave Hall - skwashd at egroupware.org
-		*@returns string body attributes
+		* @deprecated use framework::_get_js()
+		* @returns string body attributes
 		*/
 		function get_body_attribs()
 		{
-			if(@is_object($GLOBALS['egw']->js))
-			{
-				return $GLOBALS['egw']->js->get_body_attribs();
-			}
-			else
-			{
-				return '';
-			}
+			return $GLOBALS['egw']->framework->_get_body_attribs();
 		}
 
 		function hex2bin($data)
@@ -1604,6 +1363,58 @@
 
 			return $h12.':'.$min.$sec.$ampm;
 		}
+		
+		/**
+		 * Format an email address according to the system standard
+		 *
+		 * Convert all european special chars to ascii and fallback to the accountname, if nothing left eg. chiniese
+		 *
+		 * @param string $first firstname
+		 * @param string $last lastname
+		 * @param string $account account-name (lid)
+		 * @param string $domain=null domain-name or null to use eGW's default domain $GLOBALS['egw_info']['server']['mail_suffix]
+		 * @return string with email address
+		 */
+		function email_address($first,$last,$account,$domain=null)
+		{
+			//echo "<p align=right>common::email_address('$first','$last','$account')";
+			// convert all european special chars to ascii, (c) RalfBecker-AT-egroupware.org ;-)
+			static $extra = array(
+				'&szlig;' => 'ss',
+				' ' => '',
+			);
+			foreach (array('first','last','account') as $name) 
+			{
+				$$name = htmlentities($$name,ENT_QUOTES,$GLOBALS['egw']->translation->charset());
+				$$name = str_replace(array_keys($extra),array_values($extra),$$name);
+				$$name = preg_replace('/&([aAuUoO])uml;/','\\1e',$$name);	// replace german umlauts with the letter plus one 'e'
+				$$name = preg_replace('/&([a-zA-Z])(grave|acute|circ|ring|cedil|tilde|slash|uml);/','\\1',$$name);	// remove all types of acents
+				$$name = preg_replace('/&([a-zA-Z]+|#[0-9]+|);/','',$$name);	// remove all other entities
+			}
+			//echo " --> ('$first', '$last', '$account')";
+			if (!$first && !$last)	// fallback to the account-name, if real names contain only special chars
+			{
+				$first = '';
+				$last = $account;
+			}
+			if (!$first || !$last)
+			{
+				$dot = $underscore = '';
+			}
+			else
+			{
+				$dot = '.';
+				$underscore = '_';
+			}
+			if (!$domain) $domain = $GLOBALS['egw_info']['server']['mail_suffix'];
+
+			$email = str_replace(array('first','last','initial','account','dot','underscore','-'),
+				array($first,$last,substr($first,0,1),$account,$dot,$underscore,''),
+				$GLOBALS['egw_info']['server']['email_address_format'] ? $GLOBALS['egw_info']['server']['email_address_format'] : 'first-dot-last').
+				'@'.$domain;
+			//echo " = '$email'</p>\n";
+			return $email;
+		}			
 
 		// This is not the best place for it, but it needs to be shared bewteen Aeromail and SM
 		/**
