@@ -20,7 +20,7 @@
 	* Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
 	\**************************************************************************/
 
-	/* $Id: class.config.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: class.config.inc.php 22273 2006-08-17 14:32:25Z ralfbecker $ */
 
 	class config
 	{
@@ -117,7 +117,7 @@
 				$app = $this->appname;
 				$this->config_data[$name] = $value;
 			}
-			if ($app == $this->appname && $this->read_data[$name] == $value)
+			if ($app == $this->appname && isset($this->read_data[$name]) && $this->read_data[$name] == $value)
 			{
 				return True;	// no change ==> exit
 			}
