@@ -18,7 +18,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: class.egw.inc.php 21238 2006-04-06 18:33:18Z ralfbecker $ */
+  /* $Id: class.egw.inc.php 25120 2008-03-19 20:11:58Z ralfbecker $ */
 
 	/**
 	 * New written class to create the eGW enviroment AND restore it from a php-session
@@ -42,6 +42,13 @@
 		var $db;
 		var $config_table = 'egw_config';
 
+		/**
+		* tplsav2  savant2 templating object
+		 * 
+		 * @var object 
+		 */
+		var $tplsav2;
+
 		/**
 		 * Constructor: Instantiates the sub-classes
 		 *
@@ -136,7 +143,7 @@
 			$this->preferences    =& CreateObject('phpgwapi.preferences');
 			$this->applications   =& CreateObject('phpgwapi.applications');
 			$this->contenthistory =& CreateObject('phpgwapi.contenthistory');
-			$this->datetime       =& CreateObject('phpgwapi.datetime');
+			$this->datetime       =& CreateObject('phpgwapi.egw_datetime');
 
 			include_once(EGW_INCLUDE_ROOT.'/phpgwapi/inc/class.error.inc.php');
 
@@ -146,10 +153,14 @@
 			{
 				$this->verify_session();
 				$this->applications->read_installed_apps();	// to get translated app-titles, has to be after verify_session
-
+				
 				$this->define_egw_constants();
 
-				$this->load_theme_info();
+				// setup the new eGW framework (template sets)
+				$class = $GLOBALS['egw_info']['server']['template_set'].'_framework';
+				require_once(EGW_INCLUDE_ROOT . '/phpgwapi/templates/' . $GLOBALS['egw_info']['server']['template_set'].
+					'/class.'.$class.'.inc.php');
+				$this->framework = new $class;		// =& removed because of problems with php4, does not matter with php5 anyway!
 
 				$this->check_app_rights();
 
@@ -328,51 +339,25 @@
 			{
 				// This will need to use ACL in the future
 				if (!$GLOBALS['egw_info']['user']['apps'][$GLOBALS['egw_info']['flags']['currentapp']] ||
-				($GLOBALS['egw_info']['flags']['admin_only'] && !$GLOBALS['egw_info']['user']['apps']['admin']))
+					($GLOBALS['egw_info']['flags']['admin_only'] && !$GLOBALS['egw_info']['user']['apps']['admin']))
 				{
 					$this->common->egw_header();
 					if ($GLOBALS['egw_info']['flags']['nonavbar'])
 					{
 						echo parse_navbar();
 					}
-
+					error_log('Permission denied, attempted to access '.$GLOBALS['egw_info']['flags']['currentapp']);
 					$this->log->write(array('text'=>'W-Permissions, Attempted to access %1','p1'=>$GLOBALS['egw_info']['flags']['currentapp']));
-
-					echo '<p><center><b>'.lang('Access not permitted').'</b></center>';
+					
+					$this->tplsav2 = CreateObject('phpgwapi.tplsavant2');	// create it only when neccessary
+					$this->tplsav2->assign('currentapp',$GLOBALS['egw_info']['flags']['currentapp']);
+					$this->tplsav2->set_tpl_path($this->tplsav2->get_tpl_dir(false,'phpgwapi'));
+					$this->tplsav2->display('appl_access_not_permitted.tpl.php');
 					$this->common->egw_exit(True);
 				}
 			}
 		}
 
-		/**
-		 * Load old theme info into egw_info[theme]
-		 *
-		 * @deprecated all theming should be done via CSS files of the template
-		 */
-		function load_theme_info()
-		{
-			global $phpgw_info;		// this is necesary as the included theme-files use $phpgw_info !!!
-
-			// at the moment we still need the theme files, hopefully they are gone soon in favor of CSS
-			if(@file_exists(EGW_SERVER_ROOT . '/phpgwapi/themes/' . $GLOBALS['egw_info']['user']['preferences']['common']['theme'] . '.theme'))
-			{
-				include($file = EGW_SERVER_ROOT . '/phpgwapi/themes/' . $GLOBALS['egw_info']['user']['preferences']['common']['theme'] . '.theme');
-			}
-			elseif(@file_exists(EGW_SERVER_ROOT . '/phpgwapi/themes/default.theme'))
-			{
-				include($file = EGW_SERVER_ROOT . '/phpgwapi/themes/default.theme');
-			}
-			else
-			{
-				// Hope we don't get to this point.  Better then the user seeing a
-				// complety back screen and not know whats going on
-				echo '<body bgcolor="FFFFFF">';
-				$this->log->write(array('text'=>'F-Abort, No themes found'));
-
-				exit;
-			}
-		}
-
 		/**
 		 * create all the defines / constants of the eGW-environment (plus the deprecated phpgw ones)
 		 */
