@@ -8,7 +8,7 @@
 	* any later version.                                                       *
 	\**************************************************************************/
 
-	/* $Id: class.egw_db.inc.php 22915 2006-12-08 10:17:15Z ralfbecker $ */
+	/* $Id: class.egw_db.inc.php 24763 2007-12-07 00:17:35Z ralfbecker $ */
 
 	/**
 	 * Database abstraction library
@@ -119,15 +119,17 @@
 		 * @var array $capabilities, defaults will be changed be method set_capabilities($ado_driver,$db_version)
 		 */
 		var $capabilities = array(
-			'sub_queries'      => true,	// will be set to false for mysql < 4.1
-			'union'            => true, // will be set to false for mysql < 4.0
+			'sub_queries'      => true,		// will be set to false for mysql < 4.1
+			'union'            => true, 	// will be set to false for mysql < 4.0
 			'outer_join'       => false,	// does the DB has an outer join, will be set eg. for postgres
-			'distinct_on_text' => true,	// is the DB able to use DISTINCT with a text or blob column
-			'like_on_text'     => true,	// is the DB able to use LIKE with text columns
+			'distinct_on_text' => true,		// is the DB able to use DISTINCT with a text or blob column
+			'like_on_text'     => true,		// is the DB able to use LIKE with text columns
 			'name_case'        => 'upper',	// case of returned column- and table-names: upper, lower(pgSql), preserv(MySQL)
 			'client_encoding'  => false,	// db uses a changeable clientencoding
-			'order_on_text'    => true,	// is the DB able to order by a given text column, boolean or
-		);								// string for sprintf for a cast (eg. 'CAST(%s AS varchar)')
+			'case_insensitive_like' => 'LIKE',	// case insensitive version of like, eg. ILIKE for postgres
+			'require_truncate_varchar' => false,// DB requires varchar columns to be truncated to the max. size (eg. Postgres)
+			'order_on_text'    => true,		// is the DB able to order by a given text column, boolean or
+		);									// string for sprintf for a cast (eg. 'CAST(%s AS varchar)')
 
 		var $prepared_sql = array();	// sql is the index
 
@@ -282,10 +284,14 @@
 					{
 						$this->ServerInfo = $this->Link_ID->ServerInfo();
 						$this->set_capabilities($type,$this->ServerInfo['version']);
-						$Ok = $this->Link_ID->SelectDB($Database);
+						if($Database)
+						{
+						   $Ok = $this->Link_ID->SelectDB($Database);
+						}
 					}
 					if (!$Ok)
 					{
+						$Host = preg_replace('/password=[^ ]+/','password=$Password',$Host);	// eg. postgres dsn contains password
 						$this->halt("ADOdb::$connect($Host, $User, \$Password, $Database) failed.");
 						return 0;	// in case error-reporting = 'no'
 					}
@@ -341,6 +347,8 @@
 					$this->capabilities['name_case'] = 'lower';
 					$this->capabilities['client_encoding'] = (float) $db_version >= 7.4;
 					$this->capabilities['outer_join'] = true;
+					$this->capabilities['case_insensitive_like'] = 'ILIKE';
+					$this->capabilities['require_truncate_varchar'] = true;
 					break;
 
 				case 'mssql':
@@ -975,20 +983,23 @@
 			$currentPassword = $this->Password;
 			$currentDatabase = $this->Database;
 
-			$extra = array();
+			$sqls = array();
 			$set_charset = '';
 			switch ($this->Type)
 			{
 				case 'pgsql':
 					$meta_db = 'template1';
+					$sqls[] = "CREATE DATABASE $currentDatabase";
 					break;
 				case 'mysql':
+					$create = "CREATE DATABASE `$currentDatabase`";
 					if ($charset && isset($this->Link_ID->charset2mysql[$charset]) && (float) $this->ServerInfo['version'] >= 4.1)
 					{
-						$set_charset = ' DEFAULT CHARACTER SET '.$this->Link_ID->charset2mysql[$charset].';';
+						$create .= ' DEFAULT CHARACTER SET '.$this->Link_ID->charset2mysql[$charset].';';
 					}
+					$sqls[] = $create;
+					$sqls[] = "GRANT ALL ON `$currentDatabase`.* TO $currentUser@localhost IDENTIFIED BY ".$this->quote($currentPassword);
 					$meta_db = 'mysql';
-					$extra[] = "GRANT ALL ON $currentDatabase.* TO $currentUser@localhost IDENTIFIED BY '$currentPassword'";
 					break;
 				default:
 					echo "<p>db::create_database(user='$adminname',\$pw) not yet implemented for DB-type '$this->Type'</p>\n";
@@ -1001,10 +1012,9 @@
 				$this->Database = $meta_db;
 			}
 			$this->disconnect();
-			$this->query('CREATE DATABASE '.$currentDatabase.$set_charset);
-			foreach($extra as $sql)
+			foreach($sqls as $sql)
 			{
-				$this->query($sql);
+				$this->query($sql,__LINE__,__FILE__);
 			}
 			$this->disconnect();
 
@@ -1134,11 +1144,12 @@
 		* Int and Auto types are casted to int: quote('1','int') === 1, quote('','int') === 0, quote('Hello','int') === 0
 		*
 		* @param mixed $value the value to be escaped
-		* @param string/boolean $type string the type of the db-column, default False === varchar
-		* @param boolean $not_null is column NOT NULL, default true, else php null values are written as SQL NULL
+		* @param string/boolean $type=false string the type of the db-column, default False === varchar
+		* @param boolean $not_null=true is column NOT NULL, default true, else php null values are written as SQL NULL
+		* @param int $length=null length of the varchar column, to truncate it if the database requires it (eg. Postgres)
 		* @return string escaped sting
 		*/
-		function quote($value,$type=False,$not_null=true)
+		function quote($value,$type=False,$not_null=true,$length=null)
 		{
 			if ($this->Debug) echo "<p>db::quote(".(is_null($value)?'NULL':"'$value'").",'$type','$not_null')</p>\n";
 
@@ -1181,6 +1192,10 @@
 				case 'timestamp':
 					return $this->Link_ID->DBTimeStamp($value);
 			}
+			if (!is_null($length) && strlen($value) > $length)
+			{
+				$value = substr($value,0,$length);
+			}
 			return $this->Link_ID->qstr($value);
 		}
 
@@ -1218,6 +1233,9 @@
 			}
 			if ($this->Debug) echo "<p>db::column_data_implode('$glue',".print_r($array,True).",'$use_key',".print_r($only,True).",<pre>".print_r($column_definitions,True)."</pre>\n";
 
+			// do we need to truncate varchars to their max length (INSERT and UPDATE on Postgres)
+			$truncate_varchar = $glue == ',' && $this->capabilities['require_truncate_varchar'];
+
 			$keys = $values = array();
 			foreach($array as $key => $data)
 			{
@@ -1233,7 +1251,11 @@
 					}
 					$column_type = is_array($column_definitions) ? @$column_definitions[$key]['type'] : False;
 					$not_null = is_array($column_definitions) && isset($column_definitions[$key]['nullable']) ? !$column_definitions[$key]['nullable'] : false;
-
+					
+					if ($truncate_varchar)
+					{
+						$maxlength = $column_definitions[$key]['type'] == 'varchar' ? $column_definitions[$key]['precision'] : null;
+					}
 					if (is_array($data))
 					{
 						$or_null = '';
@@ -1245,7 +1267,7 @@
 								unset($data[$k]);
 								continue;
 							}
-							$data[$k] = $this->quote($v,$column_type,$not_null);
+							$data[$k] = $this->quote($v,$column_type,$not_null,$maxlength);
 						}
 						$values[] = ($or_null?'(':'').(!count($data) ? '' :
 							($use_key===True ? $this->name_quote($key).' IN ' : '') .
@@ -1261,7 +1283,7 @@
 					}
 					else
 					{
-						$values[] = ($use_key===True ? $this->name_quote($key) . '=' : '') . $this->quote($data,$column_type,$not_null);
+						$values[] = ($use_key===True ? $this->name_quote($key) . '=' : '') . $this->quote($data,$column_type,$not_null,$maxlength);
 					}
 				}
 			}
@@ -1633,7 +1655,7 @@
 			$sql = "SELECT $cols FROM $table $join";
 
 			// if we have a where clause, we need to add it together with the WHERE statement, if thats not in the join
-			if ($where) $sql .= strstr($join,"WHERE") ? ' AND ('.$where.')' : ' WHERE '.$where;
+			if ($where) $sql .= (strpos($join,"WHERE")!==false) ? ' AND ('.$where.')' : ' WHERE '.$where;
 
 			if ($append) $sql .= ' '.$append;
 
