@@ -1,22 +1,19 @@
 <?php
-  /**************************************************************************\
-  * eGroupWare - HTML creation class                                         *
-  * http://www.eGroupWare.org                                                *
-  * Written and (c) by Ralf Becker <RalfBecker@outdoor-training.de>          *
-  * --------------------------------------------                             *
-  *  This program is free software; you can redistribute it and/or modify it *
-  *  under the terms of the GNU General Public License as published by the   *
-  *  Free Software Foundation; either version 2 of the License, or (at your  *
-  *  option) any later version.                                              *
-  \**************************************************************************/
-
-  /* $Id: class.html.inc.php 22277 2006-08-18 09:22:30Z ralfbecker $ */
+/**
+ * generates html with methods representing html-tags or higher widgets
+ *
+ * @link http://www.egroupware.org
+ * @author Ralf Becker <RalfBecker-AT-outdoor-training.de> complete rewrite in 6/2006 and earlier modifications
+ * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+ * @version $Id: class.html.inc.php 25282 2008-04-15 19:02:25Z ralfbecker $
+ */
 
 /**
  * generates html with methods representing html-tags or higher widgets
  *
  * @package api
  * @subpackage html
+ * @access public
  * @author RalfBecker-AT-outdoor-training.de
  * @license GPL
  */
@@ -114,7 +111,7 @@ class html
 	{
 		if (!$this->wz_tooltip_included)
 		{
-			if (!strstr('wz_tooltip',$GLOBALS['egw_info']['flags']['need_footer']))
+			if (strpos($GLOBALS['egw_info']['flags']['need_footer'],'wz_tooltip')===false)
 			{
 				$GLOBALS['egw_info']['flags']['need_footer'] .= '<script language="JavaScript" type="text/javascript" src="'.$this->phpgwapi_js_url.'/wz_tooltip/wz_tooltip.js"></script>'."\n";
 			}
@@ -153,16 +150,16 @@ class html
 			$content);
 
 		//  First match things beginning with http:// (or other protocols)
-		$Protocol = '(http|ftp|https):\/\/';
-		$Domain = '([\w]+.[\w]+)';
+		$Protocol = '(http:\/\/|(ftp:\/\/|https:\/\/))';	// only http:// gets removed, other protocolls are shown
+		$Domain = '([\w-]+\.[\w-.]+)';
 		$Subdir = '([\w\-\.,@?^=%&;:\/~\+#]*[\w\-\@?^=%&\/~\+#])?';
 		$Expr = '/' . $NotAnchor . $Protocol . $Domain . $Subdir . '/i';
 
-		$result = preg_replace( $Expr, "<a href=\"$0\" target=\"_blank\">$2$3</a>", $result );
+		$result = preg_replace( $Expr, "<a href=\"$0\" target=\"_blank\">$2$3$4</a>", $result );
 
 		//  Now match things beginning with www.
 		$NotHTTP = '(?<!:\/\/)';
-		$Domain = 'www(.[\w]+)';
+		$Domain = 'www(\.[\w-.]+)';
 		$Subdir = '([\w\-\.,@?^=%&:\/~\+#]*[\w\-\@?^=%&\/~\+#])?';
 		$Expr = '/' . $NotAnchor . $NotHTTP . $Domain . $Subdir . '/i';
 
@@ -327,8 +324,8 @@ class html
 				$base_name.'['.$val.']','',($title ? 'title="'.$this->htmlspecialchars($title).'" ':''))."<br />\n";
 		}
 		if ($style && substr($style,-1) != ';') $style .= '; ';
-		if (!strstr($style,'height')) $style .= 'height: '.(1.7*$multiple).'em; ';
-		if (!strstr($style,'width'))  $style .= 'width: '.(4+$max_len*($max_len < 15 ? 0.65 : 0.55)).'em; ';
+		if (strpos($style,'height')===false) $style .= 'height: '.(1.7*$multiple).'em; ';
+		if (strpos($style,'width')===false)  $style .= 'width: '.(4+$max_len*($max_len < 15 ? 0.65 : 0.55)).'em; ';
 		$style .= 'background-color: white; overflow: auto; border: lightgray 2px inset;';
 
 		return $this->div($html,$options,'',$style);
@@ -347,15 +344,12 @@ class html
 	{
 		// the following compares strict as strings, to archive: '0' == 0 != ''
 		// the first non-strict search via array_search, is for performance reasons, to not always search the whole array with php
-		if (($found = ($key = array_search($value,$selected)) !== false) && !$value)
+		if (($found = ($key = array_search($value,$selected)) !== false) && (string) $value !== (string) $selected[$key])
 		{
-			if ((string) $value !== (string) $selected[$key])
+			$found = false;
+			foreach($selected as $sel)
 			{
-				$found = false;
-				foreach($selected as $sel)
-				{
-					if ($found = ((string) $value === (string) $selected[$key])) break;
-				}
+				if ($found = (((string) $value) === ((string) $selected[$key]))) break;
 			}
 		}
 		return '<option value="'.$this->htmlspecialchars($value).'"'.($found  ? ' selected="selected"' : '') .
@@ -428,149 +422,145 @@ class html
 	 */
 	function htmlarea_availible()
 	{
-		switch($this->user_agent)
-		{
-			case 'msie':
-				return $this->ua_version >= 5.5;
-			case 'mozilla':
-				return $this->ua_version >= 1.3;
-			default:
-				return False;
-		}
+		require_once(EGW_INCLUDE_ROOT.'/phpgwapi/js/fckeditor/fckeditor.php');
+
+		// use FCKeditor's own check
+		return FCKeditor_IsCompatibleBrowser();
 	}
 
 	/**
-	 * compability function for former used htmlarea. Please use function tinymce now!
+	 * compability function for former used htmlarea. Please use function fckeditor now!
 	 *
 	 * creates a textarea inputfield for the htmlarea js-widget (returns the necessary html and js)
 	 */
 	function htmlarea($name,$content='',$style='',$base_href='',$plugins='',$custom_toolbar='',$set_width_height_in_config=false)
 	{
-		if (!$plugins) $plugins = 'ColorChooser,FontChooser,ContexMenu,TableOperations';
-		return  $this->tinymce($name,$content,$style,$plugins,$base_href);
-	}
-
-	/**
-	* init the tinymce js-widget by adding the js file in the head of the page
-	*
-	* Please note: it need to be called before the call to phpgw_header() !!!
-	*
-	*/
-	function init_tinymce()
-	{
-	   /* do stuff once */
-	   if (!is_object($GLOBALS['egw']->js))
-	   {
-		  $GLOBALS['egw']->js = CreateObject('phpgwapi.javascript');
-	   }
-
-	   if (!strstr($GLOBALS['egw_info']['flags']['java_script'],'tinyMCE'))
-	   {
-		  $GLOBALS['egw']->js->validate_file('tinymce','jscripts/tiny_mce/tiny_mce');
-	   }
-	}
-
-	/**
-	* creates a textarea inputfield for the tinymce js-widget (returns the necessary html and js)
-	*
-	* Please note: if you did not run init_tinymce already you this function need to be called before the call to phpgw_header() !!!
-	*
-	* @param string $name name and id of the input-field
-	* @param string $content='' of the tinymce (will be run through htmlspecialchars !!!), default ''
-	* @param string $style='' initial css for the style attribute
-	* @param string $init_options='', see http://tinymce.moxiecode.com/ for all init options. mode and elements are allready set.
-	*                                 to make things more easy, you also can just provide a comma seperated list here with the options you need.
-	*                                 Supportet are: 'TableOperations','ContextMenu','ColorChooser'
-	* @return string the necessary html for the textarea
-	* @todo make wrapper for backwards compatibility with htmlarea
-	* @todo enable all features from htmlarea
-	*/
-	function tinymce($name,$content='',$style='',$init_options='',$base_href='')
-	{
-		if (!$style)
-		{
-			$style = 'width:100%; min-width:500px; height:300px;';
-		}
 		if (!$this->htmlarea_availible())
 		{
 			return $this->textarea($name,$content,'style="'.$style.'"');
 		}
+		return $this->fckEditor($name, $content, 'extended', array('toolbar_expanded' =>'true'), '400px', '100%', $base_href);
+	}
 
-		/* do stuff once */
-		$this->init_tinymce();
-
-		if(strpos($init_options,':') === false)
+	/**
+	* this function is a wrapper for fckEditor to create some reuseable layouts
+	*
+	* @param string $_name name and id of the input-field
+	* @param string $_content of the tinymce (will be run through htmlspecialchars !!!), default ''
+	* @param string $_mode display mode of the tinymce editor can be: simple, extended or advanced
+	* @param array  $_options (toolbar_expanded true/false)
+	* @param string $_height='400px'
+	* @param string $_width='100%'
+	* @param string $base_href='' if passed activates the browser for image at absolute path passed
+	* @return string the necessary html for the textarea
+	*/
+	function fckEditor($_name, $_content, $_mode, $_options=array('toolbar_expanded' =>'true'), $_height='400px', $_width='100%',$_base_href='')
+	{
+		if (!$this->htmlarea_availible() || $_mode == 'ascii')
 		{
-			$init = 'theme : "advanced", theme_advanced_toolbar_location : "top", theme_advanced_toolbar_align : "left"';
-			$tab1a = 'theme_advanced_buttons1_add : "';
-			$tab2a = 'theme_advanced_buttons2_add : "';
-			$tab3a = 'theme_advanced_buttons3_add : "separator,fullscreen';
-			$plugs = 'plugins : "paste,fullscreen,advimage,advlink';
-			$eve = 'extended_valid_elements : "a[name|href|target|title|onclick], img[class|src|border=0|alt|title|hspace|vspace|width|height|align|onmouseover|onmouseout|name],font[*]';
-			if($init_options)
-			{
-				foreach(explode(',',$init_options) as $plugin)
-				{
-					switch($plugin)
-					{
-						case 'TableOperations' :
-							$plugs .= ',table';
-							$tab3a .= ',separator,tablecontrols';
-							break;
-						case 'ContextMenu' :
-							$plugs .= ',contextmenu';
-							break;
-						case 'ColorChooser' :
-							$tab3a .= ',separator,forecolor,backcolor';
-							break;
-						case 'FontChooser' :
-							$tab1a .= ',fontselect,fontsizeselect';
-							$init .= ',theme_advanced_disable : "styleselect"';
-							break;
-						case 'FileManager' :
-							$plugs .= ',filemanager';
-							$tab3a .= ',separator,filemanager';
-							break;
-						case 'SearchReplace' :
-							$plugs .= ',searchreplace';
-							$tab1a .= ',separator,search,replace';
-							break;
-						case 'InsertDateTime' :
-							$plugs .= ',insertdatetime';
-							$tab2a .= ',separator,insertdate,inserttime';
-							break;
-						default:
-							if(strstr($plugin,'='))
-							{
-								$init .= ','. str_replace('=',':',$plugin);
-							}
-					}
-				}
-			}
-			if($base_href)
-			{
-				$init .= ',document_base_url : "'. $base_href. '", relative_urls : true';
-			}
+			return $this->textarea($_name,$_content,'style="width: '.$_width.'; height: '.$_height.';"');
+		}
+		include_once(EGW_INCLUDE_ROOT."/phpgwapi/js/fckeditor/fckeditor.php");
 
-			$init_options = $init. ','. $tab1a. '",'. $tab2a. '",'. $tab3a. '",'. $plugs. '",'. $eve. '"';
+		$oFCKeditor = new FCKeditor($_name) ;
+		$oFCKeditor->BasePath	= $GLOBALS['egw_info']['server']['webserver_url'].'/phpgwapi/js/fckeditor/' ;
+		$oFCKeditor->Config['CustomConfigurationsPath'] = $oFCKeditor->BasePath . 'fckeditor.egwconfig.js' ;
+		$oFCKeditor->Value	= $_content;
+		$oFCKeditor->Width	= str_replace('px','',$_width);	// FCK adds px if width contains no %
+		$oFCKeditor->Height	= str_replace('px','',$_height);
+
+		// by default switch all browsers and uploads off
+		$oFCKeditor->Config['LinkBrowser'] = $oFCKeditor->Config['LinkUpload'] = false;
+		$oFCKeditor->Config['FlashBrowser'] = $oFCKeditor->Config['FlashUpload'] = false;
+		$oFCKeditor->Config['ImageBrowser'] = $oFCKeditor->Config['ImageUpload'] = false;
+
+		// Activate the image browser+upload, if $_base_href exists and is browsable by the webserver
+		if ($_base_href && is_dir($_SERVER['DOCUMENT_ROOT'].$_base_href) && file_exists($_SERVER['DOCUMENT_ROOT'].$_base_href.'/.'))
+		{
+			// Only images for now
+			if (substr($_base_href,-1) != '/') $_base_href .= '/' ;
+			// store the path and application in the session, to make sure it can't be called with arbitrary pathes
+			$GLOBALS['egw']->session->appsession($_base_href,'FCKeditor',$GLOBALS['egw_info']['flags']['currentapp']);
+
+			$oFCKeditor->Config['ImageBrowserURL'] = $oFCKeditor->BasePath.'editor/filemanager/browser/default/browser.html?ServerPath='.$_base_href.'&Type=Image&Connector='.$oFCKeditor->BasePath.'editor/filemanager/connectors/php/connector.php';
+			$oFCKeditor->Config['ImageBrowser'] = true;
+			$oFCKeditor->Config['ImageUpload'] = is_writable($_SERVER['DOCUMENT_ROOT'].$_base_href);
+		}
+		// By default the editor start expanded
+		if ($_options['toolbar_expanded'] == 'false')
+		{
+			$oFCKeditor->Config['ToolbarStartExpanded'] = $_options['toolbar_expanded'];
+		}
+		// switching the encoding as html entities off, as we correctly handle charsets and it messes up the wiki totally
+		$oFCKeditor->Config['ProcessHTMLEntities'] = false;
+		// Now setting the admin settings
+		$spell = '';
+		if (isset($GLOBALS['egw_info']['server']['enabled_spellcheck']))
+		{
+			$spell = '_spellcheck';
+			$oFCKeditor->Config['SpellChecker'] = 'SpellerPages';
+			$oFCKeditor->Config['SpellerPagesServerScript'] = 'server-scripts/spellchecker.php?enabled=1';
+			if (isset($GLOBALS['egw_info']['server']['aspell_path']))
+			{
+				$oFCKeditor->Config['SpellerPagesServerScript'] .= '&aspell_path='.$GLOBALS['egw_info']['server']['aspell_path'];
+			}
+			if (isset($GLOBALS['egw_info']['user']['preferences']['common']['spellchecker_lang']))
+			{
+				$oFCKeditor->Config['SpellerPagesServerScript'] .= '&spellchecker_lang='.$GLOBALS['egw_info']['user']['preferences']['common']['spellchecker_lang'];
+			}
+			else
+			{
+				$oFCKeditor->Config['SpellerPagesServerScript'] .= '&spellchecker_lang='.$GLOBALS['egw_info']['user']['preferences']['common']['lang'];
+			}
+			$oFCKeditor->Config['FirefoxSpellChecker'] = false;
+		}
+		// Now setting the user preferences
+		if (isset($GLOBALS['egw_info']['user']['preferences']['common']['rte_enter_mode']))
+		{
+			$oFCKeditor->Config['EnterMode'] = $GLOBALS['egw_info']['user']['preferences']['common']['rte_enter_mode'];
+		}
+		if (isset($GLOBALS['egw_info']['user']['preferences']['common']['rte_skin']))
+		{
+			$oFCKeditor->Config['SkinPath'] = $oFCKeditor->BasePath.'editor/skins/'.$GLOBALS['egw_info']['user']['preferences']['common']['rte_skin'].'/';
 		}
 
-		/* do again and again */
-		return '<script language="javascript" type="text/javascript">
-			tinyMCE.init({
-			 mode : "exact",
- 			 language: "'.$GLOBALS['egw_info']['user']['preferences']['common']['lang'].'",
-			 plugin_insertdate_dateFormat : "'.str_replace(array('Y','m','M','d'),array('%Y','%m','%b','%d'),$GLOBALS['egw_info']['user']['preferences']['common']['dateformat']).' ",
-			 plugin_insertdate_timeFormat : "'.($GLOBALS['egw_info']['user']['preferences']['common']['timeformat'] == 12 ? '%I:%M %p' : '%H:%M').' ",
-			 elements : "'.$name.'",
-			 '.$init_options.'
-			});
-			</script>
+		switch($_mode) {
+			case 'simple':
+				$oFCKeditor->ToolbarSet = 'egw_simple'.$spell;
+				$oFCKeditor->Config['ContextMenu'] = false;
+				break;
 
-			<textarea id="'.$name.'" name="'.$name.'" style="'.$style.'">
-				'.@htmlspecialchars($content,ENT_COMPAT,$this->charset).'
-			</textarea>
-			';
+			default:
+			case 'extended':
+				$oFCKeditor->ToolbarSet = 'egw_extended'.$spell;
+				break;
+
+			case 'advanced':
+				$oFCKeditor->ToolbarSet = 'egw_advanced'.$spell;
+				break;
+		}
+		return $oFCKeditor->CreateHTML();
+	}
+
+	/**
+	* this function is a wrapper for tinymce to create some reuseable layouts
+	*
+	* Please note: if you did not run init_tinymce already you this function need to be called before the call to phpgw_header() !!!
+	*
+	* @param string $_name name and id of the input-field
+	* @param string $_mode display mode of the tinymce editor can be: simple, extended or advanced
+	* @param string $_content='' of the tinymce (will be run through htmlspecialchars !!!), default ''
+	* @param string $style='' initial css for the style attribute
+	* @param string $base_href=''
+	* @return string the necessary html for the textarea
+	*/
+	function fckEditorQuick($_name, $_mode, $_content='', $_height='400px', $_width='100%')
+	{
+		if (!$this->htmlarea_availible() || $_mode == 'ascii')
+		{
+			return "<textarea name=\"$_name\" style=\"width:100%; height:400px; border:0px;\">$_content</textarea>";
+		}
+		return $this->fckEditor($_name, $_content, $_mode, array(), $_height, $_width);
 	}
 
 	/**
@@ -591,7 +581,7 @@ class html
 	}
 
 	/**
-	 * represents html's button (input type submit or image)
+	 * represents html's button (input type submit or input type button or image)
 	 *
 	 * @param string $name name
 	 * @param string $label label of the button
@@ -600,14 +590,15 @@ class html
 	 * @param string $options attributes for the tag, default ''=none
 	 * @param string $image to show instead of the label, default ''=none
 	 * @param string $app app to search the image in
+	 * @param string $buttontype which type of html button (button|submit), default ='submit'
 	 * @return string html
 	 */
-	function submit_button($name,$label,$onClick='',$no_lang=false,$options='',$image='',$app='phpgwapi')
+	function submit_button($name,$label,$onClick='',$no_lang=false,$options='',$image='',$app='phpgwapi', $buttontype='submit')
 	{
 		// workaround for idots and IE button problem (wrong cursor-image)
 		if ($this->user_agent == 'msie')
 		{
-			$options .= ' style="cursor: pointer; cursor: hand;"';
+			$options .= ' style="cursor: pointer;"';
 		}
 		if ($image != '')
 		{
@@ -623,8 +614,8 @@ class html
 		{
 			$label = lang($label);
 		}
-		if (($accesskey = strstr($label,'&')) && $accesskey[1] != ' ' &&
-			(($pos = strpos($accesskey,';')) === False || $pos > 5))
+		if (($accesskey = @strstr($label,'&')) && $accesskey[1] != ' ' &&
+			(($pos = strpos($accesskey,';')) === false || $pos > 5))
 		{
 			$label_u = str_replace('&'.$accesskey[1],'<u>'.$accesskey[1].'</u>',$label);
 			$label = str_replace('&','',$label);
@@ -639,10 +630,10 @@ class html
 
 		// <button> is not working in all cases if ($this->user_agent == 'mozilla' && $this->ua_version < 5 || $image)
 		{
-			return $this->input($name,$label,$image != '' ? 'image' : 'submit',$options.$image);
+			return $this->input($name,$label,$image != '' ? 'image' : $buttontype,$options.$image);
 		}
-		return '<button type="submit" name="'.$name.'" value="'.$label.'" '.$options.' />'.
-			($image != '' ? "<img$image $this->prefered_img_title=\"$label\"> " : '').
+		return '<button type="'.$buttontype.'" name="'.$name.'" value="'.$label.'" '.$options.' />'.
+			($image != '' ? /*$this->image($app,$image,$label,$options)*/"<img$image $this->prefered_img_title=\"$label\"> " : '').
 			($image == '' || $accesskey ? $label_u : '').'</button>';
 	}
 
@@ -833,7 +824,7 @@ class html
 		}
 		return '<div class="onlyPrint">'.$title.'</div><div class="noPrint" title="'.$title.'" '.$options.
 			' style="height: '.$height.'; width: '.$width.'; border: 1px solid black; padding: 1px; text-align: left;'.
-			(stristr($options,'onclick="') ? ' cursor: pointer; cursor: hand;' : '').'">'."\n\t".
+			(@stristr($options,'onclick="') ? ' cursor: pointer;' : '').'">'."\n\t".
 			'<div style="height: '.$height.'; width: '.$percent.'%; background: '.$color.';"></div>'."\n</div>\n";
 	}
 
@@ -883,13 +874,14 @@ class html
 			if($GLOBALS['egw_info']['server']['webserver_url'])
 			{
 				list(,$path) = explode($GLOBALS['egw_info']['server']['webserver_url'],$url);
-				
+
 				if (!is_null($path)) $path = EGW_SERVER_ROOT.$path;
 			}
 			else
 			{
 				$path = EGW_SERVER_ROOT.$url;
 			}
+
 			if (is_null($path) || !@is_readable($path))
 			{
 				// if the image-name is a percentage, use a progressbar
@@ -904,6 +896,19 @@ class html
 		{
 			$options .= " $this->prefered_img_title=\"".$this->htmlspecialchars($title).'"';
 		}
+		if ($this->user_agent == 'msie' && $this->ua_version >= 5.5 && substr($url,-4) == '.png')
+		{
+			$extra_styles = "display: inline-block; filter:progid:DXImageTransform.Microsoft.AlphaImageLoader(src='$url',sizingMethod='image'); width: 1px; height: 1px;";
+			if (false!==strpos($options,'style="'))
+			{
+				$options = str_replace('style="','style="'.$extra_styles, $options);
+			}
+			else
+			{
+				$options .= ' style="'.$extra_styles.'"';
+			}
+			return "<span $options></span>";
+		}
 		return "<img src=\"$url\" $options />";
 	}
 
@@ -918,17 +923,25 @@ class html
 	 */
 	function a_href( $content,$url,$vars='',$options='')
 	{
-		if (!strstr($url,'/') && count(explode('.',$url)) == 3)
-		{
-			$url = "/index.php?menuaction=$url";
-		}
 		if (is_array($url))
 		{
 			$vars = $url;
 			$url = '/index.php';
 		}
+		elseif (strpos($url,'/')===false &&
+			count(explode('.',$url)) >= 3 &&
+			!(strpos($url,'mailto:')!==false ||
+			strpos($url,'://')!==false ||
+			strpos($url,'javascript:')!==false))
+		{
+			$url = "/index.php?menuaction=$url";
+		}
+		if ($url{0} == '/')		// link relative to eGW
+		{
+			$url = $this->link($url,$vars);
+		}
 		//echo "<p>html::a_href('".htmlspecialchars($content)."','$url',".print_r($vars,True).") = ".$this->link($url,$vars)."</p>";
-		return '<a href="'.$this->link($url,$vars).'" '.$options.'>'.$content.'</a>';
+		return '<a href="'.$url.'" '.$options.'>'.$content.'</a>';
 	}
 
 	/**
@@ -1067,7 +1080,7 @@ class html
 		}
 		return $html;
 	}
-	
+
 	/**
 	* tree widget using dhtmlXtree
 	*
@@ -1083,13 +1096,17 @@ class html
 	* @param string $_leafImage='' default image of a leaf-node, ''=default of foldertree, set it eg. 'folderClosed.gif' to show leafs as folders
 	* @param boolean/string $_onCheckHandler=false string with handler-name to display a checkbox for each folder, or false (default)
 	* @param string $delimiter='/' path-delimiter, default /
+	* @param mixed $folderImageDir=null string path to the tree menu images, null uses default path
 	*
 	* @return string the html code, to be added into the template
 	*/
-	function tree($_folders,$_selected,$_topFolder=false,$_onNodeSelect="null",$_divId='foldertree',$_divClass='',$_leafImage='',$_onCheckHandler=false,$delimiter='/')
+	function tree($_folders,$_selected,$_topFolder=false,$_onNodeSelect="null",$_divId='foldertree',$_divClass='',$_leafImage='',$_onCheckHandler=false,$delimiter='/',$folderImageDir=null)
 	{
-		$folderImageDir = $GLOBALS['egw_info']['server']['webserver_url'].'/phpgwapi/templates/default/images/';
-		
+	   if(is_null($folderImageDir))
+	   {
+		  $folderImageDir = $GLOBALS['egw_info']['server']['webserver_url'].'/phpgwapi/templates/default/images/';
+	   }
+
 		$html = $this->div("\n",'id="'.$_divId.'"',$_divClass);
 
 		static $tree_initialised=false;
@@ -1109,7 +1126,7 @@ class html
 			$html .= "tree.enableCheckBoxes(1);\n";
 			$html .= "tree.setOnCheckHandler('$_onCheckHandler');\n";
 		}
-		
+
 		$top = 0;
 		if ($_topFolder)
 		{
@@ -1126,7 +1143,7 @@ class html
 			else
 			{
 				$label = $_topFolder;
-			}	
+			}
 			$html .= "\ntree.insertNewItem(0,'$top','".addslashes($label)."',$_onNodeSelect,'$topImage','$topImage','$topImage','CHILD,TOP');\n";
 
 			if (is_array($_topFolder) && isset($_topFolder['title']))
@@ -1150,15 +1167,15 @@ class html
 			// evtl. remove leading delimiter
 			if ($path{0} == $delimiter) $path = substr($path,1);
 			$folderParts = explode($delimiter,$path);
-			
+
 			//get rightmost folderpart
 			$label = array_pop($folderParts);
 			if (isset($data['label'])) $label = $data['label'];
-			
+
 			// the rest of the array is the name of the parent
 			$parentName = implode((array)$folderParts,$delimiter);
 			if(empty($parentName)) $parentName = $top;
-			
+
 			$entryOptions = 'CHILD,CHECKED';
 			// highlight currently item
 			if ($_selected === $path)
@@ -1179,7 +1196,25 @@ class html
 		$html .= "tree.closeAllItems(0);\n";
 		$html .= "tree.openItem('".($_selected ? addslashes($_selected) : $top)."');\n";
 		$html .= "</script>\n";
-		
+
 		return $html;
 	}
+
+	/**
+	 * html-class singleton, return a referenze to the global instanciated html object in $GLOBALS['egw']->html
+	 *
+	 * Please use that static method in all new code, instead of instanciating an own html object:
+	 * 	$my_html =& html::singleton();
+	 *
+	 * @static
+	 * @return html
+	 */
+	function &singleton()
+	{
+		if (!is_object($GLOBALS['egw']->html))
+		{
+			$GLOBALS['egw']->html = new html;
+		}
+		return $GLOBALS['egw']->html;
+	}
 }
