@@ -11,7 +11,7 @@
   * option) any later version.                                               *
   \**************************************************************************/
 
-  /* $Id: class.http.inc.php 15134 2004-05-05 12:06:13Z reinerj $ */
+  /* $Id: class.http.inc.php 24475 2007-09-29 09:19:44Z ralfbecker $ */
 
 	class http
 	{
@@ -286,7 +286,7 @@
 			}
 			if(($success = $this->PutLine($this->request_method.' '.$request_uri.' HTTP/'.$this->protocol_version)))
 			{
-				if(($body_length = strlen($request_body)))
+				if(($body_length = bytes($request_body)))
 				{
 					$headers['Content-length'] = $body_length;
 				}
