@@ -322,13 +322,14 @@
 
 			# Split it
 			$attrarr = $this->_hair($attr);
-
+			
 			# Go through $attrarr, and save the allowed attributes for this element
 			# in $attr2
 			$attr2 = '';
 			foreach ($attrarr as $arreach)
 			{
 				$current = $this->allowed_html[strtolower($element)][strtolower($arreach['name'])];
+
 				if ($current == '')
 				{
 					# the attribute is not allowed
@@ -512,13 +513,17 @@
 		###############################################################################
 		function _bad_protocol_once($string)
 		{
-			return preg_replace(
-				'/^((&[^;]*;|[\sA-Za-z0-9])*)'.
-				'(:|&#58;|&#[Xx]3[Aa];)\s*/e',
-				'\$this->_bad_protocol_once2("\\1")',
-				$string
-			);
-			return $string;
+			$string2 = preg_split('/:|&#58;|&#x3a;/i', $string, 2);
+			if(isset($string2[1]) && !preg_match('%/\?%',$string2[0]))
+			{
+				return $this->_bad_protocol_once2($string2[0]).trim($string2[1]);
+			} else {
+				if (!isset($string2[1]))
+				{
+					return $string2[0];
+				}
+ 			}
+			return '';
 		} # function _bad_protocol_once
 
 
@@ -561,7 +566,7 @@
 		function _check_attr_val($value, $vless, $checkname, $checkvalue)
 		{
 			$ok = true;
-
+			
 			switch (strtolower($checkname))
 			{
 				# The maxlen check makes sure that the attribute value has a length not
@@ -623,6 +628,14 @@
 				}
 				break;
 
+				# The minval check checks that the attribute value is a positive integer,
+				# and that it is not smaller than the given value.
+				case 'match':
+					if (!preg_match($checkvalue, $value)) {
+						$ok = false;
+					}
+					break;
+
 			} # switch
 
 			return $ok;
@@ -668,4 +681,4 @@
 			return '0.0.2 (OOP fork of kses 0.2.1)';
 		} # function _version
 	}
-?>
\ No newline at end of file
+?>
