@@ -21,7 +21,7 @@
   * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
   \**************************************************************************/
 
-  /* $Id: class.network.inc.php 20295 2006-02-15 12:31:25Z  $ */
+  /* $Id: class.network.inc.php 23741 2007-04-30 10:29:44Z lkneschke $ */
 
 	class network
 	{
@@ -185,7 +185,7 @@
 		function gethttpsocketfile($file,$user='',$passwd='',$string=False)
 		{
 			$server = str_replace('http://','',$file);
-			$file = strstr($server,'/');
+			$file = @strstr($server,'/');
 			$server = str_replace($file,'',$server);
 
 			//allows for access to http-auth pages - added by Dave Hall <dave.hall@mbox.com.au>
