@@ -22,7 +22,7 @@
 	* along with this library; if not, write to the Free Software Foundation,  *
 	* Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
 	\**************************************************************************/
-	/* $Id: class.nextmatchs.inc.php 22380 2006-08-30 13:21:31Z ralfbecker $ */
+	/* $Id: class.nextmatchs.inc.php 24717 2007-11-27 17:23:40Z pbf $ */
 	/* $Source$ */
 
 	/*!
@@ -177,7 +177,7 @@
 				'lang_all'      => lang('All'),
 				'lang_select'   => lang('Select'),
 				'cat_field'     => $cat_field,
-				'categories'    => $GLOBALS['egw']->categories->formated_list('select','all',$cat_id,'True'),
+				'categories'    => $GLOBALS['egw']->categories->formatted_list('select','all',$cat_id,'True'),
 				'hidden'       => $GLOBALS['egw']->html->input_hidden(array(
 					'filter' => $this->_filter,
 					'qfield' => $this->_qfield,
@@ -363,7 +363,7 @@
 				'lang_all'      => lang('All'),
 				'lang_select'   => lang('Select'),
 				'cat_field'     => $cat_field,
-				'categories'    => $GLOBALS['egw']->categories->formated_list('select','all',(int)$cat_id,'True'),
+				'categories'    => $GLOBALS['egw']->categories->formatted_list('select','all',(int)$cat_id,'True'),
 				'hidden'       => $GLOBALS['egw']->html->input_hidden(array(
 					'filter' => $this->_filter,
 					'qfield' => $this->_qfield,
@@ -399,7 +399,7 @@
 
 			// If they place a '"' in their search, it will mess everything up
 			// Our only option is to remove it
-			if(strstr($_query,'"'))
+			if(strpos($_query,'"')!==false)
 			{
 				$_query = str_replace('"','',$_query);
 			}
@@ -610,14 +610,18 @@
 			{
 				$currentcolor = @$GLOBALS['tr_color'];
 			}
-
-			if ($currentcolor == $GLOBALS['egw_info']['theme']['row_on'])
+			// this is for old apps relying on the old themes
+			$row_on_color = '" class="row_on';
+			$row_off_color = '" class="row_off';
+			if ($currentcolor == $row_on_color)
 			{
-				$GLOBALS['tr_color'] = $GLOBALS['egw_info']['theme'][$class='row_off'];
+				$GLOBALS['tr_color'] = $row_off_color;
+				$class='row_off';
 			}
 			else
 			{
-				$GLOBALS['tr_color'] = $GLOBALS['egw_info']['theme'][$class='row_on'];
+				$GLOBALS['tr_color'] = $row_on_color;
+				$class='row_on';
 			}
 
 			return $do_class ? $class : $GLOBALS['tr_color'];
