@@ -21,7 +21,7 @@
   * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
   \**************************************************************************/
 
-  /* $Id: class.portalbox.inc.php 15134 2004-05-05 12:06:13Z reinerj $ */
+  /* $Id: class.portalbox.inc.php 23060 2006-12-17 11:45:09Z ralfbecker $ */
 
 	class portalbox
 	{
@@ -72,6 +72,7 @@
 			if ($var=='' || !isset($this->$var))
 			{
 				echo 'Programming Error: '.$this->getvar('classname').'->getvar('.$var.')!<br>'."\n";
+				echo function_backtrace(1);
 				$GLOBALS['phpgw']->common->phpgw_exit();
 			}
 			//echo "Var = ".$var."<br>\n";
@@ -109,14 +110,9 @@
 			$this->p->set_block('PORTAL','link_field','link_field');
 
 			$var = Array(
-				'outer_border'	=> $this->getvar('outerborderwidth'),
 				'outer_width'	=> $this->getvar('width'),
-				'outer_bordercolor'	=> $this->getvar('outerbordercolor'),
-				'outer_bgcolor'	=> $this->getvar('titlebgcolor'),
 				'title'	=> $this->getvar('title'),
 				'inner_width'	=> $this->getvar('width'),
-				'inner_bgcolor'	=> $this->getvar('innerbgcolor'),
-				'header_background_image'	=> $this->getvar('header_background_image'),
 				'control_link'	=> ''
 			);
 			$this->p->set_var($var);
