@@ -22,7 +22,7 @@
 	* Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
 	\**************************************************************************/
 
-	/* $Id: class.preferences.inc.php 20947 2006-04-05 15:20:26Z ralfbecker $ */
+	/* $Id: class.preferences.inc.php 23097 2006-12-21 14:10:59Z ralfbecker $ */
 
 	/**
 	 * preferences class used for setting application preferences
@@ -193,7 +193,7 @@
 			{
 				foreach($data as $key => $val)
 				{
-					if (!is_array($val) && strstr($val,'$$') !== False)
+					if (!is_array($val) && strpos($val,'$$') !== False)
 					{
 						$this->data[$app][$key] = $this->parse_notify($val);
 					}
@@ -201,7 +201,7 @@
 					{
 						foreach($val as $k => $v)
 						{
-							if (!is_array($v) && strstr($val,'$$') !== False)
+							if (!is_array($v) && strpos($v,'$$') !== False)
 							{
 								$this->data[$app][$key][$k] = $this->parse_notify($v);
 							}
@@ -557,10 +557,11 @@
 		 * User prefs for saveing are in $this->user not in $this->data, which are the effectiv prefs only!
 		 *
 		 * @param boolean $update_session_info=false old param, seems not to be used
-		 * @param string $type='user' which prefs to update: user/default/forced 
+		 * @param string $type='user' which prefs to update: user/default/forced
+		 * @param boolean $invalid_cache=true should we invalidate the cache, default true
 		 * @return array with new effective prefs (even when forced or default prefs are deleted!)
 		 */
-		function save_repository($update_session_info = False,$type='user')
+		function save_repository($update_session_info = False,$type='user',$invalid_cache=true)
 		{
 			switch($type)
 			{
@@ -606,7 +607,7 @@
 				$GLOBALS['egw_info']['user']['preferences'] = $this->data;
 				$GLOBALS['egw']->session->save_repositories();
 			}
-			if (method_exists($GLOBALS['egw'],'invalidate_session_cache'))	// egw object in setup is limited
+			if ($invalid_cache && method_exists($GLOBALS['egw'],'invalidate_session_cache'))	// egw object in setup is limited
 			{
 				$GLOBALS['egw']->invalidate_session_cache();	// in case with cache the egw_info array in the session
 			}
@@ -825,7 +826,7 @@
 				return $email;
 			}
 			$prefs_email_address = $GLOBALS['egw']->accounts->id2name($account_id);
-			if (strstr($prefs_email_address,'@') === False)
+			if (strpos($prefs_email_address,'@') === False)
 			{
 				$prefs_email_address .= '@' . $GLOBALS['egw_info']['server']['mail_suffix'];
 			}
