@@ -1,142 +1,177 @@
 <?php
-	/**************************************************************************\
-	* eGroupWare API - Session management                                      *
-	* This file written by Dan Kuykendall <seek3r@phpgroupware.org>            *
-	* and Joseph Engo <jengo@phpgroupware.org>                                 *
-	* and Ralf Becker <ralfbecker@outdoor-training.de>                         *
-	* Copyright (C) 2000, 2001 Dan Kuykendall                                  *
-	* Parts Copyright (C) 2003 Free Software Foundation Inc                    *
-	* -------------------------------------------------------------------------*
-	* This library is part of the eGroupWare API                               * 
-	* http://www.egroupware.org/api                                            *  
-	* ------------------------------------------------------------------------ *
-	* This library is free software; you can redistribute it and/or modify it  *
-	* under the terms of the GNU Lesser General Public License as published by *
-	* the Free Software Foundation; either version 2.1 of the License,         *
-	* or any later version.                                                    *
-	* This library is distributed in the hope that it will be useful, but      *
-	* WITHOUT ANY WARRANTY; without even the implied warranty of               *
-	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                     *
-	* See the GNU Lesser General Public License for more details.              *
-	* You should have received a copy of the GNU Lesser General Public License *
-	* along with this library; if not, write to the Free Software Foundation,  *
-	* Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
-	\**************************************************************************/
-
- 	/* $Id: class.sessions.inc.php 21940 2006-06-23 19:14:55Z lkneschke $ */
-
 	/**
-	* Session Management Libabray
+	* eGW's Session Management
 	*
-	* This allows eGroupWare to use php4 or database sessions
+	* This allows eGroupWare to use php or database sessions
 	*
-	* @package api
-	* @subpackage sessions
-	* @author NetUSE AG Boris Erdmann, Kristian Koehntopp <br> hacked on by phpGW
+	* @link www.egroupware.org
+	* @author NetUSE AG Boris Erdmann, Kristian Koehntopp
+	* @author Dan Kuykendall <seek3r@phpgroupware.org>
+	* @author Joseph Engo <jengo@phpgroupware.org>
+	* @author Ralf Becker <ralfbecker@outdoor-training.de>
 	* @copyright &copy; 1998-2000 NetUSE AG Boris Erdmann, Kristian Koehntopp <br> &copy; 2003 FreeSoftware Foundation
 	* @license LGPL
-	* @link http://www.sanisoft.com/phplib/manual/DB_sql.php
+	* @version $Id: class.sessions.inc.php 25118 2008-03-19 20:07:30Z ralfbecker $
 	*/
 
+	/**
+	* eGW's Session Management
+	*
+	* Baseclass for db- and php-sessions
+	* 
+	* @package api
+	* @subpackage sessions
+	*/
 	class sessions_
 	{
 		/**
-		* @var string current user login
+		* current user login (account_lid@domain)
+		* 
+		* @var string
 		*/
 		var $login;
 
 		/**
-		* @var string current user password
+		* current user password
+		* 
+		* @var string
 		*/
 		var $passwd;
 
 		/**
-		* @var int current user db/ldap account id
+		* current user db/ldap account id
+		* 
+		* @var int
 		*/
 		var $account_id;
 
 		/**
-		* @var string current user account login id - ie user@domain
+		* current user account login id (without the eGW-domain/-instance part
+		* 
+		* @var string
 		*/
 		var $account_lid;
 
 		/**
-		* @var string previous page call id - repost prevention
+		* previous page call id - repost prevention, not used in eGW
+		* 
+		* @var string
 		*/
 		var $history_id;
 
 		/**
-		* @var string domain for current user
+		* domain for current user
+		* 
+		* @var string
 		*/
 		var $account_domain;
 
 		/**
-		* @var session type flag, A - anonymous session, N - None, normal session
+		* type flag, A - anonymous session, N - None, normal session
+		* 
+		* @var string
 		*/
 		var $session_flags;
 
 		/**
-		* @var string current user session id
+		* current user session id
+		* 
+		* @var string
 		*/
 		var $sessionid;
 
 		/**
-		* @var string not sure what this does, but it is important :)
+		* an other session specific id (md5 from a random string),
+		* used together with the sessionid for xmlrpc basic auth and the encryption of session-data (if that's enabled)
+		* 
+		* @var string
 		*/
 		var $kp3;
 
 		/**
-		* @var string encryption key?
+		* encryption key for the encrption of the session-data, if enabled
+		* 
+		* @var string
 		*/
 		var $key;
 
 		/**
-		* @var string iv == ivegotnoidea ;) (skwashd)
+		* mcrypt's iv
+		*  
+		* @var string
 		*/
 		var $iv;
 
 		/**
-		* @var session data
+		* session data
+		* 
+		* @var array
 		*/
 		var $data;
         
 		/**
-		* @var object holder for the database object
+		* instance of the database object
+		* 
+		* @var egw_db
 		*/
 		var $db;
 		
 		/**
-		 * @var $access_table name of access-log table
+		 * name of access-log table
+		 * 
+		 * @var string
 		 */
 		var $access_table = 'egw_access_log';
         
 		/**
 		* @var array publicly available methods
 		*/
-		var $public_functions = array(
+/*		var $public_functions = array(
 			'list_methods' => True,
 			'update_dla'   => True,
 			'list'         => True,
 			'total'        => True
-		);
+		);*/
 
 		/**
-		* @var string domain for cookies
+		* domain for cookies
+		* 
+		* @var string
 		*/
 		var $cookie_domain;
+		
+		/**
+		 * path for cookies
+		 * 
+		 * @var string
+		 */
+		var $cookie_path;
 
 		/**
-		* @var name of XML-RPC/SOAP method called
+		* name of XML-RPC/SOAP method called
+		* 
+		* @var string
 		*/
 		var $xmlrpc_method_called;
 
 		/**
-		* @var Array with the name of the system domains
+		* Array with the name of the system domains
+		* 
+		* @var array
 		*/
-		var $phpgw_domains;
+		var $egw_domains;
+		
+		/**
+		 * Write debug messages about session verification to the error_log
+		 *
+		 * @var boolean
+		 */
+		var $errorlog_debug = false;
 
 		/**
 		* Constructor just loads up some defaults from cookies
+		* 
+		* @param $domain_names=null domain-names used in this install
 		*/
 		function sessions_($domain_names=null)
 		{
@@ -145,13 +180,13 @@
 			$this->sessionid = get_var('sessionid',array('GET','COOKIE'));
 			$this->kp3       = get_var('kp3',array('GET','COOKIE'));
 
-			$this->phpgw_domains = $domain_names;
+			$this->egw_domains = $domain_names;
 
 			/* Create the crypto object */
 			$GLOBALS['egw']->crypto =& CreateObject('phpgwapi.crypto');
 			if ($GLOBALS['egw_info']['server']['usecookies'])
 			{
-				$this->phpgw_set_cookiedomain();
+				$this->egw_set_cookiedomain();
 			}
 			// verfiy and if necessary create and save our config settings
 			//
@@ -221,9 +256,16 @@
 			return true;
 		}
 
-		function split_login_domain($both,&$login,&$domain)
+		/**
+		 * Splits a login-name into account_lid and eGW-domain/-instance
+		 *
+		 * @param string $login login-name (ie. user@default)
+		 * @param string &$account_lid returned account_lid (ie. user)
+		 * @param string &$domain returned domain (ie. domain)
+		 */
+		function split_login_domain($login,&$account_lid,&$domain)
 		{
-			$parts = explode('@',$both);
+			$parts = explode('@',$login);
 
 //			var_dump(debug_backtrace());
 			//conference - for strings like vinicius@thyamad.com@default ,
@@ -232,18 +274,18 @@
 			{
 				$probable_domain = array_pop($parts);
 				//Last part of login string, when separated by @, is a domain name
-				if (in_array($probable_domain,$this->phpgw_domains))
+				if (in_array($probable_domain,$this->egw_domains))
 				{
 					$got_login = true;
 					$domain = $probable_domain;
-					$login = implode('@',$parts);
+					$account_lid = implode('@',$parts);
 				}
 			}
 
 			if (!$got_login)
 			{
 				$domain = $GLOBALS['egw_info']['server']['default_domain'];
-				$login = $both;
+				$account_lid = $login;
 			}
 		}
 
@@ -257,7 +299,6 @@
 		function verify($sessionid='',$kp3='')
 		{
 			$fill_egw_info_and_repositories = !$GLOBALS['egw_info']['flags']['restored_from_session'];
-
 			if(empty($sessionid) || !$sessionid)
 			{
 				$sessionid = get_var('sessionid',array('GET','COOKIE'));
@@ -276,12 +317,13 @@
 			*/
 			if ($session['session_dla'] <= (time() - $GLOBALS['egw_info']['server']['sessions_timeout']))
 			{
+				if ($this->errorlog_debug) error_log("*** session::verify('$sessionid') session timed out");
 				$this->destroy($sessionid,$kp3);
 				return False;
 			}
 
 			$this->session_flags = $session['session_flags'];
-
+			
 			$this->split_login_domain($session['session_lid'],$this->account_lid,$this->account_domain);
 
 			/* This is to ensure that we authenticate to the correct domain (might not be default) */
@@ -301,9 +343,10 @@
 			$GLOBALS['egw_info']['user']['kp3'] = $this->kp3;
 
 			$this->update_dla();
-			$this->account_id = $GLOBALS['egw']->accounts->name2id($this->account_lid);
+			$this->account_id = $GLOBALS['egw']->accounts->name2id($this->account_lid,'account_lid','u');
 			if (!$this->account_id)
 			{
+				if ($this->errorlog_debug) error_log("*** session::verify($sessionid) !accounts::name2id('$this->account_lid')");
 				return False;
 			}
 
@@ -321,6 +364,7 @@
 
 			if ($this->user['expires'] != -1 && $this->user['expires'] < time())
 			{
+				if ($this->errorlog_debug) error_log("*** session::verify($sessionid) accounts is expired");
 				if(is_object($GLOBALS['egw']->log))
 				{
 					$GLOBALS['egw']->log->message(array(
@@ -343,6 +387,7 @@
 			}
 			if ($this->account_domain != $GLOBALS['egw_info']['user']['domain'])
 			{
+				if ($this->errorlog_debug) error_log("*** session::verify($sessionid) wrong domain");
 				if(is_object($GLOBALS['egw']->log))
 				{
 					$GLOBALS['egw']->log->message(array(
@@ -359,6 +404,7 @@
 
 			if (@$GLOBALS['egw_info']['server']['sessions_checkip'])
 			{
+				if ($this->errorlog_debug) error_log("*** session::verify($sessionid) wrong IP");
 				if((PHP_OS != 'Windows') && (PHP_OS != 'WINNT') &&
 					(!$GLOBALS['egw_info']['user']['session_ip'] || $GLOBALS['egw_info']['user']['session_ip'] != $this->getuser_ip())
 				)
@@ -388,6 +434,7 @@
 			}
 			if (! $this->account_lid)
 			{
+				if ($this->errorlog_debug) error_log("*** session::verify($sessionid) !account_lid");
 				if(is_object($GLOBALS['egw']->log))
 				{
 					// This needs some better wording
@@ -401,6 +448,24 @@
 				//echo 'DEBUG: Sessions: account_id is empty!<br>'."\n";
 				return False;
 			}
+			/* If User is Anonymous and enters a not allowed application its session will be destroyed inmediatly. */
+			$_current_app=$GLOBALS['egw_info']['flags']['currentapp'];
+			if($this->session_flags=='A' && !$GLOBALS['egw_info']['user']['apps'][$_current_app])
+			{
+				if ($this->errorlog_debug) error_log("*** session::verify($sessionid) anon user entering not allowed app");
+				$this->destroy($sessionid,$kp3);
+				
+				/* Overwrite Cookie with empty user. For 2 weeks */
+				$this->egw_setcookie('sessionid','');
+				$this->egw_setcookie('kp3','');
+				$this->egw_setcookie('domain','');
+				$this->egw_setcookie('last_domain','');
+				$this->egw_setcookie('last_loginid', ''); 
+				
+				return False;
+			}
+			if ($this->errorlog_debug) error_log("--> session::verify($sessionid) SUCCESS");
+
 			return True;
 		}
 
@@ -423,11 +488,18 @@
 		*
 		* @return string domain
 		*/
-		function phpgw_set_cookiedomain()
+		function egw_set_cookiedomain()
 		{
-			// Use HTTP_X_FORWARDED_HOST if set, which is the case behind a none-transparent proxy
-			$this->cookie_domain = isset($_SERVER['HTTP_X_FORWARDED_HOST']) ?  $_SERVER['HTTP_X_FORWARDED_HOST'] : $_SERVER['HTTP_HOST'];
-
+			if ($GLOBALS['egw_info']['server']['cookiedomain'])
+			{
+				// Admin set domain, eg. .domain.com to allow egw.domain.com and www.domain.com
+				$this->cookie_domain = $GLOBALS['egw_info']['server']['cookiedomain'];
+			}
+			else
+			{
+				// Use HTTP_X_FORWARDED_HOST if set, which is the case behind a none-transparent proxy
+				$this->cookie_domain = isset($_SERVER['HTTP_X_FORWARDED_HOST']) ?  $_SERVER['HTTP_X_FORWARDED_HOST'] : $_SERVER['HTTP_HOST'];
+			}
 			// remove port from HTTP_HOST
 			if (preg_match("/^(.*):(.*)$/",$this->cookie_domain,$arr))
 			{
@@ -440,23 +512,47 @@
 			}
 			print_debug('COOKIE_DOMAIN',$this->cookie_domain,'api');
 
-			$this->set_cookie_params($this->cookie_domain);	// for php4 sessions necessary
+			if (!$GLOBALS['egw_info']['server']['cookiepath'])
+			{
+				$this->cookie_path = '/';
+			}
+			else
+			{
+				$url_parts = parse_url($GLOBALS['egw_info']['server']['webserver_url']);
+				if (!($this->cookie_path = $url_parts['path']) ) $this->cookie_path = '/';
+			}
+			//echo "<p>cookie_path='$this->cookie_path', cookie_domain='$this->cookie_domain'</p>\n";
+
+			$this->set_cookie_params($this->cookie_domain,$this->cookie_path);	// for php4 sessions necessary
 		}
 
 		/**
 		* Set a cookie
 		*
 		* @param string $cookiename name of cookie to be set
-		* @param string $cookievalue value to be used, if unset cookie is cleared (optional)
-		* @param int $cookietime when cookie should expire, 0 for session only (optional)
+		* @param string $cookievalue='' value to be used, if unset cookie is cleared (optional)
+		* @param int $cookietime=0 when cookie should expire, 0 for session only (optional)
+		* @param string $cookiepath=null optional path (eg. '/') if the eGW install-dir should not be used
+		*/
+		function egw_setcookie($cookiename,$cookievalue='',$cookietime=0,$cookiepath=null)
+		{
+			if (!$this->cookie_domain || !$this->cookie_path)
+			{
+				$this->egw_set_cookiedomain();
+			}
+			if (is_null($cookiepath)) $cookiepath = $this->cookie_path;
+
+			if ($this->errorlog_debug) error_log("setcookie($cookiename,$cookievalue,$cookietime,$cookiepath,$this->cookie_domain)");
+
+			setcookie($cookiename,$cookievalue,$cookietime,$cookiepath,$this->cookie_domain);
+		}
+
+		/**
+		* @deprecated use egw_setcookie
 		*/
 		function phpgw_setcookie($cookiename,$cookievalue='',$cookietime=0)
 		{
-			if (!$this->cookie_domain)
-			{
-				$this->phpgw_set_cookiedomain();
-			}
-			setcookie($cookiename,$cookievalue,$cookietime,'/',$this->cookie_domain);
+			$this->egw_setcookie($cookiename,$cookievalue,$cookietime);
 		}
 
 		/**
@@ -493,11 +589,20 @@
 			$now = time();
 
 			/* This is to ensure that we authenticate to the correct domain (might not be default) */
-			if($this->account_domain != $GLOBALS['egw_info']['user']['domain'])
+			// if no domain is given we use the default domain, so we dont need to re-create everything
+			if (!$GLOBALS['egw_info']['user']['domain'] && $this->account_domain == $GLOBALS['egw_info']['server']['default_domain'])
+			{
+				$GLOBALS['egw_info']['user']['domain'] = $this->account_domain;
+			}
+			elseif($this->account_domain != $GLOBALS['egw_info']['user']['domain'])
 			{
 				$GLOBALS['egw']->ADOdb = null;
 				$GLOBALS['egw_info']['user']['domain'] = $this->account_domain;
-				// reset the db
+				// reset the db and all other (non-header!) egw_info/server data
+				$GLOBALS['egw_info']['server'] = array(
+					'sessions_type'  => $GLOBALS['egw_info']['server']['sessions_type'],
+					'default_domain' => $GLOBALS['egw_info']['server']['default_domain'],
+				);
 				$GLOBALS['egw_info']['server']['db_host'] = $GLOBALS['egw_domain'][$this->account_domain]['db_host'];
 				$GLOBALS['egw_info']['server']['db_port'] = $GLOBALS['egw_domain'][$this->account_domain]['db_port'];
 				$GLOBALS['egw_info']['server']['db_name'] = $GLOBALS['egw_domain'][$this->account_domain]['db_name'];
@@ -510,7 +615,7 @@
 			//echo "<p>session::create(login='$login'): lid='$this->account_lid', domain='$this->account_domain'</p>\n";
 			$user_ip = $this->getuser_ip();
 
-			$this->account_id = $GLOBALS['egw']->accounts->name2id($this->account_lid);
+			$this->account_id = $GLOBALS['egw']->accounts->name2id($this->account_lid,'account_lid','u');
 
 			if (($blocked = $this->login_blocked($login,$user_ip)) ||	// too many unsuccessful attempts
 				$GLOBALS['egw_info']['server']['global_denied_users'][$this->account_lid] ||
@@ -540,14 +645,14 @@
 
 			if ($GLOBALS['egw_info']['server']['usecookies'])
 			{
-				$this->phpgw_setcookie('sessionid',$this->sessionid);
-				$this->phpgw_setcookie('kp3',$this->kp3);
-				$this->phpgw_setcookie('domain',$this->account_domain);
+				$this->egw_setcookie('sessionid',$this->sessionid);
+				$this->egw_setcookie('kp3',$this->kp3);
+				$this->egw_setcookie('domain',$this->account_domain);
 			}
 			if ($GLOBALS['egw_info']['server']['usecookies'] || isset($_COOKIE['last_loginid']))
 			{ 
-				$this->phpgw_setcookie('last_loginid', $this->account_lid ,$now+1209600); /* For 2 weeks */
-				$this->phpgw_setcookie('last_domain',$this->account_domain,$now+1209600);
+				$this->egw_setcookie('last_loginid', $this->account_lid ,$now+1209600); /* For 2 weeks */
+				$this->egw_setcookie('last_domain',$this->account_domain,$now+1209600);
 			}
 			unset($GLOBALS['egw_info']['server']['default_domain']); /* we kill this for security reasons */
 
@@ -557,7 +662,7 @@
 			$GLOBALS['egw']->crypto->init(array($this->key,$this->iv));
 
 			$this->read_repositories(False);
-			if ($this->user['expires'] != -1 && $this->user['expires'] < time())
+			if ($GLOBALS['egw']->accounts->is_expired($this->user))
 			{
 				if(is_object($GLOBALS['egw']->log))
 				{
@@ -733,7 +838,7 @@
 			$GLOBALS['egw_info']['flags'] = $phpgw_info_flags;
 
 			$this->update_dla();
-			$this->account_id = $GLOBALS['egw']->interserver->name2id($this->account_lid);
+			$this->account_id = $GLOBALS['egw']->interserver->name2id($this->account_lid,'account_lid','u');
 
 			if (!$this->account_id)
 			{
@@ -869,7 +974,7 @@
 
 			if (!$GLOBALS['egw']->interserver->exists($this->account_lid))
 			{
-				$this->account_id = $GLOBALS['egw']->interserver->name2id($this->account_lid);
+				$this->account_id = $GLOBALS['egw']->interserver->name2id($this->account_lid,'account_lid','u');
 			}
 			$GLOBALS['egw_info']['user']['account_id'] = $this->account_id;
 			$GLOBALS['egw']->interserver->serverid = $this->account_id;
@@ -1165,17 +1270,24 @@
 					$url = str_replace ( 'http:', 'https:', $url);
 				}
 			}
+			$vars = array();
+			// add session params if not using cookies
+			if (!$GLOBALS['egw_info']['server']['usecookies'])
+			{
+				$vars['sessionid'] = $this->sessionid;
+				$vars['kp3'] = $this->kp3;
+				$vars['domain'] = $this->account_domain;
+			}
 			
 			// check if the url already contains a query and ensure that vars is an array and all strings are in extravars
 			list($url,$othervars) = explode('?',$url);
 			if ($extravars && is_array($extravars))
 			{
-				$vars = $extravars;
+				$vars += $extravars;
 				$extravars = $othervars;
 			}
 			else
 			{
-				$vars = array();
 				if ($othervars) $extravars .= '&'.$othervars;
 			} 
 
@@ -1196,14 +1308,6 @@
 				}
 			}
 
-			// add session params if not using cookies
-			if (!$GLOBALS['egw_info']['server']['usecookies'])
-			{
-				$vars['sessionid'] = $this->sessionid;
-				$vars['kp3'] = $this->kp3;
-				$vars['domain'] = $this->account_domain;
-			}
-
 			// if there are vars, we add them urlencoded to the url
 			if (count($vars))
 			{
@@ -1252,18 +1356,27 @@
 		* Set paramaters for cookies - only implemented in PHP4 sessions
 		*
 		* @param string $domain domain name to use in cookie
+		* @param string $path='/' path to use in cookie
 		*/
-
-		function set_cookie_params($domain)
+		function set_cookie_params($domain,$path='/')
 		{}
 
 		/**
-		* Create a new session id
+		* Create a new session id, called by session::create()
 		*
 		* @return string a new session id
 		*/
 		function new_session_id()
-		{}
+		{
+			# when synchronizing using syncml, we already have php4 based session started
+			# and we are currently not allowed to change the sessionid later
+			# to solve this problem, we simply return the current session_id
+			if(basename($_SERVER['SCRIPT_FILENAME']) == 'rpc.php' && session_id() != '') {
+				return session_id();
+			}
+			
+			return md5($GLOBALS['egw']->common->randomstring(15));
+		}
 
 		/**
 		* Create a new session
