@@ -22,8 +22,8 @@
    * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
    \**************************************************************************/
 
-   /* $Id: class.tplsavant2.inc.php 22774 2006-10-30 09:50:40Z mipmip $ */
-   
+   /* $Id: class.tplsavant2.inc.php 23550 2007-03-29 21:01:11Z mipmip $ */
+
    if(is_file(EGW_INCLUDE_ROOT.'/phpgwapi/inc/savant2/Savant2.php'))
    {
 	  include_once(EGW_INCLUDE_ROOT.'/phpgwapi/inc/savant2/Savant2.php');
@@ -79,20 +79,21 @@
 		 }
 	  }
 
-
-	  /*!
-	  @function set_tpl_path
-	  @abstract sets the preferred and fallback template search paths
-	  @return void
-	  */
-	  function set_tpl_path($man_dir=false)
+	  /**
+	   * set_tpl_path sets the preferred and fallback template search paths  
+	   * 
+	   * @param string $man_dir custom manual given template path in filesystem
+	   * @access public
+	   * @return void
+	   */
+	  function set_tpl_path($man_dir=null)
 	  {
-		 $preferred_dir=$this->get_tpl_dir();
-		 $fallback_dir=$this->get_tpl_dir(true);
+		 $preferred_dir=$this->get_tpl_dir(); 
+		 $fallback_dir=$this->get_tpl_dir(true); 
 
 		 if(!$preferred_dir && $man_dir && $fallback_dir)
 		 {
-			$this->halt(lang('No Savant2 template directories were found in:'.EGW_APP_ROOT));
+			$this->halt(lang('No Savant2 template directories were found in:'.EGW_APP_ROOT)); 
 		 }
 		 else
 		 {
@@ -100,7 +101,7 @@
 			{
 			   $this->addPath('template',$fallback_dir);
 			}
-			// add preferred tpl dir last because savant set the last added first in the search array
+			// add preferred tpl dir last because savant set the last added first in the search array  
 			if($preferred_dir)
 			{
 			   $this->addPath('template',$preferred_dir);
@@ -110,17 +111,17 @@
 			{
 			   $this->addPath('template',$man_dir);
 			}
-
 		 }
 	  }
 
-
-	  /*!
-	  @function get_tpl_dir
-	  @abstract get template dir of an application
-	  @param $fallback if true the default fallback template dir is returned
-	  @param $appname appication name optional can be derived from $GLOBALS['egw_info']['flags']['currentapp'];
-	  */
+	  /**
+	   * get_tpl_dir get template dir of an application
+	   * 
+	   * @param bool $fallback if true the default fallback template dir is returned
+	   * @param string $appname appication name optional can be derived from $GLOBALS['egw_info']['flags']['currentapp'];
+	   * @access public
+	   * @return void
+	   */
 	  function get_tpl_dir($fallback=false,$appname = '')
 	  {
 		 if (! $appname)
@@ -215,19 +216,16 @@
 	  }
 
 	  /**
-	  * set_var the same as assign()
-	  *
-	  * @param mixed $tplvar
-	  * @param string $val
-	  * @access public
-	  * @return void
-	  */
+	   * set_var the same as assign()
+	   * 
+	   * @param mixed $tplvar 
+	   * @param string $val 
+	   * @access public
+	   * @return void
+	   */
 	  function set_var($tplvar,$val='')
 	  {
 		 $this->assign($tplvar,$val);
 	  }
 
-
-	  
-
    }
