@@ -22,7 +22,7 @@
 	* Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
 	\**************************************************************************/
 
-	/* $Id: class.translation.inc.php 22888 2006-12-06 07:22:59Z ralfbecker $ */
+	/* $Id: class.translation.inc.php 25153 2008-03-22 12:37:14Z ralfbecker $ */
 
 	// define the maximal length of a message_id, all message_ids have to be unique
 	// in this length, our column is varchar 128
@@ -39,6 +39,10 @@
 	{
 		define('PHP_SHLIB_PREFIX',PHP_SHLIB_SUFFIX == 'dll' ? 'php_' : '');
 	}
+	
+	// Define prefix for langfiles (historically 'phpgw_')
+	define('EGW_LANGFILE_PREFIX', 'egw_');
+	define('PHPGW_LANGFILE_PREFIX', 'phpgw_');
 
 	class translation
 	{
@@ -49,48 +53,49 @@
 		var $lang_table = 'egw_lang';
 		var $languages_table = 'egw_languages';
 		var $config_table = 'egw_config';
+		/**
+		 * Instance of the db-class
+		 *
+		 * @var egw_db
+		 */
 		var $db;
+		/**
+		 * Mark untranslated strings with an asterisk (*), values '' or 'yes'
+		 *
+		 * @var string
+		 */
+		var $markunstranslated;
 
 		/**
 		 * Constructor, sets up a copy of the db-object, gets the system-charset and tries to load the mbstring extension
 		 */
 		function translation($warnings = False)
 		{
-			for ($i = 1; $i <= 9; $i++)
-			{
+			for ($i = 1; $i <= 9; $i++) {
 				$this->placeholders[] = '%'.$i;
 			}
 			$this->db = is_object($GLOBALS['egw']->db) ? $GLOBALS['egw']->db : $GLOBALS['egw_setup']->db;
 			if (is_object($this->db)) $this->db->set_app('phpgwapi');
 
-			if (!isset($GLOBALS['egw_setup']))
-			{
+			if (!isset($GLOBALS['egw_setup'])) {
 				$this->system_charset = @$GLOBALS['egw_info']['server']['system_charset'];
-			}
-			else
-			{
+			} else {
 				$this->system_charset =& $GLOBALS['egw_setup']->system_charset;
 			}
-			// load multi-byte-string-extension if needed, and set its internal encodeing to your system_charset
-			if ($this->system_charset && substr($this->system_charset,0,9) != 'iso-8859-1')
-			{
-				if ($this->mbstring = extension_loaded('mbstring') || @dl(PHP_SHLIB_PREFIX.'mbstring.'.PHP_SHLIB_SUFFIX))
-				{
+
+			if (extension_loaded('mbstring') || @dl(PHP_SHLIB_PREFIX.'mbstring.'.PHP_SHLIB_SUFFIX)) {
+				$this->mbstring = true;
+				if(!empty($this->system_charset)) {
 					ini_set('mbstring.internal_encoding',$this->system_charset);
-					if (ini_get('mbstring.func_overload') < 7)
-					{
-						if ($warnings)
-						{
-							echo "<p>Warning: Please set <b>mbstring.func_overload = 7</b> in your php.ini for useing <b>$this->system_charset</b> as your charset !!!</p>\n";
-						}
+				}
+				if (ini_get('mbstring.func_overload') < 7) {
+					if ($warnings) {
+						echo "<p>Warning: Please set <b>mbstring.func_overload = 7</b> in your php.ini for useing <b>$this->system_charset</b> as your charset !!!</p>\n";
 					}
 				}
-				else
-				{
-					if ($warnings)
-					{
-						echo "<p>Warning: Please get and/or enable the <b>mbstring extension</b> in your php.ini for useing <b>$this->system_charset</b> as your charset, we are defaulting to <b>iconv</b> for now !!!</p>\n";
-					}
+			} else {
+				if ($warnings) {
+					echo "<p>Warning: Please get and/or enable the <b>mbstring extension</b> in your php.ini for useing <b>$this->system_charset</b> as your charset, we are defaulting to <b>iconv</b> for now !!!</p>\n";
 				}
 			}
 		}
@@ -155,6 +160,8 @@
 				$this->add_app('common');
 			}
 			$this->add_app($GLOBALS['egw_info']['flags']['currentapp']);
+			
+			$this->markunstranslated = $GLOBALS['egw_info']['server']['markuntranslated'];
 		}
 
 		/**
@@ -171,7 +178,8 @@
 			{
 				$this->init();
 			}
-			$ret = $key.$not_found;	// save key if we dont find a translation
+			$ret = $key;				// save key if we dont find a translation
+			if ($not_found && $this->markunstranslated) $ret .= $not_found;
 
 			if (isset($this->lang_arr[$key]))
 			{
@@ -234,26 +242,30 @@
 		 */
 		function add_setup($lang)
 		{
-			$fn = EGW_SERVER_ROOT.'/setup/lang/phpgw_' . $lang . '.lang';
-			if (!file_exists($fn))
+			foreach(array(
+				EGW_SERVER_ROOT.'/setup/lang/' . EGW_LANGFILE_PREFIX . $lang . '.lang',
+				EGW_SERVER_ROOT.'/setup/lang/' . PHPGW_LANGFILE_PREFIX . $lang . '.lang',
+				EGW_SERVER_ROOT.'/setup/lang/' . EGW_LANGFILE_PREFIX . 'en.lang',
+				EGW_SERVER_ROOT.'/setup/lang/' . PHPGW_LANGFILE_PREFIX . 'en.lang',
+			) as $fn)
 			{
-				$fn = EGW_SERVER_ROOT.'/setup/lang/phpgw_en.lang';
-			}
-			if (file_exists($fn))
-			{
-				$fp = fopen($fn,'r');
-				while ($data = fgets($fp,8000))
+				if (file_exists($fn))
 				{
-					// explode with "\t" and removing "\n" with str_replace, needed to work with mbstring.overload=7
-					list($message_id,,,$content) = explode("\t",$data);
-					$phrases[strtolower(trim($message_id))] = str_replace("\n",'',$content);
-				}
-				fclose($fp);
-				
-				foreach($phrases as $message_id => $content)
-				{
-					$this->lang_arr[$message_id] = $this->convert($content,$phrases['charset']);
+					$fp = fopen($fn,'r');
+					while ($data = fgets($fp,8000))
+					{
+						// explode with "\t" and removing "\n" with str_replace, needed to work with mbstring.overload=7
+						list($message_id,,,$content) = explode("\t",$data);
+						$phrases[strtolower(trim($message_id))] = str_replace("\n",'',$content);
+					}
+					fclose($fp);
+					
+					foreach($phrases as $message_id => $content)
+					{
+						$this->lang_arr[$message_id] = $this->convert($content,$phrases['charset']);
+					}
 				}
+				break;
 			}
 			$this->loaded_apps['setup'] = $lang;
 		}
@@ -359,7 +371,7 @@
 				{
 					$data = &$this->charsets[$charset = strtolower($this->db->f('charset'))];
 					$lang = $this->langs[$this->db->f('lang')].' ('.$this->db->f('lang').')';
-					if ($distinct || strstr($data,$lang) === false)
+					if ($distinct || strpos($data,$lang) === false)
 					{
 						$data .= ($data ? ', ' : $charset.': ').$lang;
 					}						
@@ -445,15 +457,32 @@
 			}
 			if(function_exists('iconv'))
 			{
-			if($from=='EUC-CN') $from='gb18030';
-			// the above is to workaround patch #962307
-			// if using EUC-CN, for iconv it strickly follow GB2312 and fail 
-			// in an email on the first Traditional/Japanese/Korean character, 
-			// but in reality when people send mails in GB2312, UMA mostly use 
-			// extended GB13000/GB18030 which allow T/Jap/Korean characters.
-				if (($data = iconv($from,$to,$data)))
-				{
-					return $data;
+				// iconv can not convert from/to utf7-imap
+				if ($to == 'utf7-imap' && function_exists(imap_utf7_encode)) {
+					$convertedData = iconv($from, 'iso-8859-1', $data);
+					$convertedData = imap_utf7_encode($convertedData);
+					
+					return $convertedData;
+				}
+
+				if ($from == 'utf7-imap' && function_exists(imap_utf7_decode)) {
+					$convertedData = imap_utf7_decode($data);
+					$convertedData = iconv('iso-8859-1', $to, $convertedData);
+
+					return $convertedData;
+				}
+
+				// the following is to workaround patch #962307
+				// if using EUC-CN, for iconv it strickly follow GB2312 and fail 
+				// in an email on the first Traditional/Japanese/Korean character, 
+				// but in reality when people send mails in GB2312, UMA mostly use 
+				// extended GB13000/GB18030 which allow T/Jap/Korean characters.
+				if($from=='EUC-CN') {
+					$from='gb18030';
+				}
+
+				if (($convertedData = iconv($from,$to,$data))) {
+					return $convertedData;
 				}
 			}
 			#die("<p>Can't convert from charset '$from' to '$to' without the <b>mbstring extension</b> !!!</p>");
@@ -531,9 +560,10 @@
 					// Visit each app/setup dir, look for a egw_lang file
 					foreach($apps as $app)
 					{
-						$appfile = EGW_SERVER_ROOT . SEP . $app . SEP . 'setup' . SEP . 'phpgw_' . strtolower($lang) . '.lang';
+						$appfile = EGW_SERVER_ROOT . SEP . $app . SEP . 'setup' . SEP . EGW_LANGFILE_PREFIX . strtolower($lang) . '.lang';
+						$old_appfile = EGW_SERVER_ROOT . SEP . $app . SEP . 'setup' . SEP . PHPGW_LANGFILE_PREFIX . strtolower($lang) . '.lang';
 						//echo '<br>Checking in: ' . $app;
-						if($GLOBALS['egw_setup']->app_registered($app) && file_exists($appfile))
+						if($GLOBALS['egw_setup']->app_registered($app) && (file_exists($appfile) || file_exists($appfile=$old_appfile)))
 						{
 							//echo '<br>Including: ' . $appfile;
 							$lines = file($appfile);
@@ -553,6 +583,11 @@
 								}
 								$message_id = substr(strtolower(chop($message_id)),0,MAX_MESSAGE_ID_LENGTH);
 								$app_name = chop($app_name);
+								// convert new files from utf-8
+								if ($appfile != $old_appfile && isset($raw['common']['charset']) && $raw['common']['charset'] != 'utf-8')
+								{
+									$content = $this->convert($content,'utf-8',$raw['common']['charset']);
+								}
 								$raw[$app_name][$message_id] = $content;
 							}
 							if ($GLOBALS['egw_info']['server']['lang_ctimes'] && !is_array($GLOBALS['egw_info']['server']['lang_ctimes']))
@@ -658,9 +693,10 @@
 			$apps['phpgwapi'] = True;	// check the api too
 			foreach($apps as $app => $data)
 			{
-				$fname = EGW_SERVER_ROOT . "/$app/setup/phpgw_$lang.lang";
+				$fname = EGW_SERVER_ROOT . "/$app/setup/" . EGW_LANGFILE_PREFIX . "$lang.lang";
+				$old_fname = EGW_SERVER_ROOT . "/$app/setup/" . PHPGW_LANGFILE_PREFIX . "$lang.lang";
 
-				if (file_exists($fname))
+				if (file_exists($fname) || file_exists($fname = $old_fname))
 				{
 					$ctime = filectime($fname);
 					/* This is done to avoid string offset error at least in php5 */
@@ -796,4 +832,24 @@
 			
 			return $this->db->next_record() ? $this->db->f('content') : false;
 		}
+		
+		/**
+		 * Return the message_id of a given translation
+		 *
+		 * @param string $translation
+		 * @param string $app='' default check all apps
+		 * @param string $lang='' default check all langs
+		 * @return string
+		 */
+		function get_message_id($translation,$app=null,$lang=null)
+		{
+			$like = $this->db->Type == 'pgsql' ? 'ILIKE' : 'LIKE';
+			$where = array('content '.$like.' '.$this->db->quote($translation));	// like to be case-insensitive
+			if ($app) $where['app_name'] = $app;
+			if ($lang) $where['lang'] = $lang;
+			
+			$this->db->select($this->lang_table,'message_id',$where,__LINE__,__FILE__);
+			
+			return $this->db->next_record() ? $this->db->f(0) : false;
+		}
 	}
