@@ -21,7 +21,7 @@
 	* Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
 	\**************************************************************************/
 
-	/* $Id: class.vfs.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: class.vfs.inc.php 23099 2006-12-22 06:33:01Z ralfbecker $ */
 
 	if (empty ($GLOBALS['egw_info']['server']['file_repository']))
 	{
@@ -625,7 +625,8 @@
 				$data = array ();
 			}
 
-			if (substr ($data['string'], 0, 1) == "\\" || strstr ($data['string'], "..") || strstr ($data['string'], "\\..") || strstr ($data['string'], ".\\."))
+			if (substr ($data['string'], 0, 1) == '\\' || strpos($data['string'], '..') !== false || 
+				strpos($data['string'], '\\..') !== false || strpos($data['string'], '.\\.') !== false)
 			{
 				return False;
 			}
@@ -800,7 +801,8 @@
 				$basedir = ereg_replace ($sep . $sep, $sep, $basedir);
 			}
 
-			$basedir = ereg_replace ($sep . '$', '', $basedir);
+			// remove trailing slash
+			if ($basedir != '/' && substr($basedir,-1) == '/') $basedir = substr($basedir,0,-1);
 
 			return $basedir;
 		}
