@@ -21,7 +21,7 @@
 	* Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
 	\**************************************************************************/
 
-	/* $Id: class.vfs_sql.inc.php 21701 2006-06-03 01:44:24Z ralfbecker $ */
+	/* $Id: class.vfs_sql.inc.php 25073 2008-03-13 12:46:54Z leithoff $ */
 
 	/**
 	 * Virtual File System with SQL backend
@@ -54,7 +54,7 @@
 			$this->basedir = $GLOBALS['egw_info']['server']['files_dir'];
 			$this->working_id = $GLOBALS['egw_info']['user']['account_id'];
 			$this->working_lid = $GLOBALS['egw_info']['user']['account_lid'];
-			$this->now = date ('Y-m-d');
+			$this->now = date ('Y-m-d H:i:s');
 
 			/*
 				 File/dir attributes, each corresponding to a database field.  Useful for use in loops
@@ -134,7 +134,8 @@
 					'link_name' => $this->db->Record['vfs_link_name'],
 				);
 			}
-			$this->grants = $GLOBALS['egw']->acl->get_grants('filemanager');
+			// group grants in filemanage are used for group-directories, NOT as grants for each group-member!!!
+			$this->grants = $GLOBALS['egw']->acl->get_grants('filemanager',false);
 		}
 
 		/**
@@ -723,7 +724,7 @@
 			{
 				return True;
 			}
-			elseif (!$rights && $group_ok)
+			elseif (!$rights)
 			{
 				return $GLOBALS['egw_info']['server']['acl_default'] == 'grant';
 			}
@@ -770,7 +771,17 @@
 			{
 				if (($fp = fopen ($p->real_full_path, 'rb')))
 				{
-					$contents = fread ($fp, filesize ($p->real_full_path));
+				    if (filesize($p->real_full_path) > 0)
+				    {
+				        $contents = fread ($fp, filesize($p->real_full_path));
+				    }
+				    else
+				    {
+				        // files could also have no contents. In this case
+				        // the second parameter should not be present!
+				        $contents = fread ($fp);
+				    }
+					
 					fclose ($fp);
 				}
 				else
@@ -1557,7 +1568,7 @@
 			{
 				if ($this->file_actions)
 				{
-					$rr = unlink ($p->real_full_path);
+					$rr = @unlink ($p->real_full_path);
 				}
 				else
 				{
@@ -1729,8 +1740,8 @@
 			}
 
 			/* We don't allow /'s in dir names, of course */
-			if (strstr ($p->fake_name,'/'))
-			{//echo "strstr('$p->fake_name','/')";
+			if (strpos ($p->fake_name,'/') !== false)
+			{
 				return False;
 			}
 
@@ -2327,7 +2338,7 @@
 				}
 				$this->db->select($this->vfs_table,array_keys($this->attributes),$where,__LINE__,__FILE__);
 
-				$record = $this->db->Row(true,$this->vfs_column_prefix);
+				if (!($record = $this->db->Row(true,$this->vfs_column_prefix))) return array();
 
 				/* We return an array of one array to maintain the standard */
 				$rarray = array ();
@@ -2419,7 +2430,7 @@
 			for ($i = 0; ($record = $this->db->Row(true,$this->vfs_column_prefix)); $i++)
 			{
 				/* Further checking on the directory.  This makes sure /home/user/test won't match /home/user/test22 */
-				if (@!ereg ("^$dir(/|$)", $record['directory']))
+				if (@!ereg ("^$dir(/|$)", $record['directory']) || $record['name'] === '')
 				{
 					continue;
 				}
@@ -2613,4 +2624,4 @@
 			return $rarray;
 		}
 	}
-?>
\ No newline at end of file
+?>
