@@ -21,13 +21,29 @@
 	 * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
 	 \**************************************************************************/
 
-	/* $Id: common_functions.inc.php 22825 2006-11-10 11:38:34Z ralfbecker $ */
+	/* $Id: common_functions.inc.php 24475 2007-09-29 09:19:44Z ralfbecker $ */
 
 	/****************************************************************************\
 	 * Direct functions which are not part of the API classes                    *
 	 * because they are required to be available at the lowest level.            *
 	 \***************************************************************************/
 
+	/**
+	 * Return the number of bytes of a string, independent of mbstring.func_overload
+	 * AND the availability of mbstring
+	 *
+	 * @param string $str
+	 * @return int
+	 */
+	function bytes($str)
+	{
+		static $func_overload;
+		
+		if (is_null($func_overload)) $func_overload = extension_loaded('mbstring') ? ini_get('mbstring.func_overload') : 0;
+		
+		return $func_overload & 2 ? mb_strlen($str,'ascii') : strlen($str);
+	}
+
 	/**
 	 * @internal Not to be used directly. Should only be used by print_debug()
 	 */
@@ -665,7 +681,7 @@
 		
 		if ($classname == 'datetime') $classname = 'egw_datetime';	// php5.2 fix
 
-		include_once($file=EGW_INCLUDE_ROOT.'/'.$appname.'/inc/class.'.$classname.'.inc.php');
+		include_once(EGW_INCLUDE_ROOT.'/'.$appname.'/inc/class.'.$classname.'.inc.php');
 
 		if (class_exists($classname))
 		{
@@ -843,7 +859,7 @@
 		}
 		else
 		{
-			return 'error in parts';
+			return "<p>ExecMethod('$method'): error in parts!<br />".function_backtrace()."</p>\n";
 		}
 	}
 
@@ -939,30 +955,15 @@
 	 */
 	function _debug_array($array,$print=True)
 	{
-		$four = False;
-		if(@floor(phpversion()) > 3)
+		$output = '<pre>'.print_r($array,true)."</pre>\n";
+		
+		if ($print)
 		{
-			$four = True;
-		}
-		if($four)
-		{
-			if(!$print)
-			{
-				ob_start();
-			}
-			echo '<pre>';
-			print_r($array);
-			echo '</pre>';
-			if(!$print)
-			{
-				$v = ob_get_contents();
-				ob_end_clean();
-				return $v;
-			}
+			echo $output;
 		}
 		else
 		{
-			return print_r($array,False,$print);
+			return $output;
 		}
 	}
 
@@ -1234,6 +1235,32 @@
 	}
 	//if (is_array($GLOBALS['egw_unset_vars'])) { echo "egw_unset_vars=<pre>".htmlspecialchars(print_r($GLOBALS['egw_unset_vars'],true))."</pre>"; exit; }
 
+	// neutralises register_globals On, which is not used by eGW
+	// some code from the hardend php project: http://www.hardened-php.net/articles/PHPUG-PHP-Sicherheit-Parametermanipulationen.pdf
+	if (ini_get('register_globals'))
+	{
+		function unregister_globals()
+		{
+			// protect against GLOBALS overwrite or setting egw_info
+			if (isset($_REQUEST['GLOBALS']) || isset($_FILES['GLOBALS']) || isset($_REQUEST['egw_info']) || isset($_FILES['egw_info']))
+			{
+				die('GLOBALS overwrite detected!!!');
+			}
+			// unregister all globals
+			$noUnset = array('GLOBALS','_GET','_POST','_COOKIE','_SERVER','_ENV','_FILES','xajax');
+			foreach(array_unique(array_merge(
+				array_keys($_GET),array_keys($_POST),array_keys($_COOKIE),array_keys($_SERVER),array_keys($_ENV),array_keys($_FILES),
+				isset($_SESSION) && is_array($_SESSION) ? array_keys($_SESSION) : array())) as $k)
+			{
+				if (!in_array($k,$noUnset) && isset($GLOBALS[$k]))
+				{
+					unset($GLOBALS[$k]);
+				}
+			}
+		}
+		unregister_globals();
+	}
+
 	if(floor(phpversion()) <= 4)
 	{
 		/**
