@@ -23,7 +23,7 @@ include_once 'Horde/SyncML/Sync.php';
  * @author  Anthony Mills <amills@pyramid6.com>
  * @author  Karsten Fourmont <fourmont@gmx.de>
  *
- * @version $Revision: 21827 $
+ * @version $Revision: 24732 $
  * @since   Horde 3.0
  * @package Horde_SyncML
  */
@@ -211,6 +211,8 @@ class Horde_SyncML_SyncMLHdr extends Horde_SyncML_ContentHandler {
             #Horde::logMessage('SymcML: SyncHdr done. Try to load state from session.', __FILE__, __LINE__, PEAR_LOG_DEBUG);
             $state = $this->getStateFromSession($this->_sourceURI, $this->_locName, $this->_sessionID);
 
+		Horde::logMessage('SyncML['. session_id() .']: package '.$this->_msgID.' +++++++++++++++++++++ started', __FILE__, __LINE__, PEAR_LOG_DEBUG);
+
             $state->setVersion($this->_version);
             $state->setMsgID($this->_msgID);
             $state->setTargetURI($this->_targetURI);
@@ -262,7 +264,7 @@ class Horde_SyncML_SyncMLHdr extends Horde_SyncML_ContentHandler {
                 $this->_credData = base64_decode($this->_credData);
                 //}
 
-                $tmp = split(':', $this->_credData);
+                $tmp = split(':', $this->_credData, 2);
                 // set only if not set by LocName already
                 if(!isset($this->_locName))
                 {
@@ -446,6 +448,7 @@ class Horde_SyncML_SyncMLBody extends Horde_SyncML_ContentHandler {
         case 2:
             $state = & $_SESSION['SyncML.state'];
 
+
             $this->_actionCommands = false; // so far, we have not seen commands that require action from our side
             $state->_sendFinal = false;
 
@@ -481,6 +484,7 @@ class Horde_SyncML_SyncMLBody extends Horde_SyncML_ContentHandler {
             $state = & $_SESSION['SyncML.state'];
 
             // <SyncML><SyncBody><[Command]>
+            #Horde::logMessage('SyncML['. session_id() ."]:    found command    $element         ", __FILE__, __LINE__, PEAR_LOG_DEBUG);
             $this->_currentCommand = Horde_SyncML_Command::factory($element);
             $this->_currentCommand->startElement($uri, $element, $attrs);
 
@@ -493,12 +497,6 @@ class Horde_SyncML_SyncMLBody extends Horde_SyncML_ContentHandler {
             
             switch($element)
             {
-#            	case 'Final':
-#            		if($state->getClientSyncStatus() == 1)
-#            		{
-#            			$state->setClientSyncStatus(2);
-#            		}
-#            		break;
             	case 'Sync':
             		$state->setSyncStatus(CLIENT_SYNC_STARTED);
                 	Horde::logMessage('SyncML['. session_id() .']: syncStatus(client sync started) ' . $state->getSyncStatus(), __FILE__, __LINE__, PEAR_LOG_DEBUG);
@@ -518,6 +516,8 @@ class Horde_SyncML_SyncMLBody extends Horde_SyncML_ContentHandler {
 			case 2:
 				// </SyncBody></SyncML>
 				$state = & $_SESSION['SyncML.state'];
+
+				Horde::logMessage('SyncML['. session_id() .']: package ----------------------- done', __FILE__, __LINE__, PEAR_LOG_DEBUG);
 				
 				if($state->getSyncStatus() == CLIENT_SYNC_FINNISHED && $state->getAlert222Received() == true) {
 					$state->setSyncStatus(CLIENT_SYNC_ACKNOWLEDGED);
@@ -585,7 +585,7 @@ class Horde_SyncML_SyncMLBody extends Horde_SyncML_ContentHandler {
 					$state->setSyncStatus(CLIENT_SYNC_ACKNOWLEDGED);
 					Horde::logMessage('SyncML['. session_id() .']: syncStatus(client sync acknowledged) '.$state->getSyncStatus(), __FILE__, __LINE__, PEAR_LOG_DEBUG);
 				}
-				                                                                
+
 				break;
 			
 			case 3:
