@@ -145,7 +145,7 @@ define('MAX_ENTRIES',			10);
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Anthony Mills <amills@pyramid6.com>
- * @version $Revision: 22261 $
+ * @version $Revision: 24836 $
  * @since   Horde 3.0
  * @package Horde_SyncML
  */
@@ -199,7 +199,15 @@ class Horde_SyncML_State {
 	
 	// stores if we received Alert 222 already
 	var $_receivedAlert222 = false;
+	
+	// stores if we already requested the deviceinfo
+	var $_devinfoRequested = false;
 
+	/* 
+	 * store the mappings of egw uids to client uids
+	 */
+	var $_uidMappings	= array();
+	
     /**
      * Creates a new instance of Horde_SyncML_State.
      */
@@ -214,6 +222,24 @@ class Horde_SyncML_State {
 
         $this->isAuthorized = false;
     }
+    
+    /**
+     * store the sent global uid
+     */
+    function setUIDMapping($_realEgwUid, $_sentEgwUid) {
+    	$this->_uidMappings[$_sentEgwUid] = $_realEgwUid;
+    }
+
+    /**
+     * retrieve the real egw uid for a given send uid
+     */
+    function getUIDMapping($_sentEgwUid) {
+    	if(isset($this->_uidMappings[$_sentEgwUid])) {
+    		return $this->_uidMappings[$_sentEgwUid];
+	}
+	
+	return false;
+    }
 
     /**
      * Returns the DataTree used as persistence layer for SyncML.  The
@@ -625,85 +651,192 @@ class Horde_SyncML_State {
         return $guid;
     }
 
-    /**
-     * This function should use DevINF information.
-     */
-    function getPreferedContentType($type)
-    {
-#        if ($type == 'contacts') {
-#            return 'text/x-vcard';
-#        } elseif ($type == 'notes') {
-#            return 'text/x-vnote';
-#        } elseif ($type == 'tasks') {
-#            return 'text/x-vcalendar';
-#        } elseif ($type == 'calendar') {
-#            return 'text/x-vcalendar';
-#        }
-        switch($type) {
-        	case 'contacts':
-        		return 'text/x-vcard';
-        		break;
-        		
-		 case 'sifcalendar':
-		 case './sifcalendar':
-		 	return 'text/x-s4j-sife';
-		 	break;
-		                                                                 
-        	case 'sifcontacts':
-        	case './sifcontacts':
-        		return 'text/x-s4j-sifc';
-        		break;
-        		
-        	case 'siftasks':
-        	case './siftasks':
-        		return 'text/x-s4j-sift';
-        		break;
-        		
-		case 'notes':
-			return 'text/x-vnote';
-			break;
-			
-		case 'tasks':
-			return 'text/x-vcalendar';
-			break;
-			
-		case 'calendar':
-			return 'text/x-vcalendar';
-			break;
+
+	/**
+	* This function should use DevINF information.
+	*/
+	function adjustContentType($type, $target = null)
+	{
+		$ctype;
+		if (is_array($type))
+		{
+			$ctype = $type['ContentType'];
+			$res = $type;
+		}
+		else
+		{
+			$ctype = $type;
+			$res = array();
+			$res['ContentType'] = $ctype;
+		}
+
+        $deviceInfo = $this->getClientDeviceInfo();
+
+        if (isset($deviceInfo['manufacturer']))
+        {
+            switch (strtolower($deviceInfo['manufacturer']))
+            {
+                case 'funambol':
+                    if (strtolower($deviceInfo['model']) == 'thunderbird')
+                    {
+                        $res['mayFragment'] = 1;
+                    }
+
+                    if (isset($deviceInfo['softwareVersion'])
+                        && $deviceInfo['softwareVersion']{0} == '3')
+                    {
+						// anything beyond 6.0 supports fragmentation
+                        $res['mayFragment'] = 0;
+                    }
+                    else
+                    {
+                        $res['mayFragment'] = 1;
+                    }
+                    break;
+            }
+        }
+
+        if (!isset($res['mayFragment']))
+        {
+            $res['mayFragment'] = 1;
+        }
+
+
+		// the funambol specific types need to be encoded in base 64
+		switch(strtolower($ctype))
+		{
+			case 'text/x-s4j-sifc':
+			case 'text/x-s4j-sife':
+			case 'text/x-s4j-sift':
+			case 'text/x-s4j-sifn':
+				$res['ContentFormat'] = 'b64';
+				break;
+		}
+
+		return $res;
 	}
-    }
 
-    /**
-     * Returns the preferred contenttype of the client for the given
-     * sync data type (database).
-     *
-     * This is passed as an option to the Horde API export functions.
-     */
-    function getPreferedContentTypeClient($_sourceLocURI)
-    {
-    	$deviceInfo = $this->getClientDeviceInfo();
-    	
-    	if(isset($deviceInfo['dataStore'][$_sourceLocURI]['rxPreference']['contentType']))
-    	{
-    		return array('ContentType' => $deviceInfo['dataStore'][$_sourceLocURI]['rxPreference']['contentType']);
-    	}
+	function getPreferedContentType($type)
+	{
+		$_type = str_replace('./','',$type);
+		switch(strtolower($_type))
+		{
+			case 'contacts':
+				return 'text/x-vcard';
+				break;
 
-    	Horde::logMessage('SyncML: sourceLocURI ' . $_sourceLocURI .' not found', __FILE__, __LINE__, PEAR_LOG_DEBUG);
-    	return PEAR::raiseError(_('sourceLocURI not found'));
-#        elseif ($type == 'contacts') {
-#            return 'text/x-vcard';
-#        } elseif ($type == 'notes') {
-#            return array('ContentType' => 'text/x-vnote',
-#                         'ENCODING'    => 'QUOTED-PRINTABLE',
-#                         'CHARSET'     => 'UTF-8');
-#        } elseif ($type == 'tasks') {
-#            return 'text/x-vcalendar';
-#        } elseif ($type == 'calendar') {
-#            return array('ContentType' => 'text/x-vcalendar',
-#                         'ENCODING'    => 'QUOTED-PRINTABLE',
-#                         'CHARSET'     => 'UTF-8');
-#        }
-    }
+			case 'notes':
+				return 'text/x-vnote';
+				break;
+				
+			case 'calendar':
+			case 'tasks':
+			case 'caltasks':
+				return 'text/x-vcalendar';
+				break;
+				
+			case 'sifcalendar':
+			case 'scal':
+				return 'text/x-s4j-sife';
+				break;
+				
+			case 'sifcontacts':
+			case 'scard':
+				return 'text/x-s4j-sifc';
+				break;
+				
+			case 'siftasks':
+			case 'stask':
+				return 'text/x-s4j-sift';
+				break;
+
+			case 'sifnotes':
+			case 'snote':
+				return 'text/x-s4j-sifn';
+				break;
+			
+			default:
+				Horde::logMessage("SyncML: unrecognized content type '$_type'", __FILE__, __LINE__, PEAR_LOG_ERR);
+				break;
+		}
+	}
+
+	function getHordeType($type)
+	{
+		$_type = str_replace('./','',$type);
+		switch(strtolower($_type))
+		{
+			case 'contacts':
+				return 'contacts';
+				break;
+				
+			case 'notes':
+				return 'notes';
+				break;
+				
+			case 'tasks':
+				return 'tasks';
+				break;
+			
+			case 'calendar':
+			case 'caltasks':
+				return 'calendar';
+				break;
+
+			# funambol related types
+
+			case 'sifcalendar':
+			case 'scal':
+				return 'sifcalendar';
+				break;
+				
+			case 'sifcontacts':
+			case 'scard':
+				return 'sifcontacts';
+				break;
+				
+			case 'siftasks':
+			case 'stask':
+				return 'siftasks';
+				break;
+
+			case 'sifnotes':
+			case 'snote':
+				return 'sifnotes';
+				break;
+
+			default:
+				Horde::logMessage("SyncML: unknown hordeType for type=$type ($_type)", __FILE__, __LINE__, PEAR_LOG_INFO);
+				return $_type;
+				break;
+		}
+	}
+
+	/**
+	/**
+	* Returns the preferred contenttype of the client for the given
+	* sync data type (database).
+	*
+	* This is passed as an option to the Horde API export functions.
+	*/
+	
+	function getPreferedContentTypeClient($_sourceLocURI, $_targetLocURI = null) {
+		$deviceInfo = $this->getClientDeviceInfo();
+		
+		if(isset($deviceInfo['dataStore'][$_sourceLocURI]['rxPreference']['contentType']))
+		{
+			return $this->adjustContentType($deviceInfo['dataStore'][$_sourceLocURI]['rxPreference']['contentType'], $_targetLocURI);
+		}
+		
+		Horde::logMessage('SyncML: sourceLocURI ' . $_sourceLocURI .' not found', __FILE__, __LINE__, PEAR_LOG_DEBUG);
+		
+		if ($_targetLocURI != null)
+		{
+			return $this->adjustContentType($this->getPreferedContentType($_targetLocURI), $_targetLocURI);
+		}
+
+		return PEAR::raiseError(_('sourceLocURI not found'));
+	}
 
     function setClientAnchorNext($type, $a)
     {
@@ -906,7 +1039,7 @@ class Horde_SyncML_State {
      */
     function handleTasksInCalendar()
     {
-        return false;
+        return true;
     }
 
     /**
