@@ -10,7 +10,7 @@
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Mike Cochrane <mike@graftonhall.co.nz>
- * @version $Revision: 23677 $
+ * @version $Revision: 24605 $
  * @since   Horde 3.0
  * @package Horde_iCalendar
  */
@@ -510,18 +510,11 @@ class Horde_iCalendar {
                 case 'CREATED':
                 case 'LAST-MODIFIED':
                 case 'BDAY':
-                    $this->setAttribute($tag, $this->_parseDateTime($value), $params);
-                    break;
-
                 case 'DTEND':
                 case 'DTSTART':
                 case 'DUE':
                 case 'RECURRENCE-ID':
-                    if (isset($params['VALUE']) && $params['VALUE'] == 'DATE') {
-                        $this->setAttribute($tag, $this->_parseDate($value), $params);
-                    } else {
-                        $this->setAttribute($tag, $this->_parseDateTime($value), $params);
-                    }
+                    $this->setAttribute($tag, $this->_parseDateTime($value), $params);
                     break;
 
                 case 'RDATE':
@@ -550,11 +543,11 @@ class Horde_iCalendar {
                     }
                     break;
 
-                // Comma seperated dates.
+                // Comma and semicolon seperated dates.
                 case 'EXDATE':
                     $values = array();
                     $dates = array();
-                    preg_match_all('/;([^;]*)/', ';' . $value, $values);
+                    preg_match_all('/[,;]([^,;]*)/', ';' . $value, $values);
 
                     foreach ($values[1] as $value) {
                         if (isset($params['VALUE'])) {
@@ -579,7 +572,7 @@ class Horde_iCalendar {
                 case 'FREEBUSY':
                     $values = array();
                     $periods = array();
-                    preg_match_all('/,([^,]*)/', ',' . $value, $values);
+                    preg_match_all('/[,;]([^,;]*)/', ';' . $value, $values);
                     foreach ($values[1] as $value) {
                         $periods[] = $this->_parsePeriod($value);
                     }
@@ -902,7 +895,7 @@ class Horde_iCalendar {
             if (!$date = $this->_parseDate($text)) {
                 return $date;
             }
-            return @gmmktime(0, 0, 0, $date['month'], $date['mday'], $date['year']);
+            return @mktime(0, 0, 0, $date['month'], $date['mday'], $date['year']);
         }
 
         if (!$date = $this->_parseDate($dateParts[0])) {
@@ -912,6 +905,8 @@ class Horde_iCalendar {
             return $time;
         }
 
+		error_log("parseDateTime: ".$text." => ".print_r($time, true));
+
         if ($time['zone'] == 'UTC') {
             return @gmmktime($time['hour'], $time['minute'], $time['second'],
                              $date['month'], $date['mday'], $date['year']);
@@ -1016,7 +1011,12 @@ class Horde_iCalendar {
      */
     function _parseDate($text)
     {
-        if (strlen($text) != 8) {
+		if (strlen($text) == 10)
+		{
+			$text = str_replace('-','',$text);
+		}
+        if (strlen($text) != 8)
+		{
             return false;
         }
 
@@ -1328,9 +1328,9 @@ class Horde_iCalendar {
      */
     function EncodeQP ($str) {
         $encoded = $this->FixEOL($str);
-        # see bugreport http://sourceforge.net/tracker/index.php?func=detail&aid=1536674&group_id=78745&atid=554338
-        //if (substr($encoded, -(strlen($this->LE))) != $this->LE)
-        //    $encoded .= $this->LE;
+        # see bug report http://sourceforge.net/tracker/index.php?func=detail&aid=1536674&group_id=78745&atid=554338
+        #if (substr($encoded, -(strlen($this->LE))) != $this->LE)
+        #    $encoded .= $this->LE;
 
         // Replace every high ascii, control and = characters
         #$encoded = preg_replace('/([\000-\010\013\014\016-\037\075\177-\377])/e',
