@@ -18,7 +18,7 @@
 	// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 	// THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-	/* $Id: xml_functions.inc.php 20496 2006-03-08 19:40:11Z ralfbecker $ */
+	/* $Id: xml_functions.inc.php 24475 2007-09-29 09:19:44Z ralfbecker $ */
 
 	if (!function_exists('xml_parser_create'))
 	{
@@ -167,7 +167,7 @@
 		);
 		$payload = '<?xml version="1.0"?>' . "\n" . $r->serialize();
 		Header('Content-type: text/xml');
-		Header('Content-length: ' . strlen($payload));
+		Header('Content-length: ' . bytes($payload));
 		print $payload;
 		$GLOBALS['egw']->common->phpgw_exit(False);
 	}
@@ -191,70 +191,26 @@
 	* into their equivalent 'charset entity'. Charset entities enumerated this way
 	* are independent of the charset encoding used to transmit them, and all XML
 	* parsers are bound to understand them.
+	* 
+	* @author Eugene Pivnev
 	*/
-	function xmlrpc_encode_entitites($data)
+	function xmlrpc_encode_entities($data)
 	{
-		$length = strlen($data);
-		$escapeddata = "";
-		for($position = 0; $position < $length; $position++)
-		{
-			$character = substr($data, $position, 1);
-			$code = Ord($character);
-			switch($code)
-			{
-				case 34:
-					$character = "&quot;";
-					break;
-				case 38:
-					$character = "&amp;";
-					break;
-				case 39:
-					$character = "&apos;";
-					break;
-				case 60:
-					$character = "&lt;";
-					break;
-				case 62:
-					$character = "&gt;";
-					break;
-				default:
-					if($code < 32 || $code > 159)
-					{
-						$character = ("&#".strval($code).";");
-					}
-					break;
-			}
-			$escapeddata .= $character;
-		}
-		return $escapeddata;
+		return htmlspecialchars($data,ENT_QUOTES,$GLOBALS['egw']->translation->system_charset ? 
+			$GLOBALS['egw']->translation->system_charset : 'latin1');
+	}
+
+	if (!function_exists('htmlspecialchars_decode'))	// php < 5.1
+	{
+	    function htmlspecialchars_decode($text,$quote_style=ENT_COMPAT)
+	    {
+	        return strtr($text, array_flip(get_html_translation_table(HTML_SPECIALCHARS,$quote_style)));
+	    }
 	}
 
 	function xmlrpc_entity_decode($string)
 	{
-		$top = split('&', $string);
-		$op  = '';
-		$i   = 0;
-		while($i<sizeof($top))
-		{
-			if (ereg("^([#a-zA-Z0-9]+);", $top[$i], $regs))
-			{
-				$op .= ereg_replace("^[#a-zA-Z0-9]+;",
-					xmlrpc_lookup_entity($regs[1]), $top[$i]);
-			}
-			else
-			{
-				if ($i == 0)
-				{
-					$op = $top[$i];
-				}
-				else
-				{
-					$op .= '&' . $top[$i];
-				}
-			}
-			$i++;
-		}
-		return $op;
+		return htmlspecialchars_decode($data,ENT_QUOTES);
 	}
 
 	function xmlrpc_lookup_entity($ent)
