@@ -10,7 +10,7 @@
  * Read the entire license text here: http://www.gnu.org/licenses/lgpl.html
  */
 
-// $Id: calendar.js 20295 2006-02-15 12:31:25Z  $
+// $Id: calendar.js 24114 2007-06-15 13:36:23Z leithoff $
 
 /** The Calendar object constructor. */
 Calendar = function (firstDayOfWeek, dateStr, onSelected, onClose) {
@@ -61,6 +61,8 @@ Calendar = function (firstDayOfWeek, dateStr, onSelected, onClose) {
 			ar[--i] = Calendar._DN[i].substr(0, Calendar._SDN_len);
 		}
 		Calendar._SDN = ar;
+	}
+	if (typeof Calendar._SMN == "undefined") {
 		// table of short month names
 		if (typeof Calendar._SMN_len == "undefined")
 			Calendar._SMN_len = 3;
@@ -1438,9 +1440,19 @@ Calendar.prototype.parseDate = function (str, fmt) {
 	var y = 0;
 	var m = -1;
 	var d = 0;
-	var a = str.split(/\W+/);
+//	var a = str.split(/\W+/); does not work with multibyte chars, eg. german umlauts under utf-8
+//	var a = str.split(/[./-]/); does not work with old javascript
+	var a;
+	a=str.split(/\//);
+	if (a[0]==str) {
+			a=str.split(/-/);
+	}
+	if (a[0]==str) {
+			a=str.split(/\./);
+	}
+
 	if (!fmt) {
-		fmt = this.dateFormat;
+			fmt = this.dateFormat;
 	}
 	var b = fmt.match(/%./g);
 	var i = 0, j = 0;
