@@ -9,12 +9,12 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	// $Id: setup.inc.php 24005 2007-06-03 21:00:11Z ralfbecker $
+	// $Id: setup.inc.php 25279 2008-04-15 13:05:31Z ralfbecker $
 
 	/* Basic information about this app */
 	$setup_info['phpgwapi']['name']      = 'phpgwapi';
 	$setup_info['phpgwapi']['title']     = 'eGroupWare API';
-	$setup_info['phpgwapi']['version']   = '1.2.107';
+	$setup_info['phpgwapi']['version']   = '1.4.004';
 	$setup_info['phpgwapi']['versions']['current_header'] = '1.28';
 	$setup_info['phpgwapi']['enable']    = 3;
 	$setup_info['phpgwapi']['app_order'] = 1;
@@ -33,8 +33,6 @@
 	$setup_info['phpgwapi']['tables'][]  = 'egw_lang';
 	$setup_info['phpgwapi']['tables'][]  = 'egw_nextid';
 	$setup_info['phpgwapi']['tables'][]  = 'egw_categories';
-	$setup_info['phpgwapi']['tables'][]  = 'egw_addressbook';
-	$setup_info['phpgwapi']['tables'][]  = 'egw_addressbook_extra';
 	$setup_info['phpgwapi']['tables'][]  = 'egw_log';
 	$setup_info['phpgwapi']['tables'][]  = 'egw_log_msg';
 	$setup_info['phpgwapi']['tables'][]  = 'egw_interserv';
@@ -50,15 +48,24 @@
 	$setup_info['phpgwapi']['tables'][]  = 'phpgw_vfs2_versioning';
 	$setup_info['phpgwapi']['tables'][]  = 'phpgw_vfs2_customfields_data';
 	$setup_info['phpgwapi']['tables'][]  = 'phpgw_vfs2_prefixes';
-	$setup_info['phpgwapi']['tables'][]  = 'egw_contentmap';
-	$setup_info['phpgwapi']['tables'][]  = 'egw_syncmldevinfo';
-	$setup_info['phpgwapi']['tables'][]  = 'egw_syncmlsummary';
 	$setup_info['phpgwapi']['tables'][]  = 'egw_links';
+	$setup_info['phpgwapi']['tables'][]  = 'egw_addressbook';
+	$setup_info['phpgwapi']['tables'][]  = 'egw_addressbook_extra';
+	$setup_info['phpgwapi']['tables'][]  = 'egw_addressbook_lists';
+	$setup_info['phpgwapi']['tables'][]  = 'egw_addressbook2list';
+
+	// hooks used by vfs_home to manage user- and group-directories
+	$setup_info['phpgwapi']['hooks']['addaccount']		= 'phpgwapi.vfs_home.addAccount';
+	$setup_info['phpgwapi']['hooks']['deleteaccount']	= 'phpgwapi.vfs_home.deleteAccount';
+	$setup_info['phpgwapi']['hooks']['editaccount']		= 'phpgwapi.vfs_home.editAccount';
+	$setup_info['phpgwapi']['hooks']['addgroup']		= 'phpgwapi.vfs_home.addGroup';
+	$setup_info['phpgwapi']['hooks']['deletegroup']		= 'phpgwapi.vfs_home.deleteGroup';
+	$setup_info['phpgwapi']['hooks']['editgroup']		= 'phpgwapi.vfs_home.editGroup';
 
 	/* Basic information about this app */
 	$setup_info['notifywindow']['name']      = 'notifywindow';
 	$setup_info['notifywindow']['title']     = 'Notify Window';
-	$setup_info['notifywindow']['version']   = '1.2';
+	$setup_info['notifywindow']['version']   = '1.0.0';
 	$setup_info['notifywindow']['enable']    = 2;
 	$setup_info['notifywindow']['app_order'] = 1;
 	$setup_info['notifywindow']['tables']    = '';
@@ -66,5 +73,3 @@
 
 
 
-
-
