@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	// $Id: tables_current.inc.php 21980 2006-06-28 12:24:53Z nelius_weiss $
+	// $Id: tables_current.inc.php 23741 2007-04-30 10:29:44Z lkneschke $
 	// $Source$
 
 	$phpgw_baseline = array(
@@ -55,17 +55,13 @@
 				'account_id' => array('type' => 'auto','nullable' => False),
 				'account_lid' => array('type' => 'varchar','precision' => '64','nullable' => False),
 				'account_pwd' => array('type' => 'varchar','precision' => '100','nullable' => False),
-				'account_firstname' => array('type' => 'varchar','precision' => '50'),
-				'account_lastname' => array('type' => 'varchar','precision' => '50'),
 				'account_lastlogin' => array('type' => 'int','precision' => '4'),
 				'account_lastloginfrom' => array('type' => 'varchar','precision' => '255'),
 				'account_lastpwd_change' => array('type' => 'int','precision' => '4'),
 				'account_status' => array('type' => 'char','precision' => '1','nullable' => False,'default' => 'A'),
 				'account_expires' => array('type' => 'int','precision' => '4'),
 				'account_type' => array('type' => 'char','precision' => '1'),
-				'person_id' => array('type' => 'int','precision' => '4'),
-				'account_primary_group' => array('type' => 'int','precision' => '4','nullable' => False,'default' => '0'),
-				'account_email' => array('type' => 'varchar','precision' => '100')
+				'account_primary_group' => array('type' => 'int','precision' => '4','nullable' => False,'default' => '0')
 			),
 			'pk' => array('account_id'),
 			'fk' => array(),
@@ -189,79 +185,6 @@
 			'ix' => array(array('cat_appname','cat_owner','cat_parent','cat_level')),
 			'uc' => array()
 		),
-		'egw_addressbook' => array(
-			'fd' => array(
-				'id' => array('type' => 'auto','nullable' => False),
-				'lid' => array('type' => 'varchar','precision' => '32'),
-				'tid' => array('type' => 'char','precision' => '1'),
-				'owner' => array('type' => 'int','precision' => '8'),
-				'access' => array('type' => 'varchar','precision' => '7'),
-				'cat_id' => array('type' => 'varchar','precision' => '32'),
-				'fn' => array('type' => 'varchar','precision' => '64'),
-				'n_family' => array('type' => 'varchar','precision' => '64'),
-				'n_given' => array('type' => 'varchar','precision' => '64'),
-				'n_middle' => array('type' => 'varchar','precision' => '64'),
-				'n_prefix' => array('type' => 'varchar','precision' => '64'),
-				'n_suffix' => array('type' => 'varchar','precision' => '64'),
-				'sound' => array('type' => 'varchar','precision' => '64'),
-				'bday' => array('type' => 'varchar','precision' => '32'),
-				'note' => array('type' => 'text'),
-				'tz' => array('type' => 'varchar','precision' => '8'),
-				'geo' => array('type' => 'varchar','precision' => '32'),
-				'url' => array('type' => 'varchar','precision' => '128'),
-				'pubkey' => array('type' => 'text'),
-				'org_name' => array('type' => 'varchar','precision' => '64'),
-				'org_unit' => array('type' => 'varchar','precision' => '64'),
-				'title' => array('type' => 'varchar','precision' => '64'),
-				'adr_one_street' => array('type' => 'varchar','precision' => '64'),
-				'adr_one_locality' => array('type' => 'varchar','precision' => '64'),
-				'adr_one_region' => array('type' => 'varchar','precision' => '64'),
-				'adr_one_postalcode' => array('type' => 'varchar','precision' => '64'),
-				'adr_one_countryname' => array('type' => 'varchar','precision' => '64'),
-				'adr_one_type' => array('type' => 'varchar','precision' => '32'),
-				'label' => array('type' => 'text'),
-				'adr_two_street' => array('type' => 'varchar','precision' => '64'),
-				'adr_two_locality' => array('type' => 'varchar','precision' => '64'),
-				'adr_two_region' => array('type' => 'varchar','precision' => '64'),
-				'adr_two_postalcode' => array('type' => 'varchar','precision' => '64'),
-				'adr_two_countryname' => array('type' => 'varchar','precision' => '64'),
-				'adr_two_type' => array('type' => 'varchar','precision' => '32'),
-				'tel_work' => array('type' => 'varchar','precision' => '40','nullable' => False,'default' => '+1 (000) 000-0000'),
-				'tel_home' => array('type' => 'varchar','precision' => '40','nullable' => False,'default' => '+1 (000) 000-0000'),
-				'tel_voice' => array('type' => 'varchar','precision' => '40','nullable' => False,'default' => '+1 (000) 000-0000'),
-				'tel_fax' => array('type' => 'varchar','precision' => '40','nullable' => False,'default' => '+1 (000) 000-0000'),
-				'tel_msg' => array('type' => 'varchar','precision' => '40','nullable' => False,'default' => '+1 (000) 000-0000'),
-				'tel_cell' => array('type' => 'varchar','precision' => '40','nullable' => False,'default' => '+1 (000) 000-0000'),
-				'tel_pager' => array('type' => 'varchar','precision' => '40','nullable' => False,'default' => '+1 (000) 000-0000'),
-				'tel_bbs' => array('type' => 'varchar','precision' => '40','nullable' => False,'default' => '+1 (000) 000-0000'),
-				'tel_modem' => array('type' => 'varchar','precision' => '40','nullable' => False,'default' => '+1 (000) 000-0000'),
-				'tel_car' => array('type' => 'varchar','precision' => '40','nullable' => False,'default' => '+1 (000) 000-0000'),
-				'tel_isdn' => array('type' => 'varchar','precision' => '40','nullable' => False,'default' => '+1 (000) 000-0000'),
-				'tel_video' => array('type' => 'varchar','precision' => '40','nullable' => False,'default' => '+1 (000) 000-0000'),
-				'tel_prefer' => array('type' => 'varchar','precision' => '32'),
-				'email' => array('type' => 'varchar','precision' => '64'),
-				'email_type' => array('type' => 'varchar','precision' => '32','default' => 'INTERNET'),
-				'email_home' => array('type' => 'varchar','precision' => '64'),
-				'email_home_type' => array('type' => 'varchar','precision' => '32','default' => 'INTERNET'),
-				'last_mod' => array('type' => 'int','precision' => '8','nullable' => False)
-			),
-			'pk' => array('id'),
-			'fk' => array(),
-			'ix' => array(array('tid','owner','access','n_family','n_given','email'),array('tid','cat_id','owner','access','n_family','n_given','email')),
-			'uc' => array()
-		),
-		'egw_addressbook_extra' => array(
-			'fd' => array(
-				'contact_id' => array('type' => 'int','precision' => '4','nullable' => False),
-				'contact_owner' => array('type' => 'int','precision' => '8'),
-				'contact_name' => array('type' => 'varchar','precision' => '255','nullable' => False),
-				'contact_value' => array('type' => 'text')
-			),
-			'pk' => array('contact_id','contact_name'),
-			'fk' => array(),
-			'ix' => array(),
-			'uc' => array()
-		),
 		'egw_log' => array(
 			'fd' => array(
 				'log_id' => array('type' => 'auto','precision' => '4','nullable' => False),
@@ -320,8 +243,8 @@
 				'vfs_owner_id' => array('type' => 'int','precision' => '4','nullable' => False),
 				'vfs_createdby_id' => array('type' => 'int','precision' => '4'),
 				'vfs_modifiedby_id' => array('type' => 'int','precision' => '4'),
-				'vfs_created' => array('type' => 'date','nullable' => False,'default' => '1970-01-01'),
-				'vfs_modified' => array('type' => 'date'),
+				'vfs_created' => array('type' => 'timestamp','nullable' => False,'default' => 'current_timestamp'),
+				'vfs_modified' => array('type' => 'timestamp'),
 				'vfs_size' => array('type' => 'int','precision' => '4'),
 				'vfs_mime_type' => array('type' => 'varchar','precision' => '64'),
 				'vfs_deleteable' => array('type' => 'char','precision' => '1','default' => 'Y'),
@@ -332,7 +255,7 @@
 				'vfs_link_directory' => array('type' => 'varchar','precision' => '255'),
 				'vfs_link_name' => array('type' => 'varchar','precision' => '128'),
 				'vfs_version' => array('type' => 'varchar','precision' => '30','nullable' => False,'default' => '0.0.0.0'),
-				'vfs_content' => array('type' => 'text')
+				'vfs_content' => array('type' => 'blob')
 			),
 			'pk' => array('vfs_file_id'),
 			'fk' => array(),
@@ -506,50 +429,6 @@
 			'ix' => array(),
 			'uc' => array()
 		),
-		'egw_contentmap' => array(
-			'fd' => array(
-				'map_id' => array('type' => 'varchar','precision' => '128','nullable' => False),
-				'map_guid' => array('type' => 'varchar','precision' => '100','nullable' => False),
-				'map_locuid' => array('type' => 'varchar','precision' => '100','nullable' => False),
-				'map_timestamp' => array('type' => 'timestamp','nullable' => False),
-				'map_expired' => array('type' => 'bool','nullable' => False)
-			),
-			'pk' => array('map_id','map_guid','map_locuid'),
-			'fk' => array(),
-			'ix' => array('map_expired',array('map_id','map_locuid')),
-			'uc' => array()
-		),
-		'egw_syncmldevinfo' => array(
-			'fd' => array(
-				'dev_id' => array('type' => 'varchar','precision' => '255','nullable' => False),
-				'dev_dtdversion' => array('type' => 'varchar','precision' => '10','nullable' => False),
-				'dev_numberofchanges' => array('type' => 'bool','nullable' => False),
-				'dev_largeobjs' => array('type' => 'bool','nullable' => False),
-				'dev_swversion' => array('type' => 'varchar','precision' => '100','nullable' => False),
-				'dev_oem' => array('type' => 'varchar','precision' => '100','nullable' => False),
-				'dev_model' => array('type' => 'varchar','precision' => '100','nullable' => False),
-				'dev_manufacturer' => array('type' => 'varchar','precision' => '100','nullable' => False),
-				'dev_devicetype' => array('type' => 'varchar','precision' => '100','nullable' => False),
-				'dev_deviceid' => array('type' => 'varchar','precision' => '100','nullable' => False),
-				'dev_datastore' => array('type' => 'text','nullable' => False)
-			),
-			'pk' => array('dev_id'),
-			'fk' => array(),
-			'ix' => array(),
-			'uc' => array()
-		),
-		'egw_syncmlsummary' => array(
-			'fd' => array(
-				'dev_id' => array('type' => 'varchar','precision' => '255','nullable' => False),
-				'sync_path' => array('type' => 'varchar','precision' => '100','nullable' => False),
-				'sync_serverts' => array('type' => 'varchar','precision' => '20','nullable' => False),
-				'sync_clientts' => array('type' => 'varchar','precision' => '20','nullable' => False)
-			),
-			'pk' => array(array('dev_id','sync_path')),
-			'fk' => array(),
-			'ix' => array(),
-			'uc' => array()
-		),
 		'egw_links' => array(
 			'fd' => array(
 				'link_id' => array('type' => 'auto','nullable' => False),
@@ -558,12 +437,116 @@
 				'link_app2' => array('type' => 'varchar','precision' => '25','nullable' => False),
 				'link_id2' => array('type' => 'varchar','precision' => '50','nullable' => False),
 				'link_remark' => array('type' => 'varchar','precision' => '100'),
-				'link_lastmod' => array('type' => 'int','precision' => '4','nullable' => False),
+				'link_lastmod' => array('type' => 'int','precision' => '8','nullable' => False),
 				'link_owner' => array('type' => 'int','precision' => '4','nullable' => False)
 			),
 			'pk' => array('link_id'),
 			'fk' => array(),
 			'ix' => array(array('link_app1','link_id1','link_lastmod'),array('link_app2','link_id2','link_lastmod')),
 			'uc' => array()
+		),
+		'egw_addressbook' => array(
+			'fd' => array(
+				'contact_id' => array('type' => 'auto','nullable' => False),
+				'contact_tid' => array('type' => 'char','precision' => '1','default' => 'n'),
+				'contact_owner' => array('type' => 'int','precision' => '8','nullable' => False),
+				'contact_private' => array('type' => 'int','precision' => '1','default' => '0'),
+				'cat_id' => array('type' => 'varchar','precision' => '255'),
+				'n_family' => array('type' => 'varchar','precision' => '64'),
+				'n_given' => array('type' => 'varchar','precision' => '64'),
+				'n_middle' => array('type' => 'varchar','precision' => '64'),
+				'n_prefix' => array('type' => 'varchar','precision' => '64'),
+				'n_suffix' => array('type' => 'varchar','precision' => '64'),
+				'n_fn' => array('type' => 'varchar','precision' => '128'),
+				'n_fileas' => array('type' => 'varchar','precision' => '255'),
+				'contact_bday' => array('type' => 'varchar','precision' => '12'),
+				'org_name' => array('type' => 'varchar','precision' => '64'),
+				'org_unit' => array('type' => 'varchar','precision' => '64'),
+				'contact_title' => array('type' => 'varchar','precision' => '64'),
+				'contact_role' => array('type' => 'varchar','precision' => '64'),
+				'contact_assistent' => array('type' => 'varchar','precision' => '64'),
+				'contact_room' => array('type' => 'varchar','precision' => '64'),
+				'adr_one_street' => array('type' => 'varchar','precision' => '64'),
+				'adr_one_street2' => array('type' => 'varchar','precision' => '64'),
+				'adr_one_locality' => array('type' => 'varchar','precision' => '64'),
+				'adr_one_region' => array('type' => 'varchar','precision' => '64'),
+				'adr_one_postalcode' => array('type' => 'varchar','precision' => '64'),
+				'adr_one_countryname' => array('type' => 'varchar','precision' => '64'),
+				'contact_label' => array('type' => 'text'),
+				'adr_two_street' => array('type' => 'varchar','precision' => '64'),
+				'adr_two_street2' => array('type' => 'varchar','precision' => '64'),
+				'adr_two_locality' => array('type' => 'varchar','precision' => '64'),
+				'adr_two_region' => array('type' => 'varchar','precision' => '64'),
+				'adr_two_postalcode' => array('type' => 'varchar','precision' => '64'),
+				'adr_two_countryname' => array('type' => 'varchar','precision' => '64'),
+				'tel_work' => array('type' => 'varchar','precision' => '40'),
+				'tel_cell' => array('type' => 'varchar','precision' => '40'),
+				'tel_fax' => array('type' => 'varchar','precision' => '40'),
+				'tel_assistent' => array('type' => 'varchar','precision' => '40'),
+				'tel_car' => array('type' => 'varchar','precision' => '40'),
+				'tel_pager' => array('type' => 'varchar','precision' => '40'),
+				'tel_home' => array('type' => 'varchar','precision' => '40'),
+				'tel_fax_home' => array('type' => 'varchar','precision' => '40'),
+				'tel_cell_private' => array('type' => 'varchar','precision' => '40'),
+				'tel_other' => array('type' => 'varchar','precision' => '40'),
+				'tel_prefer' => array('type' => 'varchar','precision' => '32'),
+				'contact_email' => array('type' => 'varchar','precision' => '64'),
+				'contact_email_home' => array('type' => 'varchar','precision' => '64'),
+				'contact_url' => array('type' => 'varchar','precision' => '128'),
+				'contact_url_home' => array('type' => 'varchar','precision' => '128'),
+				'contact_freebusy_uri' => array('type' => 'varchar','precision' => '128'),
+				'contact_calendar_uri' => array('type' => 'varchar','precision' => '128'),
+				'contact_note' => array('type' => 'text'),
+				'contact_tz' => array('type' => 'varchar','precision' => '8'),
+				'contact_geo' => array('type' => 'varchar','precision' => '32'),
+				'contact_pubkey' => array('type' => 'text'),
+				'contact_created' => array('type' => 'int','precision' => '8'),
+				'contact_creator' => array('type' => 'int','precision' => '4','nullable' => False),
+				'contact_modified' => array('type' => 'int','precision' => '8','nullable' => False),
+				'contact_modifier' => array('type' => 'int','precision' => '4'),
+				'contact_jpegphoto' => array('type' => 'blob'),
+				'account_id' => array('type' => 'int','precision' => '4')
+			),
+			'pk' => array('contact_id'),
+			'fk' => array(),
+			'ix' => array('contact_owner','cat_id','n_fileas',array('n_family','n_given'),array('n_given','n_family'),array('org_name','n_family','n_given')),
+			'uc' => array('account_id')
+		),
+		'egw_addressbook_extra' => array(
+			'fd' => array(
+				'contact_id' => array('type' => 'int','precision' => '4','nullable' => False),
+				'contact_owner' => array('type' => 'int','precision' => '8'),
+				'contact_name' => array('type' => 'varchar','precision' => '255','nullable' => False),
+				'contact_value' => array('type' => 'text')
+			),
+			'pk' => array('contact_id','contact_name'),
+			'fk' => array(),
+			'ix' => array(),
+			'uc' => array()
+		),
+		'egw_addressbook_lists' => array(
+			'fd' => array(
+				'list_id' => array('type' => 'auto','nullable' => False),
+				'list_name' => array('type' => 'varchar','precision' => '80','nullable' => False),
+				'list_owner' => array('type' => 'int','precision' => '4','nullable' => False),
+				'list_created' => array('type' => 'int','precision' => '8'),
+				'list_creator' => array('type' => 'int','precision' => '4')
+			),
+			'pk' => array('list_id'),
+			'fk' => array(),
+			'ix' => array(),
+			'uc' => array(array('list_owner','list_name'))
+		),
+		'egw_addressbook2list' => array(
+			'fd' => array(
+				'contact_id' => array('type' => 'int','precision' => '4','nullable' => False),
+				'list_id' => array('type' => 'int','precision' => '4','nullable' => False),
+				'list_added' => array('type' => 'int','precision' => '8'),
+				'list_added_by' => array('type' => 'int','precision' => '4')
+			),
+			'pk' => array('contact_id','list_id'),
+			'fk' => array(),
+			'ix' => array(),
+			'uc' => array()
 		)
 	);
