@@ -11,12 +11,12 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: hook_home.inc.php 19418 2005-10-14 16:10:00Z ralfbecker $ */
+	/* $Id: hook_home.inc.php 23913 2007-05-22 04:04:13Z lkneschke $ */
 
 	$hp_display = (int)$GLOBALS['egw_info']['user']['preferences']['polls']['homepage_display'];
 	if($hp_display > 0)
 	{
-		$obj =& CreateObject('polls.ui');
+		$obj =& CreateObject('polls.uipolls');
 		$obj->view();
 	}
 ?>
