@@ -11,7 +11,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: hook_sidebox_menu.inc.php 19418 2005-10-14 16:10:00Z ralfbecker $ */
+	/* $Id: hook_sidebox_menu.inc.php 23913 2007-05-22 04:04:13Z lkneschke $ */
 {
 
  /*
@@ -27,9 +27,9 @@
 	$menu_title = 'Polls Menu';
 	$file = Array(
 		'Current Poll'
-			=> $GLOBALS['egw']->link('/index.php', array('menuaction'=>'polls.ui.index')),
+			=> $GLOBALS['egw']->link('/index.php', array('menuaction'=>'polls.uipolls.index')),
 		'View Results' 
-			=> $GLOBALS['egw']->link('/index.php', array('menuaction'=>'polls.ui.vote','show_results'=>$GLOBALS['poll_settings']['currentpoll']))
+			=> $GLOBALS['egw']->link('/index.php', array('menuaction'=>'polls.uipolls.vote','show_results'=>$GLOBALS['poll_settings']['currentpoll']))
 	);
 	display_sidebox($appname,$menu_title,$file);
 
@@ -45,14 +45,16 @@
 	{
 		$menu_title = 'Administration';
 		$file = Array(
-			'Poll Settings'
-				=> $GLOBALS['egw']->link('/index.php', array('menuaction'=>'polls.ui.admin','action'=>'settings')),
+			'Site configuration'
+				=> $GLOBALS['egw']->link('/index.php', array('menuaction'=>'polls.uipolls.admin','action'=>'settings')),
 			'Show Questions'
-				=> $GLOBALS['egw']->link('/index.php', array('menuaction'=>'polls.ui.admin','action'=>'show','type'=>'question')),
+				=> $GLOBALS['egw']->link('/index.php', array('menuaction'=>'polls.uipolls.admin','action'=>'show','type'=>'question')),
 			'Add Questions'
-				=> $GLOBALS['egw']->link('/index.php', array('menuaction'=>'polls.ui.admin','action'=>'add','type'=>'question')),
+				=> $GLOBALS['egw']->link('/index.php', array('menuaction'=>'polls.uipolls.admin','action'=>'add','type'=>'question')),
+			'Show Answers'
+				=> $GLOBALS['egw']->link('/index.php', array('menuaction'=>'polls.uipolls.admin','action'=>'show','type'=>'answer')),
 			'Add Answers'
-				=> $GLOBALS['egw']->link('/index.php', array('menuaction'=>'polls.ui.admin','action'=>'add','type'=>'answer')),
+				=> $GLOBALS['egw']->link('/index.php', array('menuaction'=>'polls.uipolls.admin','action'=>'add','type'=>'answer')),
 		);
 
 		display_sidebox($appname,$menu_title,$file);
