@@ -12,7 +12,7 @@
 	* Free Software Foundation; either version 2 of the License, or (at your   *
 	* option) any later version.                                               *
 	\**************************************************************************/
-	/* $Id: class.uicategories.inc.php 19703 2005-11-09 13:32:40Z ralfbecker $ */
+	/* $Id: class.uicategories.inc.php 24717 2007-11-27 17:23:40Z pbf $ */
 
 	class uicategories
 	{
@@ -113,7 +113,7 @@
 
 			// make categories called via sidebox menu of an app, to behave like a part of that app
 			$referer = $GLOBALS['egw']->common->get_referer('/preferences/index.php');
-			if (!strstr($referer,'menuaction=preferences.uicategories'))
+			if (strpos($referer,'menuaction=preferences.uicategories') === false)
 			{
 				$this->referer = $referer;
 			}
@@ -331,6 +331,8 @@
 				'cats_level'	=> $cats_level,
 				'cat_id'		=> $cat_id
 			);
+			if (!preg_match('/^(#[0-9a-f]+|[a-z]+)?$/i',$_POST['cat_data']['color'])) unset($_POST['cat_data']['color']);
+			if (!preg_match('/^[-_\.a-z0-9]+\.(png|gif|jpe?g)$/i',$_POST['cat_data']['icon'])) unset($_POST['cat_data']['icon']);
 			$new_parent			= $_POST['new_parent'];
 			$cat_parent			= $_POST['cat_parent'];
 			$cat_name			= $_POST['cat_name'];
@@ -421,7 +423,7 @@
 				$type = 'mains';
 			}
 
-			$GLOBALS['egw']->template->set_var('category_list',$this->bo->cats->formated_list(array(
+			$GLOBALS['egw']->template->set_var('category_list',$this->bo->cats->formatted_list(array(
 				'type' => $type,'selected' => $cat['parent'],
 				'globals' => $global_cats, 'self' => $cat_id
 			)));
