@@ -10,9 +10,9 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: hook_preferences.inc.php 19547 2005-11-02 11:45:52Z ralfbecker $ */
+	/* $Id: hook_preferences.inc.php 21931 2006-06-23 01:27:56Z ralfbecker $ */
 
-	if ($GLOBALS['egw']->acl->check('changepassword',1))
+	if (!$GLOBALS['egw']->acl->check('nopasswordchange',1))
 	{
 		$file['Change your Password'] = $GLOBALS['egw']->link('/index.php','menuaction=preferences.uipassword.change');
 	}
