@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: hook_settings.inc.php 19417 2005-10-14 14:31:35Z ralfbecker $ */
+	/* $Id: hook_settings.inc.php 24457 2007-09-22 15:03:03Z ralfbecker $ */
 
 	/* Setup some values to fill the array of this app's settings below */
 	$templates = $GLOBALS['egw']->common->list_templates();
@@ -40,10 +40,10 @@
 	{
 		$format .= 'H:i';
 	}
-	for($i = -23; $i<24; $i++)
+	for($i = -23.5; $i < 24.0; $i += 0.5)
 	{
-		$t = time() + $i * 60*60;
-		$tz_offset[$i] = $i . ' ' . lang('hours').': ' . date($format,$t);
+		$t = time() + round($i * 3600);
+		$tz_offset[(string)$i] = sprintf('%3.1lf',$i) . ' ' . lang('hours').': ' . date($format,$t);
 	}
 
 	$date_formats = array(
@@ -67,7 +67,6 @@
 		'24' => lang('24 hour')
 	);
 
-	$sbox =& CreateObject('phpgwapi.sbox');
 	$langs = $GLOBALS['egw']->translation->get_installed_langs();
 
 	$user_apps = array();
@@ -80,9 +79,11 @@
 	}
 
 	$account_sels = array(
-		'selectbox' => lang('Selectbox'),
+		'selectbox'     => lang('Selectbox'),
 		'primary_group' => lang('Selectbox with primary group and search'),
-		'popup'     => lang('Popup with search')
+		'popup'         => lang('Popup with search'),
+		'groupmembers'  => lang('Selectbox with groupmembers'),
+		'none'          => lang('No user-selection at all'),
 	);
 
 	$account_display = array(
@@ -163,7 +164,7 @@
 			'type'   => 'select',
 			'label'  => 'Country',
 			'name'   => 'country',
-			'values' => $sbox->country_array,
+			'values' => ExecMethod('phpgwapi.country.countries'),
 			'help'   => 'In which country are you. This is used to set certain defaults for you.',
 			'xmlrpc' => True,
 			'admin'  => False
@@ -207,7 +208,9 @@
 			'label'  => 'How do you like to select accounts',
 			'name'   => 'account_selection',
 			'values' => $account_sels,
-			'help'   => 'The selectbox shows all available users (can be very slow on big installs with many users). The popup can search users by name or group.',
+			'help'   => lang('The selectbox shows all available users (can be very slow on big installs with many users). The popup can search users by name or group.').' '.
+				lang('The two last options limit the visibility of other users. Therefore they should be forced and apply NOT to administrators.'),
+			'run_lang' => false,
 			'xmlrpc' => True,
 			'admin'  => False
 		),
@@ -227,5 +230,23 @@
 			'help'   => 'Should this help messages shown up always, when you enter the preferences or only on request.',
 			'xmlrpc' => False,
 			'admin'  => False
-		)
+		),
+		'enable_dragdrop' => array(
+			'type'   => 'check',
+			'label'  => 'Enable drag and drop functionality (experimental)',
+			'name'   => 'enable_dragdrop',
+			'help'   => 'Enables or disables drag and drop functions in all applications. If the browser does not support '.
+				    'drag and drop, it will be disabled automatically. This feature is experimental at the moment.',
+			'xmlrpc' => False,
+			'admin'  => False
+		),
+		'csv_charset' => array(
+			'type'   => 'select',
+			'label'  => 'Charset for the CSV export',
+			'name'   => 'csv_charset',
+			'values' => $GLOBALS['egw']->translation->get_installed_charsets()+array('utf-8' => 'utf-8 (Unicode)'),		
+			'help'   => 'Which charset should be used for the CSV export. The system default is the charset of this eGroupWare installation.',
+			'xmlrpc' => True,
+			'admin'  => false,
+		),
 	);
