@@ -1,26 +1,19 @@
 <?php
-/**************************************************************************\
-* eGroupWare - ProjectManager - Pricelist buisness object                  *
-* http://www.egroupware.org                                                *
-* Written and (c) 2005 by Ralf Becker <RalfBecker@outdoor-training.de>     *
-* --------------------------------------------                             *
-*  This program is free software; you can redistribute it and/or modify it *
-*  under the terms of the GNU General Public License as published by the   *
-*  Free Software Foundation; either version 2 of the License, or (at your  *
-*  option) any later version.                                              *
-\**************************************************************************/
-
-/* $Id: class.bopricelist.inc.php 23135 2006-12-27 11:12:45Z ralfbecker $ */
+/**
+ * ProjectManager - Pricelist buisness object
+ *
+ * @link http://www.egroupware.org
+ * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @package projectmanager
+ * @copyright (c) 2005 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+ * @version $Id: class.bopricelist.inc.php 23379 2007-02-05 18:50:53Z nelius_weiss $ 
+ */
 
 include_once(EGW_INCLUDE_ROOT.'/projectmanager/inc/class.sopricelist.inc.php');
 
 /**
  * Pricelist buisness object of the projectmanager
- *
- * @package projectmanager
- * @author RalfBecker-AT-outdoor-training.de
- * @copyright (c) 2005 by RalfBecker-AT-outdoor-training.de
- * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  */
 class bopricelist extends sopricelist
 {
@@ -223,7 +216,9 @@ class bopricelist extends sopricelist
 		$options = array();
 		foreach($prices as $price)
 		{
-			$options[$price['pl_id']] = $price['pl_unit'].' '.$price['pl_title'].' ('.$price['pl_price'].')';
+			$options[$price['pl_id']] = $price['pl_unit'].' '.$price['pl_title'].
+				($price['pl_customertitle'] ? ': '.$price['pl_customertitle'] : '').
+				' ('.$price['pl_price'].')';
 		}
 		return $options;
 	}
