@@ -1,16 +1,14 @@
 <?php
-/**************************************************************************\
-* eGroupWare - ProjectManager - General business object                    *
-* http://www.egroupware.org                                                *
-* Written and (c) 2005 by Ralf Becker <RalfBecker@outdoor-training.de>     *
-* --------------------------------------------                             *
-*  This program is free software; you can redistribute it and/or modify it *
-*  under the terms of the GNU General Public License as published by the   *
-*  Free Software Foundation; either version 2 of the License, or (at your  *
-*  option) any later version.                                              *
-\**************************************************************************/
-
-/* $Id: class.boprojectmanager.inc.php 22861 2006-11-22 08:19:16Z ralfbecker $ */
+/**
+ * ProjectManager - General business object
+ *
+ * @link http://www.egroupware.org
+ * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @package projectmanager
+ * @copyright (c) 2005/6 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+ * @version $Id: class.boprojectmanager.inc.php 24677 2007-11-22 14:48:38Z ralfbecker $ 
+ */
 
 include_once(EGW_INCLUDE_ROOT.'/projectmanager/inc/class.soprojectmanager.inc.php');
 
@@ -22,55 +20,70 @@ define('EGW_ACL_EDIT_BUDGET',EGW_ACL_CUSTOM_2);
  *
  * This class does all the timezone-conversation: All function expect user-time and convert them to server-time
  * before calling the storage object.
- *
- * @package projectmanager
- * @author RalfBecker-AT-outdoor-training.de
- * @copyright (c) 2005 by RalfBecker-AT-outdoor-training.de
- * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  */
 class boprojectmanager extends soprojectmanager 
 {
 	/**
-	 * @var int/string $debug 0 = no debug-messages, 1 = main, 2 = more, 3 = all, 4 = all incl. so_sql, or string with function-name to debug
+	 * Debuglevel: 0 = no debug-messages, 1 = main, 2 = more, 3 = all, 4 = all incl. so_sql, or string with function-name to debug
+	 * 
+	 * @var int/string
 	 */
 	var $debug=false;
 	/**
-	 * @var string $logfile file to log debug-messages, ''=echo them
+	 * File to log debug-messages, ''=echo them
+	 * 
+	 * @var string
 	 */
 	var $logfile='/tmp/pm_log';
 	/**
-	 * @var bolink-object $link instance of the link-class
+	 * Instance of the link-class
+	 * 
+	 * @var bolink
 	 */
 	var $link;
 	/**
-	 * @var array $timestamps timestaps that need to be adjusted to user-time on reading or saving
+	 * Timestaps that need to be adjusted to user-time on reading or saving
+	 * 
+	 * @var array
 	 */
 	var $timestamps = array(
 		'pm_created','pm_modified','pm_planned_start','pm_planned_end','pm_real_start','pm_real_end',
 	);
 	/**
-	 * @var int $tz_offset_s offset in secconds between user and server-time,
-	 *	it need to be add to a server-time to get the user-time or substracted from a user-time to get the server-time
+	 * Offset in secconds between user and server-time,	it need to be add to a server-time to get the user-time 
+	 * or substracted from a user-time to get the server-time
+	 * 
+	 * @var int
 	 */
 	var $tz_offset_s;
 	/**
-	 * @var int $now_su is the time as timestamp in user-time
+	 * Current time as timestamp in user-time
+	 * 
+	 * @var int
 	 */
 	var $now_su;
 	/**
-	 * @var object $constraints soconstraints-object, not instanciated automatic!
+	 * Instance of the soconstraints-class
+	 * 
+	 * @var soconstraints
 	 */
 	var $constraints;
 	/**
-	 * @var object $milestones somilestones-object, not instanciated automatic!
+	 * Instance of the somilestones-class
+	 * 
+	 * @var somilestones
 	 */
 	var $milestones;
 	/**
-	 * @var object $roles instance of the soroles-class, not instanciated automatic!
+	 * Instance of the soroles-class, not instanciated automatic!
+	 * 
+	 * @var soroles
 	 */
 	var $roles;
 	/**
-	 * @var boolean $is_admin atm. projectmanager-admins are identical to eGW admins, this might change in the future
+	 * Atm. projectmanager-admins are identical to eGW admins, this might change in the future
+	 * 
+	 * @var boolean
 	 */
 	var $is_admin;
 
@@ -79,6 +92,7 @@ class boprojectmanager extends soprojectmanager
 	 *
 	 * @param int $pm_id id of the project to load, default null
 	 * @param string $instanciate='' comma-separated: constraints,milestones,roles
+	 * @return boprojectmanager
 	 */
 	function boprojectmanager($pm_id=null,$instanciate='')
 	{
@@ -104,6 +118,7 @@ class boprojectmanager extends soprojectmanager
 			$GLOBALS['egw']->link =& CreateObject('phpgwapi.bolink');
 		}
 		$this->link =& $GLOBALS['egw']->link;
+		$this->links_table = $this->link->link_table;
 		
 		// atm. projectmanager-admins are identical to eGW admins, this might change in the future
 		$this->is_admin = isset($GLOBALS['egw_info']['user']['apps']['admin']);
@@ -265,7 +280,7 @@ class boprojectmanager extends soprojectmanager
 			// delete all links to project $pm_id
 			$this->link->unlink(0,'projectmanager',$pm_id);
 
-			$this->instanciate('constraints,milestones,pricelist');
+			$this->instanciate('constraints,milestones,pricelist,roles');
 
 			// delete all constraints of the project
 			$this->constraints->delete(array('pm_id' => $pm_id));
@@ -275,6 +290,9 @@ class boprojectmanager extends soprojectmanager
 			
 			// delete all pricelist items of the project
 			$this->pricelist->delete(array('pm_id' => $pm_id));
+			
+			// delete all project specific roles
+			$this->roles->delete(array('pm_id' => $pm_id));
 		}
 		return $ret;
 	}
@@ -363,7 +381,7 @@ class boprojectmanager extends soprojectmanager
 	 * @param int $required EGW_ACL_READ, EGW_ACL_WRITE, EGW_ACL_ADD, EGW_ACL_DELETE, EGW_ACL_BUDGET, EGW_ACL_EDIT_BUDGET
 	 * @param array/int $data=null project or project-id to use, default the project in $this->data
 	 * @param boolean $no_cache=false should a cached value be used, if availible, or not
-	 * @return boolean true if the rights are ok, false if not
+	 * @return boolean true if the rights are ok, false if not or null if entry not found
 	 */
 	function check_acl($required,$data=0,$no_cache=false)
 	{
@@ -384,7 +402,7 @@ class boprojectmanager extends soprojectmanager
 					$data =& $this->read($data);
 					$this->data =& $data_backup; unset($data_backup);
 				
-					if (!$data) return false;	// $pm_id not found ==> no rights
+					if (!$data) return null;	// $pm_id not found ==> no rights
 				}
 			}
 			else
@@ -411,13 +429,34 @@ class boprojectmanager extends soprojectmanager
 		return (boolean) ($rights[$pm_id] & $required);
 	}
 	
+	/**
+	 * Read a project
+	 * 
+	 * reimplemented to add an acl check
+	 *
+	 * @param array $keys
+	 * @return array/boolean array with project, null if project not found or false if no perms to view it
+	 */
+	function read($keys)
+	{
+		if (!parent::read($keys))
+		{
+			return null;
+		}
+		if (!$this->check_acl(EGW_ACL_READ))
+		{
+			return false;
+		}
+		return $this->data;
+	}
+	
 	/**
 	 * get title for an project identified by $entry
 	 * 
 	 * Is called as hook to participate in the linking
 	 *
 	 * @param int/array $entry int pm_id or array with project entry
-	 * @param string the title
+	 * @param string/boolean string with title, null if project not found or false if no perms to view it
 	 */
 	function link_title( $entry )
 	{
@@ -427,7 +466,7 @@ class boprojectmanager extends soprojectmanager
 		}
 		if (!$entry)
 		{
-			return False;
+			return $entry;
 		}
 		return $entry['pm_number'].': '.$entry['pm_title'];
 	}
@@ -489,7 +528,6 @@ class boprojectmanager extends soprojectmanager
 	 * @param array $ancestors=array() already identified ancestors, default none
 	 * @return array with ancestors
 	 */
-
 	function &ancestors($pm_id=0,$ancestors=array())
 	{
 		static $ancestors_cache = array();	// some caching
@@ -522,6 +560,48 @@ class boprojectmanager extends soprojectmanager
 		return array_merge($ancestors,$ancestors_cache[$pm_id]);
 	}
 	
+	/**
+	 * gets recursive all children (only projects) of a given project (calls itself recursivly)
+	 *
+	 * A project P is the parent of an other project C, if link_id1=P.pm_id and link_id2=C.pm_id !
+	 * To get all children of a project C, we use all links to the project, which link_id1=C.pm_id.
+	 *
+	 * @param int $pm_id=0 id or 0 to use $this->pm_id
+	 * @param array $children=array() already identified ancestors, default none
+	 * @return array with children
+	 */
+	function &children($pm_id=0,$children=array())
+	{
+		static $children_cache = array();	// some caching
+
+		if (!$pm_id && !($pm_id = $this->pm_id)) return false;
+		
+		if (!isset($children_cache[$pm_id]))
+		{
+			$children_cache[$pm_id] = array();
+
+			// read all projectmanager entries attached to this one
+			foreach($this->link->get_links('projectmanager',$pm_id,'projectmanager') as $link_id => $data)
+			{
+				// we need to read the complete link, to know if the entry is a child (link_id1 == pm_id)
+				$link = $this->link->get_link($link_id);
+				if ($link['link_id1'] != $pm_id)
+				{
+					continue;	// we are NOT the parent in this link ==> ignore it
+				}
+				$child = (int) $link['link_id2'];
+				if (!in_array($child,$children_cache[$pm_id]))
+				{
+					$children_cache[$pm_id][] = $child;
+					// now we call ourself recursivly to get all parents of the parents
+					$children_cache[$pm_id] =& $this->children($child,$children_cache[$pm_id]);
+				}			
+			}
+		}
+		//echo "<p>children($pm_id)=".print_r($children_cache[$pm_id],true)."</p>\n";
+		return array_merge($children,$children_cache[$pm_id]);
+	}
+	
 	/**
 	 * Query the project-tree from the DB, project tree is indexed by a path consisting of pm_id's delimited by slashes (/)
 	 *
@@ -731,7 +811,7 @@ class boprojectmanager extends soprojectmanager
 	 * @param int $source id of project to copy
 	 * @param int $only_stage=0 0=both stages plus saving the project, 1=copy of the project, 2=copying the element tree
 	 * @param string $parent_number='' number of the parent project, to create a sub-project-number
-	 * @return boolean true on successful copy, false otherwise (eg. permission denied)
+	 * @return int/boolean successful copy new pm_id or true if $only_stage==1, false otherwise (eg. permission denied)
 	 */
 	function copy($source,$only_stage=0,$parent_number='')
 	{
@@ -783,6 +863,6 @@ class boprojectmanager extends soprojectmanager
 		// copying the element tree
 		$elements =& CreateObject('projectmanager.boprojectelements',$this->data['pm_id']);
 		
-		return $elements->copytree((int) $source);
+		return $elements->copytree((int) $source) ? $elements->pm_id : false;
 	}
 }
\ No newline at end of file
