@@ -1,16 +1,14 @@
 <?php
-/**************************************************************************\
-* eGroupWare - ProjectManager - Ganttchart creation                        *
-* http://www.egroupware.org                                                *
-* Written and (c) 2005 by Ralf Becker <RalfBecker@outdoor-training.de>     *
-* --------------------------------------------                             *
-*  This program is free software; you can redistribute it and/or modify it *
-*  under the terms of the GNU General Public License as published by the   *
-*  Free Software Foundation; either version 2 of the License, or (at your  *
-*  option) any later version.                                              *
-\**************************************************************************/
-
-/* $Id: class.ganttchart.inc.php 22989 2006-12-12 14:07:25Z ralfbecker $ */
+/**
+ * ProjectManager - Gantchart creation
+ *
+ * @link http://www.egroupware.org
+ * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @package projectmanager
+ * @copyright (c) 2005 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+ * @version $Id: class.ganttchart.inc.php 24310 2007-07-16 10:08:15Z ralfbecker $ 
+ */
 
 include_once(EGW_INCLUDE_ROOT.'/projectmanager/inc/class.boprojectelements.inc.php');
 
@@ -20,21 +18,55 @@ if (isset($GLOBALS['php_errormsg'])) { unset ($GLOBALS['php_errormsg']); }
 // check if the admin installed a recent JPGraph parallel to eGroupWare
 if(file_exists(EGW_SERVER_ROOT . '/../jpgraph/src/jpgraph.php'))
 {
-	// using the OS font dir if we can find it, otherwise fall back to our bundled Vera font
-	foreach(array(
-		'/usr/X11R6/lib/X11/fonts/truetype/',	// linux / *nix default
-		'C:/windows/fonts/',					// windows default
-		// add your location here ...
-		EGW_SERVER_ROOT.'/projectmanager/inc/ttf-bitstream-vera-1.10/',	// our bundled Vera font
-	) as $dir)
+	if (!isset($GLOBALS['egw_info']['apps']['projectmanager']['config']))
 	{
-		if (@is_dir($dir) && (is_readable($dir.'arial.ttf') || is_readable($dir.'Vera.ttf')))
+		// read the pm ganttchart configuration and set some default if there's none
+		require_once(EGW_API_INC.'/class.config.inc.php');
+		$pm_config = new config('projectmanager');
+		$GLOBALS['egw_info']['apps']['projectmanager']['config'] = $pm_config->read_repository();
+		//_debug_array($GLOBALS['egw_info']['apps']['projectmanager']['config']);
+		unset($pm_config);
+		foreach(array(
+			'TTF_DIR'          => '',
+			'LANGUAGE_CHARSET' => 'iso-8859-1',
+			'GANTT_FONT'       => 15, //FF_ARIAL
+			'GANTT_FONT_FILE'  => 'arial.ttf',
+			'GANTT_STYLE'      => 9002, //FS_BOLD,
+			'GANTT_CHAR_ENCODE'=> false,
+		) as $name => $default)
 		{
-			define('TTF_DIR',$dir);
-			unset($dir);
-			break;
+			if (isset($GLOBALS['egw_info']['apps']['projectmanager']['config'][$name]))
+			{
+				define($name,$GLOBALS['egw_info']['apps']['projectmanager']['config'][$name]);
+			}
+			elseif($default)
+			{
+				define($name,$default);
+			}
 		}
 	}
+	if (!defined('TTF_DIR'))
+	{
+		// using the OS font dir if we can find it, otherwise fall back to our bundled Vera font
+		foreach(array(
+			'/usr/X11R6/lib/X11/fonts/truetype/',	// linux / *nix default
+			'/usr/share/fonts/ja/TrueType/',		// japanese fonts
+			'/usr/share/fonts/msttcorefonts/', 		// manual for install this fonts search at http://www.aditus.nu/jpgraph/jpdownload.php
+			'C:/windows/fonts/',					// windows default
+			// add your location here ...
+			EGW_SERVER_ROOT.'/projectmanager/inc/ttf-bitstream-vera-1.10/',	// our bundled Vera font
+		) as $dir)
+		{
+			if (@is_dir($dir) && (is_readable($dir.GANTT_FONT_FILE) || is_readable($dir.'Vera.ttf')))
+			{
+				define('TTF_DIR',$dir);
+				unset($dir);
+				break;
+			}
+		}
+	}
+	if (!defined('MBTTF_DIR')) define('MBTTF_DIR',TTF_DIR);
+
 	include(EGW_SERVER_ROOT . '/../jpgraph/src/jpgraph.php');
 	include(EGW_SERVER_ROOT . '/../jpgraph/src/jpgraph_gantt.php');
 }
@@ -43,6 +75,10 @@ else
 	include(EGW_SERVER_ROOT . '/projectmanager/inc/jpgraph-1.5.2/src/jpgraph.php');
 	include(EGW_SERVER_ROOT . '/projectmanager/inc/jpgraph-1.5.2/src/jpgraph_gantt.php');
 	define('TTF_DIR',EGW_SERVER_ROOT.'/projectmanager/inc/ttf-bitstream-vera-1.10/');
+	define('GANTT_FONT',FF_VERA);
+	define('GANTT_STYLE',FS_BOLD);
+	define('LANGUAGE_CHARSET','iso-8859-1');
+	define('GANTT_CHAR_ENCODE',true);
 }
 
 // some constanst for pre php4.3
@@ -87,21 +123,21 @@ class ganttchart extends boprojectelements
 	/**
 	 * Font used for the Gantt Chart, in the form used by JPGraphs SetFont method
 	 * 
-	 * The constructor checks for FF_ARIAL if TTF_DIR.'arial.ttf' is readable and sets FF_VERA instead if not
-	 * 
-	 * You can try with every font-family specified in jpgraph.php AND availible on your system:
-	 * eg. FF_CHINESE, FF_MINCHO, ...
-	 * Dont forget to also set $gantt_charset accordingly!
-	 * 
 	 * @var string
 	 */
-	var $gantt_font = FF_ARIAL;
+	var $gantt_font = GANTT_FONT;
 	/**
-	 * Charset used by the above font, gets set by constructor if $gannt_font is NOT set!
+	 * Charset used by the above font
 	 * 
 	 * @var string
 	 */
-	var $gantt_charset = 'iso-8859-1';
+	var $gantt_charset = LANGUAGE_CHARSET;
+	/**
+	 * Should non-ascii chars be encoded
+	 *
+	 * @var boolean
+	 */
+	var $gantt_char_encode = GANTT_CHAR_ENCODE;
 
 	var $debug;
 	var $scale_start,$scale_end;
@@ -127,6 +163,7 @@ class ganttchart extends boprojectelements
 		}
 		$this->modernJPGraph = version_compare('1.13',JPG_VERSION) < 0;
 		//echo "version=".JPG_VERSION.", modernJPGraph=".(int)$this->modernJPGraph; exit;
+		error_log("JPG_VERSION=".JPG_VERSION.", modernJPGraph=".(int)$this->modernJPGraph);
 
 		if (isset($_REQUEST['pm_id']))
 		{
@@ -156,9 +193,9 @@ class ganttchart extends boprojectelements
 		}
 		$this->charset = $GLOBALS['egw']->translation->charset();
 		$this->prefs =& $GLOBALS['egw_info']['user']['preferences'];
-		
+
 		// check if a arial font is availible and set FF_VERA (or bundled font) if not
-		if ($this->gantt_font == FF_ARIAL && !is_readable(TTF_DIR.'arial.ttf'))
+		if (!is_readable((FF_MINCHO <= GANTT_FONT && GANTT_FONT <= FF_PGOTHI ? MBTTF_DIR : TTF_DIR).GANTT_FONT_FILE))
 		{
 			$this->gantt_font = FF_VERA;
 		}
@@ -181,7 +218,7 @@ class ganttchart extends boprojectelements
 
 		// convert everything above ascii to nummeric html entities
 		// not sure if this is necessary for non iso-8859-1 charsets, try to comment it out if you have problems
-		$text = preg_replace('/[^\x00-\x7F]/e', '"&#".ord("$0").";"',$text);
+		if ($this->gantt_char_encode) $text = preg_replace('/[^\x00-\x7F]/e', '"&#".ord("$0").";"',$text);
 		
 		return $text;
 	}
@@ -300,11 +337,11 @@ class ganttchart extends boprojectelements
 		}
 		// Change the font scale 
 		$graph->scale->week->SetFont($this->gantt_font,FS_NORMAL,8);
-		$graph->scale->year->SetFont($this->gantt_font,FS_BOLD,10);
+		$graph->scale->year->SetFont($this->gantt_font,GANTT_STYLE,10);
 		
 		// Title & subtitle
 		$graph->title->Set($this->text_encode($title));
-		$graph->title->SetFont($this->gantt_font,FS_BOLD,12);
+		$graph->title->SetFont($this->gantt_font,GANTT_STYLE,12);
 		$graph->subtitle->Set($this->text_encode($subtitle));
 		$graph->subtitle->SetFont($this->gantt_font,FS_NORMAL,10);
 		
@@ -340,7 +377,7 @@ class ganttchart extends boprojectelements
 		$bar =& $this->element2bar($pe,$level,$line,$planned_times);
 
 		// set project-specific attributes: bold, solid bar, ...
-		$bar->title->SetFont($this->gantt_font,FS_BOLD,!$level ? 9 : 8);
+		$bar->title->SetFont($this->gantt_font,GANTT_STYLE,!$level ? 9 : 8);
 		$bar->SetPattern(BAND_SOLID,"#9999FF");
 		
 		if ($this->modernJPGraph && !$pe['pe_id'])	// main-project
@@ -399,15 +436,18 @@ class ganttchart extends boprojectelements
 		
 		if ($this->modernJPGraph && $pe['pe_id'])
 		{
-			$bar->SetCSIMTarget('@'.$GLOBALS['egw']->link('/index.php',array(	// @ = popup
+			$bar->SetCSIMTarget('@600x450'.$GLOBALS['egw']->link('/index.php',array(	// @ = popup
 				'menuaction' => 'projectmanager.uiprojectelements.view',
 				'pm_id'      => $pe['pm_id'],
 				'pe_id'      => $pe['pe_id'],
 			)),$pe['pe_remark'] ? $pe['pe_remark'] : lang('View this project-element'));
 			
-			$bar->title->SetCSIMTarget($GLOBALS['egw']->link('/index.php',$this->link->view($pe['pe_app'],$pe['pe_app_id'])),
+			if (($popup = $GLOBALS['egw']->link->is_popup($pe['pe_app']))) $popup = '@'.$popup;
+			$bar->title->SetCSIMTarget($popup.$GLOBALS['egw']->link('/index.php',$this->link->view($pe['pe_app'],$pe['pe_app_id'])),
 				lang('View this element in %1',lang($pe['pe_app'])));
 		}
+		$bar->title->SetFont($this->gantt_font,FS_NORMAL,!$level ? 9 : 8);
+
 		return $bar;
 	}
 
@@ -445,8 +485,8 @@ class ganttchart extends boprojectelements
 				'ms_id'      => $milestone['ms_id'],
 			));
 			$title = lang('View this milestone');
-			$ms->SetCSIMTarget('@'.$link,$title);	// @ = popup
-			$ms->title->SetCSIMTarget('@'.$link,$title);
+			$ms->SetCSIMTarget('@600x450'.$link,$title);	// @ = popup
+			$ms->title->SetCSIMTarget('@600x450'.$link,$title);
 		}
 		return $ms;
 	}
@@ -485,6 +525,7 @@ class ganttchart extends boprojectelements
 				"$end IS NOT NULL",
 				"$start <= ".(int)$this->scale_end,	// starts befor the end of our period AND
 				"$end >= ".(int)$this->scale_start,	// ends after the start of our period
+				'cumulate' => true,
 			);
 			switch ($params['filter'])
 			{
@@ -705,6 +746,21 @@ class ganttchart extends boprojectelements
 
 		return $params;		
 	}
+	
+	/**
+	 * Return message to install a new jpgraph version
+	 *
+	 * @static 
+	 * @return string/boolean message or false if a new version is installed
+	 */
+	function msg_install_new_jpgraph()
+	{
+		return version_compare('1.13',JPG_VERSION) < 0 ? false :
+			lang('You are using the old version of JPGraph, bundled with eGroupWare. It has only limited functionality.').
+			"<br />\n".lang('Please download a recent version from %1 and install it in %2.',
+			'<a href="http://www.aditus.nu/jpgraph/jpdownload.php" target="_blank">www.aditus.nu/jpgraph</a>',
+			realpath(EGW_SERVER_ROOT.'/..').SEP.'jpgraph');
+	}
 
 	/**
 	 * Shows a ganttchart
@@ -725,10 +781,7 @@ class ganttchart extends boprojectelements
 
 		if (!$GLOBALS['egw']->session->appsession('ganttchart','projectmanager') && !$this->modernJPGraph)
 		{
-			$msg .= lang('You are using the old version of JPGraph, bundled with eGroupWare. It has only limited functionality.').
-				"<br />\n".lang('Please download a recent version from %1 and install it in %2.',
-				'<a href="http://www.aditus.nu/jpgraph/jpdownload.php" target="_blank">www.aditus.nu/jpgraph</a>',
-				realpath(EGW_SERVER_ROOT.'/..').SEP.'jpgraph');
+			$msg .= $this->msg_install_new_jpgraph();
 		}
 		unset($content['update']);
 		$content = $this->url2params($content);
@@ -742,8 +795,7 @@ class ganttchart extends boprojectelements
 		$img_name = basename($img);
 		$map = $this->create($content,$img,'ganttchart');
 		// replace the regular links with popups
-		$map = preg_replace('/href="@([^"]+)"/i','href="#" onclick="window.open(\'\\1\',\'_blank\',\'dependent=yes,width=600,height=450,scrollbars=yes,status=yes\'); return false;"'
-		//.$tmpl->html->tooltip('Hallo Ralf<br>das ist ja <b>fett</b>')
+		$map = preg_replace('/href="@(\d+)x(\d+)([^"]+)"/i','href="#" onclick="egw_openWindowCentered2(\'\\3\',\'_blank\',\'dependent=yes,width=\\1,height=\\2,scrollbars=yes,status=yes\'); return false;"'
 		,$map);
 		
 		$content['ganttchart'] = $GLOBALS['egw']->link('/projectmanager/ganttchart.php',$content+array(
