@@ -1,31 +1,26 @@
 <?php
-/**************************************************************************\
-* eGroupWare - ProjectManager - UI list and edit projects-elements         *
-* http://www.egroupware.org                                                *
-* Written and (c) 2005 by Ralf Becker <RalfBecker@outdoor-training.de>     *
-* --------------------------------------------                             *
-*  This program is free software; you can redistribute it and/or modify it *
-*  under the terms of the GNU General Public License as published by the   *
-*  Free Software Foundation; either version 2 of the License, or (at your  *
-*  option) any later version.                                              *
-\**************************************************************************/
-
-/* $Id: class.uiprojectelements.inc.php 20774 2006-03-21 17:16:45Z ralfbecker $ */
+/**
+ * ProjectManager - UI to list and edit project-elments
+ *
+ * @link http://www.egroupware.org
+ * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @package projectmanager
+ * @copyright (c) 2005/6 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+ * @version $Id: class.uiprojectelements.inc.php 23913 2007-05-22 04:04:13Z lkneschke $ 
+ */
 
 include_once(EGW_INCLUDE_ROOT.'/projectmanager/inc/class.boprojectelements.inc.php');
 
 /**
  * ProjectManage UI: list and edit projects-elements
- *
- * @package projectmanager
- * @author RalfBecker-AT-outdoor-training.de
- * @copyright (c) 2005 by RalfBecker-AT-outdoor-training.de
- * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  */
 class uiprojectelements extends boprojectelements  
 {
 	/**
-	 * @var array $public_functions Functions to call via menuaction
+	 * Functions to call via menuaction
+	 * 
+	 * @var array
 	 */
 	var $public_functions = array(
 		'index' => true,
@@ -33,20 +28,28 @@ class uiprojectelements extends boprojectelements
 		'view'  => true,
 	);
 	/**
-	 * @var etemplate-object $tpl instance of the etemplate class
+	 * Instance of the etemplate class
+	 * 
+	 * @var etemplate
 	 */
 	var $tpl;
 	/**
-	 * @var array $status_labels labels for status-filter
+	 * Labels for status-filter
+	 * 
+	 * @var array
 	 */
 	var $status_labels;
 	/**
-	 * @var array $config config-settings for projectmanager
+	 * Config-settings for projectmanager
+	 * 
+	 * @var array
 	 */
 	var $config;
 
 	/**
 	 * Constructor, calls the constructor of the extended class
+	 *
+	 * @return uiprojectelements
 	 */
 	function uiprojectelements()
 	{
@@ -305,9 +308,9 @@ class uiprojectelements extends boprojectelements
 			}
 		}
 		$js .= "\nfunction calc_budget(form) {
-			form['exec[pe_used_budget]'].value = form['exec[pe_used_quantity]'].value * form['exec[pe_unitprice]'].value;
+			form['exec[pe_used_budget]'].value = form['exec[pe_used_quantity]'].value.replace(/,/,'.') * form['exec[pe_unitprice]'].value.replace(/,/,'.');
 			if (form['exec[pe_used_budget]'].value == '0') form['exec[pe_used_budget]'].value = '';
-			form['exec[pe_planned_budget]'].value = form['exec[pe_planned_quantity]'].value * form['exec[pe_unitprice]'].value;
+			form['exec[pe_planned_budget]'].value = form['exec[pe_planned_quantity]'].value.replace(/,/,'.') * form['exec[pe_unitprice]'].value.replace(/,/,'.');
 			if (form['exec[pe_planned_budget]'].value == '0') form['exec[pe_planned_budget]'].value = '';
 		}";
 		$tabs = 'dates|times|budget|constraints|resources|details';
@@ -387,14 +390,14 @@ class uiprojectelements extends boprojectelements
 	 *
 	 * reimplemented from so_sql to disable action-buttons based on the acl and make some modification on the data
 	 *
-	 * @param array $query
+	 * @param array &$query_in
 	 * @param array &$rows returned rows/cups
 	 * @param array &$readonlys eg. to disable buttons based on acl
 	 */
-	function get_rows(&$query,&$rows,&$readonlys)
+	function get_rows(&$query_in,&$rows,&$readonlys)
 	{
-		$GLOBALS['egw']->session->appsession('projectelements_list','projectmanager',$query);
-	
+		$GLOBALS['egw']->session->appsession('projectelements_list','projectmanager',$query=$query_in);
+		
 		if ($this->status_filter[$query['filter']])
 		{
 			$query['col_filter']['pe_status'] = $this->status_filter[$query['filter']];
@@ -406,19 +409,29 @@ class uiprojectelements extends boprojectelements
 		if ($query['cat_id'])
 		{
 			$query['col_filter']['cat_id'] = $query['cat_id'];
-			$query['link_add']['extra'] = array('cat_id' => $query['cat_id']);
+			$query_in['link_add']['extra'] = array('cat_id' => $query['cat_id']);
 		}
 		else
 		{
 			unset($query['col_filter']['cat_id']);
-			unset($query['link_add']['extra']);
+			unset($query_in['link_add']['extra']);
 		}
 		if (!$query['col_filter']['pe_resources'])
 		{
 			unset($query['col_filter']['pe_resources']);
 		}
+		if ($query['filter2'] & 2)	// show sub-elements (elements of sub-projects)
+		{
+			$query['col_filter']['pm_id'] = $this->project->children($this->pm_id,array($this->pm_id));
+			if (count($query['col_filter']['pm_id']) <= 1) $query['col_filter']['pm_id'] = $this->pm_id;
+			// dont show the sub-projects
+			$query['col_filter'][] = "link_app1!='projectmanager'";
+		}
+		// cumulate eg. timesheets in also included infologs
+		$query['col_filter']['cumulate'] = !($query['filter2'] & 4);
 		$total = parent::get_rows($query,$rows,$readonlys,true);
-		
+		unset($query['col_filter']['cumulate']);
+
 		// adding the project itself always as first line
 		$self = $this->update('projectmanager',$this->pm_id);
 		$self['pe_app']    = 'projectmanager';
@@ -458,8 +471,19 @@ class uiprojectelements extends boprojectelements
 						lang('View this element in %1',lang($row['pe_app'])),
 				);
 			}
-			if (!$query['filter2']) unset($row['pe_details']);
+			if (!($query['filter2']&1)) unset($row['pe_details']);
 			
+			// add project-title for elements from sub-projects
+			if (($query['filter2']&2) && $row['pm_id'] != $this->pm_id)
+			{
+				$row['pm_title'] = $this->project->link_title($row['pm_id']);
+				$row['pm_link'] = array(
+					'app'  => 'projectmanager',
+					'id'   => $row['pm_id'],
+					'title'=> $this->project->link_title($row['pm_id']),
+					'help' => lang("Select this project and show it's elements"),
+				);
+			}
 			$row['pe_completion_icon'] = $row['pe_completion'] == 100 ? 'done' : $row['pe_completion'];
 			
 			$custom_app_icons[$row['pe_app']][] = $row['pe_app_id'];
@@ -477,12 +501,31 @@ class uiprojectelements extends boprojectelements
 				}
 			}
 		}
-		$rows['no_budget'] = !$this->project->check_acl(EGW_ACL_BUDGET);
-		$rows['no_times']  = $this->project->data['pm_accounting_type'] == 'status';
+		if (!$this->project->check_acl(EGW_ACL_BUDGET))
+		{
+			$rows['no_pe_used_budget_pe_planned_budget'] = true;
+		}
+		if ($this->project->data['pm_accounting_type'] == 'status')
+		{
+			$rows['no_pe_used_time_pe_planned_time'] = true;
+		}
+		// disable time & budget columns if pm is configures for status or status and time only
+		if ($this->config['accounting_types'] == 'status')
+		{
+			$rows['no_pm_used_time_pm_planned_time'] = true;
+			$rows['no_pm_used_budget_pm_planned_budget'] = true;
+			$query_in['options-selectcols']['pm_used_time'] = $query_in['options-selectcols']['pm_planned_time'] = false;
+			$query_in['options-selectcols']['pm_used_budget'] = $query_in['options-selectcols']['pm_planned_budget'] = false;
+		}
+		if ($this->config['accounting_types'] == 'status,times')
+		{
+			$rows['no_pm_used_budget_pm_planned_budget'] = true;
+			$query_in['options-selectcols']['pm_used_budget'] = $query_in['options-selectcols']['pm_planned_budget'] = false;
+		}
 		$rows['duration_format'] = ','.$this->config['duration_format'].',,1';
-
+		if ($query['cat_id']) $rows['no_cat_id'] = true;
 		// calculate the filter-specific summary if we have a filter, beside the default pe_status=used=array(new,regular)
-		if (count($query['col_filter']) > (int)isset($query['col_filter']['pe_status']) || !is_array($query['col_filter']['pe_status']))
+		if (array_diff(array_keys($query['col_filter']),array(0,'pe_status','pm_id')) || !is_array($query['col_filter']['pe_status']))
 		{
 			$rows += $this->summary(null,$query['col_filter']);
 		}
@@ -551,10 +594,18 @@ class uiprojectelements extends boprojectelements
 				'filter_label'   => lang('Filter'),// I  label for filter    (optional)
 				'options-filter' => $this->status_labels,
 				'filter_no_lang' => True,// I  set no_lang for filter (=dont translate the options)
-				'options-filter2' => array('no details','details'),
-//				'bottom_too'     => True,// I  show the nextmatch-line (arrows, filters, search, ...) again after the rows
+				'options-filter2' => array(
+					0 => 'No details',
+					1 => 'Details',
+					2 => 'Subelements',
+					3 => 'Details of subelements',
+					4 => 'Cumulated elements too',
+					5 => 'Details of cumulated',
+				),
+				'col_filter' => array('pe_resources' => 0),	// default value, to suppress loop
 				'order'          =>	'pe_modified',// IO name of the column to sort after (optional for the sortheaders)
 				'sort'           =>	'DESC',// IO direction of the sort: 'ASC' or 'DESC'
+				'default_cols'   => '!cat_id',
 			);
 		}
 		// add "buttons" only with add-rights
@@ -579,7 +630,11 @@ class uiprojectelements extends boprojectelements
 		$content['nm']['link_add'] = array(
 			'to_id'    => $this->pm_id,
 			'to_app'   => 'projectmanager',
+			'add_app'  => 'infolog',
 		);
+		// set id for automatic linking via quick add
+		$GLOBALS['egw_info']['flags']['currentid'] = $this->pm_id;
+
 		$GLOBALS['egw_info']['flags']['app_header'] = lang('projectmanager').' - '.lang('Elementlist') .
 			': ' . $this->project->data['pm_number'] . ': ' .$this->project->data['pm_title'] ;
 		$this->tpl->read('projectmanager.elements.list');
