@@ -1,32 +1,27 @@
 <?php
-/**************************************************************************\
-* eGroupWare - ProjectManager - UI list and edit projects                  *
-* http://www.egroupware.org                                                *
-* Written and (c) 2005 by Ralf Becker <RalfBecker@outdoor-training.de>     *
-* --------------------------------------------                             *
-*  This program is free software; you can redistribute it and/or modify it *
-*  under the terms of the GNU General Public License as published by the   *
-*  Free Software Foundation; either version 2 of the License, or (at your  *
-*  option) any later version.                                              *
-\**************************************************************************/
-
-/* $Id: class.uiprojectmanager.inc.php 21517 2006-05-13 06:08:17Z ralfbecker $ */
+/**
+ * ProjectManager - Projects user interface
+ *
+ * @link http://www.egroupware.org
+ * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @package projectmanager
+ * @copyright (c) 2005 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+ * @version $Id: class.uiprojectmanager.inc.php 23741 2007-04-30 10:29:44Z lkneschke $ 
+ */
 
 include_once(EGW_INCLUDE_ROOT.'/projectmanager/inc/class.boprojectmanager.inc.php');
 include_once(EGW_INCLUDE_ROOT.'/etemplate/inc/class.uietemplate.inc.php');
 
 /**
  * ProjectManager UI: list and edit projects
- *
- * @package projectmanager
- * @author RalfBecker-AT-outdoor-training.de
- * @copyright (c) 2005 by RalfBecker-AT-outdoor-training.de
- * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  */
 class uiprojectmanager extends boprojectmanager 
 {
 	/**
-	 * @var array $public_functions Functions to call via menuaction
+	 * Functions to call via menuaction
+	 * 
+	 * @var array
 	 */
 	var $public_functions = array(
 		'index' => true,
@@ -34,20 +29,28 @@ class uiprojectmanager extends boprojectmanager
 		'view'  => true,
 	);
 	/**
-	 * @var array $status_labels for pm_status, value - label pairs
+	 * Labels for pm_status, value - label pairs
+	 * 
+	 * @var array
 	 */
 	var $status_labels;
 	/**
-	 * @var array $access_labels for pm_access, value - label pairs
+	 * Labels for pm_access, value - label pairs
+	 * 
+	 * @var array
 	 */
 	var $access_labels;
 	/**
-	 * @var array $filter_labels for mains- & sub-projects
+	 * Labels for mains- & sub-projects filter
+	 * 
+	 * @var array
 	 */
 	var $filter_labels;
 
 	/**
 	 * Constructor, calls the constructor of the extended class
+	 * 
+	 * @return uiprojectmanager
 	 */
 	function uiprojectmanager()
 	{
@@ -301,9 +304,7 @@ class uiprojectmanager extends boprojectmanager
 		}
 		$content = $this->data + array(
 			'msg'  => $msg,
-			'general|description|members|accounting|custom|links' => !$content['general|description|members|accounting|custom|links'] && 
-				!$view && $tpl->html->user_agent == 'mozilla' ? 'projectmanager.edit.description' : 
-				$content['general|description|members|accounting|custom|links'],
+			'general|description|members|accounting|custom|links' => $content['general|description|members|accounting|custom|links'],
 			'view' => $view,
 			'ds'   => $pe_summary,
 			'link_to' => array(
@@ -423,9 +424,9 @@ class uiprojectmanager extends boprojectmanager
 	 * @param array &$rows returned rows/cups
 	 * @param array &$readonlys eg. to disable buttons based on acl
 	 */
-	function get_rows($query,&$rows,&$readonlys)
+	function get_rows(&$query_in,&$rows,&$readonlys)
 	{
-		$GLOBALS['egw']->session->appsession('project_list','projectmanager',$query);
+		$GLOBALS['egw']->session->appsession('project_list','projectmanager',$query=$query_in);
 
 		// handle nextmatch filters like col_filters
 		foreach(array('cat_id' => 'cat_id','filter2' => 'pm_status') as $nm_name => $pm_name)
@@ -437,6 +438,8 @@ class uiprojectmanager extends boprojectmanager
 
 		$total = parent::get_rows($query,$rows,$readonlys,true,true);
 		
+		$this->instanciate('roles');
+		
 		$readonlys = array();
 		foreach($rows as $n => $val)
 		{
@@ -449,11 +452,59 @@ class uiprojectmanager extends boprojectmanager
 			{
 				$readonlys["delete[$row[pm_id]]"] = true;
 			}
+			$pm_ids[] = $row['pm_id'];
+			
+			if (!($row['role_acl'] & EGW_ACL_BUDGET))
+			{
+				unset($row['pm_used_budget']);
+				unset($row['pm_planned_budget']);
+			}
 		}
+		$roles = $this->roles->query_list();
+		// query the project-members only, if user choose to display them
+		if ($pm_ids && @strstr($GLOBALS['egw_info']['user']['preferences']['projectmanager']['nextmatch-projectmanager.list.rows'],',role') !== false)
+		{
+			$all_members = $this->read_members($pm_ids);
+			foreach($rows as $n => $val)
+			{
+				$row =& $rows[$n];
+				$members = $row['pm_members'] = $all_members[$row['pm_id']];
+				if (!$members) continue;
+				
+				foreach($members as $uid => $data)
+				{
+					if (($pos = array_search($data['role_id'],array_keys($roles))) !== false)
+					{
+						$row['role'.$pos][] = $uid;
+					}
+				}
+			}
+		}
+		//_debug_array($rows);
 		if ((int) $this->debug >= 2 || $this->debug == 'get_rows')
 		{
 			$this->debug_message("uiprojectmanager::get_rows(".print_r($query,true).") total=$total, rows =".print_r($rows,true)."\nreadonlys=".print_r($readonlys,true));
 		}
+		$rows['roles'] = array_values($roles);
+		for($i = count($roles); $i < 5; ++$i)
+		{
+			$rows['no_role'.$i] = true;
+		}
+		// disable time & budget columns if pm is configures for status or status and time only
+		if ($this->config['accounting_types'] == 'status')
+		{
+			$rows['no_pm_used_time_pm_planned_time'] = true;
+			$rows['no_pm_used_budget_pm_planned_budget'] = true;
+			$query_in['options-selectcols']['pm_used_time'] = $query_in['options-selectcols']['pm_planned_time'] = false;
+			$query_in['options-selectcols']['pm_used_budget'] = $query_in['options-selectcols']['pm_planned_budget'] = false;
+		}
+		if ($this->config['accounting_types'] == 'status,times')
+		{
+			$rows['no_pm_used_budget_pm_planned_budget'] = true;
+			$query_in['options-selectcols']['pm_used_budget'] = $query_in['options-selectcols']['pm_planned_budget'] = false;
+		}
+		$rows['duration_format'] = ','.$this->config['duration_format'].',,1';
+
 		return $total;		
 	}
 
@@ -572,6 +623,7 @@ class uiprojectmanager extends boprojectmanager
 //				'bottom_too'     => True,// I  show the nextmatch-line (arrows, filters, search, ...) again after the rows
 				'order'          =>	'pm_modified',// IO name of the column to sort after (optional for the sortheaders)
 				'sort'           =>	'DESC',// IO direction of the sort: 'ASC' or 'DESC'
+				'default_cols'   => '!role0,role1,role2,role3,role4',
 			);
 		}
 		$templates = array();
