@@ -11,7 +11,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.bomanagefields.inc.php 19547 2005-11-02 11:45:52Z ralfbecker $ */
+	/* $Id: class.bomanagefields.inc.php 23741 2007-04-30 10:29:44Z lkneschke $ */
 
 	class bomanagefields
 	{
@@ -55,7 +55,7 @@
 				$orig_name = $field_info['field_name'];
 				unset ($changed);
 
-				if (($field_info['field_type'] == 'text' || $field_info['field_type'] == 'textarea' || $field_info['field_type'] == 'dropdown' || $field_info['field_type'] == 'checkbox') && !$field_info['field_name'])
+				if (($field_info['field_type'] == 'text' || $field_info['field_type'] == 'textarea' || $field_info['field_type'] == 'dropdown' || $field_info['field_type'] == 'dropdownfromtable' || $field_info['field_type'] == 'checkbox') && !$field_info['field_name'])
 				{
 					continue;
 				}
