@@ -11,7 +11,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.uimanagefields.inc.php 19547 2005-11-02 11:45:52Z ralfbecker $ */
+	/* $Id: class.uimanagefields.inc.php 23741 2007-04-30 10:29:44Z lkneschke $ */
 
 	class uimanagefields
 	{
@@ -55,12 +55,13 @@
 				'lang_name_and_shortdesc' => lang ('Name (blank unless Text, Textarea, Dropdown, Checkbox; else alphanumeric only)'),
 				'lang_text'  => lang ('Text'),
 				'lang_type'  => lang ('Type'),
-				'lang_values_and_shortdesc' => lang ('Values (For Dropdown only; comma separated)'),
+				'lang_values_and_shortdesc' => lang ('Values \'For Dropdown\': comma separated), For \'Dropdown From Table\': table,valuefield,displayfield'),
 				'lang_required' => lang ('Required'),
 				'lang_remove'   => lang ('Remove'),
 				'lang_order'    => lang ('Order'),
 				'lang_textarea' => lang ('Textarea'),
 				'lang_dropdown' => lang ('Dropdown'),
+				'lang_dropdownfromtable' => lang ('Dropdown From Table'),
 				'lang_checkbox' => lang ('Checkbox'),
 				'lang_email'    => lang ('Email'),
 				'lang_first_name' => lang ('First Name'),
@@ -112,6 +113,7 @@
 					'field_type_selected_text' => '',
 					'field_type_selected_textarea' => '',
 					'field_type_selected_dropdown' => '',
+					'field_type_selected_dropdownfromtable' => '',
 					'field_type_selected_checkbox' => '',
 					'field_type_selected_email' => '',
 					'field_type_selected_first_name' => '',
@@ -145,6 +147,7 @@
 				'field_type_selected_text'       => '',
 				'field_type_selected_textarea'   => '',
 				'field_type_selected_dropdown'   => '',
+				'field_type_selected_dropdownfromtable'   => '',
 				'field_type_selected_checkbox'   => '',
 				'field_type_selected_email'      => '',
 				'field_type_selected_first_name' => '',
