@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: tables_update.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: tables_update.inc.php 23741 2007-04-30 10:29:44Z lkneschke $ */
 
 	$test[] = '0.8.1';
 	function registration_upgrade0_8_1()
@@ -56,3 +56,23 @@
 		$GLOBALS['egw_setup']->oProc->RenameTable('phpgw_reg_accounts','egw_reg_accounts');
 		return $GLOBALS['setup_info']['registration']['currentver'] = '1.2';
 	}
+
+	$test[] = '1.2';
+	function registration_upgrade1_2()
+	{
+		$GLOBALS['egw_setup']->oProc->AddColumn('egw_reg_accounts','reg_status',array(
+			'type' => 'varchar',
+			'precision' => '1',
+			'nullable' => False,
+			'default' => 'x'
+		));
+
+		return $GLOBALS['setup_info']['registration']['currentver'] = '1.3.001';
+	}
+
+	$test[] = '1.3.001';
+	function registration_upgrade1_3_001()
+	{
+		return $GLOBALS['setup_info']['registration']['currentver'] = '1.4';
+	}
+?>
