@@ -7,7 +7,7 @@
  * @link http://www.egroupware.org
  * @author Cornelius Weiss <egw@von-und-zu-weiss.de>
  * @author Lukas Weiss <wnz_gh05t@users.sourceforge.net>
- * @version $Id: class.bo_resources.inc.php 22437 2006-09-15 19:36:16Z nelius_weiss $
+ * @version $Id: class.bo_resources.inc.php 24207 2007-06-25 16:44:20Z ralfbecker $
  */
 
 
@@ -23,6 +23,12 @@ class bo_resources
 	var $thumbs_dir = '/resources/pictures/thumbs/';
 	var $resource_icons = '/resources/templates/default/images/resource_icons/';
 	var $debug = 0;
+	/**
+	 * Instance of resources so object
+	 *
+	 * @var so_resources
+	 */
+	var $so;
 	
 	function bo_resources()
 	{
@@ -68,7 +74,7 @@ class bo_resources
 		$order_by = $query['order'] ? $query['order'].' '. $query['sort'] : '';
 		$start = (int)$query['start'];
 		
-		$rows = $this->so->search($criteria,$read_onlys,$order_by,'','',$empty=False,$op='OR',$start,$filter,$join='',$need_full_no_count=false);
+		$rows = $this->so->search($criteria,$read_onlys,$order_by,'','%',$empty=False,$op='OR',$start,$filter,$join='',$need_full_no_count=false);
 		$nr = $this->so->total;
 		
 		// we are called to serve bookable resources (e.g. calendar-dialog)
@@ -97,11 +103,15 @@ class bo_resources
 			{
 				$readonlys["new_acc[$resource[res_id]]"] = true;
 			}
-			if (!$resource['bookable'] /* && calender-acl viewable */)
+			if (!$resource['bookable'])
 			{
 				$readonlys["bookable[$resource[res_id]]"] = true;
 				$readonlys["calendar[$resource[res_id]]"] = true;
 			}
+			if(!$this->acl->is_permitted($resource['cat_id'],EGW_ACL_CALREAD))
+			{
+				$readonlys["calendar[$resource[res_id]]"] = true;
+			}
 			if (!$resource['buyable'])
 			{
 				$readonlys["buyable[$resource[res_id]]"] = true;
@@ -326,10 +336,10 @@ class bo_resources
 		$only_keys = 'res_id,name,short_description';
 		$filter = array(
 			'cat_id' => array_flip((array)$this->acl->get_cats(EGW_ACL_READ)),
-			'accessory_of' => '-1'
+			//'accessory_of' => '-1'
 		);
-		$data = $this->so->search($criteria,$only_keys,$order_by='',$extra_cols='',$wildcard='%',$empty,$op='OR','',$filter);
-		foreach((array)$data as $num => $resource)
+		$data = $this->so->search($criteria,$only_keys,$order_by='',$extra_cols='',$wildcard='%',$empty,$op='OR',false,$filter);
+		foreach($data as $num => $resource)
 		{
 			$list[$resource['res_id']] = $resource['name']. ($resource['short_description'] ? ', ['.$resource['short_description'].']':'');
 		}
@@ -488,7 +498,7 @@ class bo_resources
 			case 'gen_src':
 			default :
 				$picture = $GLOBALS['egw_info']['server']['webserver_url'].$this->resource_icons;
-				$picture .= strstr($src,'.') ? $src : 'generic.png';
+				$picture .= strpos($src,'.') !== false ? $src : 'generic.png';
 		}
 		return $picture;
 	}
