@@ -7,7 +7,7 @@
  * @link http://www.egroupware.org
  * @author Cornelius Weiss <egw@von-und-zu-weiss.de>
  * @author Lukas Weiss <wnz_gh05t@users.sourceforge.net>
- * @version $Id: class.ui_resources.inc.php 21604 2006-05-18 15:29:34Z nelius_weiss $
+ * @version $Id: class.ui_resources.inc.php 23852 2007-05-09 16:29:32Z lkneschke $
  */
 
 /**
@@ -100,7 +100,7 @@ class ui_resources
 		$content['nm']['header_left']	= 'resources.resource_select.header';
 		$content['nm']['get_rows'] 	= 'resources.bo_resources.get_rows';
 		$content['nm']['no_filter'] 	= False;
-		$content['nm']['filter_label']	= 'Category';
+		$content['nm']['filter_label']	= lang('Category');
 		$content['nm']['filter_help']	= lang('Select a category'); // is this used???
 		$content['nm']['no_filter2']	= true;
 		$content['nm']['filter_no_lang'] = true;
@@ -219,8 +219,8 @@ class ui_resources
 			if ($res_id > 0)
 			{
 				$content = $this->bo->read($res_id);
-				$content['gen_src_list'] = strstr($content['picture_src'],'.') ? $content['picture_src'] : false;
-				$content['picture_src'] = strstr($content['picture_src'],'.') ? 'gen_src' : $content['picture_src'];
+				$content['gen_src_list'] = strpos($content['picture_src'],'.') !== false ? $content['picture_src'] : false;
+				$content['picture_src'] = strpos($content['picture_src'],'.') !== false ? 'gen_src' : $content['picture_src'];
 				$content['link_to'] = array(
 					'to_id' => $res_id,
 					'to_app' => 'resources'
@@ -310,8 +310,8 @@ class ui_resources
 
 		$content = array('res_id' => $res_id);
 		$content = $this->bo->read($res_id);
-		$content['gen_src_list'] = strstr($content['picture_src'],'.') ? $content['picture_src'] : false;
-		$content['picture_src'] = strstr($content['picture_src'],'.') ? 'gen_src' : $content['picture_src'];
+		$content['gen_src_list'] = strpos($content['picture_src'],'.') !== false ? $content['picture_src'] : false;
+		$content['picture_src'] = strpos($content['picture_src'],'.') !== false ? 'gen_src' : $content['picture_src'];
 		$content['link_to'] = array(
 				'to_id' => $res_id,
 				'to_app' => 'resources'
