@@ -10,14 +10,16 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: set_box.php 20295 2006-02-15 12:31:25Z  $ */
+  /* $Id: set_box.php 22864 2006-11-22 23:06:05Z milosch $ */
 
-	$GLOBALS['egw_info']['flags'] = Array(
-		'noheader' => True,
-		'nofooter' => True,
-		'currentapp' => 'home'
+	$GLOBALS['egw_info'] = array(
+		'flags' => Array(
+			'noheader' => True,
+			'nofooter' => True,
+			'currentapp' => 'home'
+		)
 	);
-	include('header.inc.php');
+	include('./header.inc.php');
 
 	@reset($GLOBALS['egw_info']['user']['preferences']);
 
@@ -97,4 +99,3 @@
 	}
 
 	$GLOBALS['egw']->redirect_link('/home/index.php');
-?>
