@@ -1,16 +1,17 @@
 <?php
-	/**************************************************************************\
-	* eGroupWare - Setup Check Installation                                    *
-	* http://www.eGroupWare.org                                                *
-	* --------------------------------------------                             *
-	*  This program is free software; you can redistribute it and/or modify it *
-	*  under the terms of the GNU General Public License as published by the   *
-	*  Free Software Foundation; either version 2 of the License, or (at your  *
-	*  option) any later version.                                              *
-	\**************************************************************************/
-	
-	/* $Id: check_install.php 22249 2006-08-15 17:01:33Z ralfbecker $ */
+  /**************************************************************************\
+  * eGroupWare - Setup Check Installation                                    *
+  * http://www.eGroupWare.org                                                *
+  * --------------------------------------------                             *
+  *  This program is free software; you can redistribute it and/or modify it *
+  *  under the terms of the GNU General Public License as published by the   *
+  *  Free Software Foundation; either version 2 of the License, or (at your  *
+  *  option) any later version.                                              *
+  \**************************************************************************/
 
+  /* $Id: check_install.php 24778 2007-12-09 22:55:39Z ralfbecker $ */
+
+	@set_time_limit(0);
 	$run_by_webserver = !!$_SERVER['PHP_SELF'];
 	$is_windows = strtoupper(substr(PHP_OS,0,3)) == 'WIN';
 
@@ -55,9 +56,9 @@
 	$checks = array(
 		'phpversion' => array(
 			'func' => 'php_version',
-			'value' => 4.3,
-			'verbose_value' => '4.3+',
-			'recommended' => '5.0',
+			'value' => $GLOBALS['egw_setup']->required_php_version,
+			'verbose_value' => $GLOBALS['egw_setup']->required_php_version.'+',
+			'recommended' => $GLOBALS['egw_setup']->recommended_php_version,
 		),
 		'safe_mode' => array(
 			'func' => 'php_ini_check',
@@ -82,10 +83,10 @@
 		),
 		'memory_limit' => array(
 			'func' => 'php_ini_check',
-			'value' => '16M',
+			'value' => '24M',
 			'check' => '>=',
-			'error' => lang('memory_limit is set to less than 16M: some applications of eGroupWare need more than the recommend 8M, expect occasional failures'),
-			'change' => 'memory_limit = 16M'
+			'error' => lang('memory_limit is set to less than %1: some applications of eGroupWare need more than the recommend 8M, expect occasional failures','24M'),
+			'change' => 'memory_limit = 24M'
 		),
 		'max_execution_time' => array(
 			'func' => 'php_ini_check',
@@ -108,28 +109,28 @@
 		),
 		'mysql' => array(
 			'func' => 'extension_check',
-			'warning' => "<div class='setup_info'>" . lang('The %1 extension is needed, if you plan to use a %2 database.','mysql','MySQL').'</div>'
+			'warning' => lang('The %1 extension is needed, if you plan to use a %2 database.','mysql','MySQL')
 		),
 		'pgsql' => array(
 			'func' => 'extension_check',
-			'warning' => '<div class="setup_info">' . lang('The %1 extension is needed, if you plan to use a %2 database.','pgsql','pgSQL').'</div>'
+			'warning' => lang('The %1 extension is needed, if you plan to use a %2 database.','pgsql','pgSQL')
 		),
 		'mssql' => array(
 			'func' => 'extension_check',
-			'warning' => '<div class="setup_info">' . lang('The %1 extension is needed, if you plan to use a %2 database.','mssql','MsSQL') . '</div>',
+			'warning' => lang('The %1 extension is needed, if you plan to use a %2 database.','mssql','MsSQL'),
 			'win_only' => True
 		),
 		'odbc' => array(
 			'func' => 'extension_check',
-			'warning' => '<div class="setup_info">' . lang('The %1 extension is needed, if you plan to use a %2 database.','odbc','MaxDB, MsSQL or Oracle') . '</div>',
+			'warning' => lang('The %1 extension is needed, if you plan to use a %2 database.','odbc','MaxDB, MsSQL or Oracle'),
 		),
 		'oci8' => array(
 			'func' => 'extension_check',
-			'warning' => '<div class="setup_info">' . lang('The %1 extension is needed, if you plan to use a %2 database.','oci','Oracle') . '</div>',
+			'warning' => lang('The %1 extension is needed, if you plan to use a %2 database.','oci','Oracle'),
 		),
 		'mbstring' => array(
 			'func' => 'extension_check',
-			'warning' => '<div class="setup_info">' . lang('The mbstring extension is needed to fully support unicode (utf-8) or other multibyte-charsets.') . "</div>"
+			'warning' => lang('The mbstring extension is needed to fully support unicode (utf-8) or other multibyte-charsets.')
 		),
 		'mbstring.func_overload' => array(
 			'func' => 'php_ini_check',
@@ -137,24 +138,13 @@
 			'warning' => '<div class="setup_info">' . lang('The mbstring.func_overload = 7 is needed to fully support unicode (utf-8) or other multibyte-charsets.') . "</div>",
 			'change' => extension_loaded('mbstring')  || function_exists('dl') && @dl(PHP_SHLIB_PREFIX.'mbstring.'.PHP_SHLIB_SUFFIX) ? 'mbstring.func_overload = 7' : '',
 		),
-		'imap' => array(
-			'func' => 'extension_check',
-			'warning' => '<div class="setup_info">' . lang('The imap extension is needed by the two email apps (even if you use email with pop3 as protocoll).') . '</div>'
-		),
 		'session' => array(
 			'func' => 'extension_check',
-			'warning' => '<div class="setup_info">' . lang('The session extension is needed to use php sessions (db-sessions work without).') . "</div>"
+			'warning' => lang('The session extension is needed to use php sessions (db-sessions work without).')
 		),
-		'' => array(
-			'func' => 'pear_check',
-			'warning' => '<div class="setup_info">' . lang('PEAR is needed by SyncML or the iCal import+export of calendar.') . "</div>"
-		),	
-		'Log' => array(
-			'func' => 'pear_check',
-			'warning' => '<div class="setup_info">' . lang('PEAR::Log is needed by SyncML.').' '.lang('You can install it by running:').' pear install Log' . "</div>"
-		),
-		'gd' => array(
-			'func' => 'gd_check',
+		'ldap' => array(
+			'func' => 'extension_check',
+			'warning' => lang("The ldap extension is needed, if you use ldap as account or contact storage, authenticate against ldap or active directory. It's not needed for a standard SQL installation."),
 		),
 		'.' => array(
 			'func' => 'permission_check',
@@ -166,15 +156,9 @@
 			'is_world_readable' => False,
 			'only_if_exists' => @$GLOBALS['egw_info']['setup']['stage']['header'] != 10
 		),
-		'fudforum' => array(
-			'func' => 'permission_check',
-			'is_writable' => True,
-			'only_if_exists' => True
-		),
 	);
-	if (extension_loaded('session'))
+	if (extension_loaded('session') && ini_get('session.save_handler') == 'files')
 	{
-		//ini_set('session.save_path','/hugo');
 		$checks[session_save_path()] = array(
 			'func' => 'permission_check',
 			'is_writable' => true,
@@ -182,6 +166,55 @@
 			'error' => lang('You will NOT be able to log into eGroupWare using PHP sessions: "session could not be verified" !!!'),
 		);
 	}
+	$setup_info = $GLOBALS['egw_setup']->detection->get_versions();
+	foreach($setup_info as $app => $app_data)
+	{
+		if (!isset($app_data['check_install'])) continue;
+
+		foreach ($app_data['check_install'] as $name => $data)
+		{
+			if (isset($checks[$name]))
+			{
+				if ($checks[$name] == $data) continue;	// identical check --> ignore it
+				
+				if ($data['func'] == 'pear_check' || in_array($data['func'],array('extension_check','php_ini_check')) && !isset($data['warning']))
+				{
+					if (isset($checks[$name]['from']) && $checks[$name]['from'] && !is_array($checks[$name]['from']))
+					{
+						$checks[$name]['from'] = array($checks[$name]['from']);
+					}
+					if (!isset($data['from'])) $data['from'] = $app;
+					if (!isset($checks[$name]['from']) || !is_array($checks[$name]['from'])) $checks[$name]['from'] = array();
+					if (!in_array($data['from'],$checks[$name]['from'])) $checks[$name]['from'][] = $data['from'];
+				}
+				else
+				{
+					$checks[$app.'_'.$name] = $data;
+				}
+			}
+			else
+			{
+				if (!isset($data['from'])) $data['from'] = $app;
+				$checks[$name] = $data;
+			}
+			//echo "added check $data[func]($name) for $app"; _debug_array($data);
+		}
+	}
+	$sorted_checks = array();
+	foreach(array('php_version','php_ini_check','extension_check','pear_check','gd_check','permission_check') as $func)
+	{
+		foreach($checks as $name => $data)
+		{
+			if ($data['func'] == $func)
+			{
+				$sorted_checks[$name] = $data;
+				unset($checks[$name]);
+			}
+		}
+	}
+	if ($checks) $sorted_checks += $checks;
+	$checks =& $sorted_checks;
+	
 	// some constants for pre php4.3
 	if (!defined('PHP_SHLIB_SUFFIX'))
 	{
@@ -196,41 +229,139 @@
 	{
 		global $passed_icon, $error_icon;
 
-		$version_ok = (float) phpversion() >= $args['value'];
+		$version_ok = version_compare(phpversion(),$args['value']) >= 0;
 
 		echo '<div>'.($version_ok ? $passed_icon : $error_icon).' <span'.($version_ok ? '' : ' class="setup_error"').'>'.
 			lang('Checking required PHP version %1 (recommended %2)',$args['verbose_value'],$args['recommended']).': '.
 			phpversion().' ==> '.($version_ok ? lang('True') : lang('False'))."</span></div>\n";
 	}
 
+	/**
+	 * quering the pear registry to find out which pear packages and versions are installed
+	 *
+	 * @return array with package-name => version pairs, eg. array('Log' => '1.9.8','PEAR' => '1.4.11')
+	 */
+	function get_installed_pear_packages()
+	{
+		$pear_config = '';	// use the system default
+		// fix for SuSE having the pear.conf only for cli, will fail with open_basedir - no idea what to do then
+		if (@is_dir('/etc/php5/apache2') && !file_exists('/etc/php5/apache2/pear.conf') && @file_exists('/etc/php5/cli/pear.conf'))
+		{
+			$pear_config = '/etc/php5/cli/pear.conf';
+		}
+		@include_once 'PEAR/Config.php';
+		
+		if (!class_exists('PEAR_Config')) return false;
+		
+		$config = new PEAR_Config('',$pear_config);
+		//echo "<pre>config = ".print_r($config,true)."</pre>\n";
+
+		$channel = $config->get('default_channel');
+		//echo "<pre>channel = ".print_r($channel,true)."</pre>\n";
+		
+		if (!method_exists($config,'getRegistry')) return false;	// PEAR version to old
+
+		$reg = &$config->getRegistry();
+		//echo "<pre>reg = ".print_r($reg,true)."</pre>\n";
+		
+		// a bug in pear causes an endless loop if the install-dir does not exist
+		// bug reported: http://pear.php.net/bugs/bug.php?id=11317
+		if (!file_exists($reg->install_dir)) return false;
+
+		$installed = $reg->packageInfo(null,null,$channel);
+
+		//echo "<pre>installed =".print_r($installed,true)."</pre>\n";
+		$packages = array();
+		foreach($installed as $package)
+		{
+			$name = isset($package['package']) ? $package['package'] : $package['name'];
+			$version = $package['version'];
+			if (is_array($version)) $version = $version['release'];
+			
+			$packages[$name] = $version;
+		//	echo "<p>$name: ".print_r($package['version'],true)."</p>\n";
+		}
+		ksort($packages);
+		
+		return $packages;
+	}
+	
 	function pear_check($package,$args)
 	{
 		global $passed_icon, $warning_icon;
 		static $pear_available = null;
+		static $pear_packages = null;
 		
-		if (is_null($pear_available))
-		{
-			$pear_available = @include('PEAR.php');
+		$min_version = isset($args['version']) ? $args['version'] : null;
 
-			if (!class_exists('PEAR')) $pear_available = false;
-		
-			echo '<div>'.($pear_available ? $passed_icon : $warning_icon).' <span'.($pear_available ? '' : ' class="setup_warning"').'>'.
-				lang('Checking PEAR%1 is installed','').': '.($pear_available ? lang('True') : lang('False'))."</span></div>\n";
-		}
-		if ($pear_available && $package)
+		if (is_null($pear_packages))
 		{
-			$available = @include($package.'.php');
+			$pear_packages = get_installed_pear_packages();
+		}
+		$version_available = false;
 
-			if (!class_exists($package)) $available = false;
-			
-			echo '<div>'.($available ? $passed_icon : $warning_icon).' <span'.($available ? '' : ' class="setup_warning"').'>'.
-				lang('Checking PEAR%1 is installed','::'.$package).': '.($available ? lang('True') : lang('False'))."</span></div>\n";
-		}
-		$available = $pear_available && (!$package || $available);
-		
-		if (!$available)
+		// check if egw-pear is availible and packages is included
+		if ($package && is_dir('../egw-pear') && file_exists('../egw-pear/'.str_replace('_','/',$package).'.php'))
 		{
-			echo $args['warning'];
+			$available = true;
+			$version_available = '999.egw-pear';
+		}
+		// packages found in the pear registry --> use that info
+		elseif ($pear_packages)
+		{
+			$pear_available = true;
+			// check if package is installed
+			if ($package && isset($pear_packages[$package])) $available = true;
+			// check if it's the right version
+			$version_available = $pear_packages[$package ? $package : 'PEAR'];
+		}
+		else	// use the old checks as fallback
+		{
+			if (is_null($pear_available))
+			{
+				$pear_available = @include_once('PEAR.php');
+	
+				if (!class_exists('PEAR')) $pear_available = false;
+			}
+			if ($pear_available && $package)
+			{
+				$file = str_replace('_','/',$package).'.php';
+
+				$available = @include_once($file);
+	
+				if (!class_exists($package)) $available = false;
+			}
+		}
+		// is the right version availible 
+		$available = (@$available || $pear_available && !$package) && (!$min_version || version_compare($min_version,$version_available) <= 0);
+		echo '<div>'.($available ? $passed_icon : $warning_icon).' <span'.($available ? '' : ' class="setup_warning"').'>'.
+			lang('Checking PEAR%1 is installed',($package?'::'.$package:'').($min_version?" ($min_version)":'')).': '.
+			($available ? ($version_available ? $version_available : lang('True')) : lang('False'))."</span></div>\n";		
+
+		if (!$available)	// give further info only if not availible
+		{
+			echo '<div class="setup_info">' . lang('PEAR%1 is needed by: %2.',$package ? '::'.$package : '',
+				is_array($args['from']) ? implode(', ',$args['from']) : $args['from']);
+				
+			if (!$pear_available)
+			{
+				echo ' '.lang('PEAR (%1) is a PHP repository and is usually in a package called %2.',
+					'<a href="http://pear.php.net" target="_blank">pear.php.net</a>','php-pear');
+			}
+			elseif ($min_version && !$version_available)
+			{
+				echo ' '.lang('We could not determine the version of %1, please make sure it is at least %2',$package,$min_version);
+			}
+			elseif ($min_version && version_compare($min_version,$version_available) > 0)
+			{
+				echo ' '.lang('Your installed version of %1 is %2, required is at least %3, please run: ',
+					$package,$version_available,$min_version).' pear update '.$package;
+			}
+			elseif ($package)
+			{
+				echo ' '.lang('You can install it by running:').' pear install '.$package;
+			}
+			echo "</div>";
 		}
 		echo "\n";
 
@@ -239,6 +370,7 @@
 
 	function extension_check($name,$args)
 	{
+		//echo "<p>extension_check($name,".print_r($args,true).")</p>\n";
 		global $passed_icon, $error_icon, $warning_icon, $is_windows;
 
 		if (isset($args['win_only']) && $args['win_only'] && !$is_windows)
@@ -252,7 +384,34 @@
 
 		if (!$available)
 		{
-			echo $args['warning'];
+			if (!isset($args['warning']))
+			{
+				$args['warning'] = lang('The %1 extension is needed from: %2.',$name,
+					is_array($args['from']) ? implode(', ',$args['from']) : $args['from']);
+			}
+			echo "<div class='setup_info'>".$args['warning'].'</div>';
+		}
+		echo "\n";
+
+		return $available;
+	}
+
+	function function_check($name,$args)
+	{
+		global $passed_icon, $error_icon, $warning_icon, $is_windows;
+
+		$available = function_exists($name);
+
+		echo '<div>'.($available ? $passed_icon : $warning_icon).' <span'.($available ? '' : ' class="setup_warning"').'>'.lang('Checking function %1 exists',$name).': '.($available ? lang('True') : lang('False'))."</span></div>\n";
+
+		if (!$available)
+		{
+			if (!isset($args['warning']))
+			{
+				$args['warning'] = lang('The function %1 is needed from: %2.',$name,
+					is_array($args['from'] ? implode(', ',$args['from']) : $args['from']));
+			}
+			echo "<div class='setup_info'>".$args['warning'].'</div>';
 		}
 		echo "\n";
 
@@ -321,7 +480,7 @@
 
 		// add a ../ for non-absolute pathes
 		$rel_name = $name;
-		if (substr($name,0,3) != '../' && $name{0} != '/' && $name{0} != '\\' && strstr($name,':') === false)
+		if (substr($name,0,3) != '../' && $name{0} != '/' && $name{0} != '\\' && strpos($name,':') === false)
 		{
 			$name = '../'.$name;
 		}
@@ -370,6 +529,7 @@
 		{
 			$msg = lang('Checking file-permissions of %1 for %2 %3: %4',$rel_name,$check_not,$checks,$perms)."<br />\n";
 		}
+		$extra_error_msg = '';
 		if (isset($args['error']) && $args['error'])
 		{
 			$extra_error_msg = "<br />\n".$args['error'];
@@ -488,14 +648,20 @@
 		}
 		if (!$result)
 		{
-			if (isset($args['warning']))
-			{
-				echo "<div>".$warning_icon.' <span class="setup_warning">'.$msg.'</span><div class="setup_info">'.$args['warning']."</div></div>\n";
-			}
 			if (isset($args['error']))
 			{
 				echo "<div>".$error_icon.' <span class="setup_error">'.$msg.'</span><div class="setup_info">'.$args['error']."</div></div>\n";
 			}
+			elseif (isset($args['warning']))
+			{
+				echo "<div>".$warning_icon.' <span class="setup_warning">'.$msg.'</span><div class="setup_info">'.$args['warning']."</div></div>\n";
+			}
+			elseif (!isset($args['safe_mode']))
+			{
+				echo "<div>".$warning_icon.' <span class="setup_warning">'.$msg.'</span><div class="setup_info">'.
+					lang('%1 is needed by: %2.',$name,is_array($args['from']) ? implode(', ',$args['from']) : $args['from'])
+					."</div></div>\n";
+			}
 			if (isset($args['safe_mode']) && $safe_mode || @$args['change'])
 			{
 				if (!isset($args['warning']) && !isset($args['error']))
