@@ -9,7 +9,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: config.php 20462 2006-03-08 09:46:26Z ralfbecker $ */
+  /* $Id: config.php 23741 2007-04-30 10:29:44Z lkneschke $ */
 
 	$GLOBALS['egw_info'] = array(
 		'flags' => array(
@@ -111,16 +111,8 @@
 		{
 			$GLOBALS['egw_setup']->db->transaction_commit();
 
-			if($newsettings['auth_type'] == 'ldap')
-			{
-				Header('Location: ldap.php');
-				exit;
-			}
-			else
-			{
-				Header('Location: index.php');
-				exit;
-			}
+			Header('Location: index.php');
+			exit;
 		}
 	}
 
@@ -182,7 +174,7 @@
 			case 'value':
 				$newval = str_replace(' ','_',$newval);
 				/* Don't show passwords in the form */
-				if(strstr($value,'passwd') || strstr($value,'password') || strstr($value,'root_pw'))
+				if(strpos($value,'passwd') !== false || strpos($value,'password') !== false || strpos($value,'root_pw') !== false)
 				{
 					$t->set_var($value,'');
 				}
