@@ -1,20 +1,17 @@
 <?php
-  /**************************************************************************\
-  * eGroupWare - Setup                                                       *
-  * http://www.egroupware.org                                                *
-  * --------------------------------------------                             *
-  * This file written by Joseph Engo<jengo@phpgroupware.org>                 *
-  *  and Dan Kuykendall<seek3r@phpgroupware.org>                             *
-  *  and Mark Peters<skeeter@phpgroupware.org>                               *
-  *  and Miles Lott<milosch@groupwhere.org>                                  *
-  * --------------------------------------------                             *
-  *  This program is free software; you can redistribute it and/or modify it *
-  *  under the terms of the GNU General Public License as published by the   *
-  *  Free Software Foundation; either version 2 of the License, or (at your  *
-  *  option) any later version.                                              *
-  \**************************************************************************/
-
-  /* $Id: class.setup.inc.php 22053 2006-07-09 06:57:00Z ralfbecker $ */
+/**
+ * Setup
+ *
+ * @link http://www.egroupware.org
+ * @package setup
+ * @author Joseph Engo <jengo@phpgroupware.org>
+ * @author Dan Kuykendall <seek3r@phpgroupware.org>
+ * @author Mark Peters <skeeter@phpgroupware.org>
+ * @author Miles Lott <milos@groupwhere.org>
+ * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+ * @version $Id: class.setup.inc.php 23836 2007-05-08 14:58:22Z lkneschke $
+ */
 
 	class egw_dummy {
 		var $db;
@@ -50,6 +47,12 @@
 		var $tbl_apps;
 		var $tbl_config;
 		var $tbl_hooks;
+		
+		/**
+		 * @var float $required_php_version php version required by eGroupWare
+		 */
+		var $required_php_version = 4.3;
+		var $recommended_php_version = '5+';
 
 		function setup($html=False, $translation=False)
 		{
@@ -172,6 +175,7 @@
 		{
 			#phpinfo();
 			$FormLogout = get_var('FormLogout',  array('GET','POST'));
+			$ConfigLang   = get_var('ConfigLang',  array('POST','COOKIE'));
 			if(!$FormLogout)
 			{
 				$ConfigLogin  = get_var('ConfigLogin', array('POST'));
@@ -185,7 +189,6 @@
 				$ConfigPW     = get_var('ConfigPW',    array('POST','COOKIE'));
 				$HeaderUser   = get_var('HeaderUser',  array('POST','COOKIE'));
 				$HeaderPW     = get_var('HeaderPW',    array('POST','COOKIE'));
-				$ConfigLang   = get_var('ConfigLang',  array('POST','COOKIE'));
 
 				/* Setup defaults to aid in header upgrade to version 1.26.
 				 * This was the first version to include the following values.
@@ -212,7 +215,7 @@
 					$this->set_cookie('ConfigUser','',$expire,'/');
 					$this->set_cookie('ConfigPW','',$expire,'/');
 					$this->set_cookie('ConfigDomain','',$expire,'/');
-					$this->set_cookie('ConfigLang','',$expire,'/');
+//					$this->set_cookie('ConfigLang','',$expire,'/');
 					$GLOBALS['egw_info']['setup']['LastDomain'] = $_COOKIE['ConfigDomain'];
 					$GLOBALS['egw_info']['setup']['ConfigLoginMSG'] = lang('You have successfully logged out');
 					$GLOBALS['egw_info']['setup']['HeaderLoginMSG'] = '';
@@ -222,7 +225,7 @@
 					$expire = time() - 86400;
 					$this->set_cookie('HeaderUser','',$expire,'/');
 					$this->set_cookie('HeaderPW','',$expire,'/');
-					$this->set_cookie('ConfigLang','',$expire,'/');
+//					$this->set_cookie('ConfigLang','',$expire,'/');
 					$GLOBALS['egw_info']['setup']['HeaderLoginMSG'] = lang('You have successfully logged out');
 					$GLOBALS['egw_info']['setup']['ConfigLoginMSG'] = '';
 					return False;
@@ -858,13 +861,16 @@
 					$this->loaddb();
 				}
 				/* Load up some configured values */
-				$this->db->query("SELECT config_name,config_value FROM $this->config_table "
-					. "WHERE config_name LIKE 'ldap%' OR config_name LIKE 'account_%' OR config_name LIKE '%encryption%'",__LINE__,__FILE__);
-				while($this->db->next_record())
+				$this->db->select($this->config_table,'config_name,config_value',
+					"config_name LIKE 'ldap%' OR config_name LIKE 'account_%' OR config_name LIKE '%encryption%' OR config_name='auth_type'",__LINE__,__FILE__);
+				while(($row = $this->db->row(true)))
 				{
-					$GLOBALS['egw_info']['server'][$this->db->f('config_name')] = $this->db->f('config_value');
+					if (!isset($GLOBALS['egw_info']['server'][$row['config_name']]))	// dont overwrite
+					{
+						$GLOBALS['egw_info']['server'][$row['config_name']] = $row['config_value'];
+					}
 				}
-				//if (!is_object($GLOBALS['egw']))
+				if (!is_object($GLOBALS['egw']))
 				{
 					$GLOBALS['egw'] =& new egw_dummy();
 					$GLOBALS['phpgw'] =& $GLOBALS['egw'];
@@ -877,9 +883,10 @@
 					!$GLOBALS['egw']->accounts->ds)
 				{
 					printf("<b>Error: Error connecting to LDAP server %s!</b><br>",$GLOBALS['egw_info']['server']['ldap_host']);
-					exit;
+					return false;
 				}
 			}
+			return true;
 		}
 
 		/**
@@ -887,42 +894,70 @@
 		 *
 		 * if the $username already exists, only the id is returned, no new user / group gets created
 		 *
-		 * @param username string alphanumerical username or groupname (account_lid)
-		 * @param first, last string first / last name
+		 * @param string $username alphanumerical username or groupname (account_lid)
+		 * @param string $first first name
+		 * @param string $last last name
 		 * @param $passwd string cleartext pw
-		 * @param $group string/boolean Groupname for users primary group or False for a group, default 'Default'
-		 * @param $changepw boolean user has right to change pw, default False
-		 * @return the numerical user-id
+		 * @param string/boolean $primary_group Groupname for users primary group or False for a group, default 'Default'
+		 * @param boolean $changepw user has right to change pw, default False = Pw change NOT allowed
+		 * @param string $email 
+		 * @return int the numerical user-id
 		 */
-		function add_account($username,$first,$last,$passwd,$group='default',$changepw=False)
+		function add_account($username,$first,$last,$passwd,$primary_group='Default',$changepw=False,$email='')
 		{
 			$this->setup_account_object();
 
-			$groupid = $group ? $GLOBALS['egw']->accounts->name2id($group) : False;
+			$primary_group_id = $primary_group ? $GLOBALS['egw']->accounts->name2id($primary_group) : False;
 
 			if(!($accountid = $GLOBALS['egw']->accounts->name2id($username)))
 			{
-				$accountid = $accountid ? $accountid : $GLOBALS['egw']->accounts->create(array(
-					'account_type'      => $group ? 'u' : 'g',
+				$account = array(
+					'account_type'      => $primary_group ? 'u' : 'g',
 					'account_lid'       => $username,
 					'account_passwd'    => $passwd,
 					'account_firstname' => $first,
 					'account_lastname'  => $last,
 					'account_status'    => 'A',
-					'account_primary_group' => $groupid,
-					'account_expires'   => -1
-				));
+					'account_primary_group' => $primary_group_id,
+					'account_expires'   => -1,
+					'account_email'     => $email,
+					'account_members'   => ''
+				);
+				if (!($accountid = $GLOBALS['egw']->accounts->save($account)))
+				{
+					error_log("setup::add_account('$username','$first','$last',\$passwd,'$primary_group',$changepw,'$email') failed! accountid=$accountid");
+					return false;
+				}
 			}
-			$accountid = (int)$accountid;
-			if($groupid)
+			if ($primary_group)	// only for users, NOT groups
 			{
-				$this->add_acl('phpgw_group',(int)$groupid,$accountid);
+				$memberships = $GLOBALS['egw']->accounts->memberships($accountid,true);
+	
+				if($primary_group_id && !in_array($primary_group_id,$memberships))
+				{
+					$memberships[] = $primary_group_id;
+					
+					$GLOBALS['egw']->accounts->set_memberships($memberships,$accountid);
+				}
+				if (!$changepw) $this->add_acl('preferences','nopasswordchange',$accountid);
 			}
-			$this->add_acl('preferences','changepassword',$accountid,(int)$changepw);
-
+			error_log("setup::add_account('$username','$first','$last',\$passwd,'$primary_group',$changepw,'$email') successfull created accountid=$accountid");
 			return $accountid;
 		}
 		
+		/**
+		 * Set the memberships of an account
+		 *
+		 * @param array $groups array of group-id's
+		 * @param int $user account_id
+		 */
+		function set_memberships($groups,$user)
+		{
+			$this->setup_account_object();
+			
+			return $GLOBALS['egw']->accounts->set_memberships($groups,$user);
+		}
+		
 		/**
 		 * Check if accounts other then the automatically installed anonymous account exist
 		 *
@@ -932,12 +967,12 @@
 		 */
 		function accounts_exist()
 		{
-			$this->setup_account_object();
+			if (!$this->setup_account_object()) return false;
 
 			$accounts = $GLOBALS['egw']->accounts->search(array(
 				'type'   => 'accounts',
 				'start'  => 0,
-				'offset' => 2,	// we only need to check 2 accounts, if we just check for not anonymous
+				'offset' => 2	// we only need to check 2 accounts, if we just check for not anonymous
 			));
 			
 			if (!$accounts || !is_array($accounts) || !count($accounts))
@@ -958,6 +993,8 @@
 		/**
 		 * Add ACL rights
 		 *
+		 * Dont use it to set group-membership, use set_memberships instead!
+		 * 
 		 * @param $app string/array with app-names
 		 * @param $locations string eg. run
 		 * @param $account int/string accountid or account_lid
@@ -965,7 +1002,8 @@
 		 */
 		function add_acl($apps,$location,$account,$rights=1)
 		{
-			if (!is_int($account))
+			error_log("setup::add_acl(".(is_array($apps) ? "array('".implode("','",$apps)."')" : "'$apps'").",'$location',$account,$rights)");
+			if (!is_numeric($account))
 			{
 				$this->setup_account_object();
 				$account = $GLOBALS['egw']->accounts->name2id($account);
@@ -984,7 +1022,7 @@
 				$this->db->delete($this->acl_table,array(
 					'acl_appname'  => $app,
 					'acl_location' => $location,
-					'acl_account'  => $account,
+					'acl_account'  => $account
 				),__LINE__,__FILE__);
 
 				if ((int) $rights)
