@@ -14,7 +14,7 @@
 	*  Free Software Foundation; either version 2 of the License, or (at your  *
 	*  option) any later version.                                              *
 	\**************************************************************************/
-	/* $Id: class.setup_process.inc.php 21308 2006-04-09 10:59:54Z ralfbecker $ */
+	/* $Id: class.setup_process.inc.php 22372 2006-08-30 04:48:56Z ralfbecker $ */
 
 	/* app status values:
 	U	Upgrade required/available
@@ -196,9 +196,9 @@
 			$is_windows = strtoupper(substr(PHP_OS,0,3)) == 'WIN';
 		
 			$GLOBALS['current_config']['site_title'] = 'eGroupWare';
-			$GLOBALS['current_config']['hostname']  = $_SERVER['HTTP_HOST'];
+			$GLOBALS['current_config']['hostname']  = $_SERVER['HTTP_HOST'] ? $_SERVER['HTTP_HOST'] : 'localhost';
 
-			// guessing the phpGW url
+			// guessing the eGW url
 			$parts = explode('/',$_SERVER['PHP_SELF']);
 			array_pop($parts);	// remove config.php
 			array_pop($parts);	// remove setup
@@ -527,11 +527,13 @@
 					$targetver  = $appdata['version'];	// The version we need to match when done
 					$appdir     = EGW_SERVER_ROOT . SEP . $appname . SEP . 'setup' . SEP;
 
-					if(file_exists($appdir . 'tables_update.inc.php') && !@$this->updateincluded[$appname])
+					if(file_exists($appdir . 'tables_update.inc.php'))
 					{
-						include ($appdir . 'tables_update.inc.php');
-						$this->updateincluded[$appname] = True;
-
+						if (!@$this->updateincluded[$appname])
+						{
+							include ($appdir . 'tables_update.inc.php');
+							$this->updateincluded[$appname] = True;
+						}
 						while ($currentver && $currentver != $targetver && 
 							function_exists($function = $appname . '_upgrade' . str_replace('.','_',$currentver)))
 						{
