@@ -1,20 +1,17 @@
 <?php
-  /**************************************************************************\
-  * eGroupWare - Setup                                                       *
-  * http://www.egroupware.org                                                *
-  * --------------------------------------------                             *
-  * This file written by Joseph Engo<jengo@phpgroupware.org>                 *
-  *  and Dan Kuykendall<seek3r@phpgroupware.org>                             *
-  *  and Mark Peters<skeeter@phpgroupware.org>                               *
-  *  and Miles Lott<milosch@groupwhere.org>                                  *
-  * --------------------------------------------                             *
-  *  This program is free software; you can redistribute it and/or modify it *
-  *  under the terms of the GNU General Public License as published by the   *
-  *  Free Software Foundation; either version 2 of the License, or (at your  *
-  *  option) any later version.                                              *
-  \**************************************************************************/
-
-  /* $Id: functions.inc.php 22065 2006-07-09 17:33:07Z ralfbecker $ */
+/**
+ * Setup
+ *
+ * @link http://www.egroupware.org
+ * @package setup
+ * @author Joseph Engo <jengo@phpgroupware.org>
+ * @author Dan Kuykendall <seek3r@phpgroupware.org>
+ * @author Mark Peters <skeeter@phpgroupware.org>
+ * @author Miles Lott <milos@groupwhere.org>
+ * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+ * @version $Id: functions.inc.php 24449 2007-09-19 12:26:02Z leithoff $
+ */
 
 	error_reporting(error_reporting() & ~E_NOTICE);
 	
@@ -38,10 +35,19 @@
 	/*  If we included the header.inc.php, but it is somehow broken, cover ourselves... */
 	if(!defined('EGW_SERVER_ROOT') && !defined('EGW_INCLUDE_ROOT'))
 	{
-		define('EGW_SERVER_ROOT','..');
-		define('EGW_INCLUDE_ROOT','..');
-		define('PHPGW_SERVER_ROOT','..');
-		define('PHPGW_INCLUDE_ROOT','..');
+		if (defined('PHPGW_SERVER_ROOT') && defined('PHPGW_INCLUDE_ROOT'))	// pre 1.2 install
+		{
+			define('EGW_SERVER_ROOT',PHPGW_SERVER_ROOT);
+			define('EGW_INCLUDE_ROOT',PHPGW_INCLUDE_ROOT);
+		}
+		else	// no install
+		{
+			define('EGW_SERVER_ROOT','..');
+			define('EGW_INCLUDE_ROOT','..');
+			define('PHPGW_SERVER_ROOT','..');
+			define('PHPGW_INCLUDE_ROOT','..');
+		}
+		define('EGW_API_INC',EGW_SERVER_ROOT.'/phpgwapi/inc');
 	}
 
 	require(EGW_INCLUDE_ROOT . '/phpgwapi/inc/common_functions.inc.php');
@@ -63,21 +69,21 @@
 			$msg = lang('does not exist');
 			return false;
 		}
-		if (!@is_writeable($dir))
+		if (!@is_writeable($dir) && $_SERVER['HTTP_HOST'])	// only do the check if we run by the webserver
 		{
 			$msg = lang('is not writeable by the webserver');
 			return false;
 		}
 		if ($check_in_docroot)
 		{
-			$docroots = array(EGW_SERVER_ROOT,$_SERVER['DOCUMENT_ROOT']);
+			$docroots = array(realpath(EGW_SERVER_ROOT),realpath($_SERVER['DOCUMENT_ROOT']));
 			$dir = realpath($dir);
 	
 			foreach ($docroots as $docroot)
 			{
 				$len = strlen($docroot);
 	
-				if ($docroot == substr($dir,0,$len))
+				if ($docroot == substr($dir,0,$len) && $len>0)
 				{
 					$rest = substr($dir,$len);
 	
@@ -101,7 +107,7 @@
 		if(!is_array($vars))
 		{
 			$vars = func_get_args();
-			array_shift($vars);     // remove $key
+			array_shift($vars);	// remove $key
 		}
 		return $GLOBALS['egw_setup']->translation->translate("$key", $vars);
 	}
@@ -148,11 +154,14 @@
 		{
 			if($data['available'] && !empty($data['lang']))
 			{
-				$selected = '';
 				$short = substr($data['lang'],0,2);
-				if ($short == $ConfigLang || empty($ConfigLang) && $short == substr($_SERVER['HTTP_ACCEPT_LANGUAGE'],0,2))
+				if ($short == $ConfigLang || $data['lang'] == $ConfigLang || empty($ConfigLang) && $short == substr($_SERVER['HTTP_ACCEPT_LANGUAGE'],0,2))
 				{
-					$selected = ' selected="selected"';
+					$selected = ' selected';
+				}
+				else
+				{
+					$selected = '';
 				}
 				$select .= '<option value="' . $data['lang'] . '"' . $selected . '>' . $data['descr'] . '</option>' . "\n";
 			}
