@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.Common_UI.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: class.Common_UI.inc.php 23913 2007-05-22 04:04:13Z lkneschke $ */
 
 	class Common_UI
 	{
@@ -141,7 +141,7 @@
 					if ($oldsitelanguages && ($oldsitelanguages != $_POST['pref']['site_languages']))
 					{
 						$oldsitelanguages = explode(',',$oldsitelanguages);
-						$newsitelanguages = explode(',',$_POST['pref']['site_languages']);
+						$newsitelanguages = split(' ?, ?',trim($_POST['pref']['site_languages']));
 						$replacedlang = array_diff($oldsitelanguages,$newsitelanguages);
 						$addedlang = array_diff($newsitelanguages,$oldsitelanguages);
 						if ($replacedlang)
@@ -209,7 +209,7 @@
 				);
 				$theme = $GLOBALS['Common_BO']->sites->current_site['default_theme'];
 				$theme_info = $GLOBALS['egw']->link('/sitemgr/theme_info.php');
-				$theme_info .= (strstr($theme_info,'?') ? '&' : '?').'theme=';
+				$theme_info .= (strpos($theme_info,'?') !== false ? '&' : '?').'theme=';
 				$preferences['default_theme'] = array(
 					'title'=>lang('Template select'),
 					'note'=>lang('Choose your site\'s theme or template.  Note that if you changed the above checkbox you need to save before choosing a theme or template.').'<br /><br />'.
@@ -224,22 +224,11 @@
 					'below' => '<iframe name="TemplateInfo" width="100%" height="180" src="'.$theme_info.($theme ? $theme : 'idots').'" frameborder="0" scrolling="auto"></iframe>',
 					'default'=>'idots'
 				);
-				$upload_dir = $GLOBALS['Common_BO']->sites->current_site['upload_dir'];
 				$preferences['upload_dir'] = array(
-					'title'=>lang('Directory for uploads (images etc.)'),
-					'note'=> $GLOBALS['Common_BO']->sites->current_site['upload_dir'] ? 
-						(
-							is_writeable($upload_dir) ? '' : 
-							lang('Directory is not writeable by webserver. Please correct this situation!')
-						) :
-						lang('Note, this directory has to be writeable by webserver!'),
-					'default'=> $GLOBALS['Common_BO']->sites->current_site['site_dir'] . SEP . 'images' .SEP
-				);
-				$upload_url = $GLOBALS['Common_BO']->sites->current_site['upload_url'];
-				$preferences['upload_url'] = array(
-					'title'=>lang('URL of directory for uploads (images etc.)'),
-					'note'=> '',
-					'default'=> $GLOBALS['Common_BO']->sites->current_site['site_url'].'images'
+					'title'=>lang('Image directory relative to document root (use / !), example:').' /images',
+					'note'=> lang('An existing AND by the webserver readable directory enables the image browser and upload.').'<br />'.
+						lang('Upload requires the directory to be writable by the webserver!').
+						$this->check_upload_dir($GLOBALS['Common_BO']->sites->current_site['upload_dir']),
 				);
 				$preferences['site_languages'] = array(
 					'title'=>lang('Languages the site user can choose from'),
@@ -300,6 +289,22 @@
 			}
 			$this->DisplayFooter();
 		}
+		
+		function check_upload_dir($dir)
+		{
+			if ($dir)
+			{
+				if (!is_dir($_SERVER['DOCUMENT_ROOT'].$dir) || !file_exists($_SERVER['DOCUMENT_ROOT'].$dir.'/.'))
+				{
+					$msg = lang('Directory does not exist, is not readable by the webserver or is not relative to the document root!');
+				}
+				elseif(!is_writable($_SERVER['DOCUMENT_ROOT'].$dir))
+				{
+					$msg = lang('Directory is NOT writable by the webserver --> disabling upload');
+				}
+			}
+			return $msg ? '<br /><font color="red">'.$msg.'</font>'  : '';
+		}
 
 		function inputText($name='',$size=40,$default='')
 		{
