@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.Content_BO.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: class.Content_BO.inc.php 24360 2007-08-08 16:05:27Z jgordor $ */
 
 require_once(EGW_INCLUDE_ROOT . SEP . 'sitemgr' . SEP . 'inc' . SEP . 'class.module.inc.php');
 
@@ -27,7 +27,9 @@ define('SITEMGR_VIEWABLE_ANONYMOUS',3);
 	class Content_BO
 	{
 		var $so;
-
+		var $blockcach;
+		var $blockdefcach;
+		
 		function Content_BO()
 		{
 			$this->so =& CreateObject('sitemgr.Content_SO', true);
@@ -171,7 +173,9 @@ define('SITEMGR_VIEWABLE_ANONYMOUS',3);
 			$cat_ancestorlist = ($cat_id != CURRENT_SITE_ID) ? 
 				$GLOBALS['Common_BO']->cats->getCategoryancestorids($cat_id,True) : 
 				False;
-			return $this->so->getvisibleblockdefsforarea($area,$cat_ancestorlist,$page_id,$isadmin,$isuser);
+			return !isset($this->blockdefcach['all'][$area][$cat_id][$page_id][$isadmin][$isuser]) ?
+				($this->blockdefcach['all'][$area][$cat_id][$page_id][$isadmin][$isuser] = $this->so->getvisibleblockdefsforarea($area,$cat_ancestorlist,$page_id,$isadmin,$isuser)) :
+				$this->blockdefcach['all'][$area][$cat_id][$page_id][$isadmin][$isuser];
 		}
 
 		function &getallblocksforarea($area,$cat_id,$page_id,$lang)
@@ -179,7 +183,9 @@ define('SITEMGR_VIEWABLE_ANONYMOUS',3);
 			$cat_ancestorlist = ($cat_id != CURRENT_SITE_ID) ? 
 				$GLOBALS['Common_BO']->cats->getCategoryancestorids($cat_id,True) : 
 				False;
-			return $this->so->getallblocksforarea($area,$cat_ancestorlist,$page_id,$lang);
+			return !isset($this->blockcach['all'][$area][$cat_id][$page_id][$lang]) ? 
+				($this->blockcach['all'][$area][$cat_id][$page_id][$lang] = $this->so->getallblocksforarea($area,$cat_ancestorlist,$page_id,$lang)) : 
+				$this->blockcach['all'][$area][$cat_id][$page_id][$lang];
 		}
 
 		function &getcommitableblocks()
@@ -388,7 +394,7 @@ define('SITEMGR_VIEWABLE_ANONYMOUS',3);
 				$state=$this->so->getblockstate($block_id,$lang);
 			}
 
-			$bo=CreateObject("sitemgr.notification_bo");
+			$bo=CreateObject("sitemgr.bonotifications");
 			$bo->notify_users($GLOBALS['Common_BO']->sites->current_site['site_id'],
 				$cat_id,
 				$state,
