@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.Modules_BO.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: class.Modules_BO.inc.php 22387 2006-08-31 10:21:26Z ralfbecker $ */
 
 	require_once(EGW_INCLUDE_ROOT . '/sitemgr/inc/class.module.inc.php');
 
@@ -62,14 +62,20 @@
 			$obj = false;
 			$classname = 'module_' . $modulename;
 			list($app) = explode('_',$modulename);
+			$files = array();
 	
-			if (@file_exists($file = EGW_INCLUDE_ROOT.'/sitemgr/modules/class.'.$classname.'.inc.php') ||
-				@file_exists($file = EGW_INCLUDE_ROOT.'/'.$app.'/sitemgr/class.'.$classname.'.inc.php'))
+			if (@file_exists($file = $files[] = EGW_INCLUDE_ROOT.'/'.$app.'/sitemgr/class.'.$classname.'.inc.php') ||
+				@file_exists($file = $files[] = EGW_INCLUDE_ROOT.'/'.$modulename.'/sitemgr/class.'.$classname.'.inc.php') ||
+				@file_exists($file = $files[] = EGW_INCLUDE_ROOT.'/sitemgr/modules/class.'.$classname.'.inc.php'))
 			{
 				include_once($file);
 				
 				$obj =& new $classname;
 			}
+			else
+			{
+				die(lang("Module '%1' not found in: %2! --> exiting",$modulename,implode(', ',$files)));
+			}
 			return $obj;
 		}
 
