@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.Pages_BO.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: class.Pages_BO.inc.php 24360 2007-08-08 16:05:27Z jgordor $ */
 
 	class Pages_BO
 	{
@@ -201,7 +201,7 @@
 				$state=$pg->state;
 			}
 			
-			$bo=CreateObject("sitemgr.notification_bo");
+			$bo=CreateObject("sitemgr.bonotifications");
 			$bo->notify_users($GLOBALS['Common_BO']->sites->current_site['site_id'], 
 				$cat_id,
 				$state,
