@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.Sites_BO.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: class.Sites_BO.inc.php 24360 2007-08-08 16:05:27Z jgordor $ */
 
 	class Sites_BO
 	{
@@ -93,6 +93,10 @@
 				$result['sitelanguages'] = $result['site_languages'] ? explode(',',$result['site_languages']) : array('en');;
 				foreach($result['sitelanguages'] as $lang)
 				{
+					if (!is_object($GLOBALS['Common_BO']))
+					{
+						$GLOBALS['Common_BO'] = CreateObject("sitemgr.Common_BO");
+					}
 					$langinfo = $GLOBALS['Common_BO']->cats->getCategory($id,$lang,True);
 					$result['site_name_' . $lang] = $langinfo->name;
 					$result['site_desc_' . $lang] = $langinfo->description;
@@ -135,9 +139,11 @@
 			{
 				$prefs['themesel'] = $prefs['default_theme'];	// use the new name
 			}
-			$this->so->saveprefs($prefs,$site_id);
 			$site_languages = $prefs['site_languages'] ? $prefs['site_languages'] : $this->current_site['site_languages'];
-			$site_languages = $site_languages ? explode(',',$site_languages) : array('en');
+			// remove extra space in the language list
+			$site_languages = $site_languages ? split(' ?, ?',trim($site_languages)) : array('en');
+			$prefs['site_languages'] = implode(',',$site_languages);
+			$this->so->saveprefs($prefs,$site_id);
 			foreach ($site_languages as $lang)
 			{
 				$GLOBALS['Common_BO']->cats->saveCategoryLang(
