@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.module.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: class.module.inc.php 23597 2007-04-14 17:41:34Z ralfbecker $ */
 
 class Transformer
 {
@@ -319,16 +319,16 @@ class Module
 				{
 					$GLOBALS['egw']->html =& CreateObject('phpgwapi.html');
 				}
-// 				return $GLOBALS['egw']->html->htmlarea($elementname,$default,$input['params']['style'],false,$input['params']['plugins']);
-				return $GLOBALS['egw']->html->tinymce($elementname,$default,$input['params']['style'],$input['params']['plugins']);
-
-// 				$GLOBALS['Common_BO']->sites->current_site['site_url']
+				return $GLOBALS['egw']->html->fckEditor($elementname,$default,
+					$GLOBALS['egw_info']['user']['preferences']['sitemgr']['rtfEditorFeatures'],	// default is extended
+					null,'300px','100%',	// 300px to fit in the popup, one can use fitWindow to expand it
+					$GLOBALS['Common_BO']->sites->current_site['upload_dir']);
 			case 'textarea':
 				return '<textarea ' . $inputdef . '>' . $default . '</textarea>';
 			case 'textfield':
 				return '<input type="text" ' . $inputdef . ' value ="' . $default . '" />';
 			case 'checkbox':
-				return '<input type="checkbox" ' . $inputdef . ($default ? 'checked="1"' :'') . '" />';
+				return '<input type="checkbox" ' . $inputdef . ($default ? 'checked="1"' :'') . ' />';
 			case 'select':
 				$select = '<select ' .($input['multiple'] ? 'multiple="1"'.($input['multiple'] > 1 ? ' size="'.$input['multiple'].'"' : '') : '') . $inputdef . '>';
 				foreach ($input['options'] as $value => $display)
