@@ -27,7 +27,7 @@
 	* Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.         *
 	\*******************************************************************/
 
-	/* $Id: class.xmltool2.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: class.xmltool2.inc.php 23741 2007-04-30 10:29:44Z lkneschke $ */
 
 	// Michael Totschnig: this is a variant of xmltool where export_var returns subelements
 	// in a subarray, even if there is only one of them
@@ -335,8 +335,8 @@
 			$retval['attributes'] = $this->attributes;
 			if($this->data_type != 'node')
 			{	
-				$found_at = strstr($this->data,'PHP_SERIALIZED_OBJECT&:');
-				if($found_at != False)
+				$found_at = strpos($this->data,'PHP_SERIALIZED_OBJECT&:');
+				if($found_at !== False)
 				{
 					$retval['value'] = unserialize(str_replace ('PHP_SERIALIZED_OBJECT&:', '', $this->data));
 				}
@@ -439,8 +439,8 @@
 
 			if($this->data_type != 'node')
 			{	
-				$found_at = strstr($this->data,'PHP_SERIALIZED_OBJECT&:');
-				if($found_at != False)
+				$found_at = strpos($this->data,'PHP_SERIALIZED_OBJECT&:');
+				if($found_at !== False)
 				{
 					return unserialize(str_replace ('PHP_SERIALIZED_OBJECT&:', '', $this->data));
 				}
