@@ -10,7 +10,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: hook_sidebox_menu.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: hook_sidebox_menu.inc.php 23597 2007-04-14 17:41:34Z ralfbecker $ */
 
 {
 
@@ -33,6 +33,11 @@
 		$menu_title = lang('Other websites');
 		display_sidebox($appname,$menu_title,$file);
 	}
+	$menu_title = lang('Preferences');
+	$file = Array(
+		'Preferences' => $GLOBALS['egw']->link('/index.php',array('menuaction'=>'preferences.uisettings.index','appname'=>'sitemgr')),
+	);
+	display_sidebox($appname,$menu_title,$file);
 	$menu_title = lang('Documentation');
 	$docs = $GLOBALS['egw_info']['server']['webserver_url'].'/sitemgr/doc/';
 	$file = array(
