@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.module_html.inc.php 22000 2006-07-05 12:29:59Z nelius_weiss $ */
+	/* $Id: class.module_html.inc.php 23300 2007-01-18 18:00:54Z nelius_weiss $ */
 
 	class module_html extends Module
 	{
@@ -22,23 +22,6 @@
 					'label' => lang('Enter the block content here'),
 					'large' => True,	// show label above content
 					'i18n' => True,
-					'params' => Array(
-						'style' => 'width:100%; min-width:500px; height:280px',
-						'plugins' => '
-							theme : "advanced",
-							theme_advanced_toolbar_location : "top",
-							theme_advanced_toolbar_align : "left",
-							theme_advanced_disable : "styleselect",
-							plugins : "filemanager,table,contextmenu,paste,fullscreen,advhr,advimage,advlink,iespell,insertdatetime,searchreplace,flash",
-							theme_advanced_buttons1_add : "fontselect,fontsizeselect,separator,search,replace",
-							theme_advanced_buttons2_add : "separator,iespell,insertdate,inserttime,separator,flash",
-							theme_advanced_buttons3_add : "separator,filemanager,fullscreen,separator,forecolor,backcolor",
-							theme_advanced_buttons3_add_before : "tablecontrols,separator,advhr",
-							verify_html: false,
-							flash_wmode : "transparent",
-							flash_quality : "high",
-							flash_menu : "false"'
-					)
 				)
 			);
 			$this->properties = array('striphtml' => array('type' => 'checkbox', 'label' => lang('Strip HTML from block content?')));
