@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.module_navigation.inc.php 20985 2006-04-06 11:02:49Z ralfbecker $ */
+	/* $Id: class.module_navigation.inc.php 22730 2006-10-24 21:38:12Z nelius_weiss $ */
 
 	/**
 	 * Navigation framework module
@@ -24,10 +24,12 @@
 	 * - current_section_only
 	 * - expand
 	 * - highlight_current_page
+	 * - main_cats_to_include
 	 * - max_cat_depth -> could be ablolute ('number')  or relative (+number)
 	 * - max_pages_depth -> could be ablolute ('number')  or relative (+number)
 	 * - nav_title
 	 * - no_full_index
+	 * - page_link_text {0 = title; 1 = subtitle }
 	 * - path_only
 	 * - show_cat_description
 	 * - show_edit_icons
@@ -48,6 +50,9 @@
 	 */
 	class module_navigation extends Module
 	{
+		var $lastcatdepth = 0;
+		var $lastpagedepth = 0;
+		
 		function module_navigation()
 		{
 			$this->arguments = array(
@@ -64,7 +69,8 @@
 						6 => 'toc',
 						7 => 'toc_block',
 						8 => 'path',
-						9 => lang('custom')
+						9 => lang('custom'),
+					   10 => 'tabs',
 					)
 				)	
 			);
@@ -99,6 +105,17 @@
 					'expand' => array(
 						'type' => 'checkbox',
 						'label' => lang('Expand current category')
+					),
+					'page_link_text' => array(
+						'type' => 'select',
+						'label' => lang('Text of page links'),
+						'options' => array(
+							0 => lang('Title'),
+							1 => lang('Subtitle'))
+					),
+					'main_cats_to_include' => array(
+						'type' => 'textfield',
+						'label' => lang('Which main categories schuld be included (comma seperated list, empty for all)'),
 					)),
 				4 => array( // Navigation
 					'description' => lang("This module displays the root categories in one block each, with pages and subcategories (incl. their pages if activated).")
@@ -116,18 +133,21 @@
 					'description' => lang('This module provides a condensed table of contents, meant for side areas')
 					),
 				8 => array( // Path
-					'description' => lang('This module provides the path to the element currently shown')
-					),
+					'description' => lang('This module provides the path to the element currently shown'),
+					'no_show_sep' => array(
+						'type' => 'checkbox',
+						'label'=> lang('Don\'t use egroupware css ">" separator (for templates that uses images/simbols for lists)')
+					)),
 				9 => array( //Custom
 					'description' => lang('This module is a customisable navigation element'),
-					'allingment' => array(
+					'alignment' => array(
 						'type' => 'select',
 						'label' => lang('Allignment of navigation elements'),
 						'options' => array(
 							'vertical' => lang('Vertical'),
 							'horizontal' => lang('Horizontal'))
 					),
-					'textallign' => array(
+					'textalign' => array(
 						'type' => 'select',
 						'label' => lang('Text allignment'),
 						'options' => array(
@@ -174,6 +194,23 @@
 						'type' => 'checkbox',
 						'label' => lang('No link to full index')
 					),
+				),
+			   10 => array( // tabs
+					'description' => lang('This module provides tabs'),
+					'tab_names' => array(
+						'type' => 'textfield',
+						'label' => lang('Name of the tabs (comma seperated)'),
+					),
+					'tab_links' => array(
+						'type' => 'textfield',
+						'label' => lang('Links for the tabs (comma seperated)'),
+					),
+					'tab_active' => array(
+						'type' => 'textfield',
+						'label' => lang('When is a tab activated?').
+							lang('Seperate Cats / Pages of one tab by :').
+							lang('cats are numeric, pages strings'),
+					),
 				));
 			$this->title = 'Navigation element';
 			$this->description = lang("This module displays any kind of navigation element.");
@@ -195,7 +232,7 @@
 					div.inactivetab{ display:none; }
 				</style>
 				<script type=\"text/javascript\">
-					var tab = new Tabs('".(string)(count($this->arguments['nav_type']['options']) -1)."',
+					var tab = new Tabs(".(string)(count($this->arguments['nav_type']['options']) -1).",
 					'activetab','inactivetab','tab','tabcontent','','','tabpage');
 					tab.init();
 				</script>",
@@ -354,7 +391,14 @@
 					));
 					break;
 				case 8 : // Path
-					$out .= "path\">\n";
+					if(!$arguments['no_show_sep'])
+					{
+						$out .= "path\">\n";	
+					}
+					else
+					{
+						$out .= "path-nosep\">\n";
+					}
 					$arguments = array_merge($arguments, array(
 						'suppress_parent' => true,
 						'suppress_show_all' => true,
@@ -364,11 +408,16 @@
 					break;
 					
 				case 9 : // Custom
-					$out .= "custrom\" ";
-					$out .= "class=\"allingment-". $arguments['allingment']."\" ";
-					$out .= "class=\"textallign-". $arguments['textallign']."\"";
+					$out .= "custom\" ";
+					$out .= "class=\"alignment-". $arguments['alignment']."\" ";
+					$out .= "class=\"textalign-". $arguments['textalign']."\"";
 					$out .= ">\n";
 					break;
+				case 10 : // tabs
+					$out .= "tabs\">\n";
+					$out .= $this->type_tabs($arguments,$properties);
+					$out .= "  </div>\n<!-- navigation context ends here -->\n</div>\n";
+					return $out;
 				case 4 : // Navigation
 				default:
 					$out .= "navigation\">\n";
@@ -426,7 +475,9 @@
 			if (strpos($arguments['max_pages_depth'],'+') === 0) (int)$arguments['max_pages_depth'] += $this->category->depth;
 			
 			$cat_tree = $cat_tree_data = array('root');
-			foreach($this->objbo->getCatLinks(0,true,true) as $cat_id => $cat)
+			
+			$this->lastcatdepth = 0; // indicate start of first cat block!
+			foreach(($this->objbo->getCatLinks(0,true,true) + array( 0 => array('depth' => 0))) as $cat_id => $cat)
 			{
 				if(array_key_exists($cat['depth'],$cat_tree))
 				{
@@ -490,10 +541,15 @@
 					break;
 				}
 				
-// 				if($arguments['current_section_only'] && $this->page->cat_id != $cat_id) continue;
  				if($arguments['current_section_only'] && array_search($this->page->cat_id,$cat_tree) === false) continue;
 				if((int)$arguments['category_id'] > 0 && (int)$arguments['category_id'] != $cat_id) continue;
-//  				_debug_array($cat_tree);
+				if(! empty($arguments['main_cats_to_include'])) {
+					$main_cats_to_include = explode(',',$arguments['main_cats_to_include']);
+					$test = array_intersect($main_cats_to_include,$cat_tree);
+					if (empty($test)) continue;
+				}
+				
+//  			_debug_array($cat_tree);
 				if($cat['depth'] <= $arguments['max_cat_depth'])
 				{
 					if(!($arguments['suppress_current_cat'] && $this->page->cat_id == $cat_id) && 
@@ -506,12 +562,12 @@
 						$out .= $this->encapsulate($arguments,array($cat_id => $cat),'cat',$cat_id,$cat['depth']);
 					}
 				}
-					if($cat['depth'] <= $arguments['max_pages_depth'])
-					{
-						$pages = $this->objbo->getPageLinks($cat_id,$arguments['showhidden'],true);
-						if($arguments['suppress_current_page']) unset($pages[$this->page->id]);
-						$out .= $this->encapsulate($arguments,$pages,'page',$cat_id,$cat['depth'] +1);
-					}
+				if($cat['depth'] <= $arguments['max_pages_depth'] && $cat['depth'] != 0)
+				{
+					$pages = $this->objbo->getPageLinks($cat_id,$arguments['showhidden'],true);
+					if($arguments['suppress_current_page']) unset($pages[$this->page->id]);
+					$out .= $this->encapsulate($arguments,$pages,'page',$cat_id,$cat['depth'] +1);
+				}
 				
 			}
 			if (!$arguments['no_full_index'])
@@ -537,11 +593,42 @@
 		 */
 		function encapsulate($arguments,$data,$type,$cat_id,$depth=1)
 		{
-			$out  = "    <div class=\"nav-".$type."-entry depth-".$depth."\">\n";
+			$out = '';
+			if(empty($arguments['main_cats_to_include']) && $arguments['nav_type'] != 6) {
+				// do we have to start or finish a block?
+				if ($type == 'cat')
+				{
+					// finish old block
+					if ($this->lastcatdepth >= $depth)
+					{
+						while($this->lastcatdepth != $depth - 1 && $this->lastcatdepth != 0)
+						{
+							$out .= "  </div>\n";
+							//$out .= "  <!-- NAV CAT BLOCK OF DEPTH ". $this->lastcatdepth. " ENDS HERE-->\n";
+							$this->lastcatdepth--;
+						}
+					}
+					$this->lastcatdepth = $depth;
+					
+					// marker to end last block
+					if ($depth == 0) return $out;
+					
+					//$out .= "  <!-- NAV CAT BLOCK OF DEPTH ". $depth. " STARTS HERE-->\n";
+					$out .= "  <div class=\"nav-cat-block blockdepth-".$depth. ($this->page->cat_id == $cat_id ? ' active' : ' inactive'). "\">\n";
+				}
+			}			
+			$out .= "    <div class=\"nav-".$type."-entry depth-".$depth."\">\n";
 			$out .= "      <ul>\n";
+			
 			if (is_array($data))
 			foreach($data as $id => $entry)
 			{
+				if (($arguments['page_link_text'] == 1 )&& $type == 'page')
+				{
+					preg_match('/href="([^"]+)"/i',$entry['link'],$matches);
+					$entry['link'] = '<a href="'. $matches[1]. '">'. $entry['subtitle']. '</a>';
+				}
+
 				if($arguments['highlight_current_page'] && $id == $this->page->id && $type == 'page')
 				{
 					$entry['link'] = "<div class=\"nav-highlight_current_page\">".$entry['link'].'</div>';
@@ -558,7 +645,7 @@
 						$this->objbo->getEditIconsPage($id,$cat_id);
 					$out .= "</span>\n";
 				}
-// 				_debug_array($entry);
+ 				
 				if(($arguments['show_cat_description'] && $type == 'cat') || ($arguments['show_page_description'] && $type == 'page'))
 				{
 					$out .= "<span class=\"nav-".$type."-description\">";
@@ -573,6 +660,7 @@
 			return $out;
 		}
 		
+
 		function type_navigation(&$arguments,$properties)
 		{
 			global $objbo,$page;
@@ -708,6 +796,35 @@
 			return $content;
 		}
 		
+		/**
+		 * provides tabs like on egroupware.org
+		 *
+		 * @param array $_arguments
+		 * @param array $_properties
+		 */
+		function type_tabs($_arguments,$_properties)
+		{
+			$out = "    <ul>\n";
+			$tab_names = explode(',',$_arguments['tab_names']);
+			$tab_links = explode(',',$_arguments['tab_links']);
+			foreach (explode(',',$_arguments['tab_active']) as $num => $active)
+			{
+				
+				$current = false;
+				foreach (explode(':',$active) as $item)
+				{
+					if (!is_numeric($item) && $GLOBALS['page']->name == $item) $current = true;
+					elseif($GLOBALS['page']->cat_id == $item) $current = true;
+					
+					if ($current) break;
+				}
+				$out .= '      <li'. ($current ? ' id="current"' : ''). '>';
+				$out .= '<a href="'. $tab_links[$num]. '">'. $tab_names[$num]. '</a></li>'."\n";
+			}
+			$out .= "    </ul>\n";
+			return $out;
+		}
+		
 		function showcat($cats)
 		{
 			foreach($cats as $cat_id => $cat)
