@@ -10,7 +10,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: default_records.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: default_records.inc.php 23913 2007-05-22 04:04:13Z lkneschke $ */
 	
 	$sitemgr_table_prefix = 'egw_sitemgr';
 	$oProc->query("INSERT INTO {$GLOBALS['egw_setup']->cats_table} (cat_parent,cat_owner,cat_access,cat_appname,cat_name,cat_description,last_mod) VALUES (0,-1,'public','sitemgr','Default Website','This website has been added by setup',".time().")");
@@ -43,21 +43,29 @@
 	$areas = array(
 		'administration' => array('left','right'),
 		'amazon' => array('left','right'),
+		'bookmarks' => array('__PAGE__'),
 		'calendar' => array('left','right'),
 		'currentsection' => array('left','right'),
 		'download' => array('__PAGE__'),
 		'filecontents' => array('left','right','header','footer','__PAGE__'),
 		'frame' => array('__PAGE__'),
+		'forum' => array('__PAGE__'),
+		'gallery' => array('left','right','__PAGE__'),
+		'gallery_imageblock' => array('left','right','__PAGE__'),
 		'google' => array('left','right'),
 		'html' => array('left','right','header','footer','__PAGE__'),
 		'lang_block' => array('left','right'),
 		'login' => array('left','right'),
 		'navigation' => array('left','right','__PAGE__'),
-		'news' => array('left','right','__PAGE__'),
+		'news_admin' => array('left','right','__PAGE__'),
 		'notify' => array('left','right'),
 		'phpbrain' => array('__PAGE__'),
+		'polls' => array('left','right','__PAGE__'),
 		'redirect' => array('__PAGE__'),
+		'resources' => array('__PAGE__'),
+		'search' => array('left','right','header','footer','__PAGE__'),
 		'template' => array('left','right','__PAGE__'),
+		'tracker' => array('__PAGE__'),
 		'validator' => array('footer'),
 		'wiki' => array('__PAGE__'),
 	);
@@ -232,4 +240,5 @@
 	{
 		echo "sitemgr-link NOT installed, you need to copy it from egroupware/sitemgr/sitemgr-link to egroupware/sitemgr-link and install it manually !!!";
 	}
-
+	
+	
\ No newline at end of file
