@@ -9,11 +9,11 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: setup.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: setup.inc.php 24360 2007-08-08 16:05:27Z jgordor $ */
 
 	$setup_info['sitemgr']['name']      = 'sitemgr';
 	$setup_info['sitemgr']['title']     = 'SiteMgr Web Content Management';
-	$setup_info['sitemgr']['version']   = '1.2';
+	$setup_info['sitemgr']['version']   = '1.4.002';
 	$setup_info['sitemgr']['app_order'] = 14;
 	$setup_info['sitemgr']['tables']    = array('egw_sitemgr_pages','egw_sitemgr_pages_lang','egw_sitemgr_categories_state','egw_sitemgr_categories_lang','egw_sitemgr_modules','egw_sitemgr_blocks','egw_sitemgr_blocks_lang','egw_sitemgr_content','egw_sitemgr_content_lang','egw_sitemgr_active_modules','egw_sitemgr_properties','egw_sitemgr_sites','egw_sitemgr_notifications','egw_sitemgr_notify_messages');
 	$setup_info['sitemgr']['enable']    = 1;
@@ -53,15 +53,16 @@ Arijit Ghosh (arijitg -AT- uci.edu)');
 	$setup_info['sitemgr']['hooks'][] = 'about';
 	$setup_info['sitemgr']['hooks'][] = 'admin';
 	$setup_info['sitemgr']['hooks'][] = 'sidebox_menu';
+	$setup_info['sitemgr']['hooks'][] = 'settings';
 
 	/* Dependencies for this app to work */
 	$setup_info['sitemgr']['depends'][] = array(
 		'appname'  => 'phpgwapi',
-		'versions' => Array('1.0.1','1.2')
+		'versions' => Array('1.3','1.4','1.5')
 	);
 	$setup_info['sitemgr']['depends'][] = array(
 		'appname'  => 'etemplate',
-		'versions' => Array('1.0.0','1.0.1','1.2')
+		'versions' => Array('1.3','1.4','1.5')
 	);
 
 
