@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: tables_update.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: tables_update.inc.php 24360 2007-08-08 16:05:27Z jgordor $ */
 
 	$test[] = '0.9.13.001';
 	function sitemgr_upgrade0_9_13_001()
@@ -908,5 +908,67 @@
 
 		$GLOBALS['setup_info']['sitemgr']['currentver'] = '1.2';
 		return $GLOBALS['setup_info']['sitemgr']['currentver'];
-	}	
+	}
+	
+	$test[] = '1.2';
+	function sitemgr_upgrade1_2()
+	{
+		// replace news module with news_admin module
+		$GLOBALS['egw_setup']->db->update('egw_sitemgr_modules',array('module_name' => 'news_admin'),array('module_name' => 'news'),__LINE__,__FILE__);
+		
+		$GLOBALS['setup_info']['sitemgr']['currentver'] = '1.3.001';
+		return $GLOBALS['setup_info']['sitemgr']['currentver'];
+	}
+
+	$test[] = '1.3.001';
+	function sitemgr_upgrade1_3_001()
+	{
+		$db = clone($GLOBALS['egw_setup']->db);
+		$db->set_app('sitemgr');
+		
+		// insert the search module into the module table
+		$db->insert('egw_sitemgr_modules',array(
+			'module_name' => 'search',
+			'description' => 'This module search throw the content (Page title/description and html content)',
+		),false,__LINE__,__FILE__);
+		$search_id = $db->get_last_insert_id('egw_sitemgr_modules','module_id');		
+
+		// insert in the active_module table the search module (all areas are permited)
+		foreach(array('left','right','header','footer','__PAGE__') as $area)
+		{
+			$db->insert('egw_sitemgr_active_modules',array(
+				'area' => $area,
+				'cat_id' => 2,
+				'module_id' => $search_id,
+			),false,__LINE__,__FILE__);			
+		}		
+
+		$GLOBALS['setup_info']['sitemgr']['currentver'] = '1.3.002';
+		return $GLOBALS['setup_info']['sitemgr']['currentver'];
+	}
+	
+
+	$test[] = '1.3.002';
+	function sitemgr_upgrade1_3_002()
+	{
+		return $GLOBALS['setup_info']['sitemgr']['currentver'] = '1.4';
+	}
+	
+	$test[] = '1.4';
+	function sitemgr_upgrade1_4()
+	{
+		$GLOBALS['egw_setup']->oProc->AlterColumn('egw_sitemgr_notifications','site_language',array(
+			'type' => 'varchar',
+			'precision' => '5',
+			'nullable' => False,
+			'default' => 'all'
+		));
+		
+		$GLOBALS['egw_setup']->oProc->AlterColumn('egw_sitemgr_notify_messages','language',array(
+			'type' => 'varchar',
+			'precision' => '5',
+		));		
+		
+		return $GLOBALS['setup_info']['sitemgr']['currentver'] = '1.4.002';
+	}
 ?>
