@@ -9,14 +9,14 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: config.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: config.inc.php 22966 2006-12-10 00:45:57Z omgs $ */
 
 	/**************************************************************\
 	* Edit the values in the following array to configure SiteMgr, *
 	* to run in a differen directory/URL as sitemgr/sitemgr-site.  *
 	\**************************************************************/
 
-	$sitemgr_info = array(
+	$GLOBALS['sitemgr_info'] = array(
 		// add trailing slash
 		'egw_path'         => '../../',
 		'htaccess_rewrite' => False,
