@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.Template3.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: class.Template3.inc.php 22682 2006-10-19 07:04:02Z nelius_weiss $ */
 
 require_once(EGW_INCLUDE_ROOT . SEP . 'sitemgr' . SEP . 'inc' . SEP . 'class.module.inc.php');
 
@@ -35,6 +35,41 @@ require_once(EGW_INCLUDE_ROOT . SEP . 'sitemgr' . SEP . 'inc' . SEP . 'class.mod
 			$this->modules = array();
 			$this->addcontent = $GLOBALS['egw']->session->appsession('addcontent','sitemgr');
 			$GLOBALS['egw']->session->appsession('addcontent','sitemgr',false);
+
+			switch ($GLOBALS['sitemgr_info']['mode'])
+			{
+			case 'Draft':
+				$transformerfile = $this->root . SEP . 'draft_transform.inc.php';
+				if (!file_exists($transformerfile))
+				{
+					$transformerfile = $this->root . '/../default/draft_transform.inc.php';
+				}
+				if (file_exists($transformerfile))
+				{
+					include_once($transformerfile);
+					if (class_exists('draft_transform'))
+					{
+						$this->draft_transformer =& new draft_transform();
+					}
+				}
+				break;
+
+			case 'Edit':
+				$transformerfile = $this->root . SEP . 'edit_transform.inc.php';
+				if (!file_exists($transformerfile))
+				{
+					$transformerfile = $this->root . '/../default/edit_transform.inc.php';
+				}
+				if (file_exists($transformerfile))
+				{
+					include_once($transformerfile);
+					if (class_exists('edit_transform'))
+					{
+						$this->edit_transformer =& new edit_transform();
+					}
+				}
+				break;
+			}
 		}
 
 		/* public: setroot(pathname $root)
@@ -98,38 +133,6 @@ require_once(EGW_INCLUDE_ROOT . SEP . 'sitemgr' . SEP . 'inc' . SEP . 'class.mod
 
 		function parse()
 		{
-			if ($GLOBALS['sitemgr_info']['mode'] == 'Draft')
-			{
-				$transformerfile = $this->root . SEP . 'draft_transform.inc.php';
-				if (!file_exists($transformerfile))
-				{
-					$transformerfile = $this->root . '/../default/draft_transform.inc.php';
-				}
-				if (file_exists($transformerfile))
-				{
-					include_once($transformerfile);
-					if (class_exists('draft_transform'))
-					{
-						$this->draft_transformer =& new draft_transform();
-					}
-				}
-			}
-			elseif ($GLOBALS['sitemgr_info']['mode'] == 'Edit')
-			{
-				$transformerfile = $this->root . SEP . 'edit_transform.inc.php';
-				if (!file_exists($transformerfile))
-				{
-					$transformerfile = $this->root . '/../default/edit_transform.inc.php';
-				}
-				if (file_exists($transformerfile))
-				{
-					include_once($transformerfile);
-					if (class_exists('edit_transform'))
-					{
-						$this->edit_transformer =& new edit_transform();
-					}
-				}
-			}
 			//get block content for contentareas
 			$str = preg_replace_callback(
 				"/\{contentarea:([^{ ]+)\}/",
@@ -157,19 +160,42 @@ require_once(EGW_INCLUDE_ROOT . SEP . 'sitemgr' . SEP . 'inc' . SEP . 'class.mod
 				$str);
 		}
 
+		function count_blocks($vars) {
+			global $page;
+			global $objbo;
+			static $cache;
+			
+			$areaname = is_array($vars) ? $vars[1] : $vars;
+			if (is_array($cache) && isset($cache[$areaname]))
+			{
+				$blocks =& $cache[$areaname];
+			}
+			else 
+			{
+				$blocks =& $this->bo->getvisibleblockdefsforarea($areaname,$page->cat_id,$page->id,$objbo->is_admin(),$objbo->isuser);
+			}
+			$n_blks = count($blocks);
+			return $GLOBALS['sitemgr_info']['mode'] == 'Edit' ? ( ($n_blks) < 1 ? 1 : $n_blks ) : $n_blks;
+		}
+		
 		/**
 		* processes all blocks for a given contentarea
 		*
 		* @param $vars string contenarea name
+		* @param $_mos_style
 		* @return string html content
 		**/
 		function process_blocks($vars)
 		{
 			global $page;
 			global $objbo;
+			static $cache;
 
 			$areaname = is_array($vars) ? $vars[1] : $vars;
-
+			if (is_array($cache) && isset($cache[$areaname]))
+			{
+				return $cache[$areaname];
+			}
 			$this->permitted_modules = array_keys($this->modulebo->getcascadingmodulepermissions($areaname,$page->cat_id));
 
 			$transformername = $areaname . '_bt';
@@ -275,9 +301,9 @@ require_once(EGW_INCLUDE_ROOT . SEP . 'sitemgr' . SEP . 'inc' . SEP . 'class.mod
 				is_object($this->edit_transformer) &&
 				method_exists($this->edit_transformer,'area_transform'))
 			{
-				return $this->edit_transformer->area_transform($areaname,$content,$page);
+				return $cache[$areaname] = $this->edit_transformer->area_transform($areaname,$content,$page);
 			}
-			return $content;
+			return $cache[$areaname] = $content;
 		}
 
 		function exec_module($vars)
