@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.sitebo.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: class.sitebo.inc.php 22781 2006-11-01 17:54:05Z nelius_weiss $ */
 
 	class sitebo
 	{
@@ -94,6 +94,28 @@
 			$page->cat_id = CURRENT_SITE_ID;
 			return true;
 		}
+		
+		function loadSearchResult($search_result,$lang,$mode,$options)
+		{
+			global $page;
+			$page->title = lang('search');
+			$page->subtitle = '';
+			$page->index = True;
+			$page->block =& CreateObject('sitemgr.Block_SO',True);
+			$page->block->module_name = 'search';
+			$page->block->arguments = array(
+					'search_result'=> $search_result, 
+					'show_results' => true, 
+					'lang'         => $lang, 
+					'mode'         => $mode,
+					'options'      => $options,
+					);
+			$page->block->module_id = $GLOBALS['Common_BO']->modules->getmoduleid('search');
+			$page->block->view = SITEMGR_VIEWABLE_EVERBODY;
+			$page->block->status = SITEMGR_STATE_PUBLISH;
+			$page->cat_id = CURRENT_SITE_ID;
+			return true;
+		}
 
 		function getIndex($showhidden=true,$rootonly=false,$subtitles=False)
 		{
@@ -367,4 +389,4 @@
 		return '';
 	}
 }
-?>
+?>
\ No newline at end of file
