@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.ui.inc.php 20295 2006-02-15 12:31:25Z  $ */
+	/* $Id: class.ui.inc.php 22781 2006-11-01 17:54:05Z nelius_weiss $ */
 
 	class ui
 	{
@@ -52,6 +52,13 @@
 			$this->generatePage();
 		}
 
+		function displaySearch($search_result,$lang,$mode,$options)
+		{
+			global $objbo;
+			$objbo->loadSearchResult($search_result,$lang,$mode,$options);
+			$this->generatePage();
+		}
+
 		function generatePage()
 		{
 			// add a content-type header to overwrite an existing default charset in apache (AddDefaultCharset directiv)
