@@ -1,16 +1,14 @@
 <?php
-/**************************************************************************\
-* eGroupWare - TimeSheet: business object                                  *
-* http://www.eGroupWare.org                                                *
-* Written and (c) 2005 by Ralf Becker <RalfBecker@outdoor-training.de>     *
-* -------------------------------------------------------                  *
-*  This program is free software; you can redistribute it and/or modify it *
-*  under the terms of the GNU General Public License as published by the   *
-*  Free Software Foundation; either version 2 of the License, or (at your  *
-*  option) any later version.                                              *
-\**************************************************************************/
-
-/* $Id: class.botimesheet.inc.php 22352 2006-08-26 10:02:47Z ralfbecker $ */
+/**
+ * TimeSheet - business object
+ *
+ * @link http://www.egroupware.org
+ * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @package timesheet
+ * @copyright (c) 2005/6 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+ * @version $Id: class.botimesheet.inc.php 24276 2007-07-10 07:35:18Z ralfbecker $ 
+ */
 
 require_once(EGW_INCLUDE_ROOT.'/etemplate/inc/class.so_sql.inc.php');
 
@@ -23,39 +21,60 @@ if (!defined('TIMESHEET_APP'))
  * Business object of the TimeSheet
  *
  * Uses eTemplate's so_sql as storage object (Table: egw_timesheet).
- *
- * @package timesheet
- * @author RalfBecker-AT-outdoor-training.de
- * @copyright (c) 2005 by RalfBecker-AT-outdoor-training.de
- * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  */
 class botimesheet extends so_sql
 {
 	/**
-	 * @var array $config timesheets config data
+	 * Timesheets config data
+	 * 
+	 * @var array
 	 */
 	var $config = array();
+
+
 	/**
-	 * @var array $timestamps timestaps that need to be adjusted to user-time on reading or saving
+	 * Timesheets config data
+	 *
+	 * @var array
+	 */
+	var $config_data = array();
+	/**
+	 * Should we show a quantity sum, makes only sense if we sum up identical units (can be used to sum up negative (over-)time)
+	 *
+	 * @var boolean
+	 */
+	var $quantity_sum=false;
+	/**
+	 * Timestaps that need to be adjusted to user-time on reading or saving
+	 * 
+	 * @var array
 	 */
 	var $timestamps = array(
 		'ts_start','ts_modified'
 	);
 	/**
-	 * @var int $tz_offset_s offset in secconds between user and server-time,
-	 *	it need to be add to a server-time to get the user-time or substracted from a user-time to get the server-time
+	 * Offset in secconds between user and server-time,	it need to be add to a server-time to get the user-time 
+	 * or substracted from a user-time to get the server-time
+	 * 
+	 * @var int
 	 */
 	var $tz_offset_s;
 	/**
-	 * @var int $now actual user-time as timestamp
+	 * Current time as timestamp in user-time
+	 * 
+	 * @var int
 	 */
 	var $now;
 	/**
-	 * @var int $today start of today in user-time
+	 * Start of today in user-time
+	 * 
+	 * @var int
 	 */
 	var $today;
 	/**
-	 * @var array $date_filters filter for search limiting the date-range
+	 * Filter for search limiting the date-range
+	 * 
+	 * @var array
 	 */
 	var $date_filters = array(	// Start: year,month,day,week, End: year,month,day,week
 		'Today'       => array(0,0,0,0,  0,0,1,0),
@@ -71,30 +90,45 @@ class botimesheet extends so_sql
 		'3 years ago' => array(-3,0,0,0, -2,0,0,0),
 	);
 	/**
-	 * @var object $link reference to the (bo)link class instanciated at $GLOBALS['egw']->link
+	 * Reference to the (bo)link class instanciated at $GLOBALS['egw']->link
+	 * 
+	 * @var bolink
 	 */
 	var $link;
 	/**
-	 * @var array $grants
+	 * Grants: $GLOBALS['egw']->acl->get_grants(TIMESHEET_APP);
+	 * 
+	 * @var array
 	 */	
 	var $grants;
 	/**
-	 * @var array $summary array sums of the last search in keys duration and price
+	 * Sums of the last search in keys duration and price
+	 * 
+	 * @var array
 	 */
 	var $summary;
 	/**
-	 * @var array $show_sums array with boolean values in keys 'day', 'week' or 'month', for the sums to return in the search
+	 * Array with boolean values in keys 'day', 'week' or 'month', for the sums to return in the search
+	 * 
+	 * @var array
 	 */
 	var $show_sums;
 
+	var $customfields=array();
+	
 	function botimesheet()
 	{
 		$this->so_sql(TIMESHEET_APP,'egw_timesheet');
 
-		$config =& CreateObject('phpgwapi.config',TIMESHEET_APP);
-		$config->read_repository();
-		$this->config =& $config->config_data;
-		unset($config);
+		$this->config =& CreateObject('phpgwapi.config',TIMESHEET_APP);
+		$this->config->read_repository();
+		$this->config_data =& $this->config->config_data;
+		$this->quantity_sum = $this->config_data['quantity_sum'] == 'true';
+
+		if (isset($this->config_data['customfields']) && is_array($this->config_data['customfields']))
+		{
+			$this->customfields = $this->config_data['customfields'];
+		}
 
 		if (!is_object($GLOBALS['egw']->datetime))
 		{
@@ -147,7 +181,7 @@ class botimesheet extends so_sql
 	 *
 	 * @param int $required EGW_ACL_READ, EGW_ACL_WRITE, EGW_ACL_ADD, EGW_ACL_DELETE, EGW_ACL_BUDGET, EGW_ACL_EDIT_BUDGET
 	 * @param array/int $data=null project or project-id to use, default the project in $this->data
-	 * @return boolean true if the rights are ok, false if not
+	 * @return boolean true if the rights are ok, null if not found, false if no rights
 	 */
 	function check_acl($required,$data=null)
 	{
@@ -160,6 +194,8 @@ class botimesheet extends so_sql
 			$save_data = $this->data;
 			$data = $this->read($data,true);
 			$this->data = $save_data;
+			
+			if (!$data) return null; 	// entry not found
 		}
 		$rights = $this->grants[$data['ts_owner']];
 		
@@ -287,13 +323,14 @@ class botimesheet extends so_sql
 			$this->summary = array();
 			return array();
 		}
-		$this->summary = parent::search($criteria,"SUM(ts_duration) AS duration,SUM($total_sql) AS price",
+		$this->summary = parent::search($criteria,"SUM(ts_duration) AS duration,SUM($total_sql) AS price".
+			($this->quantity_sum ? ",SUM(ts_quantity) AS quantity" : ''),
 			'','',$wildcard,$empty,$op,false,$filter,$join);
 		$this->summary = $this->summary[0];
 		
 		if ($only_summary) return $this->summary;
 
-		if ($this->show_sums && strstr($order_by,'ts_start') && 	// sums only make sense if ordered by ts_start
+		if ($this->show_sums && strpos($order_by,'ts_start') !== false && 	// sums only make sense if ordered by ts_start
 			$this->db->capabilities['union'] && ($from_unixtime_ts_start = $this->db->from_unixtime('ts_start')))
 		{
 			$sum_sql = array(
@@ -321,10 +358,12 @@ class botimesheet extends so_sql
 				$union_order[] = 'is_sum_'.$type;
 				$sum_extra_cols[$type]{0} = '1';
 				// the $type sum
-				parent::search($criteria,$sum_ts_id[$type].",'','','',MIN(ts_start),SUM(ts_duration) AS ts_duration,0,0,0,0,0,0,0,SUM($total_sql) AS ts_total",
+				parent::search($criteria,$sum_ts_id[$type].",'','','',MIN(ts_start),SUM(ts_duration) AS ts_duration,".
+					($this->quantity_sum ? "SUM(ts_quantity) AS ts_quantity" : '0').",0,NULL,0,0,0,0,SUM($total_sql) AS ts_total",
 					'GROUP BY '.$sum_sql[$type],$sum_extra_cols,$wildcard,$empty,$op,'UNION',$filter,$join,$need_full_no_count);
 				$sum_extra_cols[$type]{0} = '0';
 			}
+			$union_order[] = 'ts_start '.$sort;
 			return parent::search('','',implode(',',$union_order),'','',false,'',$start);
 		}
 		return parent::search($criteria,$only_keys,$order_by,$extra_cols,$wildcard,$empty,$op,$start,$filter,$join,$need_full_no_count);
@@ -335,17 +374,43 @@ class botimesheet extends so_sql
 	 *
 	 * @param int $ts_id
 	 * @param boolean $ignore_acl=false should the acl be checked
-	 * @return array/boolean array with timesheet entry or false if no rights
+	 * @return array/boolean array with timesheet entry, null if timesheet not found or false if no rights
 	 */
 	function read($ts_id,$ignore_acl=false)
 	{
-		if (!(int)$ts_id || !$ignore_acl && !$this->check_acl(EGW_ACL_READ,$ts_id) ||
+		$ret = null;
+		if (!(int)$ts_id || !$ignore_acl && !($ret = $this->check_acl(EGW_ACL_READ,$ts_id)) ||
 			$this->data['ts_id'] != (int)$ts_id && !parent::read((int)$ts_id))
 		{
-			return false;	// no read rights, or entry not found
+			return $ret;	// no read rights, or entry not found
 		}
+
+		//assign custom fields
+		foreach($this->customfields as $name => $value) {
+			$row = $this->read_extra($name);
+			$this->data['#'.$name] = $row['ts_extra_value'];
+		}
+
 		return $this->data;
 	}
+
+	/**
+	 * reads a timesheet extra entry of the current timesheet dataset
+	 *
+	 * @param int $name => name of the current timesheet extra entry
+	 * @param int $value => value of the current timesheet extra entry
+	 * @return array of resultset
+	 */
+	function read_extra($name='',$value='')
+	{
+		strlen($value) > 0 ? $where = ' and ts_extra_value ='.$this->db->quote($value) : '';
+		strlen($name) > 0 ? $where .= ' and ts_extra_name ='.$this->db->quote($name) : '';
+
+		$this->db->select('egw_timesheet_extra', 'ts_extra_name, ts_extra_value',$query,__LINE__,__FILE__,False,'',False,0,'where ts_id='.$this->data['ts_id'].$where);
+		$row = $this->db->row(true);
+
+		return $row;
+	}
 	
 	/**
 	 * saves a timesheet entry
@@ -372,11 +437,50 @@ class botimesheet extends so_sql
 		}
 		if (!($err = parent::save()))
 		{
+			//saves data of custom fields in timesheet_extra
+			$this->save_extra();
+
 			// notify the link-class about the update, as other apps may be subscribt to it
 			$this->link->notify_update(TIMESHEET_APP,$this->data['ts_id'],$this->data);
 		}
 		return $err;
 	}
+
+	/**
+	 * saves a timesheet extra entry based one the "custom fields" settings
+	 *
+	 * @param boolean  $updateNames => if true "change timesheet extra name", otherwise update existing datasets or insert new ones
+	 * @param boolean  $oldname => original name of the timesheet extra entry
+	 * @param boolean  $name => new name of the timesheet extra entry
+	 * @return int true on success else false
+	 */
+	function save_extra($updateNames=False,$oldname='',$name='')
+	{
+		if($updateNames) {
+			$keys = array('ts_extra_name' => $oldname);
+			$fieldAssign = array('ts_extra_name' => $name);
+			$this->db->update('egw_timesheet_extra',$fieldAssign,$keys,__LINE__,__FILE__);
+			return true;
+		}
+		else {
+			foreach($this->customfields as $namecf => $valuecf) {
+				//if entry not exist => insert
+				if(!$this->read_extra($namecf)) {
+					$fieldAssign = array('ts_id' => $this->data['ts_id'],'ts_extra_name' => $namecf,'ts_extra_value' => $this->data['#'.$namecf]);
+					$this->db->insert('egw_timesheet_extra',$fieldAssign,false,__LINE__,__FILE__);
+				}
+				//otherwise update existing dataset
+				else {
+					$keys = array('ts_extra_name' => $namecf, 'ts_id' => $this->data['ts_id']);
+					$fieldAssign = array('ts_extra_value' => $this->data['#'.$namecf]);
+					$this->db->update('egw_timesheet_extra',$fieldAssign,$keys,__LINE__,__FILE__);
+				}
+			}
+			return true;
+		}
+
+		return false;
+	}
 	
 	/**
 	 * deletes a timesheet entry identified by $keys or the loaded one, reimplemented to notify the link class (unlink)
@@ -399,12 +503,35 @@ class botimesheet extends so_sql
 		}
 		if (($ret = parent::delete($keys)) && $ts_id)
 		{
+			//delete custom fields entries
+			$this->delete_extra($ts_id);
+
 			// delete all links to timesheet entry $ts_id
 			$this->link->unlink(0,TIMESHEET_APP,$ts_id);
 		}
 		return $ret;
 	}
 
+
+	/**
+	 * deletes a timesheet extra entry identified by $ts_id and/or $ts_exra_name
+	 *
+	 * @param int $ts_id => number of timesheet
+	 * @param string ts_extra_name => certain custom field name
+	 * @return int false if an error
+	 */
+	function delete_extra($ts_id='',$ts_extra_name='')
+	{
+		strlen($ts_id) > 0 ? $where['ts_id'] = $ts_id : '';
+		strlen($ts_extra_name) > 0 ? $where['ts_extra_name'] = $ts_extra_name : '';
+
+		if(count($where) > 0) {
+			return $this->db->delete('egw_timesheet_extra', $where,__LINE__,__FILE__);
+		}
+
+		return false;
+	}
+
 	/**
 	 * changes the data from the db-format to your work-format
 	 *
@@ -466,7 +593,7 @@ class botimesheet extends so_sql
 	 * Is called as hook to participate in the linking
 	 *
 	 * @param int/array $entry int ts_id or array with timesheet entry
-	 * @param string the title
+	 * @return string/boolean string with title, null if timesheet not found, false if no perms to view it
 	 */
 	function link_title( $entry )
 	{
@@ -476,7 +603,7 @@ class botimesheet extends so_sql
 		}
 		if (!$entry)
 		{
-			return False;
+			return $entry;
 		}
 		$format = $GLOBALS['egw_info']['user']['preferences']['common']['dateformat'];
 		if (date('H:i',$entry['ts_start']) != '00:00')	// dont show 00:00 time, as it means date only
@@ -504,7 +631,7 @@ class botimesheet extends so_sql
 		$result = array();
 		foreach((array) $this->search($criteria,false,'','','%',false,'OR') as $ts )
 		{
-			$result[$ts['ts_id']] = $this->link_title($ts);
+			if ($ts) $result[$ts['ts_id']] = $this->link_title($ts);
 		}
 		return $result;
 	}
@@ -533,4 +660,87 @@ class botimesheet extends so_sql
 			'add_popup'  => '600x400',			
 		);
 	}
+	
+	/**
+	 * Return the timesheets linked with given project(s) AND with entries of other apps, which are also linked to the same project
+	 * 
+	 * Projectmanager will cumulate them in the other apps entries.
+	 *
+	 * @param array $param int/array $param['pm_id'] project-id(s)
+	 * @return array with pm_id, pe_id, pe_app('timesheet'), pe_app_id(ts_id), other_id, other_app, other_app_id
+	 */
+	function cumulate($param)
+	{
+		$links = $this->link->get_3links(TIMESHEET_APP,'projectmanager',$param['pm_id']);
+		
+		$rows = array();
+		foreach($links as $link)
+		{
+			$rows[$link['id']] = array(
+				'pm_id'       => $link['id2'],
+				'pe_id'       => $link['id'],
+				'pe_app'      => $link['app1'],
+				'pe_app_id'   => $link['id1'],
+				'other_id'    => $link['link3'],
+				'other_app'   => $link['app3'],
+				'other_app_id'=> $link['id3'],
+			);
+		}
+		return $rows;
+	}
+
+	/**
+	 * updates the project titles in the timesheet application (called whenever a project name is changed in the project manager)
+	 *
+	 * Todo: implement via notification
+	 *
+	 * @param string $oldtitle => the origin title of the project
+	 * @param string $newtitle => the new title of the project
+	 * @return boolean true for success, false for invalid parameters
+	 */
+	 function update_ts_project($oldtitle='', $newtitle='')
+	 {
+		if(strlen($oldtitle) > 0 && strlen($newtitle) > 0) {
+			$keys = array('ts_project' => $oldtitle);
+			$fieldAssign = array('ts_project' => $newtitle,'ts_title' => $newtitle);
+			$this->db->update('egw_timesheet',$fieldAssign,$keys,__LINE__,__FILE__);
+
+			return true;
+		}
+
+		return false;
+	 }
+
+	/**
+	 * returns array with relation link_id and ts_id (necessary for project-selection)
+	 *
+	 * @param int $pm_id ID of selected project
+	 * @return array containing link_id and ts_id
+	 */	
+	function get_ts_links($pm_id=0) {
+		$tslist = array();		
+		if(strlen($pm_id) > 0) {
+			if(isset($GLOBALS['egw_info']['user']['apps']['projectmanager'])) {	
+				$bo_pm = CreateObject('projectmanager.boprojectmanager');
+				$childs = $bo_pm->children($pm_id);
+				$childs[] = $pm_id;
+				$pmChilds = implode(",",$childs);
+				$this->db->select(	'egw_links','link_id, link_id1',$query,
+							__LINE__,__FILE__,False,
+							'',False,0,
+							'JOIN egw_pm_projects ON (pm_id = link_id2)
+							 WHERE 
+								link_app1 = \'timesheet\' AND
+								link_app2 = \'projectmanager\' AND
+								link_id2 IN ('.$pmChilds.')');
+					
+				while($row = $this->db->row(true)) {
+					$tslist[$row['link_id']] = $row['link_id1'];
+				}
+					
+			}
+
+		} 
+		return $tslist;
+	}
 }
\ No newline at end of file
