@@ -1,27 +1,20 @@
 <?php
-/**************************************************************************\
-* eGroupWare - TimeSheet: user interface                                   *
-* http://www.eGroupWare.org                                                *
-* Written and (c) 2005 by Ralf Becker <RalfBecker@outdoor-training.de>     *
-* -------------------------------------------------------                  *
-*  This program is free software; you can redistribute it and/or modify it *
-*  under the terms of the GNU General Public License as published by the   *
-*  Free Software Foundation; either version 2 of the License, or (at your  *
-*  option) any later version.                                              *
-\**************************************************************************/
-
-/* $Id: class.uitimesheet.inc.php 20961 2006-04-05 16:26:17Z ralfbecker $ */
+/**
+ * TimeSheet - user interface
+ *
+ * @link http://www.egroupware.org
+ * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @package timesheet
+ * @copyright (c) 2005/6 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
+ * @version $Id: class.uitimesheet.inc.php 24276 2007-07-10 07:35:18Z ralfbecker $ 
+ */
 
 require_once(EGW_INCLUDE_ROOT.'/etemplate/inc/class.uietemplate.inc.php');
 require_once('class.botimesheet.inc.php');
 
 /**
  * User interface object of the TimeSheet
- *
- * @package timesheet
- * @author RalfBecker-AT-outdoor-training.de
- * @copyright (c) 2005 by RalfBecker-AT-outdoor-training.de
- * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  */
 class uitimesheet extends botimesheet
 {
@@ -30,10 +23,32 @@ class uitimesheet extends botimesheet
 		'edit' => true,
 		'index' => true,
 	);
+	/**
+	 * ProjectManager integration: 'none', 'full' or default null
+	 *
+	 * @var string
+	 */
+	var $pm_integration;
 
+	/**
+	 * TimeSheet view type: 'short' or 'normal'
+	 *
+	 * @var string
+	 */	
+	var $ts_viewtype;
+	
 	function uitimesheet()
 	{
 		$this->botimesheet();
+		
+		$config =& CreateObject('phpgwapi.config',TIMESHEET_APP);
+		$config->read_repository();
+		$this->pm_integration = $config->config_data['pm_integration'];
+		$this->ts_viewtype = $config->config_data['ts_viewtype'];
+
+		// our javascript
+		// to be moved in a seperate file if rewrite is over
+		$GLOBALS['egw_info']['flags']['java_script'] .= $this->js();
 	}
 
 	function view()
@@ -43,7 +58,8 @@ class uitimesheet extends botimesheet
 	
 	function edit($content = null,$view = false)
 	{
-		$tabs = 'general|notes|links';
+		$tabs = 'general|notes|links|customfields';
+		$etpl =& new etemplate('timesheet.edit');
 
 		if (!is_array($content))
 		{
@@ -64,20 +80,37 @@ class uitimesheet extends botimesheet
 			{
 				$this->data = array(
 					'ts_start' => $this->today,
+					'end_time' => $this->now - $this->today,
 					'ts_owner' => $GLOBALS['egw_info']['user']['account_id'],
 					'cat_id'   => (int) $_REQUEST['cat_id'],
 				);
 			}
 			$referer = preg_match('/menuaction=([^&]+)/',$_SERVER['HTTP_REFERER'],$matches) ? $matches[1] : 
-				(strstr($_SERVER['HTTP_REFERER'],'/infolog/index.php') ? 'infolog.uiinfolog.index' : TIMESHEET_APP.'.uitimesheet.index');
+				(strpos($_SERVER['HTTP_REFERER'],'/infolog/index.php') !== false ? 'infolog.uiinfolog.index' : TIMESHEET_APP.'.uitimesheet.index');
 		}
 		else
 		{
+			//echo "<p>ts_start=$content[ts_start], start_time=$content[start_time], end_time=$content[end_time], ts_duration=$content[ts_duration], ts_quantity=$content[ts_quantity]</p>\n";
+			// we only need 2 out of 3 values from start-, end-time or duration (the date in ts_start is always required!)
+			if ($content['start_time'])		// start-time specified
+			{
+				$content['ts_start'] += $content['start_time'];
+			}
+			if ($content['end_time'] && $content['start_time'])	// start- & end-time --> calculate the duration
+			{
+				$content['ts_duration'] = ($content['end_time'] - $content['start_time']) / 60;
+			}
+			elseif ($content['ts_duration'] && $content['end_time'])	// no start, calculate from end and duration
+			{
+				$content['ts_start'] += $content['end_time'] - 60*$content['ts_duration'];
+			}
+			if ($content['ts_duration'] > 0) unset($content['end_time']);
+			// now we only deal with start (date+time) and duration
 			list($button) = @each($content['button']);
 			$view = $content['view'];
 			$referer = $content['referer'];
 			$this->data = $content;
-			foreach(array('button','view','referer',$tabs) as $key)
+			foreach(array('button','view','referer',$tabs,'start_time') as $key)
 			{
 				unset($this->data[$key]);
 			}
@@ -90,12 +123,36 @@ class uitimesheet extends botimesheet
 				case 'save':
 				case 'save_new':
 				case 'apply':
-					if (!$this->data['ts_quantity'])	// set the quantity (in h) from the duration (in min)
+					if (!$this->data['ts_quantity'] && $this->data['ts_duration'])	// set the quantity (in h) from the duration (in min)
 					{
 						$this->data['ts_quantity'] = $this->data['ts_duration'] / 60.0;
 					}
+					if (!$this->data['ts_quantity'])
+					{
+						$etpl->set_validation_error('ts_quantity',lang('Field must not be empty !!!'));
+					}
+					if ($this->data['ts_duration'] < 0)	// for layout purpose we show the error behind the quantity field
+					{
+						$etpl->set_validation_error('ts_quantity',lang('Starttime has to be before endtime !!!'));
+					}
+					//echo "<p>ts_start=$content[ts_start], start_time=$content[start_time], end_time=$content[end_time], ts_duration=$content[ts_duration], ts_quantity=$content[ts_quantity]</p>\n";
 					if (!$this->data['ts_project']) $this->data['ts_project'] = $this->data['ts_project_blur'];
-					if (!$this->data['ts_title']) $this->data['ts_title'] = $this->data['ts_title_blur'];
+					// set ts_title to ts_project if short viewtype (title is not editable) 
+					if($this->ts_viewtype == 'short') 
+					{
+						$this->data['ts_title'] = $this->data['ts_project'];							
+					}
+					if (!$this->data['ts_title'])
+					{
+						$this->data['ts_title'] = $this->data['ts_title_blur'] ? 
+							$this->data['ts_title_blur'] : $this->data['ts_project_blur'];
+
+						if (!$this->data['ts_title'])
+						{
+							$etpl->set_validation_error('ts_title',lang('Field must not be empty !!!'));
+						}
+					}
+					if ($etpl->validation_errors()) break;	// the user need to fix the error, before we can save the entry
 
 					if ($this->save() != 0)
 					{
@@ -130,12 +187,24 @@ class uitimesheet extends botimesheet
 					if ($button == 'apply') break;
 					if ($button == 'save_new')
 					{
+						$msg .= ', '.lang('creating new entry');		// giving some feedback to the user
+
+						if (!is_array($content['link_to']['to_id']))	// set links again, so new entry gets the same links as the existing one
+						{
+							$content['link_to']['to_id'] = 0;
+							foreach($this->link->get_links(TIMESHEET_APP,$this->data['ts_id'],'!'.$this->link->vfs_appname) as $link)
+							{
+								$this->link->link(TIMESHEET_APP,$content['link_to']['to_id'],$link['app'],$link['id'],$link['remark']);
+							}
+						}
 						// create a new entry
 						$this->data['ts_start'] += 60 * $this->data['ts_duration'];
 						foreach(array('ts_id','ts_title','ts_description','ts_duration','ts_quantity','ts_modified','ts_modifier') as $name)
 						{
 							unset($this->data[$name]);
 						}
+						// save the selected project, to delete the project-link, if the user changes the project
+						$this->data['old_pm_id'] = $this->data['pm_id'];
 						break;
 					}
 					// fall-through for save
@@ -171,11 +240,13 @@ class uitimesheet extends botimesheet
 			'view' => $view,
 			$tabs  => $content[$tabs],
 			'link_to' => array(
-				'to_id' => $this->data['ts_id'] || $button == 'save_new' ? $this->data['ts_id'] : $content['link_to']['to_id'],
+				'to_id' => $this->data['ts_id'] ? $this->data['ts_id'] : $content['link_to']['to_id'],
 				'to_app' => TIMESHEET_APP,
 			),
 			'js' => "<script>\n$js\n</script>\n",
 			'ts_quantity_blur' => $this->data['ts_duration'] ? round($this->data['ts_duration'] / 60.0,3) : '',
+			'start_time' => $this->datetime2time($this->data['ts_start']),
+			'pm_integration' => $this->pm_integration,
 		));
 		$links = array();
 		// create links specified in the REQUEST (URL)
@@ -194,6 +265,7 @@ class uitimesheet extends botimesheet
 							$links[] = $link_id;
 							break;
 						case 'infolog':
+							// a preserved title blur is only set for other (non-project) links, it stays with Save&New!
 							$preserv['ts_title_blur'] = $this->link->title('infolog',$link_id);
 							break;
 					}
@@ -204,14 +276,29 @@ class uitimesheet extends botimesheet
 		{
 			$links = $this->link->get_links(TIMESHEET_APP,$this->data['ts_id'],'projectmanager');
 		}
-		$preserv['old_pm_id'] = array_shift($links);
-		if (!isset($this->data['pm_id']) && $preserv['old_pm_id']) $content['pm_id'] = $preserv['old_pm_id'];
-
+		// make all linked projects availible for the pm-pricelist widget, to be able to choose prices from all
+		$content['all_pm_ids'] = array_values($links);
+        
+		// set old id, pm selector (for later removal)
+		if (count($links) > 0) 
+		{  
+			$preserv['old_pm_id'] = array_shift($links);
+		}
+		if (!isset($this->data['pm_id']) && $preserv['old_pm_id']) 
+		{
+			$content['pm_id'] = $preserv['old_pm_id'];
+		}
 		if ($content['pm_id'])
 		{
 			$preserv['ts_project_blur'] = $content['ts_project_blur'] = $this->link->title('projectmanager',$content['pm_id']);
 		}
-		$content['ts_title_blur'] = $preserv['ts_title_blur'] = $preserv['ts_title_blur'] ? $preserv['ts_title_blur'] : $preserv['ts_project_blur'];
+		if ($this->pm_integration == 'full')
+		{
+			$preserv['ts_project'] = $preserv['ts_project_blur'];
+		}
+		// the actual title-blur is either the preserved title blur (if we are called from infolog entry),
+		// or the preserved project-blur comming from the current selected project
+		$content['ts_title_blur'] = $preserv['ts_title_blur'] ? $preserv['ts_title_blur'] : $preserv['ts_project_blur'];
 
 		$readonlys = array(
 			'button[delete]'   => !$this->data['ts_id'] || !$this->check_acl(EGW_ACL_DELETE),
@@ -226,6 +313,7 @@ class uitimesheet extends botimesheet
 			{
 				$readonlys[$key] = true;
 			}
+			$readonlys['start_time'] = $readonlys['end_time'] = true;
 		}
 		$edit_grants = $this->grant_list(EGW_ACL_EDIT);
 		if (count($edit_grants) == 1)
@@ -235,17 +323,36 @@ class uitimesheet extends botimesheet
 		$GLOBALS['egw_info']['flags']['app_header'] = lang('timesheet').' - '.
 			($view ? lang('View') : ($this->data['ts_id'] ? lang('Edit') : lang('Add')));
 		
-		$etpl =& new etemplate('timesheet.edit');
 		// supress unknow widget 'projectmanager-*', if projectmanager is not installed or old
 		if (!@file_exists(EGW_INCLUDE_ROOT.'/projectmanager/inc/class.projectmanager_widget.inc.php'))
 		{
 			$etpl->set_cell_attribute('pm_id','disabled',true);
 			$etpl->set_cell_attribute('pl_id','disabled',true);
 		}		
+
+		if($this->ts_viewtype == 'short') 
+		{
+			$content['ts_viewtype'] = $readonlys[$tabs]['notes'] = true;
+		}
+		if (!$this->customfields) $readonlys[$tabs]['customfields'] = true;	// suppress tab if there are not customfields
+						
 		return $etpl->exec(TIMESHEET_APP.'.uitimesheet.edit',$content,array(
 			'ts_owner' => $edit_grants,
 		),$readonlys,$preserv,2);
 	}
+	
+	/**
+	 * Calculate the time from a timestamp containing date & time
+	 *
+	 * @param int $datetime
+	 * @return int
+	 */
+	function datetime2time($datetime)
+	{
+		if (!$datetime) return 0;
+
+		return $datetime - mktime(0,0,0,date('m',$datetime),date('d',$datetime),date('Y',$datetime));
+	}
 
 	/**
 	 * query projects for nextmatch in the projects-list
@@ -255,8 +362,10 @@ class uitimesheet extends botimesheet
 	 * @param array &$query
 	 * @param array &$rows returned rows/cups
 	 * @param array &$readonlys eg. to disable buttons based on acl
+	 * @param boolean $id_only=false if true only return (via $rows) an array of contact-ids, dont save state to session
+	 * @return int total number of contacts matching the selection
 	 */
-	function get_rows(&$query_in,&$rows,&$readonlys)
+	function get_rows(&$query_in,&$rows,&$readonlys,$id_only=false)
 	{
 		$this->show_sums = false;
 		if ($query_in['filter'])
@@ -301,13 +410,25 @@ class uitimesheet extends botimesheet
 		//echo "<p align=right>show_sums=".print_r($this->show_sums,true)."</p>\n";
 		$GLOBALS['egw']->session->appsession('index',TIMESHEET_APP,$query_in);
 		$query = $query_in;	// keep the original query
+
+		// PM project filter for the PM integration
+		if ((string)$query['col_filter']['pm_id'] != '')
+		{
+			//$query['col_filter']['ts_id'] = $this->link->get_links('projectmanager',$query['col_filter']['pm_id'],'timesheet');
+			$query['col_filter']['ts_id'] = $this->get_ts_links($query['col_filter']['pm_id']);
+			if (!$query['col_filter']['ts_id']) $query['col_filter']['ts_id'] = 0;
+		}
+		unset($query['col_filter']['pm_id']);
 		
+		// filter for no project
+		if ((string)$query['col_filter']['ts_project'] == '0') $query['col_filter']['ts_project'] = null;
+
 		if ((int)$query['filter2'] != (int)$GLOBALS['egw_info']['user']['preferences'][TIMESHEET_APP]['show_details'])
 		{
 			$GLOBALS['egw']->preferences->add(TIMESHEET_APP,'show_details',(int)$query['filter2']);
 			$GLOBALS['egw']->preferences->save_repository(true);
 		}
-		unset($query['col_filter']['cat_id']);
+		// category filter: cat_id or ''=All cats or 0=No cat
 		if ($query['cat_id'])
 		{
 			if (!is_object($GLOBALS['egw']->categories))
@@ -317,6 +438,14 @@ class uitimesheet extends botimesheet
 			$cats = $GLOBALS['egw']->categories->return_all_children((int)$query['cat_id']);
 			$query['col_filter']['cat_id'] = count($cats) > 1 ? $cats : $query['cat_id'];
 		}
+		elseif ((string)$query['cat_id'] == '0')	// no category
+		{
+			$query['col_filter']['cat_id'] = null;
+		}
+		else	// all cats --> no filter
+		{
+			unset($query['col_filter']['cat_id']);
+		}
 		$GLOBALS['egw_info']['flags']['app_header'] = lang('timesheet');
 		if ($query['col_filter']['ts_owner'])
 		{
@@ -374,13 +503,25 @@ class uitimesheet extends botimesheet
 		}
 		$total = parent::get_rows($query,$rows,$readonlys);
 		
+		if ($id_only)
+		{
+			foreach($rows as $n => $row)
+			{
+				$rows[$n] = $row['ts_id'];
+			}
+			return $this->total;	// no need to set other fields or $readonlys
+		}
+
 		unset($query['col_filter'][0]);
 		
 		$readonlys = array();
+		$have_cats = false;
 		foreach($rows as $n => $val)
 		{
 			$row =& $rows[$n];
 			
+			if ($row['cat_id']) $have_cats = true;
+
 			$row['class'] = 'row';
 			if ($row['ts_id'] <= 0)	// sums
 			{
@@ -402,7 +543,8 @@ class uitimesheet extends botimesheet
 						$row['ts_title'] = lang('Sum %1:',$row['ts_year']);
 						break;
 				}	
-				$row['ts_start'] = $row['ts_quantity'] = $row['ts_unitprice'] = '';
+				$row['ts_start'] = $row['ts_unitprice'] = '';
+				if (!$this->quantity_sum) $row['ts_quantity'] = '';
 				$row['class'] = 'th';
 				$row['titleClass'] = 'titleSum';
 				continue;
@@ -439,13 +581,19 @@ class uitimesheet extends botimesheet
 				$row['titleClass'] = 'titleDetails';
 			}
 		}
+		if (!$have_cats || $query['cat_id']) $rows['no_cat_id'] = true;
 		if ($query['col_filter']['ts_owner']) $rows['ownerClass'] = 'noPrint';
 		$rows['no_owner_col'] = $query['no_owner_col'];
 		if ($query['filter'])
 		{
-			$rows['duration'] = $this->summary['duration'];
-			$rows['price'] = $this->summary['price'];
+			$rows += $this->summary;
 		}
+		$rows['pm_integration'] = $this->pm_integration;
+
+		if($this->ts_viewtype == 'short') {
+			$rows['ts_viewtype'] = true;
+		}
+		
 		return $total;		
 	}
 
@@ -453,6 +601,7 @@ class uitimesheet extends botimesheet
 	 * List timesheet entries
 	 *
 	 * @param array $content=null
+	 * @param string $msg=''
 	 */
 	function index($content = null,$msg='')
 	{
@@ -491,17 +640,46 @@ class uitimesheet extends botimesheet
 				'options-filter2' => array('No details','Details'),
 				'order'          =>	'ts_start',// IO name of the column to sort after (optional for the sortheaders)
 				'sort'           =>	'DESC',// IO direction of the sort: 'ASC' or 'DESC'
-				'header_right'   => 'timesheet.index.dates',
+				'header_left'    => 'timesheet.index.dates',
+				'header_right'   => 'timesheet.index.add',
 				'filter_onchange' => "set_style_by_class('*','custom_hide','visibility',this.value == 'custom' ? 'visible' : 'hidden'); if (this.value != 'custom') this.form.submit();",
 				'filter2'        => (int)$GLOBALS['egw_info']['user']['preferences'][TIMESHEET_APP]['show_details'],
 			);
 		}
 		$read_grants = $this->grant_list(EGW_ACL_READ);
 		$content['nm']['no_owner_col'] = count($read_grants) == 1;
-
-		return $etpl->exec(TIMESHEET_APP.'.uitimesheet.index',$content,array(
-			'ts_project' => $this->query_list('ts_project'),
+		
+		$sel_options = array(
 			'ts_owner'   => $read_grants,
-		),$readonlys,$preserv);
+			'pm_id'      => array(lang('No project')),
+			'cat_id'     => array(lang('None')),
+		);
+		if ($this->pm_integration != 'full')
+		{
+			$projects =& $this->query_list('ts_project');
+			if (!is_array($projects)) $projects = array();
+			$sel_options['ts_project'] = $projects + array(lang('No project'));
+		}
+		// dont show [Export] button if app is not availible to the user or we are on php4
+		$readonlys['export'] = !$GLOBALS['egw_info']['user']['apps']['importexport'] || (int) phpversion() < 5;
+
+		return $etpl->exec(TIMESHEET_APP.'.uitimesheet.index',$content,$sel_options,$readonlys,$preserv);
 	}
+
+
+
+	function js()
+	{
+		return '<script LANGUAGE="JavaScript">
+
+		function timesheet_export()
+		{
+			egw_openWindowCentered(
+				"'. $GLOBALS['egw']->link('/index.php','menuaction=importexport.uiexport.export_dialog&appname=timesheet&selection=use_all') . '",
+				"Export",400,400);
+			return false;
+		}
+		</script>';
+	}
+
 }
