@@ -11,7 +11,7 @@
 *  option) any later version.                                              *
 \**************************************************************************/
 
-/* $Id: class.bowiki.inc.php 22005 2006-07-05 18:00:22Z tt_oscar $ */
+/* $Id: class.bowiki.inc.php 24009 2007-06-04 06:43:09Z ralfbecker $ */
 
 // old global stuff, is still need for now, but hopefully will go away
 global $ParseEngine,$DiffEngine,$DisplayEngine,$ConvertEngine,$SaveMacroEngine,$ViewMacroEngine;
@@ -19,7 +19,7 @@ global $UpperPtn,$LowerPtn,$AlphaPtn,$LinkPtn,$UrlPtn,$InterwikiPtn,$MaxNesting,
 global $EditBase,$ViewBase,$HistoryBase;
 
 require_once(EGW_INCLUDE_ROOT.'/wiki/lib/defaults.php');
-if ($GLOBALS['egw']->translation->charset() == 'iso-8859-1')	// allow all iso-8859-1 extra-chars
+if (is_object($GLOBALS['egw']->translation) && $GLOBALS['egw']->translation->charset() == 'iso-8859-1')	// allow all iso-8859-1 extra-chars
 {
 	$UpperPtn = "[A-Z\xc0-\xde]";
 	$LowerPtn = "[a-z\xdf-\xff]";
@@ -47,7 +47,7 @@ require_once(EGW_INCLUDE_ROOT.'/wiki/inc/class.sowiki.inc.php');
 
 class bowiki extends sowiki
 {
-	var $upload_url,$upload_dir;
+	var $upload_dir;
 	var $config;
 
 	function bowiki($wiki_id=0)
@@ -69,12 +69,11 @@ class bowiki extends sowiki
 		if (!isset($this->config['wikihome'])) $this->config['wikihome'] = 'eGroupWare';
 		$HomePage = $this->config['wikihome'];
 		$InterWikiPrefix = isset($this->config['InterWikiPrefix'])   ? $this->config['InterWikiPrefix'] : 'EGroupWare';
-		$EnableFreeLinks = isset($this->config['Enable_Free_Links']) ? $this->config['Enable_Free_Links'] : 1;
-		$EnableWikiLinks = isset($this->config['Enable_Wiki_Links']) ? $this->config['Enable_Wiki_Links'] : 1;
+		$EnableFreeLinks = isset($this->config['Enable_Free_Links']) ? $this->config['Enable_Free_Links'] == 'True' : true;
+		$EnableWikiLinks = isset($this->config['Enable_Wiki_Links']) ? $this->config['Enable_Wiki_Links'] == 'True' : true;
 		
 		$this->ExpireLen = $this->config['ExpireLen'];
 		$this->upload_dir = $this->config['upload_dir'];
-		$this->upload_url = $this->config['upload_url'];
 
 		global $Charset,$UserName;
 		$Charset = $GLOBALS['egw']->translation->charset();
@@ -341,7 +340,7 @@ class bowiki extends sowiki
 	 * Is called as hook to participate in the linking
 	 *
 	 * @param string/object $page string with page-name or sowikipage object
-	 * @return string the title
+	 * @return string/boolean string with title, null if page not found or false if not view perms
 	 */
 	function link_title( $page )
 	{
@@ -350,7 +349,9 @@ class bowiki extends sowiki
 			$page =& $this->page( $page );
 			$page->read();
 		}
-		return $page->exists ? strip_tags($page->title) : false;
+		if (!$page->exists) return null;
+		
+		return $page->acl_check(true)  ? strip_tags($page->title) : false;
 	}
 
 	/**
