@@ -10,7 +10,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.xmlwiki.inc.php 19336 2005-10-10 14:20:26Z ralfbecker $ */
+	/* $Id: class.xmlwiki.inc.php 23741 2007-04-30 10:29:44Z lkneschke $ */
 
 	if (!function_exists('var2xml'))
 	{
@@ -123,7 +123,7 @@
 				// use our network class, as it deals with proxies and the proxy-config in admin->configuration
 				$network =& CreateObject('phpgwapi.network');
 				$xmldata = $network->gethttpsocketfile($url);
-				$xmldata = strstr(implode('',$xmldata),'<?xml');	// discard everything before the start of the xml-file
+				$xmldata = @strstr(implode('',$xmldata),'<?xml');	// discard everything before the start of the xml-file
 			}
 			else
 			{
