@@ -10,13 +10,13 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: hook_sidebox_menu.inc.php 19415 2005-10-14 14:08:53Z ralfbecker $ */
+	/* $Id: hook_sidebox_menu.inc.php 23595 2007-04-14 17:01:43Z ralfbecker $ */
 {
 
 	$menu_title = lang('Wiki Menu');
 	$file = Array(
 		'Recent Changes' => $GLOBALS['egw']->link('/wiki/index.php','page=RecentChanges'),
-		'Preferences' => $GLOBALS['egw']->link('/wiki/index.php','action=prefs')
+		'Preferences' => $GLOBALS['egw']->link('/index.php',array('menuaction'=>'preferences.uisettings.index','appname'=>'wiki')),
 	);
 	display_sidebox($appname,$menu_title,$file);
 
