@@ -1,5 +1,5 @@
 <?php
-// $Id: category.php 20295 2006-02-15 12:31:25Z  $
+// $Id: category.php 25210 2008-03-30 18:06:19Z ralfbecker $
 
 if (!function_exists('parseText'))
 {
@@ -15,7 +15,8 @@ function add_to_category($page, $catlist)
 	$pagenames = array();
 	preg_replace('/' . $FlgChr . '(\\d+)' . $FlgChr . '/e',
 							 '$pagenames[]=$Entity[\\1][1]', $parsed);
-
+	$page = get_name($page);
+	
 	if(validate_page($page) == 2)
 		{ $page = '((' . $page . '))'; }
 
@@ -45,7 +46,7 @@ function add_to_category($page, $catlist)
 		 
 			$pg->version++;
 			$pg->comment  = '';
-			$pg->hostname = gethostbyaddr($REMOTE_ADDR);
+			$pg->hostname = gethostbyaddr($_SERVER['REMOTE_ADDR']);
 			$pg->username = $UserName;
 
 			$pg->write();
