@@ -1,10 +1,10 @@
 <?php
-/* $Id: url.php 21452 2006-04-25 16:19:16Z ralfbecker $ */
+/* $Id: url.php 24329 2007-07-21 06:11:23Z ralfbecker $ */
 
 // Under phpgw these URL's are NOT configurable, you can set the phpgw install-path in setup
 
 $ScriptBase = $GLOBALS['egw']->link('/wiki/index.php');
-$ScriptBase .= strstr($ScriptBase,'?') ? '&' : '?';
+$ScriptBase .= strpos($ScriptBase,'?') !== false ? '&' : '?';
 
 $AdminScript = $ScriptBase . 'action=admin';
 
@@ -75,7 +75,7 @@ if(!function_exists('historyURL'))
 		{
 			$lang = '&lang=' . ($lang ? $lang : $page['lang']);
 		}
-		return $HistoryBase . urlencode(is_array($page) ? $page['name'] : $page) . $lang;
+		return $HistoryBase . urlencode(is_array($page) ? $page['name'] : $page) . $lang .
 				($full == '' ? '' : '&full=1');
 	}
 }
