@@ -1,5 +1,5 @@
 <?php
-// $Id: html.php 20988 2006-04-06 11:09:19Z ralfbecker $
+// $Id: html.php 23865 2007-05-14 20:43:23Z lkneschke $
 
 // These functions take wiki entities like 'bold_begin' or 'ref' and return
 //   HTML representing these entities.  They are used throught this script
@@ -176,7 +176,7 @@ function html_ref($page, $appearance, $hover = '', $anchor = '', $anchor_appeara
 {
 	global $SeparateLinkWords,$EditBase;
 
-	if (!is_array($page) && strstr($page,':'))
+	if (!is_array($page) && strpos($page,':') !== false)
 	{
 	list($name,$lang) = explode(':',$page);
 	if (strlen($lang) == 2 || strlen($lang) == 5 && $lang[2] == '-')
@@ -200,13 +200,15 @@ function html_ref($page, $appearance, $hover = '', $anchor = '', $anchor_appeara
 
 	if($p->exists())
 	{
+		//echo "<p>$page exists</p>\n";
 		if($SeparateLinkWords && $title == $appearance)
 			{ $appearance = html_split_name($title); }
 		return '<a href="' . viewURL($page) . $anchor . '"' . $hover . ' class="wiki">'
 					 . $appearance . $anchor_appearance . '</a>';
 	}
-	elseif(!$p->acl_check() || !$EditBase)
+	elseif(!$p->acl_check(true) || !$EditBase)
 	{
+		//echo "<p>$page NOT accessible</p>\n";
 		if(validate_page($title) == 1        // Normal WikiName
 			 && $appearance == $title)         // ... and is what it appears
 			{ return $title; }
@@ -215,6 +217,7 @@ function html_ref($page, $appearance, $hover = '', $anchor = '', $anchor_appeara
 	}
 	else
 	{
+		//echo "<p>$page does NOT exist</p>\n";
 		if(validate_page($title) == 1        // Normal WikiName
 			 && $appearance == $title)         // ... and is what it appears
 			{ return $title . '<a href="' . editURL($page) . '"' . $hover . '>?</a>'; }
