@@ -8,11 +8,11 @@
 	*  Free Software Foundation; either version 2 of the License, or (at your  *
 	*  option) any later version.                                              *
 	\**************************************************************************/
-	/* $Id: setup.inc.php 20988 2006-04-06 11:09:19Z ralfbecker $ */
+	/* $Id: setup.inc.php 23741 2007-04-30 10:29:44Z lkneschke $ */
 
 	$setup_info['wiki']['name']      = 'wiki';
 	$setup_info['wiki']['title']     = 'Wiki';
-	$setup_info['wiki']['version']   = '1.2';
+	$setup_info['wiki']['version']   = '1.4';
 	$setup_info['wiki']['app_order'] = 11;
 	$setup_info['wiki']['enable']    = 1;
 
@@ -34,18 +34,19 @@
 	$setup_info['wiki']['hooks'][] = 'admin';
 	$setup_info['wiki']['hooks'][] = 'sidebox_menu';
 	$setup_info['wiki']['hooks'][] = 'config_validate';
+	$setup_info['wiki']['hooks'][] = 'settings';
 	$setup_info['wiki']['hooks']['search_link'] = 'wiki.bowiki.search_link';
 
 	/* Dependencies for this app to work */
 	$setup_info['wiki']['depends'][] = array
 	(
 		'appname'  => 'phpgwapi',
-		'versions' => Array('1.0.0','1.0.1','1.2')
+		'versions' => Array('1.3','1.4','1.5')
 	);
 	$setup_info['wiki']['depends'][] = array
 	(
 		'appname'  => 'etemplate',
-		'versions' => Array('1.0.0','1.0.1','1.2')
+		'versions' => Array('1.3','1.4','1.5')
 	);
 
 
